OC.L10N.register(
    "notes",
    {
    "Notes" : "ئىزاھاتلار",
    "Create new note" : "يېڭى خاتىرە قۇر",
    "More notes" : "تېخىمۇ كۆپ خاتىرىلەر",
    "Reading notes from filesystem has failed." : "ھۆججەت سىستېمىسىدىكى خاتىرىلەرنى ئوقۇش مەغلۇب بولدى.",
    "Error" : "خاتالىق",
    "New note" : "يېڭى خاتىرە",
    "Distraction-free notes and writing" : "دىققىتى چېچىلىدىغان خاتىرە ۋە يېزىق",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notes ئەپ [Nextcloud](https://www.nextcloud.com/) ئۈچۈن دىققەتنى چېچىدىغان خاتىرە ئېلىش ئەپى بولۇپ، ئۇ تېخىمۇ ياخشى تەشكىللەش ئۈچۈن تۈرلەر بىلەن تەمىنلەيدۇ ھەمدە [Markdown](https://en.wikipedia.org/wiki/Markdown) سىنتاكسىسى ئارقىلىق فورماتلاشنى قوللايدۇ. خاتىرىلەر Nextcloud دا ھۆججەت سۈپىتىدە ساقلىنىدۇ، شۇڭا سىز ئۇلارنى ھەر بىر Nextcloud خېرىدارى بىلەن كۆرەلەيسىز ۋە تەھرىرلىيەلەيسىز. بۇنىڭدىن باشقا، ئايرىم [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) ئەپلەرگە ([Android](https://github.com/nextcloud/notes-android)، [iOS](https://github.com/nextcloud/notes-ios)، شۇنداقلا [3-تەرەپ ئەپلىرى](https://github.com/nextcloud/notes/wiki#3rd-party-clients) ئاسان بىرلەشتۈرۈشكە يول قويىدۇ، بۇ Nextcloud خاتىرىلىرىڭىزگە قولايلىق ئېرىشىشكە يول قويىدۇ). باشقا ئىقتىدارلار خاتىرىلەرنى ياقتۇرۇلغانلار قىلىپ بەلگىلەشنى ئۆز ئىچىگە ئالىدۇ.",
    "Deleted {title}" : "ئۆچۈرۈلگەن {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} خاتىرە ئۆچۈرۈلدى","{number} خاترە ئۆچۈرۈلدى"],
    "Undo Delete" : "ئەمەلدىن قالدۇرۇش",
    "Note recovered" : "ئەسكەرتىش ئەسلىگە كەلتۈرۈلدى",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} خاتىرە ئەسلىگە كەلدى","{number} خاتىرە ئەسلىگە كەلدى"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "ساقلانمىغان خاتىرىلەر بار. بەتتىن ئايرىلغاندا بارلىق ئۆزگىرىشلەر تاشلىنىدۇ!",
    "Notes settings" : "ئەسكەرتىش تەڭشىكى",
    "Please see Nextcloud server log for details." : "تەپسىلاتىنى Nextcloud مۇلازىمېتىر خاتىرىسىنى كۆرۈڭ.",
    "Custom" : "خاس",
    "Rich text" : "مول تېكىست",
    "Plain text" : "ئاددىي تېكىست",
    "Preview" : "ئالدىن كۆرۈش",
    "Make the selection bold" : "تاللاشنى دادىل قىلىڭ",
    "Make the selection italic" : "تاللاشنى يانتۇ قىلىڭ",
    "Wrap the selection in quotes" : "تاللاشنى نەقىلگە ئوراپ قويۇڭ",
    "The selection will be turned into monospace" : "تاللاش مونوپولغا ئايلىنىدۇ",
    "Remove any styles from the selected text" : "تاللانغان تېكىستتىكى ئۇسلۇبلارنى ئۆچۈرۈڭ",
    "Makes the current line a list element" : "نۆۋەتتىكى قۇرنى تىزىملىك ئېلېمېنتى قىلىدۇ",
    "Makes the current line a list element with a number" : "نۆۋەتتىكى قۇرنى سان بىلەن تىزىملىك ئېلېمېنتى قىلىدۇ",
    "Toggle heading for current line" : "نۆۋەتتىكى قۇرغا قاراپ ماڭىدۇ",
    "Set the current line as a big heading" : "نۆۋەتتىكى قۇرنى چوڭ ماۋزۇ قىلىپ تەڭشەڭ",
    "Insert link" : "ئۇلىنىش قىستۇر",
    "Insert image" : "رەسىم قىستۇرۇش",
    "Switch between editor and viewer" : "تەھرىرلىگۈچ بىلەن كۆرگۈچ ئارىسىدا ئالماشتۇرۇڭ",
    "Pick a notes folder" : "خاتىرە ھۆججەت قىسقۇچىنى تاللاڭ",
    "Set notes folder" : "خاتىرە ھۆججەت قىسقۇچىنى بەلگىلەڭ",
    "General" : "ئۇمۇمىي",
    "Display" : "كۆرسىتىش",
    "File extension" : "ھۆججەت كېڭەيتىلمىسى",
    "For new notes" : "يېڭى خاتىرە ئۈچۈن",
    "Custom file extension" : "خاس ھۆججەت كېڭەيتىلمىسى",
    "Files" : "ھۆججەتلەر",
    "Notes folder" : "خاتىرە قىسقۇچى",
    "Mobile apps" : "كۆچمە ئەپلەر",
    "Shortcuts" : "تېزلەتمە",
    "Delete" : "ئۆچۈر",
    "Cancel" : "ۋاز كەچ",
    "All notes" : "بارلىق خاتىرىلەر",
    "Categories" : "سەھىپىلەر",
    "Create a sample note with Markdown" : "Markdown بىلەن ئۈلگە خاتىرە قۇر",
    "No notes yet" : "تېخى خاتىرە يوق",
    "Select an image" : "رەسىمنى تاللاڭ",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "خاتىرە ھۆججەت قىسقۇچىڭىزنىڭ سىرتىدىكى رەسىملەرنى تاللىيالمايسىز. خاتىرە ھۆججەت قىسقۇچىڭىز: {folder} ",
    "Wrong image" : "خاتا رەسىم",
    "The file was not uploaded. Check your server logs." : "ھۆججەت يۈكلەنمىدى. مۇلازىمېتىر خاتىرىڭىزنى تەكشۈرۈڭ.",
    "Upload image" : "رەسىم يوللاش",
    "Android" : "ئاندىرويىد",
    "iPhone and iPad" : "ئايفون ھەمدە ئايپەد",
    "Rich text editor" : "مول تېكىست تەھرىرلىگۈچى",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "ھازىر ئىشلىتىشكە قۇلايلىق ۋە چېچىلىدىغان ھەقسىز مول تېكىست تەھرىرلىگۈچنى ئالماشتۇرالايسىز. ئۇ Markdown بەلگىسىنى كۆرمەي تۇرۇپ خاتىرىلەرنى تەھرىرلىيەلەيسىز.",
    "This option can also be changed later on in the Notes app settings." : "بۇ تاللانمىنى كېيىن «خاتىرە» ئەپ تەڭشىكىدە ئۆزگەرتكىلى بولىدۇ.",
    "Keep plain Markdown editor" : "Markdown تەھرىرلىگۈچىنى ساقلاڭ",
    "Use rich editor" : "مول تەھرىرلىگۈچ ئىشلىتىڭ",
    "Remove from favorites" : "ياقتۇردىغاندىن چىقىرۋەت",
    "Add to favorites" : "ياقتۇردىغانغا قوش",
    "Error while renaming note." : "ئىزاھاتنىڭ نامىنى ئۆزگەرتىشتە خاتالىق.",
    "Error during preparing note for deletion." : "ئۆچۈرۈش ئۈچۈن خاتىرە تەييارلاش جەريانىدا خاتالىق.",
    "Share" : "ھەمبەھىر",
    "Change category" : "سەھىپىنى ئۆزگەرتىش",
    "Rename" : "ئىسىم ئۆزگەرت",
    "Rename note" : "ئەسكەرتىش",
    "Delete note" : "ئۆچۈرۈش",
    "Error from Nextcloud server: {msg}" : "Nextcloud مۇلازىمېتىرىدىكى خاتالىق: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "خاتىرە باشقا بىر يىغىندا ئۆزگەرتىلدى. قايسى نەشرىنى ساقلاش كېرەكلىكىنى تاللاڭ.",
    "Use version from server" : "مۇلازىمېتىردىن نەشرىنى ئىشلىتىڭ",
    "Use current version" : "نۆۋەتتىكى نەشرىنى ئىشلىتىڭ",
    "Empty note" : "قۇرۇق خاتىرە",
    "Write …" : "يېزىش…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "تەھرىر",
    "Exit full screen" : "تولۇق ئېكراندىن چىقىڭ",
    "Full screen" : "تولۇق ئېكران",
    "Note is read-only. You cannot change it." : "ئەسكەرتىش پەقەت ئوقۇشقىلا بولىدۇ. ئۇنى ئۆزگەرتەلمەيسىز.",
    "Save failed. Click to retry." : "ساقلاش مەغلۇب بولدى. قايتا سىناڭ.",
    "Update conflict. Click for resolving manually." : "توقۇنۇشنى يېڭىلاش. قولدا ھەل قىلىش ئۈچۈن چېكىڭ.",
    "Today" : "بۈگۈن",
    "Yesterday" : "تۈنۈگۈن",
    "This week" : "بۇ ھەپتە",
    "Last week" : "ئالدىنقى ھەپتە",
    "This month" : "بۇ ئاي",
    "Last month" : "ئالدىنقى ئاي",
    "Search for notes" : "خاتىرە ئىزدەڭ",
    "Loading …" : "يۈكلەۋاتىدۇ…",
    "Find in all categories" : "بارلىق تۈرلەردىن ئىزدەڭ",
    "Write down your thoughts without any distractions." : "خىياللىرىڭىزنى قالايمىقانلاشتۇرماي يېزىڭ.",
    "Use Markdown markups to style your text." : "Markdown بەلگىسىنى ئىشلىتىپ تېكىستنى ئۇسلۇب قىلىڭ.",
    "Organize your notes in categories." : "خاتىرىلىرىڭىزنى تۈرلەرگە ئايرىڭ.",
    "Note not found." : "دىققەت تېپىلمىدى.",
    "Note is locked." : "ئەسكەرتىش قۇلۇپلاندى.",
    "Insufficient storage." : "ساقلاش يېتەرلىك ئەمەس.",
    "See JavaScript console and server log for details." : "تەپسىلاتىنى JavaScript كونترول سۇپىسى ۋە مۇلازىمېتىر خاتىرىسىدىن كۆرۈڭ.",
    "Updating settings has failed." : "تەڭشەكلەرنى يېڭىلاش مەغلۇب بولدى.",
    "Fetching notes for dashboard has failed." : "باشقۇرۇش تاختىسىنىڭ خاتىرىسىنى ئېلىش مەغلۇب بولدى.",
    "Fetching notes has failed." : "خاتىرە ئېلىش مەغلۇب بولدى.",
    "Fetching note {id} has failed." : "ئەسكەرتىش {id} مەغلۇب بولدى.",
    "Refreshing note {id} has failed." : "يېڭىلاش خاتىرىسى {id} مەغلۇپ بولدى.",
    "Renaming note {id} has failed." : "ئىزاھات {id} نىڭ نامىنى ئۆزگەرتىش مەغلۇب بولدى.",
    "Creating new note has failed." : "يېڭى خاتىرە قۇرۇش مەغلۇب بولدى.",
    "Saving note {id} has failed." : "خاتىرە {id} نى ساقلاش مەغلۇب بولدى.",
    "Updating title for note {id} has failed." : "Not {id} note نىڭ نامىنى يېڭىلاش مەغلۇب بولدى.",
    "Undo delete has failed for note {title}." : "ئەمەلدىن قالدۇرۇش خاتىرە {title} for ئۈچۈن مەغلۇپ بولدى.",
    "Deleting note {id} has failed." : "خاتىرە {id} ئۆچۈرۈش مەغلۇب بولدى.",
    "Toggling favorite for note {id} has failed." : "خاتىرە {id} for ئۈچۈن ياقتۇرىدىغان خەتكۈچ مەغلۇب بولدى.",
    "Updating the note's category has failed. Is the target directory writable?" : "خاتىرە تۈرىنى يېڭىلاش مەغلۇب بولدى. نىشان مۇندەرىجىنى يازغىلى بولامدۇ؟",
    "Updating the category for note {id} has failed." : "خاتىرە {id} for تۈرىنى يېڭىلاش مەغلۇب بولدى.",
    "Uncategorized" : "تۈرگە ئايرىلمىغان",
    "Sample note" : "ئۈلگە ئىزاھات",
    "15 January 2021, via Nextcloud Notes" : "2021-يىلى 15-يانۋار ، Nextcloud Notes ئارقىلىق",
    "Me, you, and all our friends!" : "مەن ، سىز ۋە بارلىق دوستلىرىمىز!",
    "Tasks" : "ۋەزىپەلەر",
    "Write nice todo lists" : "چىرايلىق todo تىزىملىكىنى يېزىڭ",
    "Buy Fries" : "Fries نى سېتىۋېلىڭ",
    "Birthdays" : "تۇغۇلغان كۈنى",
    "Jen, in three days!" : "جېن ، ئۈچ كۈندە!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "تەكشۈرۈش باسقۇچلىرى",
    "Turn PC off" : "PC نى ئېتىۋېتىڭ",
    "Turn PC on" : "كومپيۇتېرنى ئېچىڭ",
    "Then call IT" : "ئاندىن IT غا تېلېفون قىلىڭ",
    "Quotes" : "نەقىل",
    "Nextcloud, a safe home for all your data" : "Nextcloud، بارلىق سانلىق مەلۇماتلىرىڭىزنىڭ بىخەتەر ئۆيى",
    "Development Mode" : "تەرەققىيات ھالىتى",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "قارىغاندا خاتىرە دېتالى تەرەققىيات مەنبەسىدىن قاچىلانغاندەك قىلىدۇ. ئۇنىڭ ئورنىغا رەسمىي <a href=\"%1$s\"> Nextcloud ئەپ دۇكىنى </a> دىن قاچىلاڭ. ئەگەر سىز خاتىرە دېتالىنى ئۆزىڭىز قۇرماقچى بولسىڭىز ، <a href=\"%2$s\"> ئاچقۇچىلار كۆرسەتمىسى </a> گە ئەگىشىڭ."
},
"nplurals=2; plural=(n != 1);");
