OC.L10N.register(
    "notes",
    {
    "Notes" : "شسیب",
    "Error" : "شسیب",
    "Files" : "فایلونه",
    "Cancel" : "پرېښول",
    "Remove from favorites" : "له نښو ويستل",
    "Add to favorites" : "په نښه کول",
    "Share" : "شریکول",
    "Today" : "نن",
    "Yesterday" : "پرون"
},
"nplurals=2; plural=(n != 1);");
