OC.L10N.register(
    "notes",
    {
    "Notes" : "Notater",
    "Create new note" : "Opprett et nytt notat",
    "More notes" : "Flere notater",
    "Reading notes from filesystem has failed." : "Lesing av notater fra filsystemet mislyktes.",
    "Error" : "Feil",
    "New note" : "Ny lapp",
    "Distraction-free notes and writing" : "Distraksjonsfrie notater og skriving",
    "Deleted {title}" : "Slettet {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Slettet {number} notat","Slettet {number} notater"],
    "Undo Delete" : "Angre sletting",
    "Note recovered" : "Merket gjenopprettet",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Gjenopprettet {number} notat","Gjenopprettet {number} notater"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det er ulagrede notater. Hvis du forlater siden, forkastes alle endringer!",
    "Notes settings" : "Innstillinger for notater",
    "Please see Nextcloud server log for details." : "Se Nextcloud-serverloggen for detaljer.",
    "Preview" : "Forhåndsvisning",
    "Make the selection bold" : "Gjør valget fet",
    "Make the selection italic" : "Gjør valget kursiv",
    "Wrap the selection in quotes" : "Pakk utvalget inn i anførselstegn",
    "The selection will be turned into monospace" : "Utvalget vil bli omgjort til monospace",
    "Remove any styles from the selected text" : "Fjern eventuelle stiler fra den valgte teksten",
    "Makes the current line a list element" : "Gjør gjeldende linje til et listeelement",
    "Makes the current line a list element with a number" : "Gjør gjeldende linje til et listeelement med et tall",
    "Toggle heading for current line" : "Veksle overskrift for gjeldende linje",
    "Set the current line as a big heading" : "Angi gjeldende linje som en stor overskrift",
    "Insert link" : "Sett inn lenke",
    "Insert image" : "Sett inn bilde",
    "Switch between editor and viewer" : "Bytt mellom redaktør og seer",
    "Pick a notes folder" : "Velg en mappe for notater",
    "Set notes folder" : "Angi mappe for notater",
    "Display" : "Visning",
    "File extension" : "Filutvidelse",
    "Mobile apps" : "Mobilapper",
    "Shortcuts" : "Snarveier",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "All notes" : "Alle notater",
    "Categories" : "Kategorier",
    "Create a sample note with Markdown" : "Lag et eksempelnotat med Markdown",
    "No notes yet" : "Ingen notater ennå",
    "Select an image" : "Velg et bilde",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Du kan ikke velge bilder utenfor notatmappen. Din notatmapp er: {folder}",
    "Wrong image" : "Feil bilde",
    "The file was not uploaded. Check your server logs." : "Filen ble ikke lastet opp. Sjekk serverloggene dine.",
    "Upload image" : "Last opp bilde",
    "Rich text editor" : "Rich text editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Du kan nå bytte til å bruke den brukervennlige og distraksjonsfrie riktekstredigereren. Den lar deg redigere notater uten å se noen Markdown-merker.",
    "This option can also be changed later on in the Notes app settings." : "Dette alternativet kan også endres senere i Notes-appens innstillinger.",
    "Keep plain Markdown editor" : "Behold vanlig Markdown-editor",
    "Use rich editor" : "Bruk rich editor",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "Error while renaming note." : "Feil under omdøping av notat.",
    "Error during preparing note for deletion." : "Feil under forberedelse av notat for sletting.",
    "Share" : "Del",
    "Change category" : "Endre kategori",
    "Rename" : "Endre navn",
    "Rename note" : "Endre navn på notat",
    "Delete note" : "Slett notat",
    "Error from Nextcloud server: {msg}" : "Feil fra Nextcloud-server: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Notatet er endret i en annen økt. Vennligst velg hvilken versjon som skal lagres.",
    "Use version from server" : "Bruk versjon fra server",
    "Use current version" : "Bruk gjeldende versjon",
    "Empty note" : "Tom lapp",
    "Write …" : "Skrive …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Redigere",
    "Exit full screen" : "Avslutt fullskjerm",
    "Full screen" : "Full skjerm",
    "Note is read-only. You cannot change it." : "Notatet er skrivebeskyttet. Du kan ikke endre det.",
    "Save failed. Click to retry." : "Lagring mislyktes. Klikk for å prøve på nytt.",
    "Update conflict. Click for resolving manually." : "Oppdateringskonflikt. Klikk for å løse manuelt.",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "This week" : "Denne uka",
    "Last week" : "Forrige uke",
    "This month" : "Denne måneden",
    "Last month" : "Forrige måned",
    "Search for notes" : "Søk etter notater",
    "Loading …" : "Laster inn …",
    "Find in all categories" : "Finn i alle kategorier",
    "Write down your thoughts without any distractions." : "Skriv ned tankene dine uten distraksjoner.",
    "Use Markdown markups to style your text." : "Bruk Markdown-markeringer for å style teksten din.",
    "Organize your notes in categories." : "Organiser notatene dine i kategorier.",
    "Note not found." : "Notat ikke funnet.",
    "Note is locked." : "Notatet er låst.",
    "Insufficient storage." : "Manglende lagringsplass.",
    "See JavaScript console and server log for details." : "Se JavaScript-konsollen og serverloggen for detaljer.",
    "Updating settings has failed." : "Oppdatering av innstillinger mislyktes.",
    "Fetching notes for dashboard has failed." : "Henting av notater for dashbordet mislyktes.",
    "Fetching notes has failed." : "Henting av notater mislyktes.",
    "Fetching note {id} has failed." : "Henting av notat {id} mislyktes.",
    "Refreshing note {id} has failed." : "Oppdater notatet {id} mislyktes.",
    "Renaming note {id} has failed." : "Endre navn på notat {id} mislyktes.",
    "Creating new note has failed." : "Oppretting av nytt notat mislyktes.",
    "Saving note {id} has failed." : "Lagring av notat {id} mislyktes.",
    "Updating title for note {id} has failed." : "Oppdatering av tittel for notat {id} mislyktes.",
    "Undo delete has failed for note {title}." : "Angre sletting mislyktes for notat {title}.",
    "Deleting note {id} has failed." : "Sletting av notat {id} mislyktes.",
    "Toggling favorite for note {id} has failed." : "Veksling av favoritt for notat {id} mislyktes.",
    "Updating the note's category has failed. Is the target directory writable?" : "Oppdatering av notatkategorien mislyktes. Er målkatalogen skrivbar?",
    "Updating the category for note {id} has failed." : "Oppdatering av kategorien for notat {id} mislyktes.",
    "Uncategorized" : "Ukategorisert",
    "Sample note" : "Eksempelnotat",
    "15 January 2021, via Nextcloud Notes" : "15. januar 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Meg, du og alle vennene våre!",
    "Tasks" : "Oppgaver",
    "Write nice todo lists" : "Skriv fine gjøremålslister",
    "Buy Fries" : "Kjøp pommes frites",
    "Birthdays" : "Bursdager",
    "Jen, in three days!" : "Jen, om tre dager!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Gjennomgå trinn",
    "Turn PC off" : "Slå av PC-en",
    "Turn PC on" : "Slå på PC-en",
    "Then call IT" : "Så ring IT",
    "Quotes" : "Sitater",
    "Nextcloud, a safe home for all your data" : "Nextcloud, et trygt hjem for alle dataene dine",
    "Development Mode" : "Utviklingsmodus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut til at notatappen ble installert fra en utviklingskilde. Installer den fra den offisielle <a href=\"%1$s\">Nextcloud App Store</a> i stedet. Hvis du vil bygge Notes-appen selv, følg <a href=\"%2$s\">utviklerinstruksjonene</a>."
},
"nplurals=2; plural=(n != 1);");
