OC.L10N.register(
    "notes",
    {
    "Notes" : "Noter",
    "Create new note" : "Opret ny note",
    "Error" : "Fejl",
    "New note" : "Ny note",
    "Undo Delete" : "Annuller Slet",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
    "Notes settings" : "Noter indstillinger",
    "Rich text" : "Formateret tekst",
    "Plain text" : "Rå tekst",
    "Preview" : "Forhåndsvis",
    "Insert image" : "Indsæt billede",
    "Display" : "Vis",
    "File extension" : "Filendelse",
    "Files" : "Filer",
    "Notes folder" : "Noter mappe",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "All notes" : "Alle noter",
    "Categories" : "Kategorier",
    "No notes yet" : "Ingen noter endnu",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Føj til favoritter",
    "Share" : "Share",
    "Rename" : "Rename",
    "Delete note" : "Slet note",
    "Use current version" : "Brug aktuelle version",
    "Edit" : "Redigér",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "This week" : "Denne uge",
    "Last week" : "Sidste uge",
    "This month" : "Denne måned",
    "Last month" : "Seneste måned",
    "Search for notes" : "Søg efter noter",
    "Loading …" : "Indlæser…",
    "Uncategorized" : "Udenfor kategori",
    "Tasks" : "Opgaver"
},
"nplurals=2; plural=(n != 1);");
