OC.L10N.register(
    "notes",
    {
    "Notes" : "Mazingatio",
    "Create new note" : "Tengeneza zingatio jipya",
    "More notes" : "Mazingatio zaidi",
    "Reading notes from filesystem has failed." : "Kusoma mazingatio kutoka kwa mfumo wa faili kumeshindwa.",
    "Error" : "Hitilafu",
    "New note" : "Zingatio jipya",
    "Distraction-free notes and writing" : "Distraction-free notes and writing",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites.",
    "Deleted {title}" : "Imefutwa {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Deleted {number} note","Deleted {number} notes"],
    "Undo Delete" : "Tendua ufutaji",
    "Note recovered" : "Dokezo limepatikana",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Recovered {number} note","Madokezo {number} yamerejeshwa"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Kuna madokezo ambayo hayajahifadhiwa. Kuondoka kwenye ukurasa kutatupa mabadiliko yote!",
    "Notes settings" : "Mipangilio ya vidokezo",
    "Please see Nextcloud server log for details." : "Tafadhali angalia logi ya seva ya Nextcloud kwa maelezo.",
    "Custom" : "Desturi",
    "Rich text" : "Nakala tajiri",
    "Plain text" : "Maandishi tupu",
    "Preview" : "Hakiki",
    "Make the selection bold" : "Fanya uteuzi kuwa mnene",
    "Make the selection italic" : "Fanya uteuzi kuwa italiki",
    "Wrap the selection in quotes" : "Funga uteuzi kwa nukuu",
    "The selection will be turned into monospace" : "Uteuzi utageuzwa kuwa nafasi moja",
    "Remove any styles from the selected text" : "Ondoa mitindo yoyote kutoka kwenye maandishi uliyochagua",
    "Makes the current line a list element" : "Hufanya mstari wa sasa kuwa kipengele cha orodha",
    "Makes the current line a list element with a number" : "Hufanya mstari wa sasa kuwa kipengele cha orodha chenye nambari",
    "Toggle heading for current line" : "Geuza kichwa kwa mstari wa sasa",
    "Set the current line as a big heading" : "Weka mstari wa sasa kama kichwa kikubwa",
    "Insert link" : "Weka kiungo",
    "Insert image" : "Weka picha",
    "Switch between editor and viewer" : "Badili kati ya mhariri na mtazamaji",
    "Pick a notes folder" : "Chagua folda ya madokezo",
    "Set notes folder" : "Weka folda ya madokezo",
    "General" : "Kuu",
    "Display" : "Onekana",
    "File extension" : "Kiendelezi cha faili",
    "Files" : "Mafaili",
    "Notes folder" : "Folda ya madokezo",
    "Mobile apps" : "Programu za simu",
    "Shortcuts" : "Njia za mikato",
    "Delete" : "Futa",
    "Cancel" : "Ghaili",
    "All notes" : "Mazingatio yote",
    "Categories" : "Kategoria",
    "Create a sample note with Markdown" : "Create a sample note with Markdown",
    "No notes yet" : "Bado hakuna madokezo",
    "Select an image" : "Chagua picha",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Huwezi kuchagua picha nje ya folda yako ya madokezo. Folda yako ya madokezo ni: {folder}",
    "Wrong image" : "Picha isiyo sahihi",
    "The file was not uploaded. Check your server logs." : "Faili haikupakiwa. Angalia kumbukumbu za seva yako.",
    "Upload image" : "Pakia picha",
    "Rich text editor" : "Mhariri tajiri wa maandishi",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Sasa unaweza kubadilisha ili utumie kihariri cha maandishi tajiri kilicho rahisi kutumia na kuvuruga. Inakuruhusu kuhariri madokezo bila kuona alama zozote za Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Chaguo hili pia linaweza kubadilishwa baadaye katika mipangilio ya programu ya madokezo",
    "Keep plain Markdown editor" : "Weka kihariri wazi cha Markdown",
    "Use rich editor" : "Tumia kihariri tajiri",
    "Remove from favorites" : "Ondoa kutoka katika vipendwa",
    "Add to favorites" : "Ongeza katika vipendwa",
    "Error while renaming note." : "Hitilafu wakati wa kubadilisha dokezo.",
    "Error during preparing note for deletion." : "Hitilafu wakati wa kuandaa dokezo la kufutwa.",
    "Share" : "Shirikisha",
    "Change category" : "Badilisha kategoria",
    "Rename" : "Badili jina",
    "Rename note" : "Badilisha jina la dokezo",
    "Delete note" : "Futa dokezo",
    "Error from Nextcloud server: {msg}" : "Hitilafu kutoka kwenye seva ya Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Dokezo limebadilishwa katika kipindi kingine. Tafadhali chagua ni toleo gani linapaswa kuhifadhiwa.",
    "Use version from server" : "Tumia toleo kutoka kwenye seva",
    "Use current version" : "Tumia toleo la sasa",
    "Empty note" : "Dokezo tupu",
    "Write …" : "Andika …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Hariri",
    "Exit full screen" : "Ondoka kwenye skrini nzima",
    "Full screen" : "Skrini nzima",
    "Note is read-only. You cannot change it." : "Dokezo ni la kusoma pekee. Huwezi kuibadilisha.",
    "Save failed. Click to retry." : "Imeshindwa kuhifadhi. Bofya ili kujaribu tena.",
    "Update conflict. Click for resolving manually." : "Sasisha mzozo. Bofya ili usuluhishe wewe mwenyewe.",
    "Today" : "Leo",
    "Yesterday" : "Jana",
    "This week" : "Wiki hii",
    "Last week" : "Wiki iliyopita",
    "This month" : "Mwezi huu",
    "Last month" : "Mwezi uliopita",
    "Search for notes" : "Tafuta maelezo",
    "Loading …" : "Inapakia",
    "Find in all categories" : "Pata katika kategoria zote",
    "Write down your thoughts without any distractions." : "Andika mawazo yako bila usumbufu wowote.",
    "Use Markdown markups to style your text." : "Tumia alama za Markdown kupamba maandishi yako.",
    "Organize your notes in categories." : "Panga madokezo yako katika kategoria.",
    "Note not found." : "Dokezo halikupatikana.",
    "Note is locked." : "Dokezo limefungwa",
    "Insufficient storage." : "Uhifadhi hautoshi.",
    "See JavaScript console and server log for details." : "Angalia konsole ya JavaScript na kumbukumbu ya seva kwa maelezo zaidi.",
    "Updating settings has failed." : "Sasisho la mipangilio limefeli.",
    "Fetching notes for dashboard has failed." : "Kupata madokezo kwa dashibodi imeshindikana.",
    "Fetching notes has failed." : "Imeshindwa kupata madokezo.",
    "Fetching note {id} has failed." : "Imeshindwa kuleta dokezo {id}.",
    "Refreshing note {id} has failed." : "Kidokezo cha kuonyesha upya {id} hakijafaulu.",
    "Renaming note {id} has failed." : "Kubadilisha jina la dokezo {id} kumeshindwa.",
    "Creating new note has failed." : "Imeshindwa kuunda dokezo jipya.",
    "Saving note {id} has failed." : "Imeshindwa kuhifadhi dokezo {id}.",
    "Updating title for note {id} has failed." : "Imeshindwa kusasisha kichwa cha dokezo {id}.",
    "Undo delete has failed for note {title}." : "Imeshindwa kutendua kufuta dokezo {title}.",
    "Deleting note {id} has failed." : "Imeshindwa kufuta dokezo {id}.",
    "Toggling favorite for note {id} has failed." : "Kugeuza kipendwa kwa dokezo {id} kumeshindwa.",
    "Updating the note's category has failed. Is the target directory writable?" : "Imeshindwa kusasisha aina ya dokezo. Je! saraka inayolengwa inaweza kuandikwa?",
    "Updating the category for note {id} has failed." : "Imeshindwa kusasisha kategoria ya dokezo {id}.",
    "Uncategorized" : "Isiyowekwa katika kundi",
    "Sample note" : "Sampuli ya dokezo",
    "15 January 2021, via Nextcloud Notes" : "15 Januari 2021, kupitia madokezo ya Nextcloud",
    "Me, you, and all our friends!" : "Mimi, wewe, na marafiki zetu wote!",
    "Tasks" : "Kazi",
    "Write nice todo lists" : "Andika orodha nzuri za kufanya",
    "Buy Fries" : "Nunua Fries",
    "Birthdays" : "Siku za kuzaliwa",
    "Jen, in three days!" : "Jen, ndani ya siku tatu!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Kagua Hatua",
    "Turn PC off" : "Zima kompyuta",
    "Turn PC on" : "Washa Kompyuta",
    "Then call IT" : "Kisha piga simu IT",
    "Quotes" : "Manukuu",
    "Nextcloud, a safe home for all your data" : "Nextcloud, nyumba salama kwa data zako zote",
    "Development Mode" : "Njia ya Maendeleo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Inaonekana programu ya madokezo ilisakinishwa kutoka kwa chanzo cha usanidi. Tafadhali isakinishe kutoka kwa <a href=\"%1$s\">Nextcloud App Store</a> badala yake. Ikiwa unataka kuunda programu ya Vidokezo peke yako, tafadhali fuata maagizo ya <a href=\"%2$s\">developer</a>."
},
"nplurals=2; plural=(n != 1);");
