OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Create new note" : "Créer une nouvelle note",
    "More notes" : "Plus de notes",
    "Reading notes from filesystem has failed." : "La lecture des notes du système de fichiers a échoué.",
    "Error" : "Erreur",
    "New note" : "Nouvelle note",
    "Distraction-free notes and writing" : "Notes et écriture sans distraction",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "L'application Notes est une application de prise de notes qui va à l'essentiel pour [Nextcloud](https://www.nextcloud.com/). Elle propose des catégories pour une meilleure organisation et supporte le formatage en syntaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). Les notes sont sauvegardées en tant que fichiers dans votre Nextcloud, donc vous pouvez les voir et les modifier avec n'importe quel client Nextcloud. De plus, une [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md)  séparée permet une intégration facile dans les applications ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), ainsi que des [applications tierces](https://github.com/nextcloud/notes/wiki#3rd-party-clients) qui permettent un accès pratique à vos notes Nextcloud). D'autres fonctionnalités incluent le marquage comme favoris.",
    "Deleted {title}" : "La note {title} a été supprimée",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} note supprimée","{number} notes supprimées","{number} notes supprimées"],
    "Undo Delete" : "Annuler la suppression",
    "Note recovered" : "Note restaurée",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} note restaurée","{number} notes restaurées","{number} notes restaurées"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Il y a des notes non sauvegardées. Quitter la page vous fera perdre toutes les modifications !",
    "Notes settings" : "Paramètres de Notes",
    "Please see Nextcloud server log for details." : "Veuillez consulter les logs du serveur Nextcloud pour plus de détails.",
    "Custom" : "Personnalisé",
    "Rich text" : "Texte enrichi",
    "Plain text" : "Texte brut",
    "Preview" : "Aperçu",
    "Make the selection bold" : "Mettre la sélection en gras",
    "Make the selection italic" : "Mettre la sélection en italique",
    "Wrap the selection in quotes" : "Entoure la sélection de guillemets",
    "The selection will be turned into monospace" : "La sélection sera changée en police à chasse fixe ",
    "Remove any styles from the selected text" : "Supprime tous les styles du texte sélectionné",
    "Makes the current line a list element" : "Fait de la ligne courante une entrée de liste",
    "Makes the current line a list element with a number" : "Fait de la ligne courante une entrée de liste numérotée",
    "Toggle heading for current line" : "Permuter titre / corps pour la ligne courante",
    "Set the current line as a big heading" : "Définir la ligne actuelle comme un titre",
    "Insert link" : "Insérer un lien",
    "Insert image" : "Insérer une image",
    "Switch between editor and viewer" : "Basculer entre les modes éditeur et visionneur",
    "Pick a notes folder" : "Choisir un dossier de notes",
    "Set notes folder" : "Définir un dossier de notes ",
    "General" : "Général",
    "Display" : "Affichage",
    "File extension" : "Extension des fichiers",
    "For new notes" : "Pour les nouvelles notes",
    "Custom file extension" : "Extension de fichier personnalisée",
    "Files" : "Fichiers",
    "Notes folder" : "Dossier des notes",
    "Mobile apps" : "Applications mobiles",
    "Shortcuts" : "Raccourcis",
    "Delete" : "Supprimer",
    "Cancel" : "Cancel",
    "All notes" : "Toutes les notes",
    "Categories" : "Catégories",
    "Create a sample note with Markdown" : "Créer un exemple de note avec Markdown",
    "No notes yet" : "Aucune note pour l'instant",
    "Select an image" : "Sélectionner une image",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Vous ne pouvez pas sélectionner des images en dehors du dossier de vos notes. Le dossier de vos notes est : {folder}",
    "Wrong image" : "Mauvaise image",
    "The file was not uploaded. Check your server logs." : "Le fichier n'a pas été téléversé. Vérifiez les logs du serveur.",
    "Upload image" : "Téléverser une image",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone et iPad",
    "Rich text editor" : "Éditeur de texte enrichi",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Vous pouvez maintenant passer à l'éditeur de texte enrichi, facile à utiliser et sans distraction. Il vous permet d'éditer des notes sans voir les balises Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Cette option peut également être modifiée ultérieurement dans les paramètres de l'application Notes.",
    "Keep plain Markdown editor" : "Conserver l'éditeur Markdown simple",
    "Use rich editor" : "Utiliser un éditeur enrichi",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "Error while renaming note." : "Erreur lors du renommage de la note.",
    "Error during preparing note for deletion." : "Erreur lors de la préparation de la suppression de la note.",
    "Share" : "Partager",
    "Change category" : "Changer la catégorie",
    "Rename" : "Renommer",
    "Rename note" : "Renommer la note",
    "Delete note" : "Supprimer la note",
    "Error from Nextcloud server: {msg}" : "Erreur du serveur Nextcloud : {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "La note a été modifiée dans une autre session. Veuillez choisir la version à enregistrer.",
    "Use version from server" : "Utiliser la version provenant du serveur",
    "Use current version" : "Utiliser la version actuelle",
    "Empty note" : "Note vide",
    "Write …" : "Écrire...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modifier",
    "Exit full screen" : "Quitter le plein écran",
    "Full screen" : "Plein écran",
    "Note is read-only. You cannot change it." : "La note est en lecture seule. Vous ne pouvez pas la modifier.",
    "Save failed. Click to retry." : "L’enregistrement a échoué. Cliquez pour réessayer.",
    "Update conflict. Click for resolving manually." : "Conflit de mise à jour. Cliquez pour le résoudre manuellement.",
    "Today" : "Aujourd'hui",
    "Yesterday" : "Hier",
    "This week" : "Cette semaine",
    "Last week" : "Semaine dernière",
    "This month" : "Ce mois-ci",
    "Last month" : "Le mois dernier",
    "Search for notes" : "Rechercher des notes",
    "Loading …" : "Chargement …",
    "Find in all categories" : "Rechercher dans toutes les catégories",
    "Write down your thoughts without any distractions." : "Notez vos pensées sans aucune distraction.",
    "Use Markdown markups to style your text." : "Utilisez la syntaxe Markdown pour mettre en forme votre texte.",
    "Organize your notes in categories." : "Organisez vos notes en catégories.",
    "Note not found." : "Note non trouvée.",
    "Note is locked." : "La note est verrouillée.",
    "Insufficient storage." : "Espace libre insuffisant.",
    "See JavaScript console and server log for details." : "Voir la console Javascript et les logs du serveur pour plus de détails.",
    "Updating settings has failed." : "La mise à jour des paramètres a échoué.",
    "Fetching notes for dashboard has failed." : "La récupération des notes pour le tableau de bord a échoué.",
    "Fetching notes has failed." : "La récupération de notes a échoué.",
    "Fetching note {id} has failed." : "La récupération de la note {id} a échoué.",
    "Refreshing note {id} has failed." : "L'actualisation de la note {id} a échoué.",
    "Renaming note {id} has failed." : "Impossible de renommer la note {id}.",
    "Creating new note has failed." : "La création d'une nouvelle note a échoué.",
    "Saving note {id} has failed." : "L'enregistrement de la note {id} a échoué.",
    "Updating title for note {id} has failed." : "La mise à jour du titre de la note {id} a échoué.",
    "Undo delete has failed for note {title}." : "Impossible d'annuler la suppression de la note {title}.",
    "Deleting note {id} has failed." : "La suppression de la note {id} a échoué.",
    "Toggling favorite for note {id} has failed." : "L'ajout aux favoris (ou retrait) de la note {id} a échoué.",
    "Updating the note's category has failed. Is the target directory writable?" : "Impossible de mettre à jour la catégorie de la note. Vérifiez que vous avez le droit d'écriture dans ce dossier.",
    "Updating the category for note {id} has failed." : "La mise à jour de la catégorie pour la note {id} a échoué.",
    "Uncategorized" : "Non catégorisé",
    "Sample note" : "Exemple de note",
    "15 January 2021, via Nextcloud Notes" : "15 janvier 2021, via les notes Nextcloud",
    "Me, you, and all our friends!" : "Moi, vous et tous vos amis !",
    "Tasks" : "Tâches",
    "Write nice todo lists" : "Écrire de belles listes de tâches",
    "Buy Fries" : "Acheter des frites",
    "Birthdays" : "Anniversaires",
    "Jen, in three days!" : "Jen, dans trois jours !",
    "Moss, 21.03.1973" : "Moss, 21/03/1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Étapes de révision",
    "Turn PC off" : "Éteindre le PC",
    "Turn PC on" : "Allumer le PC",
    "Then call IT" : "Ensuite appeler le support informatique",
    "Quotes" : "Devis",
    "Nextcloud, a safe home for all your data" : "Nextcloud, un lieu sûr pour toutes vos données",
    "Development Mode" : "Mode développeur",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Il semble que l'application Notes ait été installée depuis une source de développement. Veuillez plutôt l'installer depuis le <a href=\"%1$s\">magasin d'applications Nextcloud</a> officiel. Si vous voulez construire l'application Notes par vous-même, veuillez suivre les <a href=\"%2$s\">instructions pour le développement</a>."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
