OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "Xatolik",
    "New note" : "New note",
    "General" : "Umumiy",
    "Files" : "Fayllar",
    "Delete" : "O'chirish",
    "Cancel" : "Bekor qilish",
    "Categories" : "Kategoriyalar",
    "Share" : "Ulashish",
    "Rename" : "Nomini o'zgartirish",
    "Tasks" : "Tasks"
},
"nplurals=1; plural=0;");
