OC.L10N.register(
    "notes",
    {
    "Notes" : "Nodiadau",
    "Error" : "Gwall",
    "New note" : "Nodyn newydd",
    "Preview" : "Rhagolwg",
    "Files" : "Ffeiliau",
    "Delete" : "Delete",
    "Cancel" : "Diddymu",
    "All notes" : "Pob nodyn",
    "No notes yet" : "Dim nodiadau eto",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Rhannu",
    "Rename" : "Rename",
    "Edit" : "Golygu",
    "Today" : "Heddiw",
    "Yesterday" : "Ddoe",
    "This week" : "Wythnos yma",
    "This month" : "Mis yma",
    "Loading …" : "Yn llwytho …",
    "Uncategorized" : "Dim categori"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
