OC.L10N.register(
    "notes",
    {
    "Error" : "Erreur",
    "Files" : "Ifuyla",
    "Cancel" : "Sefsex",
    "Add to favorites" : "Rnu ismal",
    "Edit" : "Ẓreg",
    "Today" : "Ass-a",
    "Yesterday" : "Iḍelli",
    "This week" : "Dduṛt agi"
},
"nplurals=2; plural=(n != 1);");
