OC.L10N.register(
    "notes",
    {
    "Notes" : "یادداشت ها",
    "Create new note" : "ایجاد یادداشت جدید",
    "More notes" : "یادداشت‌های بیشتر",
    "Reading notes from filesystem has failed." : "خواندن یادداشت ها از پوشه ی سیستم با شکست مواجه شده است",
    "Error" : "خطا",
    "New note" : "یادداشت جدید",
    "Distraction-free notes and writing" : "یادداشت ها و نوشتن بدون حواس پرتی",
    "Deleted {title}" : "{title} حذف شد",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} یادداشت حذف شد","{number} یادداشت حذف شدند"],
    "Undo Delete" : "Undo Delete",
    "Note recovered" : "یادداشت بازیابی شده",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} یادداشت یازیابی شد","{number} یادداشت یازیابی شدند"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشتهای ذخیره نشده وجود دارد. ترک صفحه باعث می شود همه تغییرات از بین بروند!",
    "Notes settings" : "تنظیمات یادداشت‌ها",
    "Please see Nextcloud server log for details." : "لطفا لاگ سرور nextcloud را برای جزییات بیشتر مشاهده نمایید .",
    "Preview" : "پیش نمایش",
    "Make the selection bold" : "متن انتخابی ضخیم شود",
    "Make the selection italic" : "متن انتخابی کج شود",
    "Wrap the selection in quotes" : "قراردادن متن انتخابی در علامت نقل‌قول",
    "The selection will be turned into monospace" : "متن انتخابی به monospace تغییر خواهد بافت",
    "Remove any styles from the selected text" : "Remove any styles from the selected text",
    "Makes the current line a list element" : "Makes the current line a list element",
    "Makes the current line a list element with a number" : "Makes the current line a list element with a number",
    "Toggle heading for current line" : "Toggle heading for current line",
    "Set the current line as a big heading" : "Set the current line as a big heading",
    "Insert link" : "Insert link",
    "Insert image" : "Insert image",
    "Switch between editor and viewer" : "Switch between editor and viewer",
    "File extension" : "پسوند پرونده",
    "Files" : "فایل‌ها",
    "Mobile apps" : "کاره‌های همراه",
    "Shortcuts" : "میان‌برها",
    "Delete" : "Delete",
    "Cancel" : "لغو",
    "All notes" : "همه یادداشت ها",
    "Categories" : "دسته بندی ها",
    "Create a sample note with Markdown" : "ایجاد یادداشت نمونه با مارک‌داون",
    "No notes yet" : "هنوز هیچ یادداشتی وجود ندارد",
    "Select an image" : "Select an image",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "You cannot select images outside of your notes folder. Your notes folder is: {folder}",
    "Wrong image" : "Wrong image",
    "The file was not uploaded. Check your server logs." : "The file was not uploaded. Check your server logs.",
    "Upload image" : "Upload image",
    "Rich text editor" : "Rich text editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks.",
    "This option can also be changed later on in the Notes app settings." : "This option can also be changed later on in the Notes app settings.",
    "Keep plain Markdown editor" : "حفظ ویرایش‌گر ساده مارک‌داون",
    "Use rich editor" : "Use rich editor",
    "Remove from favorites" : "حذف از برگزیده‌ها",
    "Add to favorites" : "افزودن به علاقه مندی ها",
    "Error during preparing note for deletion." : "در هنگام آماده سازی یادداشت برای حذف خطایی رخ داده است",
    "Share" : "هم‌رسانی",
    "Delete note" : "حذف یادداشت",
    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست کلود : {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "The note has been changed in another session. Please choose which version should be saved.",
    "Use version from server" : "Use version from server",
    "Use current version" : "از نسخه فعلی استفاده کنید",
    "Empty note" : "یادداشت خالی",
    "Write …" : "نوشتن …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "ویرایش",
    "Exit full screen" : "خروج از تمام صفحه",
    "Full screen" : "تمام صفحه",
    "Note is read-only. You cannot change it." : "Note is read-only. You cannot change it.",
    "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
    "Update conflict. Click for resolving manually." : "Update conflict. Click for resolving manually.",
    "Today" : "Today",
    "Yesterday" : "دیروز",
    "This week" : "این هفته",
    "Last week" : "هفته گذشته",
    "This month" : "این ماه",
    "Last month" : "ماه گذشته",
    "Search for notes" : "Search for notes",
    "Loading …" : "بارگذاری …",
    "Find in all categories" : "Find in all categories",
    "Write down your thoughts without any distractions." : "افکار خود را بدون هیچ گونه حواس پرتی بنویسید.",
    "Use Markdown markups to style your text." : "برای سبک‌دهی به متن خود از نشانگرهای مارک‌داون استفاده کنید.",
    "Organize your notes in categories." : "یادداشت های خود را در دسته بندی ها ترتیب دهید.",
    "Note not found." : "یادداشتی یافت نشد",
    "Note is locked." : "یادداشت قفل شده است",
    "Insufficient storage." : "Insufficient storage.",
    "See JavaScript console and server log for details." : "See JavaScript console and server log for details.",
    "Updating settings has failed." : "به روزرسانی تنظیمات انجام نشد.",
    "Fetching notes for dashboard has failed." : "Fetching notes for dashboard has failed.",
    "Fetching notes has failed." : "ثبت نام یادداشت انجام نشد.",
    "Fetching note {id} has failed." : "یادداشت برداری {id} انجام نشد.",
    "Refreshing note {id} has failed." : "Refreshing note {id} has failed.",
    "Renaming note {id} has failed." : "Renaming note {id} has failed.",
    "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
    "Saving note {id} has failed." : "Saving note {id} has failed.",
    "Updating title for note {id} has failed." : "Updating title for note {id} has failed.",
    "Undo delete has failed for note {title}." : "Undo delete has failed for note {title}.",
    "Deleting note {id} has failed." : "حذف یادداشت {id} شکست خورد.",
    "Toggling favorite for note {id} has failed." : "تغییر وضعیت علاقه‌مندی برای یادداشت {id} شکست خورد.",
    "Updating the note's category has failed. Is the target directory writable?" : "به روزرسانی دسته یادداشت انجام نشد. آیا فهرست مسیر قابل نوشتن است؟",
    "Updating the category for note {id} has failed." : "به‌روزرسانی دسته برای یادداشت {id} شکست خورد.",
    "Uncategorized" : "دسته‌بندی نشده",
    "Sample note" : "Sample note",
    "15 January 2021, via Nextcloud Notes" : "15 January 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Me, you, and all our friends!",
    "Tasks" : "وظایف",
    "Write nice todo lists" : "Write nice todo lists",
    "Buy Fries" : "Buy Fries",
    "Birthdays" : "تاریخ تولدها",
    "Jen, in three days!" : "Jen, in three days!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Review Steps",
    "Turn PC off" : "Turn PC off",
    "Turn PC on" : "Turn PC on",
    "Then call IT" : "Then call IT",
    "Quotes" : "Quotes",
    "Nextcloud, a safe home for all your data" : "نکست‌کلود، خانه‌ای امن برای تمامی داده‌هایتان",
    "Development Mode" : "حالت توسعه",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "به نظر می رسد که برنامه یادداشت ها از یک منبع توسعه نصب شده است. لطفاً آن را از طریق رسمی  نصب کنید <a href=\"%1$s\">فروشگاه برنامه نکست کلود</a>بجای.اگر می خواهید برنامه Notes توسط خودتان بسازید ، لطفاً دنبال کنید <a href=\"%2$s\">دستورالعمل های توسعه دهنده</a>."
},
"nplurals=2; plural=(n > 1);");
