OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "Create new note" : "Crea nuova nota",
    "More notes" : "Altre note",
    "Reading notes from filesystem has failed." : "La lettura delle note dal filesystem non è riuscita.",
    "Error" : "Errore",
    "New note" : "Nuova nota",
    "Distraction-free notes and writing" : "Annotazioni e scrittura senza distrazioni",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "L'applicazione Note è un'app per prendere appunti senza distrazioni per [Nextcloud](https://www.nextcloud.com/). Fornisce categorie per una migliore organizzazione e supporta la formattazione utilizzando la sintassi [Markdown](https://en.wikipedia.org/wiki/Markdown). Le note vengono salvate come file nel tuo Nextcloud, così puoi visualizzarle e modificarle con ogni client Nextcloud. Inoltre, una [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) separata consente una facile integrazione nelle applicazioni ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), così come [applicazioni di terze parti](https://github.com/nextcloud/notes/wiki#3rd-party-clients) che consentono un comodo accesso alle tue note Nextcloud). Ulteriori funzionalità includono la marcatura delle note come preferite.",
    "Deleted {title}" : "Eliminato {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Eliminata {number} nota","Eliminate {number} note","Eliminate {number} note"],
    "Undo Delete" : "Annulla eliminazione",
    "Note recovered" : "Nota ripristinata",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Ripristinata {number} nota","Ripristinate {number} note","Ripristinate {number} note"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ci sono note non salvate. Se abbandoni la pagina perderai tutte le modifiche!",
    "Notes settings" : "Impostazioni delle note",
    "Please see Nextcloud server log for details." : "Vedi i log del server Nextcloud per i dettagli.",
    "Custom" : "Personalizzato",
    "Rich text" : "Testo formattato",
    "Plain text" : "Testo semplice",
    "Preview" : "Anteprima",
    "Make the selection bold" : "Imposta la selezione in grassetto",
    "Make the selection italic" : "Imposta la selezione in corsivo",
    "Wrap the selection in quotes" : "Racchiudi la selezione tra virgolette",
    "The selection will be turned into monospace" : "La selezione diventerà a spaziatura fissa",
    "Remove any styles from the selected text" : "Rimuovi qualsiasi stile dal testo selezionato",
    "Makes the current line a list element" : "Rende la riga corrente un elemento della lista",
    "Makes the current line a list element with a number" : "Rende la riga corrente un elemento della lista con un numero",
    "Toggle heading for current line" : "Attiva/disattiva l'intestazione della riga corrente",
    "Set the current line as a big heading" : "Imposta la riga corrente come una grande intestazione",
    "Insert link" : "Inserisci collegamento",
    "Insert image" : "Inserisci immagine",
    "Switch between editor and viewer" : "Passa da editor a visualizzatore",
    "Pick a notes folder" : "Seleziona una cartella di note",
    "Set notes folder" : "Imposta cartella note",
    "General" : "Generale",
    "Display" : "Schermo",
    "File extension" : "Estensione file",
    "For new notes" : "Per nuove note",
    "Custom file extension" : "Estensione di file personalizzata",
    "Files" : "File",
    "Notes folder" : "Cartella note",
    "Mobile apps" : "Applicazioni per dispositivi mobili",
    "Shortcuts" : "Scorciatoie",
    "Delete" : "Elimina",
    "All notes" : "Tutte le note",
    "Categories" : "Categorie",
    "Create a sample note with Markdown" : "Creare una nota di esempio con Markdown",
    "No notes yet" : "Ancora nessuna nota",
    "Select an image" : "Seleziona un'immagine",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Non è possibile selezionare immagini al di fuori della cartella delle note. La tua cartella delle note è: {folder}",
    "Wrong image" : "Immagine errata",
    "The file was not uploaded. Check your server logs." : "Il file non è stato caricato. Controlla i log del tuo server.",
    "Upload image" : "Carica immagine",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone e iPad",
    "Rich text editor" : "Editor con formattazione",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Puoi passare all'utilizzo dell'editor di testo RTF, facile da usare e privo di distrazioni. Ti consente di modificare le note senza vedere alcun contrassegno Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Questa opzione può anche essere modificata successivamente nelle impostazioni dell'applicazione Note.",
    "Keep plain Markdown editor" : "Mantieni l'editor Markdown semplice",
    "Use rich editor" : "Utilizza l'editor RTF",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Error while renaming note." : "Errore durante la rinomina della nota.",
    "Error during preparing note for deletion." : "Errore durante l'eliminazione della nota.",
    "Share" : "Condivisione",
    "Change category" : "Cambia categoria",
    "Rename" : "Rinomina",
    "Rename note" : "Rinomina nota",
    "Delete note" : "Elimina nota",
    "Error from Nextcloud server: {msg}" : "Errore dal server di Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "La nota è stata modificata in un'altra sessione. Scegli quale versione deve essere salvata.",
    "Use version from server" : "Utilizza la versione dal server",
    "Use current version" : "Utilizza la versione corrente",
    "Empty note" : "Nota vuota",
    "Write …" : "Scrivi...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modifica",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Note is read-only. You cannot change it." : "La nota è in sola lettura. Non puoi modificarla.",
    "Save failed. Click to retry." : "Salvataggio non riuscito. Fai clic per riprovare.",
    "Update conflict. Click for resolving manually." : "Conflitto di aggiornamento. Fai clic per risolvere manualmente.",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "This week" : "Questa settimana",
    "Last week" : "Settimana scorsa",
    "This month" : "Questo mese",
    "Last month" : "Mese scorso",
    "Search for notes" : "Cerca note",
    "Loading …" : "Caricamento...",
    "Find in all categories" : "Trova in tutte le categorie",
    "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
    "Organize your notes in categories." : "Organizza le tue note in categorie.",
    "Note not found." : "Nota non trovata.",
    "Note is locked." : "La nota è bloccata.",
    "Insufficient storage." : "Spazio di archiviazione insufficiente.",
    "See JavaScript console and server log for details." : "Vedi la console JavaScript e i log del server per i dettagli.",
    "Updating settings has failed." : "Aggiornamento delle impostazioni non riuscito.",
    "Fetching notes for dashboard has failed." : "Recupero delle note per il cruscotto non riuscito.",
    "Fetching notes has failed." : "Recupero delle note non riuscito.",
    "Fetching note {id} has failed." : "Recupero della nota {id} non riuscito.",
    "Refreshing note {id} has failed." : "L'aggiornamento della nota {id} non è riuscito.",
    "Renaming note {id} has failed." : "La rinomina della nota {id} non è riuscita.",
    "Creating new note has failed." : "Creazione nuova nota non riuscita.",
    "Saving note {id} has failed." : "Il salvataggio della nota {id} non è riuscito.",
    "Updating title for note {id} has failed." : "L'aggiornamento del titolo per la nota {id} non è riuscito.",
    "Undo delete has failed for note {title}." : "Annullamento eliminazione non riuscito per la nota {title}.",
    "Deleting note {id} has failed." : "Eliminazione della nota {id} non riuscita.",
    "Toggling favorite for note {id} has failed." : "L'attivazione come preferito della nota {id} non è riuscita",
    "Updating the note's category has failed. Is the target directory writable?" : "L'aggiornamento della categoria delle note non è riuscito. La cartella di destinazione è scrivibile?",
    "Updating the category for note {id} has failed." : "Aggiornamento della categoria per la nota {id} non riuscito.",
    "Uncategorized" : "Senza categoria",
    "Sample note" : "Nota di esempio",
    "15 January 2021, via Nextcloud Notes" : "15 gennaio 2021, tramite Nextcloud Note",
    "Me, you, and all our friends!" : "Io, tu e tutti i nostri amici!",
    "Tasks" : "Attività",
    "Write nice todo lists" : "Scrivi piacevoli liste di cose da fare",
    "Buy Fries" : "Compra patatine fritte",
    "Birthdays" : "Compleanni",
    "Jen, in three days!" : "Gio, tra tre giorni!",
    "Moss, 21.03.1973" : "Mario, 21/03/1973",
    "Roy, 1979" : "Roberto, 1979",
    "Review Steps" : "Passaggi di revisione",
    "Turn PC off" : "Spegni il PC",
    "Turn PC on" : "Accendi il PC",
    "Then call IT" : "Poi chiama l'IT",
    "Quotes" : "Citazioni",
    "Nextcloud, a safe home for all your data" : "Nextcloud, un posto sicuro per tutti i tuoi dati",
    "Development Mode" : "Modalità di sviluppo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembra che l'applicazione delle note sia stata installata da una sorgente di sviluppo. Installala invece dal <a href=\"%1$s\">Negozio delle applicazioni di Nextcloud</a> ufficiale. Se desideri compilare l'applicazione Note in autonomia, segui le <a href=\"%2$s\">istruzioni per sviluppatori</a>"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
