OC.L10N.register(
    "notes",
    {
    "Notes" : "Notizen",
    "Create new note" : "Neue Notiz erstellen",
    "More notes" : "Weitere Notizen",
    "Reading notes from filesystem has failed." : "Laden der Notizen vom Dateisystem ist fehlgeschlagen.",
    "Error" : "Fehler",
    "New note" : "Neue Notiz",
    "Distraction-free notes and writing" : "Ablenkungsfreie Notizen und Schreiben",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Die Notes-App ist eine ablenkungsfreie App zum Erstellen von Notizen für [Nextcloud](https://www.nextcloud.com/). Sie bietet Kategorien für eine bessere Organisation und unterstützt die Formatierung mit der [Markdown](https://en.wikipedia.org/wiki/Markdown)-Syntax. Notizen werden als Dateien in Ihrer Nextcloud gespeichert, sodass Sie sie mit jedem Nextcloud-Client anzeigen und bearbeiten können. Darüber hinaus ermöglicht eine separate [REST-API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) eine einfache Integration in Apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) sowie [Apps von Drittanbietern](https://github.com/nextcloud/notes/wiki#3rd-party-clients), die einen bequemen Zugriff auf Ihre Nextcloud-Notizen ermöglichen). Weitere Funktionen umfassen das Markieren von Notizen als Favoriten.",
    "Deleted {title}" : "{title} gelöscht",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} Notiz gelöscht","{number} Notizen gelöscht"],
    "Undo Delete" : "Wiederherstellen",
    "Note recovered" : "Notiz wiederhergestellt",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} Notiz wiederhergestellt","{number} Notizen wiederhergestellt"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Es existieren nicht-gespeicherte Notizen. Beim Verlassen der Seite gehen alle Änderungen verloren!",
    "New category" : "Neue Kategorie",
    "Notes settings" : "Notizen-Einstellungen",
    "Please see Nextcloud server log for details." : "Für Details siehe Protokolldatei des Nextcloud-Servers.",
    "Custom" : "Benutzerdefiniert",
    "Rich text" : "Rich-Text",
    "Plain text" : "Klartext",
    "Preview" : "Vorschau",
    "Make the selection bold" : "Die Auswahl fett machen",
    "Make the selection italic" : "Die Auswahl kursiv machen",
    "Wrap the selection in quotes" : "Die Auswahl mit Anführungszeichen einschließen",
    "The selection will be turned into monospace" : "Die Auswahl wird in Monospace umgewandelt",
    "Remove any styles from the selected text" : "All Formatierungen von dem ausgewählten Text entfernen",
    "Makes the current line a list element" : "Macht aus der aktuellen Zeile ein Listenelement",
    "Makes the current line a list element with a number" : "Macht aus der aktuellen Zeile ein nummeriertes Listenelement",
    "Toggle heading for current line" : "Überschrift für die aktuelle Zeile umschalten",
    "Set the current line as a big heading" : "Legen Sie die aktuelle Zeile als große Überschrift fest",
    "Insert link" : "Link einfügen",
    "Insert image" : "Bild einfügen",
    "Switch between editor and viewer" : "Zwischen Editor und Viewer wechseln",
    "Pick a notes folder" : "Einen Notizordner auswählen",
    "Set notes folder" : "Notizordner setzen",
    "General" : "Allgemein",
    "Display" : "Anzeige",
    "File extension" : "Dateierweiterung",
    "For new notes" : "Für neue Notizen",
    "Custom file extension" : "Benutzerdefinierte Dateierweiterung",
    "Files" : "Dateien",
    "Notes folder" : "Notizenordner",
    "Mobile apps" : "Mobile Apps",
    "Shortcuts" : "Tastaturkürzel",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Kategorie \"{category}\" und ihre {count} Notiz löschen?","Kategorie \"{category}\" und ihre {count} Notizen löschen?"],
    "Delete category" : "Kategorie löschen",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "All notes" : "Alle Notizen",
    "Categories" : "Kategorien",
    "Rename category" : "Kategorie umbenennen",
    "Create a sample note with Markdown" : "Eine Beispielnotiz mit Markdown erstellen",
    "No notes yet" : "Noch keine Notizen vorhanden",
    "Select an image" : "Ein Bild auswählen",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Sie können keine Bilder außerhalb Ihres Notizenordners auswählen. Ihr Notizenordner ist: {folder}",
    "Wrong image" : "Falsches Bild",
    "The file was not uploaded. Check your server logs." : "Die Datei wurde nicht hochgeladen. Überprüfen Sie Ihre Serverprotokolle.",
    "Upload image" : "Bild hochladen",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone und iPad",
    "Rich text editor" : "Rich-Text-Editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Sie können jetzt zum benutzerfreundlichen und ablenkungsfreien Rich-Text-Editor wechseln. Dort können Sie Notizen bearbeiten, ohne Markdown-Codes zu sehen.",
    "This option can also be changed later on in the Notes app settings." : "Diese Einstellung kann auch später in den Einstellungen der Notes-App geändert werden.",
    "Keep plain Markdown editor" : "Einfachen Markdown-Editor beibehalten",
    "Use rich editor" : "Rich-Text Editor benutzen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu Favoriten hinzufügen",
    "Error while renaming note." : "Fehler beim Umbenennen der Notiz.",
    "Error during preparing note for deletion." : "Fehler beim Vorbereiten der Notiz für die Löschung.",
    "Share" : "Teilen",
    "Change category" : "Kategorie ändern",
    "Rename" : "Umbenennen",
    "Rename note" : "Notiz umbenennen",
    "Delete note" : "Notiz löschen",
    "Error from Nextcloud server: {msg}" : "Fehler vom Nextcloud-Server: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Die Notiz wurde in einer anderen Sitzung geändert. Bitte wählen Sie aus, welche Version gespeichert werden soll.",
    "Use version from server" : "Version vom Server verwenden",
    "Use current version" : "Aktuelle Version verwenden",
    "Empty note" : "Leere Notiz",
    "Write …" : "Schreibe …",
    "CTRL + /" : "STRG + /",
    "Edit" : "Bearbeiten",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Note is read-only. You cannot change it." : "Notiz ist schreibgeschützt. Sie können sie nicht ändern.",
    "Save failed. Click to retry." : "Speichern fehlgeschlagen. Klicken Sie, um es erneut zu versuchen.",
    "Update conflict. Click for resolving manually." : "Aktualisierungskonflikt. Bitte klicken, um den Konflikt manuell zu lösen.",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "This week" : "Diese Woche",
    "Last week" : "Letzte Woche",
    "This month" : "Dieser Monat",
    "Last month" : "Letzter Monat",
    "Search for notes" : "Nach Notizen suchen",
    "Loading …" : "Lade …",
    "Find in all categories" : "In allen Kategorien suchen",
    "Write down your thoughts without any distractions." : "Die eigenen Gedanken ohne Ablenkung aufschreiben.",
    "Use Markdown markups to style your text." : "Verwenden Sie Markdown, um Ihren Text zu gestalten.",
    "Organize your notes in categories." : "Sortieren Sie Ihre Notizen in Kategorien.",
    "Start writing a note by clicking on “{newnote}”." : "Eine Notiz durch Klick auf \"{newnote}\" erstellen.",
    "Note not found." : "Notiz nicht gefunden.",
    "Note is locked." : "Notiz ist gesperrt.",
    "Insufficient storage." : "Speicherplatz nicht ausreichend.",
    "See JavaScript console and server log for details." : "Siehe JavaScript-Konsole und Serverprotokoll für Details.",
    "Updating settings has failed." : "Aktualisierung der Einstellungen fehlgeschlagen.",
    "Fetching notes for dashboard has failed." : "Laden der Notizen für das Dashboard ist fehlgeschlagen.",
    "Fetching notes has failed." : "Laden der Notizen fehlgeschlagen.",
    "Fetching note {id} has failed." : "Abruf der Notiz {id} fehlgeschlagen.",
    "Refreshing note {id} has failed." : "Aktualisieren der Notiz {id} fehlgeschlagen.",
    "Renaming note {id} has failed." : "Umbenennen der Notiz {id} fehlgeschlagen.",
    "Creating new note has failed." : "Erstellen der neuen Notiz fehlgeschlagen.",
    "Saving note {id} has failed." : "Speichern der Notiz {id} fehlgeschlagen.",
    "Updating title for note {id} has failed." : "Ändern des Titels für Notiz {id} fehlgeschlagen.",
    "Undo delete has failed for note {title}." : "Fehler beim Wiederherstellen der Notiz {title}.",
    "Deleting note {id} has failed." : "Löschen der Notiz {id} fehlgeschlagen.",
    "Toggling favorite for note {id} has failed." : "Die Notiz {id} konnte nicht als Favorit gesetzt werden.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualisierung der Notizen-Kategorie ist gescheitert. Bestehen Schreibrechte für das Zielverzeichnis?",
    "Updating the category for note {id} has failed." : "Ändern der Kategorie für Notiz {id} fehlgeschlagen.",
    "Renaming category \"{category}\" has failed." : "Umbenennen der Kategorie \"{category}\" fehlgeschlagen.",
    "Deleting category \"{category}\" has failed." : "Löschen der Kategorie \"{category}\" fehlgeschlagen.",
    "Uncategorized" : "Ohne Kategorie",
    "Sample note" : "Beispielnotiz",
    "15 January 2021, via Nextcloud Notes" : "15. Januar 2021, über Nextcloud Notes",
    "Me, you, and all our friends!" : "Ich, Sie und all unsere Freunde!",
    "Tasks" : "Aufgaben",
    "Write nice todo lists" : "Schöne Todo-Listen erstellen",
    "Buy Fries" : "Pommes kaufen",
    "Birthdays" : "Geburtstage",
    "Jen, in three days!" : "Jen, in drei Tagen!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Überprüfungsschritte",
    "Turn PC off" : "PC ausschalten",
    "Turn PC on" : "PC einschalten",
    "Then call IT" : "Dann die IT anrufen",
    "Quotes" : "Zitate",
    "Nextcloud, a safe home for all your data" : "Nextcloud, ein sicherer Ort für all Ihre Daten",
    "Development Mode" : "Entwickler-Modus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Es scheint, dass die Notizen-App von einer Entwickler-Quelle installiert wurde. Bitte stattdessen von dem offiziellen <a href=\"%1$s\">Nextcloud-App-Store</a> installieren. Wenn Sie die Notizen-App selbst bauen möchten, folgen Sie bitte den <a href=\"%2$s\">Entwickler-Anleitungen</a>."
},
"nplurals=2; plural=(n != 1);");
