(()=>{var e,o,d={},s={};function _(e){var o=s[e];if(void 0!==o)return o.exports;var t=s[e]={id:e,exports:{}};return d[e].call(t.exports,t,t.exports,_),t.exports}_.m=d,_.n=e=>{var o=e&&e.__esModule?()=>e.default:()=>e;return _.d(o,{a:o}),o},_.d=(e,o)=>{for(var d in o)_.o(o,d)&&!_.o(e,d)&&Object.defineProperty(e,d,{enumerable:!0,get:o[d]})},_.f={},_.e=e=>Promise.all(Object.keys(_.f).reduce((o,d)=>(_.f[d](e,o),o),[])),_.u=e=>"notes-"+e+".js?v="+{"vendors-node_modules_striptags_src_striptags_js-node_modules_nextcloud_vue_dist_assets_NcAvat-e169ac":"ea450c218b1b20e934cb","vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vuex_dist_vuex_esm_js-no-57b2dc":"5ed2054416c5964a7558","dashboard-lazy":"f3844f8d4813ec1b2211","vendors-node_modules_nextcloud_dialogs_dist_chunks__plugin-vue_export-helper-1tPrXgE0_mjs-nod-88e649":"9a4fdedf39c21da39a5c","vendors-node_modules_mdi_js_mdi_js-node_modules_nextcloud_dialogs_dist_chunks_preview-BIbJGxX-8a4549":"adbc58343efb90b20c0d","vendors-node_modules_nextcloud_dialogs_dist_chunks_ConflictPicker-CWBf0soh_mjs":"4be3f43f4b31ffa2d762","vendors-node_modules_floating-ui_dom_dist_floating-ui_dom_mjs":"89042719b37425936226","vendors-node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcTextField-759f92":"4f69ba1fa9be8f3e1a58","vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-C1yRZfLt_mjs":"43b4f3d78d263c493930","node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-7_GNN76e_mjs":"4e5dea25816ef8553eb7","vendors-node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcColorPick-2135ac":"ff6a803f59aa5b8dcec3","vendors-node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcDateTimeP-55190c":"9d5a1bfea0b20c59416b"}[e],_.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),_.o=(e,o)=>Object.prototype.hasOwnProperty.call(e,o),e={},o="notes:",_.l=(d,s,t,n)=>{if(e[d])e[d].push(s);else{var r,a;if(void 0!==t)for(var u=document.getElementsByTagName("script"),i=0;i<u.length;i++){var l=u[i];if(l.getAttribute("src")==d||l.getAttribute("data-webpack")==o+t){r=l;break}}r||(a=!0,(r=document.createElement("script")).charset="utf-8",_.nc&&r.setAttribute("nonce",_.nc),r.setAttribute("data-webpack",o+t),r.src=d),e[d]=[s];var c=(o,s)=>{r.onerror=r.onload=null,clearTimeout(m);var t=e[d];if(delete e[d],r.parentNode&&r.parentNode.removeChild(r),t&&t.forEach(e=>e(s)),o)return o(s)},m=setTimeout(c.bind(null,void 0,{type:"timeout",target:r}),12e4);r.onerror=c.bind(null,r.onerror),r.onload=c.bind(null,r.onload),a&&document.head.appendChild(r)}},_.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},_.p="/apps/notes/js/",(()=>{var e={dashboard:0};_.f.j=(o,d)=>{var s=_.o(e,o)?e[o]:void 0;if(0!==s)if(s)d.push(s[2]);else{var t=new Promise((d,t)=>s=e[o]=[d,t]);d.push(s[2]=t);var n=_.p+_.u(o),r=new Error;_.l(n,d=>{if(_.o(e,o)&&(0!==(s=e[o])&&(e[o]=void 0),s)){var t=d&&("load"===d.type?"missing":d.type),n=d&&d.target&&d.target.src;r.message="Loading chunk "+o+" failed.\n("+t+": "+n+")",r.name="ChunkLoadError",r.type=t,r.request=n,s[1](r)}},"chunk-"+o,o)}};var o=(o,d)=>{var s,t,[n,r,a]=d,u=0;if(n.some(o=>0!==e[o])){for(s in r)_.o(r,s)&&(_.m[s]=r[s]);if(a)a(_)}for(o&&o(d);u<n.length;u++)t=n[u],_.o(e,t)&&e[t]&&e[t][0](),e[t]=0},d=self.webpackChunknotes=self.webpackChunknotes||[];d.forEach(o.bind(null,0)),d.push=o.bind(null,d.push.bind(d))})(),_.nc=void 0,_.nc=btoa(OC.requestToken),_.p=OC.linkTo("notes","js/"),document.addEventListener("DOMContentLoaded",()=>{OCA.Dashboard.register("notes",async e=>{const{default:o}=await Promise.all([_.e("vendors-node_modules_striptags_src_striptags_js-node_modules_nextcloud_vue_dist_assets_NcAvat-e169ac"),_.e("vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vuex_dist_vuex_esm_js-no-57b2dc"),_.e("dashboard-lazy")]).then(_.bind(_,5471)),{default:d}=await Promise.all([_.e("vendors-node_modules_striptags_src_striptags_js-node_modules_nextcloud_vue_dist_assets_NcAvat-e169ac"),_.e("vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vuex_dist_vuex_esm_js-no-57b2dc"),_.e("dashboard-lazy")]).then(_.bind(_,4335));o.mixin({methods:{t,n}});(new(o.extend(d))).$mount(e)})})})();
//# sourceMappingURL=notes-dashboard.js.map?v=7268d279c7a8a7ef1e58