OC.L10N.register(
    "notes",
    {
    "Notes" : "Bilješke",
    "Create new note" : "Stvori novu bilješku",
    "More notes" : "Više bilješki",
    "Reading notes from filesystem has failed." : "Čitanje bilješki iz datotečnog sustava nije uspjelo.",
    "Error" : "Pogreška",
    "New note" : "Nova bilješka",
    "Distraction-free notes and writing" : "Bilješke i pisanje bez ometanja",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikacija Bilješke je aplikacija za bilježenje bez ometanja za [Nextcloud](https://www.nextcloud.com/). Nudi kategorije za bolju organizaciju i podržava oblikovanje pomoću sintakse [Markdown](https://en.wikipedia.org/wiki/Markdown). Bilješke se spremaju kao datoteke u vašem Nextcloudu, pa ih možete pregledavati i uređivati svakim Nextcloud klijentom. Nadalje, zasebni [RESTAPI](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) omogućuje jednostavnu integraciju u aplikacije ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) te [aplikacije trećih strana](https://github.com/nextcloud/notes/wiki#3rd-party-clients) koje omogućuju praktičan pristup vašim Nextcloud bilješkama). Dodatne značajke uključuju označavanje bilješki kao omiljenih.",
    "Deleted {title}" : "Izbrisano {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Izbrisana {number} bilješka","Izbrisane {number} bilješke","Izbrisano {number} bilješki"],
    "Undo Delete" : "Vrati izbrisano",
    "Note recovered" : "Bilješka je oporavljena",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Oporavljena {number} bilješka","Oporavljene {number} bilješke","Oporavljeno {number} bilješki"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Postoje nespremljene bilješke. Ako napustite stranicu, odbacit ćete sve promjene!",
    "Notes settings" : "Postavke Bilješki",
    "Please see Nextcloud server log for details." : "Pojedinosti potražite u zapisniku Nextcloudovog poslužitelja.",
    "Custom" : "Prilagođeno",
    "Rich text" : "Obogaćeni tekst",
    "Plain text" : "Običan tekst",
    "Preview" : "Pretpregled",
    "Make the selection bold" : "Podebljaj odabir",
    "Make the selection italic" : "Ukosi odabir",
    "Wrap the selection in quotes" : "Stavi odabir u navodnike",
    "The selection will be turned into monospace" : "Odabir će se pretvoriti u monospace font",
    "Remove any styles from the selected text" : "Ukloni sva oblikovanja iz odabranog teksta",
    "Makes the current line a list element" : "Pretvori trenutni redak u stavku popisa",
    "Makes the current line a list element with a number" : "Pretvori trenutni redak u numeriranu stavku popisa",
    "Toggle heading for current line" : "Uključi/isključi naslov za trenutni redak",
    "Set the current line as a big heading" : "Postavi trenutni redak kao veliki naslov",
    "Insert link" : "Umetni poveznicu",
    "Insert image" : "Umetni sliku",
    "Switch between editor and viewer" : "Prebaci između uređivača i prikaza",
    "Pick a notes folder" : "Odaberite mapu bilješki",
    "Set notes folder" : "Postavi mapu bilješki",
    "General" : "Općenito",
    "Display" : "Prikaz",
    "File extension" : "Ekstenzija datoteke",
    "For new notes" : "Za nove bilješke",
    "Custom file extension" : "Prilagođena ekstenzija datoteke",
    "Files" : "Datoteke",
    "Notes folder" : "Mapa bilješki",
    "Mobile apps" : "Mobilne aplikacije",
    "Shortcuts" : "Prečaci",
    "Delete" : "Obriši",
    "Cancel" : "Cancel",
    "All notes" : "Sve bilješke",
    "Categories" : "Kategorije",
    "Create a sample note with Markdown" : "Stvori oglednu bilješku s Markdownom",
    "No notes yet" : "Još nema bilješki",
    "Select an image" : "Odaberite sliku",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ne možete odabrati slike izvan svoje mape bilješki. Vaša mapa bilješki je: {folder}",
    "Wrong image" : "Pogrešna slika",
    "The file was not uploaded. Check your server logs." : "Datoteka nije prenesena. Provjerite zapisnike poslužitelja.",
    "Upload image" : "Prenesi sliku",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone i iPad",
    "Rich text editor" : "Uređivač obogaćenog teksta",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Sada možete prijeći na jednostavan i nenametljiv uređivač obogaćenog teksta. Omogućuje uređivanje bilješki bez prikaza Markdown oznaka.",
    "This option can also be changed later on in the Notes app settings." : "Ovu opciju možete promijeniti i kasnije u postavkama aplikacije Bilješke.",
    "Keep plain Markdown editor" : "Zadrži obični Markdown uređivač",
    "Use rich editor" : "Koristi obogaćeni uređivač",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "Error while renaming note." : "Pogreška pri preimenovanju bilješke.",
    "Error during preparing note for deletion." : "Pogreška tijekom pripremanja bilješke za brisanje.",
    "Share" : "Dijeli",
    "Change category" : "Promijeni kategoriju",
    "Rename" : "Preimenuj",
    "Rename note" : "Preimenuj bilješku",
    "Delete note" : "Izbriši bilješku",
    "Error from Nextcloud server: {msg}" : "Pogreška Nextcloudovog poslužitelja: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Bilješka je promijenjena u drugoj sesiji. Odaberite koju inačicu želite spremiti.",
    "Use version from server" : "Koristi verziju s poslužitelja",
    "Use current version" : "Koristi trenutnu verziju",
    "Empty note" : "Prazna bilješka",
    "Write …" : "Napiši...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Uredi",
    "Exit full screen" : "Zatvori prikaz preko cijelog zaslona",
    "Full screen" : "Prikaz preko cijelog zaslona",
    "Note is read-only. You cannot change it." : "Bilješka je samo za čitanje. Ne možete je promijeniti.",
    "Save failed. Click to retry." : "Spremanje nije uspjelo. Kliknite za ponovni pokušaj.",
    "Update conflict. Click for resolving manually." : "Nepodudaranje ažuriranja. Kliknite za ručno otklanjanje nepodudaranja.",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "This week" : "Ovaj tjedan",
    "Last week" : "Prošli tjedan",
    "This month" : "Ovaj mjesec",
    "Last month" : "Prošli mjesec",
    "Search for notes" : "Pretraži bilješke",
    "Loading …" : "Učitavanje…",
    "Find in all categories" : "Pronađi u svim kategorijama",
    "Write down your thoughts without any distractions." : "Zapišite svoje misli bez ometanja.",
    "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
    "Organize your notes in categories." : "Organizirajte svoje bilješke po kategorijama.",
    "Note not found." : "Bilješka nije pronađena.",
    "Note is locked." : "Bilješka je zaključana.",
    "Insufficient storage." : "Nedovoljno prostora za pohranu.",
    "See JavaScript console and server log for details." : "Pojedinosti potražite u JavaScript konzoli i zapisniku poslužitelja.",
    "Updating settings has failed." : "Ažuriranje postavki nije uspjelo.",
    "Fetching notes for dashboard has failed." : "Dohvaćanje bilješki za nadzornu ploču nije uspjelo.",
    "Fetching notes has failed." : "Dohvaćanje bilješki nije uspjelo.",
    "Fetching note {id} has failed." : "Dohvaćanje bilješke {id} nije uspjelo.",
    "Refreshing note {id} has failed." : "Osvježavanje bilješke {id} nije uspjelo.",
    "Renaming note {id} has failed." : "Preimenovanje bilješke {id} nije uspjelo.",
    "Creating new note has failed." : "Stvaranje nove bilješke nije uspjelo.",
    "Saving note {id} has failed." : "Spremanje bilješke {id} nije uspjelo.",
    "Updating title for note {id} has failed." : "Ažuriranje naslova bilješke {id} nije uspjelo.",
    "Undo delete has failed for note {title}." : "Nije uspjelo vraćanje izbrisanog za bilješku {title}.",
    "Deleting note {id} has failed." : "Brisanje bilješke {id} nije uspjelo.",
    "Toggling favorite for note {id} has failed." : "Postavljanje favorita za bilješku {id} nije uspjelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Ažuriranje kategorije bilješke nije uspjelo. Može li se pisati u ciljni direktorij?",
    "Updating the category for note {id} has failed." : "Ažuriranje kategorije za bilješku {id} nije uspjelo.",
    "Uncategorized" : "Nekategorizirani",
    "Sample note" : "Ogledna bilješka",
    "15 January 2021, via Nextcloud Notes" : "15. siječnja 2021., putem Nextcloud Bilješki",
    "Me, you, and all our friends!" : "Ja, ti i svi naši prijatelji!",
    "Tasks" : "Zadaci",
    "Write nice todo lists" : "Napišite lijepe popise zadataka",
    "Buy Fries" : "Kupi pomfrit",
    "Birthdays" : "Rođendani",
    "Jen, in three days!" : "Jen, za tri dana!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973.",
    "Roy, 1979" : "Roy, 1979.",
    "Review Steps" : "Koraci provjere",
    "Turn PC off" : "Isključi računalo",
    "Turn PC on" : "Uključi računalo",
    "Then call IT" : "Zatim nazovi IT",
    "Quotes" : "Citati",
    "Nextcloud, a safe home for all your data" : "Nextcloud, siguran dom za sve vaše podatke",
    "Development Mode" : "Razvojni način rada",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Čini se da je aplikacija za upravljanje bilješkama instalirana iz razvojnog izvora. Instalirajte je iz trgovine aplikacija <a href=\"%1$s\">Nextcloud App Store</a>. Ako želite sami izraditi aplikaciju Notes, slijedite <a href=“%2$s“>upute za razvojne inženjere</a>."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
