OC.L10N.register(
    "notes",
    {
    "Notes" : "Catatan",
    "Create new note" : "Buat catatan baru",
    "More notes" : "Catatan lainnya",
    "Reading notes from filesystem has failed." : "Gagal membaca catatan dari sistem berkas.",
    "Error" : "Kesalahan",
    "New note" : "Catatan baru",
    "Distraction-free notes and writing" : "Catatan dan menulis tanpa gangguan",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikasi Notes adalah aplikasi pencatatan tanpa gangguan untuk [Nextcloud](https://www.nextcloud.com/). Aplikasi ini menyediakan kategori untuk pengorganisasian yang lebih baik dan mendukung pemformatan menggunakan sintaks [Markdown](https://en.wikipedia.org/wiki/Markdown). Catatan disimpan sebagai berkas di Nextcloud Anda, sehingga Anda dapat melihat dan mengeditnya dengan setiap klien Nextcloud. Selain itu, [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) terpisah memungkinkan integrasi yang mudah ke dalam aplikasi ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), serta [aplikasi pihak ketiga](https://github.com/nextcloud/notes/wiki#3rd-party-clients) yang memungkinkan akses yang nyaman ke catatan Nextcloud Anda). Fitur lainnya mencakup menandai catatan sebagai favorit.",
    "Deleted {title}" : "{title} dihapus",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} catatan dihapus"],
    "Undo Delete" : "Urungkan Penghapusan",
    "Note recovered" : "Catatan dipulihkan",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} catatan dipulihkan"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ada catatan yang belum disimpan. Meninggalkan halaman akan membuang semua perubahan!",
    "Notes settings" : "Pengaturan catatan",
    "Please see Nextcloud server log for details." : "Silakan lihat log server Nextcloud untuk detail.",
    "Custom" : "Kustom",
    "Rich text" : "Teks kaya",
    "Plain text" : "Teks polos",
    "Preview" : "Pratinjau",
    "Make the selection bold" : "Buat pilihan menjadi tebal",
    "Make the selection italic" : "Buat pilihan menjadi miring",
    "Wrap the selection in quotes" : "Bungkus pilihan dalam kutipan",
    "The selection will be turned into monospace" : "Pilihan akan diubah menjadi monospace",
    "Remove any styles from the selected text" : "Hapus semua gaya dari teks yang dipilih",
    "Makes the current line a list element" : "Jadikan baris saat ini sebagai elemen daftar",
    "Makes the current line a list element with a number" : "Jadikan baris saat ini sebagai elemen daftar bernomor",
    "Toggle heading for current line" : "Alihkan heading untuk baris saat ini",
    "Set the current line as a big heading" : "Tetapkan baris saat ini sebagai heading besar",
    "Insert link" : "Sisipkan tautan",
    "Insert image" : "Sisipkan gambar",
    "Switch between editor and viewer" : "Beralih antara editor dan penampil",
    "Pick a notes folder" : "Pilih folder catatan",
    "Set notes folder" : "Atur folder catatan",
    "General" : "Umum",
    "Display" : "Tampilan",
    "File extension" : "Ekstensi berkas",
    "For new notes" : "Untuk catatan baru",
    "Custom file extension" : "Ekstensi berkas kustom",
    "Files" : "Berkas",
    "Notes folder" : "Folder catatan",
    "Mobile apps" : "Aplikasi seluler",
    "Shortcuts" : "Pintasan",
    "Delete" : "Delete",
    "Cancel" : "Membatalkan",
    "All notes" : "Semua catatan",
    "Categories" : "Kategori",
    "Create a sample note with Markdown" : "Buat contoh catatan dengan Markdown",
    "No notes yet" : "Belum ada catatan",
    "Select an image" : "Pilih gambar",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Anda tidak dapat memilih gambar di luar folder catatan Anda. Folder catatan Anda adalah: {folder}",
    "Wrong image" : "Gambar salah",
    "The file was not uploaded. Check your server logs." : "Berkas tidak diunggah. Periksa log server Anda.",
    "Upload image" : "Unggah gambar",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone dan iPad",
    "Rich text editor" : "Editor teks kaya",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Sekarang Anda dapat beralih menggunakan editor teks kaya yang mudah digunakan dan tanpa gangguan. Editor ini memungkinkan Anda mengedit catatan tanpa melihat tanda-tanda Markdown apa pun.",
    "This option can also be changed later on in the Notes app settings." : "Opsi ini juga dapat diubah nanti di pengaturan aplikasi Notes.",
    "Keep plain Markdown editor" : "Pertahankan editor Markdown polos",
    "Use rich editor" : "Gunakan editor teks kaya",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "Error while renaming note." : "Kesalahan saat mengganti nama catatan.",
    "Error during preparing note for deletion." : "Kesalahan saat menyiapkan catatan untuk dihapus.",
    "Share" : "Bagikan",
    "Change category" : "Ubah kategori",
    "Rename" : "Ganti nama",
    "Rename note" : "Ganti nama catatan",
    "Delete note" : "Hapus catatan",
    "Error from Nextcloud server: {msg}" : "Kesalahan dari server Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Catatan telah diubah dalam sesi lain. Silakan pilih versi mana yang harus disimpan.",
    "Use version from server" : "Gunakan versi dari server",
    "Use current version" : "Gunakan versi saat ini",
    "Empty note" : "Catatan kosong",
    "Write …" : "Tulis …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Sunting",
    "Exit full screen" : "Keluar layar penuh",
    "Full screen" : "Layar penuh",
    "Note is read-only. You cannot change it." : "Catatan hanya-baca. Anda tidak dapat mengubahnya.",
    "Save failed. Click to retry." : "Penyimpanan gagal. Klik untuk mencoba lagi.",
    "Update conflict. Click for resolving manually." : "Konflik pembaruan. Klik untuk menyelesaikan secara manual.",
    "Today" : "Hari ini",
    "Yesterday" : "Kemarin",
    "This week" : "Pekan ini",
    "Last week" : "Minggu lalu",
    "This month" : "Bulan ini",
    "Last month" : "Bulan lalu",
    "Search for notes" : "Cari catatan",
    "Loading …" : "Memuat …",
    "Find in all categories" : "Cari di semua kategori",
    "Write down your thoughts without any distractions." : "Tuliskan pikiran Anda tanpa gangguan apa pun.",
    "Use Markdown markups to style your text." : "Gunakan markup Markdown untuk menata teks Anda.",
    "Organize your notes in categories." : "Atur catatan Anda dalam kategori.",
    "Note not found." : "Catatan tidak ditemukan.",
    "Note is locked." : "Catatan terkunci.",
    "Insufficient storage." : "Penyimpanan tidak mencukupi.",
    "See JavaScript console and server log for details." : "Lihat konsol JavaScript dan log server untuk detail.",
    "Updating settings has failed." : "Gagal memperbarui pengaturan.",
    "Fetching notes for dashboard has failed." : "Gagal mengambil catatan untuk dasbor.",
    "Fetching notes has failed." : "Gagal mengambil catatan.",
    "Fetching note {id} has failed." : "Gagal mengambil catatan {id}.",
    "Refreshing note {id} has failed." : "Gagal menyegarkan catatan {id}.",
    "Renaming note {id} has failed." : "Gagal mengganti nama catatan {id}.",
    "Creating new note has failed." : "Gagal membuat catatan baru.",
    "Saving note {id} has failed." : "Gagal menyimpan catatan {id}.",
    "Updating title for note {id} has failed." : "Gagal memperbarui judul untuk catatan {id}.",
    "Undo delete has failed for note {title}." : "Gagal mengurungkan penghapusan untuk catatan {title}.",
    "Deleting note {id} has failed." : "Gagal menghapus catatan {id}.",
    "Toggling favorite for note {id} has failed." : "Gagal mengubah status favorit untuk catatan {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Gagal memperbarui kategori catatan. Apakah direktori tujuan dapat ditulisi?",
    "Updating the category for note {id} has failed." : "Gagal memperbarui kategori untuk catatan {id}.",
    "Uncategorized" : "Tanpa kategori",
    "Sample note" : "Contoh catatan",
    "15 January 2021, via Nextcloud Notes" : "15 Januari 2021, melalui Nextcloud Notes",
    "Me, you, and all our friends!" : "Saya, kamu, dan semua teman kita!",
    "Tasks" : "Tugas",
    "Write nice todo lists" : "Buat daftar tugas yang rapi",
    "Buy Fries" : "Beli Kentang Goreng",
    "Birthdays" : "Ulang tahun",
    "Jen, in three days!" : "Jen, tiga hari lagi!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Tinjau langkah-langkah",
    "Turn PC off" : "Matikan PC",
    "Turn PC on" : "Nyalakan PC",
    "Then call IT" : "Lalu hubungi IT",
    "Quotes" : "Kutipan",
    "Nextcloud, a safe home for all your data" : "Nextcloud, rumah yang aman untuk semua data Anda",
    "Development Mode" : "Mode Pengembangan",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Tampaknya aplikasi Notes dipasang dari sumber pengembangan. Silakan pasang dari <a href=\"%1$s\">Nextcloud App Store</a> resmi. Jika Anda ingin membangun aplikasi Notes sendiri, silakan ikuti <a href=\"%2$s\">instruksi pengembang</a>."
},
"nplurals=1; plural=0;");
