OC.L10N.register(
    "notes",
    {
    "Notes" : "Nota",
    "Error" : "Ralat",
    "New note" : "Note baharu",
    "Files" : "Fail",
    "Delete" : "Delete",
    "Cancel" : "Batal",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Kongsi",
    "Rename" : "Rename",
    "Delete note" : "Hapus nota",
    "Edit" : "Sunting",
    "Today" : "Hari ini",
    "Yesterday" : "Semalam"
},
"nplurals=1; plural=0;");
