OC.L10N.register(
    "notes",
    {
    "Notes" : "Jegyzetek",
    "Create new note" : "Új jegyzet létrehozása",
    "More notes" : "További jegyzetek",
    "Reading notes from filesystem has failed." : "A jegyzetek olvasása a fájlrendszerről sikertelen.",
    "Error" : "Hiba",
    "New note" : "Új jegyzet",
    "Distraction-free notes and writing" : "Figyelemelterelés nélküli jegyzetelés és írás",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "A Jegyzetek alkalmazás egy figyelemelterelés-mentes jegyzetelő alkalmazás a [Nextcloudhoz](https://www.nextcloud.com/). Kategóriákat biztosít a jobb rendszerezéshez, és támogatja a [Markdown](https://en.wikipedia.org/wiki/Markdown) szintaxisú formázással. A jegyzeteket fájlként menti a Nextcloud, így megtekintheti és szerkesztheti őket bármely Nextcloud klienssel. Ezenkívül egy külön [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) lehetővé teszi az egyszerű integrációt alkalmazásokba ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), valamint [harmadik felek alkalmazásai](https://github.com/nextcloud/notes/wiki#3rd-party-clients) vannak jegyzet alkalmazások, melyek kényelmes hozzáférést biztosítanak a nextcloudos jegyzeteihez). A további funkciók közé tartozik a jegyzetek kedvencként való megjelölése.",
    "Deleted {title}" : "{title} törölve",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} jegyzet törölve","{number} jegyzet törölve"],
    "Undo Delete" : "Törlés visszavonása",
    "Note recovered" : "Jegyzet helyreállítva",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} jegyzet helyreállítva","{number} jegyzet helyreállítva"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "El nem mentett jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
    "Notes settings" : "Jegyzetek beállításai",
    "Please see Nextcloud server log for details." : "További részletekért tekintse meg a Nextcloud kiszolgálónaplóját.",
    "Custom" : "Egyéni",
    "Rich text" : "Formázott szöveg",
    "Plain text" : "Egyszerű szöveg",
    "Preview" : "Előnézet",
    "Make the selection bold" : "A kijelölés félkövérré alakítása",
    "Make the selection italic" : "A kijelölés dőltté alakítása",
    "Wrap the selection in quotes" : "A kijelölés idézőjelek közé rakása",
    "The selection will be turned into monospace" : "A kijelölés rögzített szélességűvé lesz alakítva",
    "Remove any styles from the selected text" : "Összes stílus eltávolítása a kijelölt szövegről",
    "Makes the current line a list element" : "A jelenlegi sor egy listaelemmé alakítja",
    "Makes the current line a list element with a number" : "A jelenlegi sor egy számozott listaelemmé alakítja",
    "Toggle heading for current line" : "A jelenlegi sor címsorrá alakítása",
    "Set the current line as a big heading" : "A jelenlegi sor nagy címsorrá alakítása",
    "Insert link" : "Hivatkozás beszúrása",
    "Insert image" : "Kép beszúrása",
    "Switch between editor and viewer" : "Váltás a szerkesztő és a megjelenítő között",
    "Pick a notes folder" : "Válasszon jegyzetmappát",
    "Set notes folder" : "Jegyzetmappa beállítása",
    "General" : "Általános",
    "Display" : "Megjelenítés",
    "File extension" : "Fájlkiterjesztés",
    "For new notes" : "Új jegyzetekhez",
    "Custom file extension" : "Egyéni fájlkiterjesztés",
    "Files" : "Fájlok",
    "Notes folder" : "Jegyzetek mappa",
    "Mobile apps" : "Mobilalkalmazások",
    "Shortcuts" : "Gyorsbillentyűk",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "All notes" : "Összes jegyzet",
    "Categories" : "Kategóriák",
    "Create a sample note with Markdown" : "Új példajegyzet létrehozása Markdownnal",
    "No notes yet" : "Még nincs jegyzet",
    "Select an image" : "Válasszon képet",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nem választhat a jegyzeteken mappán kívül lévő képet. Az Ön jegyzetek mappája: {folder}",
    "Wrong image" : "Hibás kép",
    "The file was not uploaded. Check your server logs." : "A fájl nem lett feltöltve. Nézze meg a kiszolgálónaplókat.",
    "Upload image" : "Kép feltöltése",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone és iPad",
    "Rich text editor" : "Formázott szöveges szerkesztő",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Most átválthat a könnyen használható és zavaró tényezőktől mentes formázott szöveges szerkesztőre. Lehetővé teszi, hogy úgy szerkessze a jegyzeteit, hogy nem lát Markdown-jelöléseket.",
    "This option can also be changed later on in the Notes app settings." : "Ez a beállítás a Jegyzetek alkalmazás beállításaiban is módosítható.",
    "Keep plain Markdown editor" : "Egyszerű Mardown-szerkesztő megtartása",
    "Use rich editor" : "Formázott szöveges szerkesztő használata",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "Error while renaming note." : "Hiba a jegyzet átnevezése során.",
    "Error during preparing note for deletion." : "Hiba történt a jegyzettörlésre felkészülés során.",
    "Share" : "Megosztás",
    "Change category" : "Kategória módosítása",
    "Rename" : "Átnevezés",
    "Rename note" : "Jegyzet átnevezése",
    "Delete note" : "Jegyzet törlése",
    "Error from Nextcloud server: {msg}" : "Nextcloud kiszolgálói hiba: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "A jegyzet egy másik munkamenetben megváltozott. Válasszon, hogy melyik verzió legyen mentve.",
    "Use version from server" : "Kiszolgáló változatának használata",
    "Use current version" : "Jelenlegi verzió használata",
    "Empty note" : "Üres jegyzet",
    "Write …" : "Írás…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Szerkesztés",
    "Exit full screen" : "Kilépés a teljes képernyőből",
    "Full screen" : "Teljes képernyő",
    "Note is read-only. You cannot change it." : "A jegyzet írásvédett. Nem változtathat rajta.",
    "Save failed. Click to retry." : "A mentés sikertelen. Próbálja újra.",
    "Update conflict. Click for resolving manually." : "Frissítési ütközés. Kattintson ide a probléma kézi megoldásához.",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "This week" : "Ez a hét",
    "Last week" : "Előző hét",
    "This month" : "Ez a hónap",
    "Last month" : "Előző hónap",
    "Search for notes" : "Jegyzetek keresése",
    "Loading …" : "Betöltés…",
    "Find in all categories" : "Keresés az összes kategóriában",
    "Write down your thoughts without any distractions." : "Írd le a gondolatait, zavaró tényezők nélkül.",
    "Use Markdown markups to style your text." : "Használjon Markdown leírást a szövege formázásához.",
    "Organize your notes in categories." : "Rendezze kategóriákba a jegyzeteit.",
    "Note not found." : "A jegyzet nem található.",
    "Note is locked." : "A jegyzet zárolva van.",
    "Insufficient storage." : "Nincs elegendő tárhely a mentéshez.",
    "See JavaScript console and server log for details." : "További a részletekért nézze meg a JavaScript konzolt és a kiszolgálónaplót.",
    "Updating settings has failed." : "A beállítások frissítése sikertelen.",
    "Fetching notes for dashboard has failed." : "Az irányítópult jegyzeteinek lekérése sikertelen.",
    "Fetching notes has failed." : "A jegyzetek lekérése sikertelen.",
    "Fetching note {id} has failed." : "A(z) {id} jegyzet lekérése sikertelen.",
    "Refreshing note {id} has failed." : "A(z) {id} jegyzet újratöltése sikertelen.",
    "Renaming note {id} has failed." : "A(z) {id} jegyzet átnevezése sikertelen.",
    "Creating new note has failed." : "Új jegyzet létrehozása sikertelen.",
    "Saving note {id} has failed." : "A(z) {id} jegyzet mentése sikertelen.",
    "Updating title for note {id} has failed." : "A(z) {id} jegyzet címének frissítése sikertelen.",
    "Undo delete has failed for note {title}." : "A(z) {title} jegyzet törlésének visszavonása sikertelen.",
    "Deleting note {id} has failed." : "A(z) {id} jegyzet törlése sikertelen.",
    "Toggling favorite for note {id} has failed." : "A(z) {id} jegyzet hozzáadása a kedvencekhez sikertelen.",
    "Updating the note's category has failed. Is the target directory writable?" : "A jegyzet kategóriájának frissítése sikertelen. Írható a célkönyvtár?",
    "Updating the category for note {id} has failed." : "A jegyzet kategóriájának módosítása sikertelen.",
    "Uncategorized" : "Kategorizálatlan",
    "Sample note" : "Mintajegyzet",
    "15 January 2021, via Nextcloud Notes" : "2021. január 15., a Nextcloud Jegyzetek használatával",
    "Me, you, and all our friends!" : "Én, te és az összes barátunk!",
    "Tasks" : "Feladatok",
    "Write nice todo lists" : "Írjon szép teendőlistákat",
    "Buy Fries" : "Sültkrumplit venni",
    "Birthdays" : "Születésnapok",
    "Jen, in three days!" : "Jen, három nap múlva!",
    "Moss, 21.03.1973" : "Moss, 1973. 03. 21.",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Átnézési lépések",
    "Turn PC off" : "Számítógép kikapcsolása",
    "Turn PC on" : "Számítógép bekapcsolása",
    "Then call IT" : "Majd hívni az IT-t",
    "Quotes" : "Árajánlatok",
    "Nextcloud, a safe home for all your data" : "Nextcloud, egy biztonságos hely az adatai számára",
    "Development Mode" : "Fejlesztői mód",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Úgy tűnik, hogy a Jegyzetek alkalmazást fejlesztői forrásból telepítették. Inkább telepítse a hivatalos <a href=\"%1$s\">Nextcloud alkalmazástárból </a>. Ha Ön szeretné összeállítani a Jegyzetek alkalmazást, akkor kövesse a <a href=\"%2$s\">fejlesztői utasításokat</a>."
},
"nplurals=2; plural=(n != 1);");
