/**
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

.icon-notes {
	background-image: url(../img/notes-dark.svg);
	filter: var(--background-invert-if-dark);
}

.icon-notes-trans {
	background-image: url(../img/notes-trans.svg);
	filter: var(--background-invert-if-dark);
}

