OC.L10N.register(
    "notes",
    {
    "Notes" : "Нотатки",
    "Create new note" : "Створити нову нотатку",
    "More notes" : "Більше нотаток",
    "Reading notes from filesystem has failed." : "Не вдалося прочитати нотатки з файлової системи.",
    "Error" : "Помилка",
    "New note" : "Нова нотатка",
    "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Додаток Notes — це додаток для створення нотаток без відволікань для [Nextcloud](https://www.nextcloud.com/). Він надає категорії для кращої організації та підтримує форматування за допомогою синтаксису [Markdown](https://en.wikipedia.org/wiki/Markdown). Нотатки зберігаються як файли у вашому Nextcloud, тому ви можете переглядати та редагувати їх за допомогою будь-якого клієнта Nextcloud. Крім того, окремий [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) дозволяє легко інтегрувати додаток у програми ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), а також [сторонніх додатків](https://github.com/nextcloud/notes/wiki#3rd-party-clients), що забезпечують зручний доступ до ваших нотаток Nextcloud). Додаткові функції включають позначення нотаток як улюблених.",
    "Deleted {title}" : "Вилучено {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Вилучено {number} нотатку","Вилучено {number} нотатки","Вилучено {number} нотаток","Вилучено {number} нотаток"],
    "Undo Delete" : "Повернути вилучення",
    "Note recovered" : "Примітку відновлено",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатку","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
    "Notes settings" : "Налаштування",
    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера хмари Nextcloud для отримання додаткової інформації.",
    "Custom" : "Нестандартний",
    "Rich text" : "Розширений текст",
    "Plain text" : "Звичайний текст",
    "Preview" : "Перегляд",
    "Make the selection bold" : "Зробити виділене грубим",
    "Make the selection italic" : "Зробити виділене курсивом",
    "Wrap the selection in quotes" : "Додати лапки до виділеного фрагменту",
    "The selection will be turned into monospace" : "Перетворити шрифт виділеного тексту у моноширинний",
    "Remove any styles from the selected text" : "Прибрати стилі з виділеного тексту",
    "Makes the current line a list element" : "Зробити рядок елементом списку",
    "Makes the current line a list element with a number" : "Зробити рядок елементом нумерованого списку",
    "Toggle heading for current line" : "Зробити рядок заголовком",
    "Set the current line as a big heading" : "Зробити рядок великим заголовком",
    "Insert link" : "Вставити посилання",
    "Insert image" : "Додати зображення",
    "Switch between editor and viewer" : "Перемкнути редактор та переглядач",
    "Pick a notes folder" : "Виберіть каталог для нотаток",
    "Set notes folder" : "Встановити каталог для нотаток",
    "General" : "Загальне",
    "Display" : "Дисплей",
    "File extension" : "Розширення",
    "For new notes" : "Для нових нотаток",
    "Custom file extension" : "Власне розширення файлів",
    "Files" : "Робота з файлами",
    "Notes folder" : "Папка Нотатки",
    "Mobile apps" : "Застосунки",
    "Shortcuts" : "Скорочення",
    "Delete" : "Вилучити",
    "Cancel" : "Скасувати",
    "All notes" : "Усі нотатки",
    "Categories" : "Категорії",
    "Create a sample note with Markdown" : "Створіть зразок примітки з використанням текстової розмітки",
    "No notes yet" : "Нотатки відсутні",
    "Select an image" : "Виберіть зображення",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ви не можете вибрати зображення за межами каталогу з нотатками. Ваш каталог нотаток: {folder}",
    "Wrong image" : "Недійсне зображення",
    "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали сервера.",
    "Upload image" : "Завантажити зображення",
    "iPhone and iPad" : "iPhone та iPad",
    "Rich text editor" : "Редактор з форматуванням",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ви можете почати використовувати простий у користуванні редактор форматованого тексту, який дозволить вводити текст без службових символів позначення форматування.",
    "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
    "Keep plain Markdown editor" : "Використовувати простий редактор розмітки",
    "Use rich editor" : "Використовувати редактор з форматуванням",
    "Remove from favorites" : "Прибрати зірочку",
    "Add to favorites" : "Додати зірочку",
    "Error while renaming note." : "Помилка під час перейменування нотатки.",
    "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
    "Share" : "Поділитися",
    "Change category" : "Змінити категорію",
    "Rename" : "Перейменувати",
    "Rename note" : "Перейменувати нотатку",
    "Delete note" : "Вилучити",
    "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
    "Use version from server" : "Використовувати віддалену версію",
    "Use current version" : "Використовувати поточну версію",
    "Empty note" : "Порожня нотатка",
    "Write …" : "Напишіть …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Редагувати",
    "Exit full screen" : "Вийти з повноекранного режиму",
    "Full screen" : "Повноекранний режим",
    "Note is read-only. You cannot change it." : "Нотатка доступна лише для читання. Ви не можете це змінити.",
    "Save failed. Click to retry." : "Не вдалося зберегти. Клацніть, щоб повторити спробу.",
    "Update conflict. Click for resolving manually." : "Конфлікт під час оновлення. Клацніть, щоб прийняти рішення вручну.",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "This week" : "Цього тижня",
    "Last week" : "Минулого тижня",
    "This month" : "Цього місяця",
    "Last month" : "Минулого місяця",
    "Search for notes" : "Пошук нотаток",
    "Loading …" : "Завантаження ...",
    "Find in all categories" : "Шукати в усіх категоріях",
    "Write down your thoughts without any distractions." : "Занотовуйте свої думки, не відволікаючись.",
    "Use Markdown markups to style your text." : "Використовувати текстову розмітку для стилізації тексту.",
    "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
    "Note not found." : "Нотатку не знайдено.",
    "Note is locked." : "Нотатку заблоковано.",
    "Insufficient storage." : "Недостатньо місця для зберігання.",
    "See JavaScript console and server log for details." : "Додаткову інформацію дивіться у консолі JavaScript та журналі сервера.",
    "Updating settings has failed." : "Не вдалося оновити налаштування.",
    "Fetching notes for dashboard has failed." : "Не вдалося отримати нотатки у інформаційній панелі.",
    "Fetching notes has failed." : "Помилка під час отримання нотаток.",
    "Fetching note {id} has failed." : "Не вдалося отримати нотатку {id}.",
    "Refreshing note {id} has failed." : "Не вдалося оновити нотатку {id}.",
    "Renaming note {id} has failed." : "Не вдалося перейменувати нотатку {id}.",
    "Creating new note has failed." : "Не вдалося створити нотатку.",
    "Saving note {id} has failed." : "Не вдалося зберегти нотатку {id}.",
    "Updating title for note {id} has failed." : "Помилка оновлення назви нотатки {id}.",
    "Undo delete has failed for note {title}." : "Не вдалося скасувати вилучення нотатки {title}.",
    "Deleting note {id} has failed." : "Не вдалося вилучити нотатку {id}.",
    "Toggling favorite for note {id} has failed." : "Помилка додавання зірочки до нотатки {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Не вдалося оновити категорію нотатки. Перевірте, чи доступний каталог нотаток для запису?",
    "Updating the category for note {id} has failed." : "Не вдалося оновити категорію для примітки {id}.",
    "Uncategorized" : "Некатегоризоване",
    "Sample note" : "Приклад нотатки",
    "15 January 2021, via Nextcloud Notes" : "15 січня 2021 р., у Нотатках Nextcloud",
    "Me, you, and all our friends!" : "Я, ти та всі наші друзі!",
    "Tasks" : "Завдання",
    "Write nice todo lists" : "Написати зручний список справ",
    "Buy Fries" : "Купити пиріжків",
    "Birthdays" : "Дні народження",
    "Jen, in three days!" : "Петро, через три дні!",
    "Moss, 21.03.1973" : "Іванка, 21.03.1973",
    "Roy, 1979" : "Роман, 1979",
    "Review Steps" : "Переглянути послідовність кроків",
    "Turn PC off" : "Вимкнути комп'ютер",
    "Turn PC on" : "Увімкнути комп'ютер",
    "Then call IT" : "Далі зателефонуйте до служби підтримки",
    "Quotes" : "Цитати",
    "Nextcloud, a safe home for all your data" : "Хмара у Nextcloud, безпечний простір для ваших даних",
    "Development Mode" : "Режим розробки",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Схоже, застосунок для нотаток було встановлено з джерела розробки. Установіть його з офіційного <a href=\"%1$s\">каталогу застосунків Nextcloud</a>. Якщо ви хочете збілдити застосунок \"Нотатки\" самостійно, дотримуйтесь <a href=\"%2$s\">інструкцій розробника</a>."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
