OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Create new note" : "Criar nova nota",
    "More notes" : "Mais notas",
    "Reading notes from filesystem has failed." : "Falha ao ler notas do sistema de arquivos.",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Distraction-free notes and writing" : "Notas e escrita sem distração",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "O aplicativo Notas é um aplicativo de notas sem distrações para o [Nextcloud](https://www.nextcloud.com/). Ele oferece categorias para melhor organização e suporta formatação usando a sintaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). As notas são salvas como arquivos no Nextcloud, para que você possa visualizá-las e editá-las com qualquer cliente Nextcloud. Além disso, uma [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) separada permite uma fácil integração em aplicativos ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), bem como [aplicativos de terceiros](https://github.com/nextcloud/notes/wiki#3rd-party-clients) que permitem acesso conveniente às suas notas do Nextcloud). Outros recursos incluem marcar notas como favoritas.",
    "Deleted {title}" : "{title} excluído",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} nota apagada","{number} notas apagadas","{number} notas apagadas"],
    "Undo Delete" : "Desfazer Exclusão",
    "Note recovered" : "Nota recuperada",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} nota recuperada","{number} notas recuperadas","{number} notas recuperadas"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Há notas não salvas. Sair da página descartará todas as alterações!",
    "New category" : "Nova categoria",
    "Notes settings" : "Configurações de notas",
    "Please see Nextcloud server log for details." : "Verifique os logs do servidor Nextcloud para detalhes.",
    "Custom" : "Personalizada",
    "Rich text" : "Texto rich",
    "Plain text" : "Texto puro",
    "Preview" : "Pré-visualização",
    "Make the selection bold" : "Tornar seleção negrito",
    "Make the selection italic" : "Tornar seleção itálico",
    "Wrap the selection in quotes" : "Colocar seleção entre aspas",
    "The selection will be turned into monospace" : "A seleção será transformada em monoespaçado",
    "Remove any styles from the selected text" : "Remover todos os estilos do texto selecionado",
    "Makes the current line a list element" : "Torna a linha atual um elemento de lista",
    "Makes the current line a list element with a number" : "Torna a linha atual um elemento de lista com um número",
    "Toggle heading for current line" : "Alternar o título para a linha atual",
    "Set the current line as a big heading" : "Definir a linha atual como um cabeçalho grande",
    "Insert link" : "Inserir link",
    "Insert image" : "Inserir imagem",
    "Switch between editor and viewer" : "Alternar entre editor e visualizador",
    "Pick a notes folder" : "Escolha uma pasta de notas",
    "Set notes folder" : "Definir pasta de notas",
    "General" : "Geral",
    "Display" : "Exibição",
    "File extension" : "Extensão de arquivo",
    "For new notes" : "Para novas notas",
    "Custom file extension" : "Extensão de arquivo personalizada",
    "Files" : "Arquivos",
    "Notes folder" : "Pasta de notas",
    "Mobile apps" : "Aplicativos móveis",
    "Shortcuts" : "Atalhos",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Excluir a categoria \"{category}\" sua {count} nota","Excluir a categoria \"{category}\" suas {count} de notas","Excluir a categoria \"{category}\" suas {count} notas"],
    "Delete category" : "Excluir categoria",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "All notes" : "Todas as notas",
    "Categories" : "Categorias",
    "Rename category" : "Renomear categoria",
    "Create a sample note with Markdown" : "Criar uma nota de amostra com Markdown",
    "No notes yet" : "Nenhuma nota ainda",
    "Select an image" : "Selecione uma imagem",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Você não pode selecionar imagens fora de sua pasta de notas. Sua pasta de notas é: {folder}",
    "Wrong image" : "Imagem errada",
    "The file was not uploaded. Check your server logs." : "O arquivo não foi carregado. Verifique os logs do seu servidor.",
    "Upload image" : "Enviar imagem",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone e iPad",
    "Rich text editor" : "Editor de texto rich",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Agora você pode alternar para usar o editor de texto rich fácil de usar e livre de distrações. Ele permite que você edite notas sem ver nenhuma marca de Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Esta opção também pode ser alterada posteriormente nas configurações do aplicativo Notas.",
    "Keep plain Markdown editor" : "Manter o editor de Markdown simples",
    "Use rich editor" : "Usar editor de texto rich",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Error while renaming note." : "Erro ao renomear nota.",
    "Error during preparing note for deletion." : "Erro ao preparar nota para exclusão.",
    "Share" : "Compartilhar",
    "Change category" : "Alterar categoria",
    "Rename" : "Renomear",
    "Rename note" : "Renomear nota",
    "Delete note" : "Excluir nota",
    "Error from Nextcloud server: {msg}" : "Erro do servidor Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "A nota foi alterada em outra sessão. Escolha qual versão deve ser salva.",
    "Use version from server" : "Use a versão do servidor",
    "Use current version" : "Use a versão atual",
    "Empty note" : "Nota vazia",
    "Write …" : "Escrever...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Sair da tela inteira",
    "Full screen" : "Tela inteira",
    "Note is read-only. You cannot change it." : "Esta nota é apenas para leitura. Você não pode mudá-la.",
    "Save failed. Click to retry." : "Falha ao salvar. Clique para retentar.",
    "Update conflict. Click for resolving manually." : "Conflito de atualização. Clique para resolver manualmente.",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "This week" : "Esta semana",
    "Last week" : "Última semana",
    "This month" : "Este mês",
    "Last month" : "Último mês",
    "Search for notes" : "Pesquisar notas",
    "Loading …" : "Carregando...",
    "Find in all categories" : "Pesquisar em todas as categorias",
    "Write down your thoughts without any distractions." : "Anote seus pensamentos sem distrações.",
    "Use Markdown markups to style your text." : "Use marcações Markdown para estilizar seu texto.",
    "Organize your notes in categories." : "Organize suas notas em categorias.",
    "Start writing a note by clicking on “{newnote}”." : "Comece a escrever uma nota clicando em \"{newnote}\".",
    "Note not found." : "Nota não encontrada.",
    "Note is locked." : "A nota está trancada.",
    "Insufficient storage." : "Armazenamento insuficiente.",
    "See JavaScript console and server log for details." : "Veja o console JavaScript console e os logs do servidor para detalhes.",
    "Updating settings has failed." : "A atualização das configurações falhou.",
    "Fetching notes for dashboard has failed." : "A obtenção de notas para o painel falhou.",
    "Fetching notes has failed." : "A busca de notas falhou.",
    "Fetching note {id} has failed." : "A busca da nota {id} falhou.",
    "Refreshing note {id} has failed." : "Falha na atualização da nota {id}.",
    "Renaming note {id} has failed." : "Falha ao renomear a nota {id}.",
    "Creating new note has failed." : "A criação de uma nova nota falhou.",
    "Saving note {id} has failed." : "Erro ao salvar a nota {id}.",
    "Updating title for note {id} has failed." : "A atualização do título da nota {id} falhou.",
    "Undo delete has failed for note {title}." : "Falha ao desfazer exclusão da nota {title}.",
    "Deleting note {id} has failed." : "A exclusão da nota {id} falhou.",
    "Toggling favorite for note {id} has failed." : "A alternância de favoritos para a nota {id} falhou.",
    "Updating the note's category has failed. Is the target directory writable?" : "A atualização da categoria da nota falhou. O diretório de destino é gravável?",
    "Updating the category for note {id} has failed." : "A atualização da categoria da nota {id} falhou.",
    "Renaming category \"{category}\" has failed." : "A renomeação da categoria \"{category}\" falhou.",
    "Deleting category \"{category}\" has failed." : "A remoção da categoria \"{category}\" falhou.",
    "Uncategorized" : "Sem categoria",
    "Sample note" : "Nota de amostra",
    "15 January 2021, via Nextcloud Notes" : "15 de janeiro de 2021, via Nextcloud Notas",
    "Me, you, and all our friends!" : "Eu, você e todos os nossos amigos!",
    "Tasks" : "Tarefas",
    "Write nice todo lists" : "Escreva boas listas de tarefas",
    "Buy Fries" : "Compre Batatas Fritas",
    "Birthdays" : "Aniversários",
    "Jen, in three days!" : "Jen, em três dias!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Etapas de Revisão",
    "Turn PC off" : "Desligue o computador",
    "Turn PC on" : "Ligue o computador",
    "Then call IT" : "Depois, ligue para TI",
    "Quotes" : "Citações",
    "Nextcloud, a safe home for all your data" : "Nextcloud, um lar seguro para todos os seus dados",
    "Development Mode" : "Modo de Desenvolvimento",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que o aplicativo Notes foi instalado a partir de uma fonte de desenvolvimento. Ao invés disso, instale-o a partir da <a href=\"%1$s\">Loja de Aplicativos Nextcloud</a> oficial. Se deseja criar o aplicativo Notes você mesmo, siga as <a href=\"%2$s\">instruções do desenvolvedor</a>."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
