OC.L10N.register(
    "notes",
    {
    "Notes" : "Белешке",
    "Create new note" : "Креирајте нову белешку",
    "More notes" : "Још белешки",
    "Reading notes from filesystem has failed." : "Читање белешки са система фајлова није успело.",
    "Error" : "Грешка",
    "New note" : "Нова белешка",
    "Distraction-free notes and writing" : "Белешке и писање без ометања",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Апликација Белешке је апликација за хватање белешки без ометања прављена за [Nextcloud](https://www.nextcloud.com/). Обезбеђује категорије ради лакше организације и форматирање употребом [Markdown](https://en.wikipedia.org/wiki/Markdown) синтаксе. Белешке се чувају као фајлови у вашем Nextcloud, тако да их можете видети и мењати са сваким Nextcloud клијентом. Такође, посебан [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) омогућава лаку интеграцију са апликацијама [Андроид](https://github.com/nextcloud/notes-android), за [iOS](https://github.com/nextcloud/notes-ios), као и [апликацијама треће стране](https://github.com/nextcloud/notes/wiki#3rd-party-clients) које омогућавају једноставан приступ вашим Nextcloud белешкама). Још једна од могућности је и означавање белешки као омиљених.",
    "Deleted {title}" : "Обрисана {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Обрисано {number} белешка","Обрисано {number} белешке","Обрисано {number} белешки"],
    "Undo Delete" : "Опозови брисање",
    "Note recovered" : "Белешка опорављена",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Опорављено {number} белешка","Опорављено {number} белешке","Опорављено {number} белешки"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има несачуваних белешки. Напуштањем стране ћете поништити све измене!",
    "Notes settings" : "Подешавања белешки",
    "Please see Nextcloud server log for details." : "Погледајте Некстклауд серверске логове за детаље.",
    "Custom" : "Прилагођено",
    "Rich text" : "Обогаћени текст",
    "Plain text" : "Прости текст",
    "Preview" : "Претпреглед",
    "Make the selection bold" : "Подебљај изабрана слова",
    "Make the selection italic" : "Претвори изабрана слова у курзив",
    "Wrap the selection in quotes" : "Постави изабрани текст у знаке навода",
    "The selection will be turned into monospace" : "Изабрани текст ће се претворити у слова фиксне ширине",
    "Remove any styles from the selected text" : "Уклони све стилове из изабраног текста",
    "Makes the current line a list element" : "Претвара текућу линију у елемент листе",
    "Makes the current line a list element with a number" : "Претвара текућу линију у елемент нумерисане листе",
    "Toggle heading for current line" : "Укљ./искљ. наслов за текућу линију",
    "Set the current line as a big heading" : "Постави текућу линију као велики наслов",
    "Insert link" : "Уметни линк",
    "Insert image" : "Убаци слику",
    "Switch between editor and viewer" : "Пребаци се између едитора и прегледача",
    "Pick a notes folder" : "Изаберите фолдер за напомене",
    "Set notes folder" : "Постави фолдер за напомене",
    "Display" : "Приказ",
    "File extension" : "Екстензија фајла",
    "Notes folder" : "Фолдер за Белешке",
    "Mobile apps" : "Мобилне апликације",
    "Shortcuts" : "Пречице",
    "Delete" : "Delete",
    "Cancel" : "Поништи",
    "All notes" : "Све белешке",
    "Categories" : "Категорије",
    "Create a sample note with Markdown" : "Креирај белешку за пример са Markdown",
    "No notes yet" : "Још нема белешки",
    "Select an image" : "Изаберите слику",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Не можете да бирате слике ван свог фолдера белешки. Ваш фолдер белешки је: {folder}",
    "Wrong image" : "Погрешна слика",
    "The file was not uploaded. Check your server logs." : "Фајл није отпремљен. Проверите дневнике вашег сервера.",
    "Upload image" : "Отпреми слику",
    "Rich text editor" : "Едитор форматираног текста",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Сада можете да пређете на едитор форматираног текста, једноставан за коришћење и без непотребних ствари. Помоћу њега можете да уређујете белешке тако да вам се не приказују Markdown ознаке.",
    "This option can also be changed later on in the Notes app settings." : "Ова опција такође може и касније да се промени у подешавањима апликације Белешке.",
    "Keep plain Markdown editor" : "Задржи прости Markdown едитор",
    "Use rich editor" : "Користи едитор форматираног текста",
    "Remove from favorites" : "Уклони из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Error while renaming note." : "Грешка приликом промене имена белешке.",
    "Error during preparing note for deletion." : "Грешка приликом припремања белешке за брисање.",
    "Share" : "Подели",
    "Change category" : "Промените категорију",
    "Rename" : "Rename",
    "Rename note" : "Промени назив белешке",
    "Delete note" : "Обриши белешку",
    "Error from Nextcloud server: {msg}" : "Грешка са Некстклауд сервера: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Белешка је промењена у другој сесији. Молимо вас да изаберете верзију која би требало да се сачува.",
    "Use version from server" : "Користи верзију са сервера",
    "Use current version" : "Користи тренутну верзију",
    "Empty note" : "Празна белешка",
    "Write …" : "Пиши…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Измени",
    "Exit full screen" : "Напусти цео екран",
    "Full screen" : "Цео екран",
    "Note is read-only. You cannot change it." : "Напомена може само да се чита. Не можете да је измените.",
    "Save failed. Click to retry." : "Грешка при чувању. Кликните да покушате поново.",
    "Update conflict. Click for resolving manually." : "Конфликт ажурирања. Кликните да ручно разрешите.",
    "Today" : "Данас",
    "Yesterday" : "Јуче",
    "This week" : "Ове недеље",
    "Last week" : "Прошле недеље",
    "This month" : "Овог месеца",
    "Last month" : "Прошлог месеца",
    "Search for notes" : "Претражи белешке",
    "Loading …" : "Учитавање…",
    "Find in all categories" : "Пронађи у свим категоријама",
    "Write down your thoughts without any distractions." : "Запишите Ваше мисли без ометања.",
    "Use Markdown markups to style your text." : "Користите Markdown језик да стилизујете текст.",
    "Organize your notes in categories." : "Организујте белешке у категорије.",
    "Note not found." : "Белешка није нађена.",
    "Note is locked." : "Белешка је закључана.",
    "Insufficient storage." : "Недовољно места.",
    "See JavaScript console and server log for details." : "Погледајте JavaScript конзолу и дневник са сервера за детаље.",
    "Updating settings has failed." : "Ажурирање подешавања није успело.",
    "Fetching notes for dashboard has failed." : "Дохватање белешки за контролну таблу није успело.",
    "Fetching notes has failed." : "Дохватање белешки није успело.",
    "Fetching note {id} has failed." : "Дохватање белешке {id} није успело.",
    "Refreshing note {id} has failed." : "Освежавање белешке {id} није успело.",
    "Renaming note {id} has failed." : "Преименовање белешке {id} није успело.",
    "Creating new note has failed." : "Прављење нове белешке није успело.",
    "Saving note {id} has failed." : "Чување белешке {id} није успело.",
    "Updating title for note {id} has failed." : "Промена наслова белешке {id} није успела.",
    "Undo delete has failed for note {title}." : "Опозивање брисања није успело за белешку {title}.",
    "Deleting note {id} has failed." : "Брисање белешке {id} није успело.",
    "Toggling favorite for note {id} has failed." : "Стављање/уклањање омиљене белешке {id} није успело.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање категорије белешке. Да ли у одредишни директоријум може да се пише?",
    "Updating the category for note {id} has failed." : "Ажурирање категорије белешке {id} није успело.",
    "Uncategorized" : "Некатегоризовано",
    "Sample note" : "Белешка за пример",
    "15 January 2021, via Nextcloud Notes" : "15 јануар 2021, из Nextcloud Белешке",
    "Me, you, and all our friends!" : "Ја, ти и сви наши пријатељи!",
    "Tasks" : "Задаци",
    "Write nice todo lists" : "Пишите лепе листе обавеза",
    "Buy Fries" : "Купи помфрит",
    "Birthdays" : "Рођендани",
    "Jen, in three days!" : "Мица, за три дана!",
    "Moss, 21.03.1973" : "Mарко, 21.03.1973.",
    "Roy, 1979" : "Петар, 1979.",
    "Review Steps" : "Прегледајте кораке",
    "Turn PC off" : "Искључи PC",
    "Turn PC on" : "Укључи PC",
    "Then call IT" : "Затим позови IT`",
    "Quotes" : "Наводи",
    "Nextcloud, a safe home for all your data" : "Nextcloud, сигурно место за све ваше податке",
    "Development Mode" : "Развојни режим",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Изгледа да је апликација белешки инсталирана из развојног извора. Молимо да је инсталирате из званичне <a href=\"%1$s\">Некстклауд продавнице</a>. Ако желите само да искомпајлирате апликацију Белешки, пратите <a href=\"%2$s\">инструкције за програмере</a>."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
