OC.L10N.register(
    "notes",
    {
    "Notes" : "Užrašai",
    "Create new note" : "Sukurti naują užrašą",
    "More notes" : "Daugiau užrašų",
    "Reading notes from filesystem has failed." : "Nepavyko perskaityti užrašų iš failų sistemos.",
    "Error" : "Klaida",
    "New note" : "Nauji užrašai",
    "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "„Notes“ – tai dėmesio neblaškanti užrašų kūrimo programa, skirta [Nextcloud](https://www.nextcloud.com/). Ji siūlo kategorijas, padedančias geriau tvarkyti užrašus, ir palaiko formatavimą naudojant [Markdown](https://en.wikipedia.org/wiki/Markdown) sintaksę. Užrašai išsaugomi kaip failai jūsų „Nextcloud“ paskyroje, todėl juos galite peržiūrėti ir redaguoti naudodami bet kurį „Nextcloud“ klientą. Be to, atskiras [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) leidžia lengvai integruoti programą į kitas programas ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), taip pat [trečiųjų šalių programėles](https://github.com/nextcloud/notes/wiki#3rd-party-clients), kurios leidžia patogiai pasiekti jūsų „Nextcloud“ užrašus). Tarp kitų funkcijų yra užrašų žymėjimas kaip mėgstamiausi.",
    "Deleted {title}" : "{title} ištrinta",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Ištrinti {number} užrašai","Ištrinti {number} užrašai","Ištrinta {number} užrašų","Ištrinti {number} užrašai"],
    "Undo Delete" : "Atšaukti ištrynimą",
    "Note recovered" : "Užrašas atkurtas",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Atkurti {number} užrašai","Atkurti {number} užrašai","Atkurta {number} užrašų","Atkurti {number} užrašai"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
    "Notes settings" : "Užrašų nustatymai",
    "Please see Nextcloud server log for details." : "Išsamesnei informacijai žiūrėkite Nextcloud serverio žurnalą.",
    "Custom" : "Tinkinta",
    "Rich text" : "Raiškusis tekstas",
    "Plain text" : "Grynasis tekstas",
    "Preview" : "Peržiūra",
    "Make the selection bold" : "Paryškinti pasirinkimą",
    "Make the selection italic" : "Pakeisti tekstą į kursyvą",
    "Wrap the selection in quotes" : "Pasirinkimą įrašyti į kabutes",
    "The selection will be turned into monospace" : "Tekstas bus pakeistas į vienodo pločio šriftą",
    "Remove any styles from the selected text" : "Pašalinti visus stilius iš pažymėto teksto",
    "Makes the current line a list element" : "Paverčia esamą eilutę sąrašo elementu",
    "Makes the current line a list element with a number" : "Paverčia esamą eilutę sąrašo elementu su numeriu",
    "Toggle heading for current line" : "Perjungti antraštę dabartinėje eilutėje",
    "Set the current line as a big heading" : "Nustatyti esamą eilutę kaip didelę antraštę",
    "Insert link" : "Įterpti nuorodą",
    "Insert image" : "Įterpti paveikslą",
    "Switch between editor and viewer" : "Perjungti tarp redaktoriaus ir žiūryklės",
    "Pick a notes folder" : "Pasirinkti užrašų aplanką",
    "Set notes folder" : "Nustatyti užrašų aplanką",
    "General" : "Bendra",
    "Display" : "Rodymas",
    "File extension" : "Failo plėtinys",
    "For new notes" : "Naujiems užrašams",
    "Custom file extension" : "Pasirinktinis failo plėtinys",
    "Files" : "Failai",
    "Notes folder" : "Užrašų aplankas",
    "Mobile apps" : "Programėlės mobiliesiems",
    "Shortcuts" : "Sparčiosios nuorodos",
    "Delete" : "Ištrinti",
    "Cancel" : "Atsisakyti",
    "All notes" : "Visi užrašai",
    "Categories" : "Kategorijos",
    "Create a sample note with Markdown" : "Sukurti pavyzdinę pastabą naudojant Markdown",
    "No notes yet" : "Kol kas užrašų nėra",
    "Select an image" : "Pasirinkite paveikslą",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Negali pasirinkti vaizdų, esančių už užrašų aplanko ribų. Tavo užrašų aplankas yra: {folder}",
    "Wrong image" : "Neteisingas paveikslas",
    "The file was not uploaded. Check your server logs." : "Failas nebuvo įkeltas. Patikrinkite savo serverio žurnalus.",
    "Upload image" : "Įkelti paveikslą",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone ir iPad",
    "Rich text editor" : "Formatuoto teksto redaktorius",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Dabar galite pereiti prie patogaus ir dėmesio neblaškančio teksto redaktoriaus. Jis leidžia redaguoti užrašus nematant jokių Markdown žymių.",
    "This option can also be changed later on in the Notes app settings." : "Šį nustatymą taip pat galima pakeisti vėliau programėlės „Notes“ nustatymuose.",
    "Keep plain Markdown editor" : "Išsaugoti paprastą Markdown redaktorių",
    "Use rich editor" : "Naudoti išplėstinį redaktorių",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Error while renaming note." : "Pervadinant užrašą įvyko klaida.",
    "Error during preparing note for deletion." : "Įvyko klaida ruošiant užrašą ištrinimui.",
    "Share" : "Bendrinti",
    "Change category" : "Keisti kategoriją",
    "Rename" : "Pervadinti",
    "Rename note" : "Pervadinti užrašą",
    "Delete note" : "Ištrinti užrašus",
    "Error from Nextcloud server: {msg}" : "Klaida iš Nextcloud serverio: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Pastaba buvo pakeista kitoje sesijoje. Prašome pasirinkti, kuri versija turi būti išsaugota.",
    "Use version from server" : "Naudoti versiją iš serverio",
    "Use current version" : "Naudoti esamą versiją",
    "Empty note" : "Tušti užrašai",
    "Write …" : "Rašykite…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Taisyti",
    "Exit full screen" : "Išeiti iš viso ekrano",
    "Full screen" : "Visas ekranas",
    "Note is read-only. You cannot change it." : "Užrašai yra tik skaitymui. Jūs negalite jų keisti.",
    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
    "Update conflict. Click for resolving manually." : "Atnaujinimų konfliktas. Spustelėkite, jei norite išspręsti rankiniu būdu.",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "This week" : "Šią savaitę",
    "Last week" : "Praeitą savaitę",
    "This month" : "Šį mėnesį",
    "Last month" : "Praeitą mėnesį",
    "Search for notes" : "Ieškoti užrašų",
    "Loading …" : "Įkeliama…",
    "Find in all categories" : "Ieškoti visose kategorijose",
    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
    "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
    "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
    "Note not found." : "Užrašai nerasti.",
    "Note is locked." : "Užrašai užrakinti.",
    "Insufficient storage." : "Nepakankama atminties talpa.",
    "See JavaScript console and server log for details." : "Išsamesnės informacijos ieškokite „JavaScript“ konsolėje ir serverio žurnale.",
    "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
    "Fetching notes for dashboard has failed." : "Nepavyko gauti pastabų ataskaitų suvestinei.",
    "Fetching notes has failed." : "Nepavyko gauti užrašų.",
    "Fetching note {id} has failed." : "Nepavyko atsisiųsti {id} užrašą.",
    "Refreshing note {id} has failed." : "Nepavyko atnaujinti {id} užrašo.",
    "Renaming note {id} has failed." : "Nepavyko pervadinti {id} užrašo.",
    "Creating new note has failed." : "Nepavyko sukurti naujos pastabos.",
    "Saving note {id} has failed." : "Nepavyko išsaugoti {id} užrašo.",
    "Updating title for note {id} has failed." : "Nepavyko atnaujinti {id} užrašo pavadinimo.",
    "Undo delete has failed for note {title}." : "Nepavyko anuliuoti {title} užrašo ištrynimo.",
    "Deleting note {id} has failed." : "Nepavyko ištrinti {id} užrašo.",
    "Toggling favorite for note {id} has failed." : "Nepavyko perjungti {id} užrašo į mėgstamiausius.",
    "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
    "Updating the category for note {id} has failed." : "Nepavyko atnaujinti {id} užrašo kategorijos.",
    "Uncategorized" : "Nekategorizuoti",
    "Sample note" : "Pavyzdinis užrašas",
    "15 January 2021, via Nextcloud Notes" : "2021 m. sausio 15 d., naudojant „Nextcloud Notes“",
    "Me, you, and all our friends!" : "Aš, tu ir visi mūsų draugai!",
    "Tasks" : "Užduotys",
    "Write nice todo lists" : "Sudarykite gražius užduočių sąrašus",
    "Buy Fries" : "Pirkite bulvytes",
    "Birthdays" : "Gimtadieniai",
    "Jen, in three days!" : "Jen, po trijų dienų!",
    "Moss, 21.03.1973" : "Moss, 1973 m. kovo 21 d.",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Peržiūros žingsniai",
    "Turn PC off" : "Išjunkti kompiuterį",
    "Turn PC on" : "Įjungti kompiuterį",
    "Then call IT" : "Tada paskambink IT",
    "Quotes" : "Kabutės",
    "Nextcloud, a safe home for all your data" : "„Nextcloud“ – saugūs namai visiems jūsų duomenims",
    "Development Mode" : "Plėtotojo veiksena",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Panašu, kad užrašų programėlė buvo įdiegta iš kūrėjo šaltinio. Vietoj to įdiekite ją iš oficialios <a href=\"%1$s\">Nextcloud App Store</a> parduotuvės. Jei norite patys sukurti užrašų programėlę, vadovaukitės <a href=\"%2$s\">kūrėjo instrukcijomis</a>."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
