OC.L10N.register(
    "notes",
    {
    "Notes" : "Beležka",
    "Create new note" : "Ustvari novo zabeležko",
    "More notes" : "Več zabeležk",
    "Reading notes from filesystem has failed." : "Branje zabeležk z datotečnega sistema je spodletelo.",
    "Error" : "Napaka",
    "New note" : "Nova zabeležka",
    "Distraction-free notes and writing" : "Enostavno beleženje in zapisovanje",
    "Deleted {title}" : "Izbrisano {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Izbrisana je {number} zabeležka.","Izbrisani sta {number} zabeležki.","Izbrisane so {number} zabeležke.","Izbrisanih je {number} zabeležk."],
    "Undo Delete" : "Razveljavi brisanje",
    "Note recovered" : "Zabeležka je obnovljena",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Obnovljena je {number} zabeležka.","Obnovljeni sta {number} zabeležki.","Obnovljene so {number} zabeležke.","Obnovljenih je {number} zabeležk."],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Zabeležke še niso shranjene. Če zapustite stran, bodo spremembe izgubljene!",
    "Notes settings" : "Nastavitve beležk",
    "Please see Nextcloud server log for details." : "Za več podrobnosti si oglejte dnevniški zapis strežnika Nextcloud.",
    "Preview" : "Predogled",
    "Make the selection bold" : "Oblikuj izbor krepko",
    "Make the selection italic" : "Oblikuj izbor ležeče",
    "Wrap the selection in quotes" : "Postavi izbor v navednice",
    "The selection will be turned into monospace" : "Izbor bo izpisan v pisavi enotne širine",
    "Remove any styles from the selected text" : "Odstrani oblikovanje z izbranega besedila",
    "Makes the current line a list element" : "Oblikuje trenutno vrstico kot predmet vrstičnega seznama",
    "Makes the current line a list element with a number" : "Oblikuje trenutno vrstico kot predmet oštevilčenega seznama",
    "Toggle heading for current line" : "Preklopi glavo trenutne vrstice",
    "Set the current line as a big heading" : "Nastavi trenutno vrstico kot velik naslov",
    "Insert link" : "Vstavi povezavo",
    "Insert image" : "Vstavi sliko",
    "Switch between editor and viewer" : "Preklopi med urejevalnikom in pregledovalnikom",
    "Pick a notes folder" : "Določi mapo zabeležk",
    "Set notes folder" : "Nastavi mapo zabeležk",
    "File extension" : "Pripona datotek",
    "Mobile apps" : "Mobilni programi",
    "Shortcuts" : "Bližnjice",
    "Delete" : "Pobriši",
    "Cancel" : "Cancel",
    "All notes" : "Vse zabeležke",
    "Categories" : "Kategorije",
    "Create a sample note with Markdown" : "Ustvari enostavno zabeležko z oblikovanim jezikom Markdown",
    "No notes yet" : "Ni še dodane nobene zabeležke.",
    "Select an image" : "Izbor slike",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ni mogoče izbrati slik izven mape beležk. Ustrezna mapa je: {folder}.",
    "Wrong image" : "Napačna slika",
    "The file was not uploaded. Check your server logs." : "Datoteka ni poslana. Več podrobnosti je zapisanih v dnevniškem zapisu strežnika.",
    "Upload image" : "Pošlji sliko",
    "Rich text editor" : "Oblikovalni urejevalnik",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Sedaj je na voljo enostaven in uporaben urejevalnik besedila, s katerim je urejanje mogoče brez prikaza oznak Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Možnost je mogoče tudi kasneje spremeniti med nastavitvami programa.",
    "Keep plain Markdown editor" : "Ohrani enostaven urejevalnik Markdown",
    "Use rich editor" : "Uporabi oblikovalni urejevalnik",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "Error while renaming note." : "Prišlo je do napake med preimenovanjem beležke.",
    "Error during preparing note for deletion." : "Prišlo je do napake med pripravo zabeležke za brisanje.",
    "Share" : "Souporaba",
    "Change category" : "Spremeni kategorijo",
    "Rename" : "Preimenuj",
    "Rename note" : "Preimenuj beležko",
    "Delete note" : "Izbriši beležko",
    "Error from Nextcloud server: {msg}" : "Napaka s strežnika Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Sporočilce je bilo spremenjeno v drugem programo. Izberite, katera različica naj bo shranjena.",
    "Use version from server" : "Uporabi različico s strežnika",
    "Use current version" : "Uporabi trenutno različico",
    "Empty note" : "Prazno sporočilo",
    "Write …" : "Zapisovanje ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Uredi",
    "Exit full screen" : "Končaj celozaslonski način",
    "Full screen" : "Celozaslonski način",
    "Note is read-only. You cannot change it." : "Sporočilo je le za branje in ga ni mogoče spreminjati.",
    "Save failed. Click to retry." : "Shranjevanje je spodletelo. Kliknite za ponovni poskus.",
    "Update conflict. Click for resolving manually." : "Zaznan je spor usklajevanja, ki ga je treba razrešiti ročno.",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "This week" : "Ta teden",
    "Last week" : "Zadnji teden",
    "This month" : "Ta mesec",
    "Last month" : "Zadnji mesec",
    "Search for notes" : "Iskanje beležk",
    "Loading …" : "Poteka nalaganje …",
    "Find in all categories" : "Preišči v vseh kategorijah",
    "Write down your thoughts without any distractions." : "Zapisovanje beležk brez vsakršnih motenj.",
    "Use Markdown markups to style your text." : "Za oblikovanje besedila je mogoče uporabiti jezik Markdown.",
    "Organize your notes in categories." : "Beležke je mogoče razvrstiti v kategorije.",
    "Note not found." : "Zabeležke ni mogoče najti",
    "Note is locked." : "Zabeležka je zaklenjena.",
    "Insufficient storage." : "Nezadostna količina prostora.",
    "See JavaScript console and server log for details." : "Več podrobnosti je zbranih v konzoli JavaScript.",
    "Updating settings has failed." : "Posodabljanje nastavitev je spodletelo.",
    "Fetching notes for dashboard has failed." : "Pridobivanje zabeležk za Nadzorno ploščo je spodletelo.",
    "Fetching notes has failed." : "Pridobivanje zabeležk je spodletelo.",
    "Fetching note {id} has failed." : "Pridobivanje določila {id} sporočila je spodletelo.",
    "Refreshing note {id} has failed." : "Osveževanje zabeležke {id} je spodletelo.",
    "Renaming note {id} has failed." : "Preimenovanje zabeležke {id} je spodletelo.",
    "Creating new note has failed." : "Ustvarjanje nove zabeležke je spodletelo.",
    "Saving note {id} has failed." : "Shranjevanje zabeležke {id} je spodletelo.",
    "Updating title for note {id} has failed." : "Posodabljanje naslova zabeležke {id} je spodletelo.",
    "Undo delete has failed for note {title}." : "Razveljavitev brisanja je za zabeležko {title} spodletelo.",
    "Deleting note {id} has failed." : "Brisanje določila {id} sporočila je spodletelo.",
    "Toggling favorite for note {id} has failed." : "Preklop oznake priljubljeno za beležko {id} je spodletelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Posodabljanje kategorije zabeležke je spodletelo. Ali ima ciljno mesto nastavljena ustrezna dovoljenja za zapisovanje?",
    "Updating the category for note {id} has failed." : "Posodabljanje kategorije za beležko {id} je spodletelo.",
    "Uncategorized" : "Neopredeljeno",
    "Sample note" : "Vzorčna zabeležka",
    "15 January 2021, via Nextcloud Notes" : "15 Januar 2021, z Nextcloud Notes",
    "Me, you, and all our friends!" : "Ti, jaz in vsi najini prijatelji!",
    "Tasks" : "Naloge",
    "Write nice todo lists" : "Pripravi dobre sezname nalog",
    "Buy Fries" : "Kupi pomfrit",
    "Birthdays" : "Rojstni dnevi",
    "Jen, in three days!" : "Jana, čez tri dni!",
    "Moss, 21.03.1973" : "Mateja, 21.03.1973",
    "Roy, 1979" : "Robert, 1979",
    "Review Steps" : "Preglej korake",
    "Turn PC off" : "Izklopi računalnik",
    "Turn PC on" : "Vklopi računalnik",
    "Then call IT" : "Nato pokliči službo IT",
    "Quotes" : "Ponudbe",
    "Nextcloud, a safe home for all your data" : "Nextcloud – varno okolje za pomembne podatke",
    "Development Mode" : "Razvojni način",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Kaže, da je program nameščen in razvojne različice. Priporočena je namestitev iz uradne trgovine <a href=\"%1$s\">Nextcloud App Store</a>. Seveda lahko program izgradite tudi sami, upoštevajoč <a href=\"%2$s\">navodila za razvijalce</a>."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
