OC.L10N.register(
    "notes",
    {
    "Notes" : "الملاحظات",
    "Create new note" : "إنشاء ملاحظة جديدة",
    "More notes" : "مزيد من الملاحظات",
    "Reading notes from filesystem has failed." : "تعذّرت قراءة الملاحظات من نظام الملفات",
    "Error" : "خطأ",
    "New note" : "ملاحظة جديدة ",
    "Distraction-free notes and writing" : "ملاحظات وكتابة سلسة",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "تطبيق \"الملاحظات\" Notes هو تطبيق لتدوين الملاحظات بدون تشتيت الانتباه من [نكست كلاود] (https://www.nextcloud.com/). يوفر التطبيق إمكانية تصنيف الملاحظات إلى فئات لتنظيم أفضل؛ كما يدعم التنسيق باستخدام صيغة [مارك داون](https://en.wikipedia.org/wiki/Markdown). يتم حفظ الملاحظات كملفات في خادوم نكست كلاود خاصّتك، حتى تتمكن من عرضها وتحريرها باستخدام أي عميل لنكست كلاود. علاوة على ذلك، تتيح واجهة برمجة تطبيقات [REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) المنفصلة التكامل السهل في التطبيقات ([Android](https://github.com/nextcloud/notes-android)، [iOS](https://github.com/nextcloud/notes-ios)، بالإضافة إلى [تطبيقات من أي طرف ثالث](https://github.com/nextcloud/notes/wiki#3rd-party-clients) التي تتيح الوصول بسهولة إلى \"ملاحظات\" على نكست كلاود). تتضمن الميزات الإضافية تمييز الملاحظات كـ\"مُفضّلة\".",
    "Deleted {title}" : "تمّ حذف {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} ملاحظات محذوفة","{number} ملاحظة محذوفة","{number} ملاحظات محذوفة","{number} ملاحظات محذوفة","{number} ملاحظات محذوفة","{number} ملاحظات محذوفة"],
    "Undo Delete" : "تراجع عن الحذف",
    "Note recovered" : "تمّ استرجاع الملاحظة",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} ملاحظات تم استردادها","{number} ملاحظة تم استردادها","{number} ملاحظات تم استردادها","{number} ملاحظات تم استردادها","{number} ملاحظات تم استردادها","{number} ملاحظات تم استردادها"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "هنالك ملاحظات غير محفوظة. مغادرة الصفحة ستؤدي إلى إهمال كل التغييرات!",
    "Notes settings" : "إعدادات الملاحظات",
    "Please see Nextcloud server log for details." : "للتفاصيل، يُرجى مطالعة سجل الأنشطة لخادم نكست كلاود.",
    "Rich text" : "نص مُنسّق",
    "Plain text" : "نص عادي",
    "Preview" : "معاينة",
    "Make the selection bold" : "جعل التحديد ثخيناً bold",
    "Make the selection italic" : "جعل التحديد مائلاً italic",
    "Wrap the selection in quotes" : "ضع التحديد في اقتباس quotes",
    "The selection will be turned into monospace" : "سيتم تحويل التحديد إلى أُحادي المِسَاحة monospace",
    "Remove any styles from the selected text" : "قم بإزالة أي تنسيقات styles من النص",
    "Makes the current line a list element" : "إجعل السطر الحالي بنداً في قائمة list element",
    "Makes the current line a list element with a number" : "إجعل السطر الحالي بنداً مُرقّماً في قائمة  ",
    "Toggle heading for current line" : "أظهر/إخف العنوان للسطر الحالي",
    "Set the current line as a big heading" : "إجعل السطر الحالي عنواناً كبيراً",
    "Insert link" : "أدخِل رابطاً",
    "Insert image" : "أدخِل صورةً",
    "Switch between editor and viewer" : "التبديل ما بين المحرر و العارض",
    "Pick a notes folder" : "إختَر مجلداً للملاحظات",
    "Set notes folder" : "تعيين مجلد الملاحظات",
    "Display" : "عرض",
    "File extension" : "إمتداد الملف",
    "Notes folder" : "مجلد الملاحظات",
    "Mobile apps" : "التطبيقات المحمولة",
    "Shortcuts" : "اختصارات ",
    "Delete" : "حذف",
    "Cancel" : "إلغاء",
    "All notes" : "جميع الملاحظات",
    "Categories" : "التصنيفات",
    "Create a sample note with Markdown" : "إنشاء ملاحظة تجريبية بتسنيق  Markdown",
    "No notes yet" : "لا توجد ملاحظات حتى الآن",
    "Select an image" : "إختَر صورةً",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "لا يمكنك اختيار صورٍ من خارج مجلد ملاحظاتك؛ و الذي هو: {folder}",
    "Wrong image" : "صورة غير صحيحة",
    "The file was not uploaded. Check your server logs." : "لم يتم رفع الملف. راجع سجل الأنشطة في الخادم",
    "Upload image" : "إرفَع صورةً",
    "Rich text editor" : "مُحرر نصوص مُنسّقة",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "يمكنك الآن التبديل لاستخدام محرر نصوص منسقة سلس و سهل الاستخدام يسمح لك بتحرير الملاحظات دون رؤية أي علامات ماركداون Markdown.",
    "This option can also be changed later on in the Notes app settings." : "يمكن تغيير هذا الخيار لاحقًا في إعدادات تطبيق \"الملاحظات\" Notes.",
    "Keep plain Markdown editor" : "إستمر كمحرر ماركداون بسيط plain Markdown editor",
    "Use rich editor" : "إستعمل المُحرّر المُنسِّق rich editor",
    "Remove from favorites" : "حذف من المفضلة",
    "Add to favorites" : "إضافة إلى المفضلة",
    "Error while renaming note." : "حدث خطأ أثناء تغيير تسمية الملاحظة",
    "Error during preparing note for deletion." : "حدث خطأ أثناء التحضير لحذف الملاحظة.",
    "Share" : "مشاركة",
    "Change category" : "غيِّر التصنيف",
    "Rename" : "إعادة التسمية",
    "Rename note" : "تغيير تسمية الملاحظة",
    "Delete note" : "حذف الملاحظة ",
    "Error from Nextcloud server: {msg}" : "خطـأ من خادم نكست كلاود: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "تم تغيير الملاحظة في جلسة session أخرى. الرجاء اختيار النسخة الذي ترغب بحفظها.",
    "Use version from server" : "إستخدم نسخةً من الخادم",
    "Use current version" : "إستخدم النسخة الحاليّة",
    "Empty note" : "ملاحظة فارغة",
    "Write …" : "كتابة ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "تعديل",
    "Exit full screen" : "إنهاء ملء الشاشة",
    "Full screen" : "ملء الشاشة",
    "Note is read-only. You cannot change it." : "الملاحظة \"للقراءة فقط\". لا يمكنك تعديلها,",
    "Save failed. Click to retry." : "تعذّر الحفظ. أُنقُر لإعادة المحاولة.",
    "Update conflict. Click for resolving manually." : "تضارب في الرفع. إضغط للحلّ يدويّاً.",
    "Today" : "اليوم",
    "Yesterday" : "أمس",
    "This week" : "هذا الأسبوع",
    "Last week" : "الأسبوع الماضي",
    "This month" : "هذا الشهر",
    "Last month" : "الشهر الماضي",
    "Search for notes" : "البحث عن ملاحظات",
    "Loading …" : "التحميل جارٍ …",
    "Find in all categories" : "إبحث في كل التصنيفات",
    "Write down your thoughts without any distractions." : "دون أفكارك بكل يسر وسلاسة.",
    "Use Markdown markups to style your text." : "إستعمل علامات ماركداون لتنسيق نَصِّك.",
    "Organize your notes in categories." : "تنظيم ملاحظاتك في فئات.",
    "Note not found." : "الملاحظة غير موجودة",
    "Note is locked." : "الملاحظة مقفلة",
    "Insufficient storage." : "مساحة التخزين لا تكفي",
    "See JavaScript console and server log for details." : "أنظر JavaScript console و سجل أنشطة الخادم لمزيد التفاصيل.",
    "Updating settings has failed." : "فشل تحديث الإعدادات.",
    "Fetching notes for dashboard has failed." : "تعذّر جلب الملاحظات للوحة القيادة dashboard",
    "Fetching notes has failed." : "تعذّر جلب الملاحظات.",
    "Fetching note {id} has failed." : "تعذّر جلب الملاحظة {id}.",
    "Refreshing note {id} has failed." : "تعذّر تحديث refreshing الملاحظة {id}.",
    "Renaming note {id} has failed." : "تعذّر تغيير تسمية الملاحظة {id}.",
    "Creating new note has failed." : "فشل إنشاء ملاحظة جديدة.",
    "Saving note {id} has failed." : "تعذّر حفظ الملاحظة {id}.",
    "Updating title for note {id} has failed." : "تعذّر رفع عنوان الملاحظة {id}.",
    "Undo delete has failed for note {title}." : "تعذّر إلغاء حذف الملاحظة {id}.",
    "Deleting note {id} has failed." : "تعذّر حذف الملاحظة {id}.",
    "Toggling favorite for note {id} has failed." : "تعذّر وضع/سحب الملاحظة من قائمة المفضلة {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "تعذّر تحديث تصنيف الملاحظات. هل الدليل المَقصِد target directory قابل للكتابة؟",
    "Updating the category for note {id} has failed." : "تعذّر تغيبر تصنيف الملاحظة {id}.",
    "Uncategorized" : "غير مصنف",
    "Sample note" : "ملاحظة عيّنة sample",
    "15 January 2021, via Nextcloud Notes" : "15 يناير 2021؛ عبر نكست كلاود",
    "Me, you, and all our friends!" : "أنا و أنت و جميع الأصدقاء",
    "Tasks" : "المهام",
    "Write nice todo lists" : "أكتب قائمة مهمة حلوة",
    "Buy Fries" : "إشترِ سندوتشاتٍ",
    "Birthdays" : "أعياد الميلاد",
    "Jen, in three days!" : "جَنَى، في ظرف ثلاثة أيام!",
    "Moss, 21.03.1973" : "موسى، 21.03.1973",
    "Roy, 1979" : "رياض، 1979",
    "Review Steps" : "خطوات المراجعة",
    "Turn PC off" : "أطفيء الجهاز",
    "Turn PC on" : "شغّل الجهاز",
    "Then call IT" : "ثم اتصل بقسم تقنية المعلومات",
    "Quotes" : "عروض و فواتير",
    "Nextcloud, a safe home for all your data" : "نكست كلاود كمحلٍّ آمن لبياناتك",
    "Development Mode" : "وضعية المُطوِّر",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "يبدو أن تطبيق \"الملاحظات\" Notes هذا لم يتم تنصيبه من المصدر الرسمي <a href=\"%1$s\">متجر تطبيقات نكست كلاود Nextcloud App Store</a>. أما إذا رغبت في بناء التطبيق من الكود المصدري بنفسك، فاتّبع رجاءً  <a href=\"%2$s\">تعليمات للمطوِّرين developer instructions</a>."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
