OC.L10N.register(
    "notes",
    {
    "Notes" : "Piezīmes",
    "More notes" : "Vairāk piezīmju",
    "Error" : "Kļūda",
    "New note" : "Jauna piezīme",
    "Notes settings" : "Piezīmju iestatījumi",
    "Preview" : "Priekšskatīt",
    "Files" : "Datnes",
    "Delete" : "Izdzēst",
    "Cancel" : "Atcelt",
    "All notes" : "Visas piezīmes",
    "Categories" : "Kategorijas",
    "No notes yet" : "Nav nevienas piezīmes",
    "Remove from favorites" : "Noņemt no izlases",
    "Add to favorites" : "Pievienot izlasei",
    "Share" : "Koplietot",
    "Rename" : "Pārdēvēt",
    "Rename note" : "Pārdēvēt piezīmi",
    "Delete note" : "Izdzēst piezīmi",
    "Use version from server" : "Izmantot servera versiju",
    "Use current version" : "Izmantot pašreizējo versiju",
    "Edit" : "Labot",
    "Exit full screen" : "Iziet no pilnekrāna",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "This week" : "Šonedēļ",
    "This month" : "Šis mēnesis",
    "Loading …" : "Notiek ielāde ...",
    "Updating settings has failed." : "Iestatījumu atjaunināšana neizdevās.",
    "Uncategorized" : "Bez kategorijas",
    "Tasks" : "Uzdevumi",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Izskatās, ka piezīmju lietotne tika uzstādīta un izstrādes avota. Lūgums uzstādīt to no officiālā <a href=\"%1$s\">Nextcloud lietotņu veikala</a>. Ja ir vēlēšanās būvēt piezīmju lietotni pašam, lūgums sekot <a href=\"%2$s\">norādēm izstrādātājiem</a>."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
