OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "Create new note" : "Creează o notă nouă",
    "More notes" : "Mai multe notițe",
    "Reading notes from filesystem has failed." : "Citirea notiţelor din sistemul de fişiere a eşuat.",
    "Error" : "Eroare",
    "New note" : "Notă nouă",
    "Distraction-free notes and writing" : "Scrie notiţe fără a fi distras",
    "Deleted {title}" : "{title} a fost şters",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["A fost ștearsă {number} notă","Au fost șterse {number} note","Au fost șterse {number} note"],
    "Undo Delete" : "Anulează ștergerea",
    "Note recovered" : "Notiţa a fost recuperată",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["A fost recuperat {number} notiţă","Au fost recuperate {number} notiţe","Au fost recuperate {number} de notiţe"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Există notiţe nesalvate. Dacă părăsiţi această pagină aceste schimbări vor fi pierdute!",
    "Notes settings" : "Setări Note",
    "Please see Nextcloud server log for details." : "Vă rugăm să verificaţi fişierele log de pe serverul Nextcloud pentru mai multe detalii.",
    "Preview" : "Previzualizare",
    "Make the selection bold" : "Îngroașă selecția",
    "Make the selection italic" : "Înclină selecția",
    "Wrap the selection in quotes" : "Pune selecția în ghilimele",
    "The selection will be turned into monospace" : "Selecția va fi transformată în monospațiu",
    "Remove any styles from the selected text" : "Elimină formatarea textului",
    "Makes the current line a list element" : "Transformă linia în element de listă",
    "Makes the current line a list element with a number" : "Transformă linia curentă în element de listă numerotată",
    "Toggle heading for current line" : "Comută nivelul pentru linia curentă",
    "Set the current line as a big heading" : "Setează linia curentă ca titlu mare",
    "Insert link" : "Inserează link",
    "Insert image" : "Introdu imagine",
    "Switch between editor and viewer" : "Comută între editare și vizualizare",
    "File extension" : "Extensie fișier",
    "Files" : "Fișiere",
    "Mobile apps" : "Aplicații mobile",
    "Shortcuts" : "Scurtături",
    "Delete" : "Delete",
    "Cancel" : "Anulează",
    "All notes" : "Toate notițele",
    "Categories" : "Categorii",
    "Create a sample note with Markdown" : "Creați o notă demo cu Markdown",
    "No notes yet" : "Nu există notițe",
    "Select an image" : "Selectează o imagine",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nu poți selecta imagini din exteriorul dosarului de notițe. Dosarul tău de notițe este: {folder}",
    "Wrong image" : "Imagine greșită",
    "The file was not uploaded. Check your server logs." : "Imaginea nu a fost încărcată. Verifică fișierele log.",
    "Upload image" : "Încarcă imagine",
    "Rich text editor" : "Editor cu formatare",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Acum puteți comuta la editorul cu formatare, ușor de utilizat și intuitiv. Acesta permite editarea fără a afișa marcajele Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Această opțiune poate fi modificată și din setările aplicației Note",
    "Keep plain Markdown editor" : "Rămâneți în modul de editare Markdown",
    "Use rich editor" : "Utilizați editorul cu formatare",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adăugați la favorite",
    "Error while renaming note." : "Eroare la redenumirea notiței",
    "Error during preparing note for deletion." : "A apărut o eroare în timpul pregătirii ştergerii notiţei.",
    "Share" : "Share",
    "Change category" : "Schimbă categoria",
    "Rename" : "Rename",
    "Rename note" : "Redenumește notița",
    "Delete note" : "Şterge nota",
    "Error from Nextcloud server: {msg}" : "Eroare din partea severului Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Această notiţă a fost schimbată în altă sesiune. Vă rugăm să alegeţi ce versiune să fie salvată.",
    "Use version from server" : "Foloseşte versiunea de pe server",
    "Use current version" : "Folosește versiunea curentă",
    "Empty note" : "Notiţă goală",
    "Write …" : "Scrie ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editează",
    "Exit full screen" : "Ieşire din modul ecran complet",
    "Full screen" : "Ecran complet",
    "Note is read-only. You cannot change it." : "Notiţa este numai pentru citire. Nu este posibil să o modifici.",
    "Save failed. Click to retry." : "Salvarea a eşuat. Click pentru a reîncerca.",
    "Update conflict. Click for resolving manually." : "Actualizează conflictul. Click pentru a resolva manual această problemă.",
    "Today" : "Azi",
    "Yesterday" : "Ieri",
    "This week" : "Săptămâna asta",
    "Last week" : "Săptămâna trecută ",
    "This month" : "Luna asta",
    "Last month" : "Luna trecută ",
    "Search for notes" : "Căutare note",
    "Loading …" : "Se încarcă…",
    "Find in all categories" : "Căutare în toate categoriile",
    "Write down your thoughts without any distractions." : "Scrie-ţi gândurile fără orice altă distracţie.",
    "Use Markdown markups to style your text." : "Foloseşte limbajul Markdown pentru a-ţi stiliza textul.",
    "Organize your notes in categories." : "Organizează-ţi notiţele pe categorii.",
    "Note not found." : "Notița nu a fost găsită.",
    "Note is locked." : "Notiţa este blocată.",
    "Insufficient storage." : "Spaţiu de stocare insuficient.",
    "See JavaScript console and server log for details." : "Pentru mai multe detalii verificaţi consola JavaScript şi fişierele log.",
    "Updating settings has failed." : "Actualizarea setărilor a eşuat.",
    "Fetching notes for dashboard has failed." : "Preluarea notiţelor pentru ecranul principal a eşuat.",
    "Fetching notes has failed." : "Preluarea notiţelor a eşuat.",
    "Fetching note {id} has failed." : "Preluarea notiţei {id} a eşuat.",
    "Refreshing note {id} has failed." : "Actualizarea notiţei{id} a eşuat.",
    "Renaming note {id} has failed." : "Redenumirea notiţei {id} a eşuat.",
    "Creating new note has failed." : "Creearea unei notiţe noi a eşuat.",
    "Saving note {id} has failed." : "Salvarea notiţei {id} a eşuat. ",
    "Updating title for note {id} has failed." : "Actualizarea titlului pentru notiţa {id} a eşuat.",
    "Undo delete has failed for note {title}." : "Anularea ştergerii notiţei {title} a eşuat.",
    "Deleting note {id} has failed." : "Ştergerea notiţei {id} a eşuat.",
    "Toggling favorite for note {id} has failed." : "Adăugarea la favorite a notiţei {id} a eşuat.",
    "Updating the note's category has failed. Is the target directory writable?" : "Actualizarea categoriei notiţei a eşuat. Există permisiunea de a scrie în dosarul ţintă?",
    "Updating the category for note {id} has failed." : "Actualizarea categoriei pentru notiţa {id} a eşuat.",
    "Uncategorized" : "Fără categorie ",
    "Sample note" : "Notă demo",
    "15 January 2021, via Nextcloud Notes" : "15 ianuarie 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Eu, tu și toți prietenii noștri!",
    "Tasks" : "Sarcini",
    "Write nice todo lists" : "Scrieți liste de sarcini",
    "Birthdays" : "Zile de naștere",
    "Turn PC off" : "Oprește PC",
    "Turn PC on" : "Pornește PC",
    "Then call IT" : "Apoi apelează la IT",
    "Quotes" : "Citate",
    "Nextcloud, a safe home for all your data" : "Nextcloud, o casă sigură pentru toate datele dumneavoastră",
    "Development Mode" : "Mod dezvoltator",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Se pare că aplicaţia de luat notiţe a fost instalată dintr-o sursă destinată dezvoltatorilor. Vă rugăm să instalaţi aplicaţia oficială de pe <a href=\"%1$s\">Magazinul Play</a>. Dacă doriţi să contruiţi aplicaţia Notes, vă rugăm să urmaţi <a href=\"%2$s\">instrucţiunile pentru dezvoltatori</a>."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
