OC.L10N.register(
    "notes",
    {
    "Notes" : "筆記",
    "Create new note" : "建立新筆記",
    "More notes" : "更多筆記",
    "Reading notes from filesystem has failed." : "從檔案系統讀取筆記失敗。",
    "Error" : "錯誤",
    "New note" : "新筆記",
    "Distraction-free notes and writing" : "無干擾的筆記和寫作",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "筆記應用程式是用於 [Nextcloud](https://www.nextcloud.com/) 的無干擾筆記應用程式。其提供了更好的組織分類，並使用 [Markdown](https://zh.wikipedia.org/wiki/Markdown) 語法來支援格式化。筆記是以檔案的形式儲存在您的 Nextcloud 中，這樣您就可以使用各種 Nextcloud 客戶端檢視並編輯它們。此外，也有獨立的 [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) 可輕鬆地整合至應用程式中（[Android](https://github.com/stefan-niedermann/nextcloud-notes)、[iOS](https://github.com/owncloud/notes-iOS-App) 與[第三方應用程式](https://github.com/nextcloud/notes/wiki#3rd-party-clients)，可讓您方便存取您的 Nextcloud 筆記）。還有將筆記加入收藏的功能。",
    "Deleted {title}" : "已刪除 {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["已刪除 {number} 個筆記"],
    "Undo Delete" : "還原刪除",
    "Note recovered" : "筆記已復原",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["已回復 {number} 個筆記"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未儲存內容。離開頁面會有遺失資料風險。",
    "New category" : "新分類",
    "Notes settings" : "Notes 設定",
    "Please see Nextcloud server log for details." : "請檢視 Nextcloud 伺服器記錄以取得進一步資訊。",
    "Custom" : "自訂",
    "Rich text" : "格式化文字",
    "Plain text" : "純文字",
    "Preview" : "預覽",
    "Make the selection bold" : "讓所選範圍變為粗體",
    "Make the selection italic" : "讓所選範圍變為斜體",
    "Wrap the selection in quotes" : "將所選範圍用引號括起來",
    "The selection will be turned into monospace" : "所選範圍將會變為等寬",
    "Remove any styles from the selected text" : "從所選的文字移除任何樣式",
    "Makes the current line a list element" : "讓目前行變為清單元素",
    "Makes the current line a list element with a number" : "讓目前行變為帶有數字的清單元素",
    "Toggle heading for current line" : "切換目前行的標題",
    "Set the current line as a big heading" : "將目前行設定為大標題",
    "Insert link" : "插入連結",
    "Insert image" : "插入圖像",
    "Switch between editor and viewer" : "在編輯器與檢視器間切換",
    "Pick a notes folder" : "選擇一個備註資料夾",
    "Set notes folder" : "設置備註資料夾",
    "General" : "一般",
    "Display" : "顯示",
    "File extension" : "檔案擴展名",
    "For new notes" : "供新筆記使用",
    "Custom file extension" : "自訂副檔名",
    "Files" : "文件",
    "Notes folder" : "Notes 資料夾",
    "Mobile apps" : "流動應用程式",
    "Shortcuts" : "捷徑",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["刪除分類「{category}」與其 {count} 則筆記？"],
    "Delete category" : "刪除分類",
    "Delete" : "移除",
    "Cancel" : "取消",
    "All notes" : "全部筆記",
    "Categories" : "分類",
    "Rename category" : "重新命名分類",
    "Create a sample note with Markdown" : "使用 Markdown 建立範例筆記",
    "No notes yet" : "尚未有筆記",
    "Select an image" : "選擇圖像",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "您不能選擇筆記資料夾之外的圖像。 您的筆記資料夾是：{folder}",
    "Wrong image" : "錯誤的圖像",
    "The file was not uploaded. Check your server logs." : "檔案未上傳。請檢查您的伺服器紀錄檔。",
    "Upload image" : "上傳圖像",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone 與 iPad",
    "Rich text editor" : "以富文字模式打開",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "您現在可以切換到使用易於使用且無干擾的富文字編輯器。它允許您在編輯筆記時看不到任何 markdown 標記。",
    "This option can also be changed later on in the Notes app settings." : "稍後也可以在 Notes 應用程式設置中更改此選項。",
    "Keep plain Markdown editor" : "保留普通的 markdown 編輯器",
    "Use rich editor" : "使用富文字編輯器",
    "Remove from favorites" : "從最愛中移除",
    "Add to favorites" : "加到我的最愛",
    "Error while renaming note." : "重新命名筆記時發生錯誤。",
    "Error during preparing note for deletion." : "準備刪除筆記時出錯。",
    "Share" : "共享",
    "Change category" : "變更分類",
    "Rename" : "Rename",
    "Rename note" : "重新命名筆記",
    "Delete note" : "刪除筆記",
    "Error from Nextcloud server: {msg}" : "來自 Nextcloud 伺服器的錯誤通知：{msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "該筆記在另一節中已更改。請選擇應保存的版本。",
    "Use version from server" : "使用伺服器版本",
    "Use current version" : "使用目前版本",
    "Empty note" : "無內容",
    "Write …" : "編寫 ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "編輯",
    "Exit full screen" : "退出全螢幕",
    "Full screen" : "全螢幕",
    "Note is read-only. You cannot change it." : "筆記是唯讀的。您無法更改。",
    "Save failed. Click to retry." : "保存失敗。點擊重試。",
    "Update conflict. Click for resolving manually." : "更新有衝突。 單擊以人手解決。",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "This week" : "本星期",
    "Last week" : "上星期",
    "This month" : "本月",
    "Last month" : "上月",
    "Search for notes" : "搜尋註釋",
    "Loading …" : "正在載入……",
    "Find in all categories" : "尋找所有分类",
    "Write down your thoughts without any distractions." : "專心記下你的想法。",
    "Use Markdown markups to style your text." : "使用 Markdown 標記來設定您的文字樣式。",
    "Organize your notes in categories." : "以不同分類組織筆記。",
    "Start writing a note by clicking on “{newnote}”." : "點選「{newnote}」開始寫筆記。",
    "Note not found." : "找不到筆記。",
    "Note is locked." : "筆記已上鎖。",
    "Insufficient storage." : "儲存空間不足。",
    "See JavaScript console and server log for details." : "請檢視 JavaScript 主控台與伺服器紀錄檔以取得詳細資訊。",
    "Updating settings has failed." : "更新設定失敗。",
    "Fetching notes for dashboard has failed." : "為儀表板擷取筆記失敗。",
    "Fetching notes has failed." : "筆記擷取失敗。",
    "Fetching note {id} has failed." : "筆記 {id} 擷取失敗。",
    "Refreshing note {id} has failed." : "筆記 {id} 更新失敗。",
    "Renaming note {id} has failed." : "筆記 {id} 重新命名失敗。",
    "Creating new note has failed." : "創建新筆記失敗。",
    "Saving note {id} has failed." : "筆記 {id} 儲存失敗。",
    "Updating title for note {id} has failed." : "筆記 {id} 標題更新失敗。",
    "Undo delete has failed for note {title}." : "還原已刪除筆記 {title} 失敗。",
    "Deleting note {id} has failed." : "刪除筆記 {id} 失敗。",
    "Toggling favorite for note {id} has failed." : "增/減筆記 {id} 到最愛失敗。",
    "Updating the note's category has failed. Is the target directory writable?" : "更新筆記的分類失敗。檢查目的地目錄屬性是否為可寫入？",
    "Updating the category for note {id} has failed." : "更新筆記 {id} 的分類失敗。",
    "Renaming category \"{category}\" has failed." : "重新命名分類「{category}」失敗。",
    "Deleting category \"{category}\" has failed." : "刪除分類「{category}」失敗。",
    "Uncategorized" : "未分類",
    "Sample note" : "範例筆記",
    "15 January 2021, via Nextcloud Notes" : "2021年1月15日，透過 Nextcloud Notes",
    "Me, you, and all our friends!" : "我，您與所有我們的朋友！",
    "Tasks" : "任務",
    "Write nice todo lists" : "編寫漂亮的待辦事項清單",
    "Buy Fries" : "買薯條",
    "Birthdays" : "生日",
    "Jen, in three days!" : "Jen，三天後！",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "檢閱步驟",
    "Turn PC off" : "把電腦關掉",
    "Turn PC on" : "開啟電腦",
    "Then call IT" : "然後致電 IT",
    "Quotes" : "報價",
    "Nextcloud, a safe home for all your data" : "Nextcloud，您資料的安全屋",
    "Development Mode" : "研發模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "看來筆記應用程式是從開發中的原始碼安裝的。請從官方的 <a href=\"%1$s\">Nextcloud App Store</a> 安裝。如果您想要自行建構筆記應用程式，請遵循<a href=\"%2$s\">開發者說明</a>進行操作。"
},
"nplurals=1; plural=0;");
