OC.L10N.register(
    "notes",
    {
    "Notes" : "메모",
    "Create new note" : "새 메모 쓰기",
    "More notes" : "더 많은 메모",
    "Reading notes from filesystem has failed." : "파일시스템에서 메모를 불러오기 실패",
    "Error" : "오류",
    "New note" : "새 메모",
    "Distraction-free notes and writing" : "방해 없는 무료 메모 작성 앱",
    "Deleted {title}" : "{title} 삭제함",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number}개의 메모를 삭제함"],
    "Undo Delete" : "삭제 취소",
    "Note recovered" : "메모 복원됨",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number}개의 메모를 복구함"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "저장하지 않은 메모가 있습니다. 이 페이지를 벗어나면 변경 사항이 손실됩니다!",
    "Notes settings" : "메모 설정",
    "Please see Nextcloud server log for details." : "Nextcloud 서버 로그에서 자세한 사항을 확인하십시오.",
    "Preview" : "미리 보기",
    "Make the selection bold" : "선택 영역 굵게",
    "Make the selection italic" : "선택 영역 기울이기",
    "Wrap the selection in quotes" : "선택 영역 인용문으로 묶기",
    "Remove any styles from the selected text" : "선택 영역에 지정된 모든 스타일 제거",
    "Makes the current line a list element" : "현재 줄을 목록으로 만들기",
    "Makes the current line a list element with a number" : "현재 줄을 숫자가 붙은 목록으로 만들기",
    "Insert link" : "링크 삽입",
    "Insert image" : "이미지 삽입",
    "Switch between editor and viewer" : "편집자와 독자 간 전환",
    "Display" : "디스플레이",
    "File extension" : "파일 확장자",
    "Mobile apps" : "모바일 앱",
    "Shortcuts" : "단축키",
    "Delete" : "삭제",
    "Cancel" : "취소",
    "All notes" : "모든 메모",
    "Categories" : "분류",
    "Create a sample note with Markdown" : "마크다운으로 간단한 메모를 작성하세요",
    "No notes yet" : "아직 메모 없음",
    "Select an image" : "이미지 선택",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "메모 폴더 밖에서 이미지를 선택할 수 없습니다. 현재 메모 폴더는 {folder}입니다",
    "Wrong image" : "잘못된 이미지",
    "The file was not uploaded. Check your server logs." : "파일이 업로드되지 않았습니다. 서버 로그를 참조하십시오.",
    "Upload image" : "이미지 업로드",
    "Rich text editor" : "리치 텍스트 편집기",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "이제 사용이 간편한 리치 텍스트 편집기로 전환할 수 있습니다. 각종 마크다운 표기 없이 메모를 수정할 수 있습니다.",
    "This option can also be changed later on in the Notes app settings." : "이 옵션은 Notes 앱 설정에서 언제든 변경할 수 있습니다.",
    "Keep plain Markdown editor" : "기본 마크다운 편집기 유지",
    "Use rich editor" : "리치 텍스트 편집기 사용",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add to favorites" : "즐겨찾기에 추가",
    "Error while renaming note." : "메모 이름을 바꾸는 중 오류 발생",
    "Error during preparing note for deletion." : "메모 삭제를 준비하는 중 오류 발생",
    "Share" : "공유",
    "Change category" : "카테고리 변경",
    "Rename" : "이름 바꾸기",
    "Rename note" : "메모 이름 바꾸기",
    "Delete note" : "메모 삭제",
    "Error from Nextcloud server: {msg}" : "Nextcloud 서버 오류: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "다른 세션에서 이 메모를 편집했습니다. 보존할 버전을 선택하십시오.",
    "Use version from server" : "서버 버전 사용",
    "Use current version" : "최근 버전을 사용하십시오.",
    "Empty note" : "빈 메모",
    "Write …" : "작성하기 ...",
    "Edit" : "편집",
    "Exit full screen" : "전체화면에서 나가기",
    "Full screen" : "전체화면",
    "Note is read-only. You cannot change it." : "메모가 읽기 전용이며 편집할 수 없습니다",
    "Save failed. Click to retry." : "저장을 실패했습니다. 클릭하여 다시 시도하십시오.",
    "Update conflict. Click for resolving manually." : "갱신 과정에서 충돌이 발생했습니다. 클릭하여 수동으로 문제를 해결하십시오.",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "This week" : "이번 주",
    "Last week" : "저번 주",
    "This month" : "이번 달",
    "Last month" : "저번 달",
    "Search for notes" : "메모 검색",
    "Loading …" : "불러오는 중 …",
    "Find in all categories" : "모든 카테고리에서 찾기",
    "Use Markdown markups to style your text." : "마크다운 기호 및 명령을 활용하여 문자를 꾸미십시오.",
    "Note not found." : "메모 없음",
    "Note is locked." : "메모가 잠겨 있습니다.",
    "Insufficient storage." : "저장소 용량이 부족합니다.",
    "See JavaScript console and server log for details." : "더 자세한 정보는 JavaScript 콘솔과 서버 로그를 참조하십시오.",
    "Updating settings has failed." : "설정을 갱신하지 못했습니다.",
    "Fetching notes for dashboard has failed." : "대시보드에 메모를 불러오지 못했습니다.",
    "Fetching notes has failed." : "메모를 불러오지 못했습니다.",
    "Fetching note {id} has failed." : "메모 {id}을(를) 불러오지 못했습니다.",
    "Refreshing note {id} has failed." : "메모 {id}(을)를 새로고침하지 못했습니다.",
    "Renaming note {id} has failed." : "메모 {id}의 이름을 변경하지 못했습니다.",
    "Creating new note has failed." : "새 메모를 만들지 못했습니다.",
    "Saving note {id} has failed." : "메모 {id}을(를) 저장하지 못했습니다.",
    "Updating title for note {id} has failed." : "메모 {id}의 제목을 갱신하지 못했습니다.",
    "Undo delete has failed for note {title}." : "메모 {title}의 삭제를 취소하지 못했습니다.",
    "Deleting note {id} has failed." : "메모 {id}을(를) 삭제하지 못했습니다.",
    "Toggling favorite for note {id} has failed." : "메모 {id}의 즐겨찾기 설정을 변경하지 못했습니다.",
    "Updating the note's category has failed. Is the target directory writable?" : "메모의 카테고리를 갱신하지 못했습니다. 대상 디렉토리에 쓰기 권한이 있는지 확인하십시오.",
    "Updating the category for note {id} has failed." : "메모 {id}의 카테고리를 갱신하지 못했습니다.",
    "Uncategorized" : "분류되지 않음",
    "Sample note" : "예시 메모",
    "15 January 2021, via Nextcloud Notes" : "2021년 1월 15일, Nextcloud Notes에서 작성됨",
    "Me, you, and all our friends!" : "당신, 나, 그리고 우리 모두에게!",
    "Tasks" : "작업",
    "Write nice todo lists" : "멋진 할 일 목록을 작성하기",
    "Buy Fries" : "튀김 사기",
    "Birthdays" : "생일",
    "Jen, in three days!" : "영철, 3일 남음",
    "Moss, 21.03.1973" : "철수, 1973년 3월 21일",
    "Roy, 1979" : "영희, 1979년",
    "Review Steps" : "단계별 과정 점검하기",
    "Turn PC off" : "컴퓨터 끄기",
    "Turn PC on" : "컴퓨터 켜기",
    "Then call IT" : "IT 부서에 연락하기",
    "Quotes" : "인용문",
    "Nextcloud, a safe home for all your data" : "Nextcloud, 내 모든 데이터의 안전한 저장소",
    "Development Mode" : "개발자 모드",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Notes 앱이 개발 플랫폼에서 설치된 것 같습니다. <a href=\"%1$s\">Nextcloud App Store</a>에서 다시 설치하십시오. Notes 앱을 직접 빌드하고자 한다면, <a href=\"%2$s\">개발자 지침</a>을 준수하십시오."
},
"nplurals=1; plural=0;");
