OC.L10N.register(
    "notes",
    {
    "Notes" : "Нататкі",
    "Create new note" : "Стварыць нататку",
    "More notes" : "Больш нататак",
    "Reading notes from filesystem has failed." : "Не ўдалося прачытаць нататкі з файлавай сістэмы.",
    "Error" : "Памылка",
    "New note" : "Новая нататка",
    "Distraction-free notes and writing" : "Нататкі і запісы, якія не адцягваюць увагу",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Праграма Нататкі — гэта праграма для стварэння нататак для [Nextcloud](https://www.nextcloud.com/). Яна прапануе катэгорыі для лепшай арганізацыі і падтрымлівае фарматаванне з выкарыстаннем сінтаксісу [Markdown](https://en.wikipedia.org/wiki/Markdown). Нататкі захоўваюцца ў выглядзе файлаў у вашым Nextcloud, таму вы можаце праглядаць і рэдагаваць іх з дапамогай любога кліента Nextcloud. Акрамя таго, асобны [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) дазваляе лёгка інтэграваць іх у праграмы ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), а таксама ў [староннія праграмы](https://github.com/nextcloud/notes/wiki#3rd-party-clients), якія забяспечваюць зручны доступ да вашых нататак Nextcloud). Дадатковыя функцыі ўключаюць пазначэнне нататак як абраных.",
    "Deleted {title}" : "Выдалена {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Выдалена {number} нататка","Выдалены {number} нататкі","Выдалена {number} нататак","Выдалена {number} нататак"],
    "Undo Delete" : "Адрабіць выдаленне",
    "Note recovered" : "Нататка адноўлена",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Адноўлена {number} нататка","Адноўлены {number} нататкі","Адноўлена {number} нататак","Адноўлена {number} нататак"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ёсць незахаваныя нататкі. Калі пакінуць старонку, усе змены будуць скасаваны!",
    "New category" : "Новая катэгорыя",
    "Notes settings" : "Налады Нататак",
    "Please see Nextcloud server log for details." : "Больш падрабязную інфармацыю шукайце ў журнале Nextcloud",
    "Rich text" : "Фарматаваны тэкст",
    "Plain text" : "Звычайны тэкст",
    "Preview" : "Перадпрагляд",
    "Make the selection bold" : "Зрабіць вылучэнне тоўстым",
    "Make the selection italic" : "Зрабіць вылучэнне курсівам",
    "Wrap the selection in quotes" : "Заключыце вылучэнне ў двукоссі",
    "The selection will be turned into monospace" : "Вылучэнне будзе ператворана ў монашырынны фармат",
    "Remove any styles from the selected text" : "Выдаліць усе стылі з вылучанага тэксту",
    "Makes the current line a list element" : "Ператварае бягучы радок у элемент спісу",
    "Makes the current line a list element with a number" : "Ператварае бягучы радок у элемент спісу з нумарам",
    "Toggle heading for current line" : "Пераключыць загаловак для бягучага радка",
    "Set the current line as a big heading" : "Задаць бягучы радок як вялікі загаловак",
    "Insert link" : "Уставіць спасылку",
    "Insert image" : "Уставіць відарыс",
    "Switch between editor and viewer" : "Пераключыцца паміж рэдактарам і праглядальнікам",
    "Pick a notes folder" : "Выберыце папку для нататак",
    "Set notes folder" : "Задаць папку для нататак",
    "General" : "Агульныя",
    "Display" : "Выгляд",
    "File extension" : "Пашырэнне файла",
    "For new notes" : "Для новых нататак",
    "Custom file extension" : "Карыстальніцкае пашырэнне файла",
    "Files" : "Файлы",
    "Mobile apps" : "Мабільныя праграмы",
    "Shortcuts" : "Спалучэнні клавіш",
    "Delete category" : "Выдаліць катэгорыю",
    "Delete" : "Выдаліць",
    "Cancel" : "Скасаваць",
    "All notes" : "Усе нататкі",
    "Categories" : "Катэгорыі",
    "Create a sample note with Markdown" : "Стварыць узорную нататку з дапамогай Markdownown",
    "No notes yet" : "Пакуль няма нататак",
    "Select an image" : "Выберыце відарыс",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Вы не можаце выбіраць відарысы па-за папкай для нататак. Ваша папка для нататак: {folder}",
    "Wrong image" : "Няправільны відарыс",
    "The file was not uploaded. Check your server logs." : "Файл не быў запампаваны. Праверце журналы сервера.",
    "Upload image" : "Запампаваць відарыс",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone і iPad",
    "Rich text editor" : "Рэдактар фарматаванага тэксту",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Цяпер вы можаце пераключыцца на просты ў выкарыстанні рэдактар ​​фарматаванага тэксту. Ён дазваляе рэдагаваць нататкі, не бачачы ніякіх пазнак Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Гэтую опцыю можна змяніць пазней у наладах праграмы \"Нататкі\".",
    "Keep plain Markdown editor" : "Пакінуць звычайны рэдактар ​​Markdown",
    "Use rich editor" : "Выкарыстоўваць рэдактар фарматаванага тэксту",
    "Remove from favorites" : "Выдаліць з абранага",
    "Add to favorites" : "У абранае",
    "Error while renaming note." : "Памылка пры перайменаванні нататкі.",
    "Error during preparing note for deletion." : "Памылка падчас падрыхтоўкі нататкі да выдалення.",
    "Share" : "Абагуліць",
    "Change category" : "Змяніць катэгорыю",
    "Rename" : "Перайменаваць",
    "Rename note" : "Перайменаваць нататку",
    "Delete note" : "Выдаліць нататку",
    "Error from Nextcloud server: {msg}" : "Памылка сервера Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Нататка была зменена ў іншым сеансе. Выберыце, якую версію трэба захаваць.",
    "Use version from server" : "Выкарыстоўваць версію з сервера",
    "Use current version" : "Выкарыстоўваць бягучую версію",
    "Empty note" : "Пустая нататка",
    "Write …" : "Пішыце …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Рэдагаваць",
    "Exit full screen" : "Выйсці з поўнаэкраннага рэжыму",
    "Full screen" : "На ўвесь экран",
    "Note is read-only. You cannot change it." : "Нататка толькі для чытання. Вы не можаце яе змяніць.",
    "Save failed. Click to retry." : "Не ўдалося захаваць. Націсніце, каб паўтарыць спробу.",
    "Update conflict. Click for resolving manually." : "Канфлікт абнаўленняў. Націсніце, каб вырашыць уручную.",
    "Today" : "Сёння",
    "Yesterday" : "Учора",
    "This week" : "Гэты тыдзень",
    "Last week" : "Мінулы тыдзень",
    "This month" : "Гэты месяц",
    "Last month" : "Мінулы месяц",
    "Search for notes" : "Пошук нататак",
    "Loading …" : "Загрузка …",
    "Find in all categories" : "Знайсці ва ўсіх катэгорыях",
    "Write down your thoughts without any distractions." : "Запісвайце свае думкі без адцягнення ўвагі.",
    "Use Markdown markups to style your text." : "Выкарыстоўваць разметку Markdown для стылізацыі тэксту.",
    "Organize your notes in categories." : "Арганізуйце свае нататкі па катэгорыях.",
    "Note not found." : "Нататка не знойдзена.",
    "Note is locked." : "Нататка заблакіравана.",
    "Insufficient storage." : "Недастаткова сховішча.",
    "See JavaScript console and server log for details." : "Больш падрабязную інфармацыю шукайце ў кансолі JavaScript і журнале сервера.",
    "Updating settings has failed." : "Не атрымалася абнавіць налады.",
    "Fetching notes for dashboard has failed." : "Не ўдалося атрымаць нататкі для панэлі кіравання.",
    "Fetching notes has failed." : "Не ўдалося атрымаць нататкі.",
    "Fetching note {id} has failed." : "Не ўдалося атрымаць нататку {id}.",
    "Refreshing note {id} has failed." : "Не ўдалося абнавіць нататку {id}.",
    "Renaming note {id} has failed." : "Не ўдалося перайменаваць нататку {id}.",
    "Creating new note has failed." : "Не ўдалося стварыць новую нататку.",
    "Saving note {id} has failed." : "Не ўдалося захаваць нататку {id}.",
    "Updating title for note {id} has failed." : "Не ўдалося абнавіць загаловак нататкі {id}.",
    "Undo delete has failed for note {title}." : "Не ўдалося адрабіць выдаленне нататкі {title}.",
    "Deleting note {id} has failed." : "Не ўдалося выдаліць нататку {id}.",
    "Toggling favorite for note {id} has failed." : "Не ўдалося дадаць/выдаліць нататку {id} з абранага.",
    "Updating the note's category has failed. Is the target directory writable?" : "Не ўдалося абнавіць катэгорыю нататкі. Ці даступны для запісу мэтавы каталог?",
    "Updating the category for note {id} has failed." : "Не ўдалося абнавіць катэгорыю нататкі {id}.",
    "Uncategorized" : "Без катэгорыі",
    "Sample note" : "Узор нататкі",
    "15 January 2021, via Nextcloud Notes" : "15 студзеня 2021 г., праз Нататкі Nextcloud",
    "Me, you, and all our friends!" : "Я, ты і ўсе нашы сябры!",
    "Tasks" : "Заданні",
    "Write nice todo lists" : "Пішыце прыгожыя спісы задач",
    "Buy Fries" : "Купіць бульбу",
    "Birthdays" : "Дні нараджэння",
    "Jen, in three days!" : "Ян, праз тры дні!",
    "Moss, 21.03.1973" : "Мойшэ, 21.03.1973",
    "Roy, 1979" : "Рыгор, 1979",
    "Review Steps" : "Этапы агляду",
    "Turn PC off" : "Выключыць камп'ютар",
    "Turn PC on" : "Уключыць камп'ютар",
    "Then call IT" : "Потым выклікаць ІТ-службу",
    "Quotes" : "Цытаты",
    "Nextcloud, a safe home for all your data" : "Nextcloud, бяспечны дом для ўсіх вашых даных",
    "Development Mode" : "Рэжым распрацоўкі",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Здаецца, праграма Нататкі была ўсталявана з зыходнікаў для распрацоўкі. Усталюйце яе з афіцыйнай крамы <a href=\"%1$s\">Nextcloud App Store</a>. Калі вы хочаце сабраць праграму самастойна, скарыстайцеся <a href=\"%2$s\">інструкцыяй для распрацоўшчыкаў</a>."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
