OC.L10N.register(
    "notes",
    {
    "Notes" : "Shënime",
    "Error" : "Error",
    "New note" : "Shënim i ri",
    "Preview" : "Parapamje ",
    "General" : "I përgjithshëm",
    "Files" : "Skedarët",
    "Delete" : "Fshini",
    "Cancel" : "Anullo",
    "All notes" : "Të gjitha shënimet",
    "Categories" : "Kategoritë",
    "No notes yet" : "Nuk ka shënime",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Shtoje tek të parapëlqyerat",
    "Share" : "Shpërndaje",
    "Rename" : "Rename",
    "Delete note" : "Fshije shënimin",
    "Use current version" : "Përdor versionin aktual",
    "Edit" : "Përpuno",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "This week" : "Këtë javë",
    "This month" : "Këtë muaj",
    "Uncategorized" : "Të pakategorizuara",
    "Tasks" : "Detyra"
},
"nplurals=2; plural=(n != 1);");
