OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Create new note" : "Crear una nota nueva",
    "More notes" : "Más notas",
    "Reading notes from filesystem has failed." : "Ha fallado la lectura de las notas desde el sistema de archivos.",
    "Error" : "Error",
    "New note" : "Nueva nota",
    "Distraction-free notes and writing" : "Escritura de notas sin distracciones",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "La aplicación Notas es una aplicación para tomar notas sin distracciones para [Nextcloud](https://www.nextcloud.com/). Permite categorizar las notas y también darles formato con [Markdown](https://en.wikipedia.org/wiki/Markdown). Las notas se guardan como archivos en tu Nextcloud, para que puedas verlas y editarlas con cualquier cliente de Nextcloud. Además, hay una [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) que permite integrarla en aplicaciones ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), y también [aplicaciones de terceros](https://github.com/nextcloud/notes/wiki#3rd-party-clients), que te permiten acceder cómodamente a tus notas de Nextcloud). También se puede marcar notas como favoritas.",
    "Deleted {title}" : "Borrado {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Borrada {number} nota","Borradas {number} notas","Borradas {number} notas"],
    "Undo Delete" : "Deshacer Borrado",
    "Note recovered" : "Nota recuperada",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Se recuperó {number} nota","Se recuperaron {number} notas","Se recuperaron {number} notas"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin guardar. ¡Abandonar la página descartará los cambios!",
    "Notes settings" : "Configuración de Notes",
    "Please see Nextcloud server log for details." : "Por favor, revisa el registro del servidor de Nextcloud para ver los detalles.",
    "Custom" : "Personalizado",
    "Rich text" : "Texto enriquecido",
    "Plain text" : "Texto plano",
    "Preview" : "Vista previa",
    "Make the selection bold" : "Hacer la selección negrita",
    "Make the selection italic" : "Hacer la selección cursiva",
    "Wrap the selection in quotes" : "Colocar la selección entre comillas",
    "The selection will be turned into monospace" : "La selección será convertida a monoespaciada",
    "Remove any styles from the selected text" : "Eliminar cualquier estilo del texto seleccionado",
    "Makes the current line a list element" : "Hace de la línea actual un elemento de lista",
    "Makes the current line a list element with a number" : "Hace de la línea actual un elemento de lista numerado",
    "Toggle heading for current line" : "Conmutar cabecera para la línea actual",
    "Set the current line as a big heading" : "Establecer la línea actual como cabecera grande",
    "Insert link" : "Insertar hipervínculo",
    "Insert image" : "Insertar imagen",
    "Switch between editor and viewer" : "Cambiar entre editor y visor",
    "Pick a notes folder" : "Elige una carpeta de notas",
    "Set notes folder" : "Establece una carpeta de notas",
    "General" : "General",
    "Display" : "Mostrar",
    "File extension" : "Extensión de archivo",
    "Notes folder" : "Carpeta de Notes",
    "Mobile apps" : "Aplicaciones móviles",
    "Shortcuts" : "Atajos",
    "Delete" : "Eliminar",
    "Cancel" : "Cancel",
    "All notes" : "Todas las notas",
    "Categories" : "Categorías",
    "Create a sample note with Markdown" : "Crear una nota de ejemplo con Markdown",
    "No notes yet" : "Aún no hay notas",
    "Select an image" : "Selecciona una imagen",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "No puedes seleccionar imágenes fuera de tu carpeta de notas. Tu carpeta de notas es: {folder}",
    "Wrong image" : "Imagen errónea",
    "The file was not uploaded. Check your server logs." : "El archivo no se ha subido. Comprueba los registros de tu servidor.",
    "Upload image" : "Subir imagen",
    "Rich text editor" : "Editor de texto enriquecido",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Puede ahora cambiar al sencillo y libre de distracciones editor de texto enriquecido. Le permite editar notas sin observar ninguna etiqueta Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Es opción puede también luego en la configuración de la app de Notas.",
    "Keep plain Markdown editor" : "Mantener el editor plano Markdown",
    "Use rich editor" : "Utilizar editor enriquecido",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "Error while renaming note." : "Error al renombrar la nota.",
    "Error during preparing note for deletion." : "Error al preparar nota para borrado.",
    "Share" : "Share",
    "Change category" : "Cambiar categoría",
    "Rename" : "Cambiar nombre",
    "Rename note" : "Renombrar nota",
    "Delete note" : "Eliminar nota",
    "Error from Nextcloud server: {msg}" : "Error desde el servidor Nextcloudr: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "La nota ha sido cambiada en otra sesión. Por favor, elija cuál debe ser guardada.",
    "Use version from server" : "Usar la versión del servidor",
    "Use current version" : "Usar esta versión",
    "Empty note" : "Nota vacía",
    "Write …" : "Escribir",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Salir de pantalla completa",
    "Full screen" : "Pantalla completa",
    "Note is read-only. You cannot change it." : "La nota es de sólo lectura. No la puede cambiar.",
    "Save failed. Click to retry." : "Fallo al guardar. Presiona para reintentarlo.",
    "Update conflict. Click for resolving manually." : "Conflicto al actualizar. Elija manualmente para resolver el problema.",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "This week" : "Esta semana",
    "Last week" : "La semana pasada",
    "This month" : "Este mes",
    "Last month" : "El mes pasado",
    "Search for notes" : "Buscar notas",
    "Loading …" : "Cargando …",
    "Find in all categories" : "Encontrar en todas las categorías",
    "Write down your thoughts without any distractions." : "Escribe tus pensamientos sin distracciones.",
    "Use Markdown markups to style your text." : "Utilice etiquetado Markdown para dar estilo a su texto.",
    "Organize your notes in categories." : "Organice sus notas en categorías.",
    "Note not found." : "Nota no encontrada.",
    "Note is locked." : "La nota está bloqueada.",
    "Insufficient storage." : "Almacenamiento insuficiente.",
    "See JavaScript console and server log for details." : "Revise la consola JavaScript y el registro del servidor para ver los detalles.",
    "Updating settings has failed." : "Fallo al guardar la configuración modificada.",
    "Fetching notes for dashboard has failed." : "Fallo al recuperar notas desde el  tablero.",
    "Fetching notes has failed." : "Fallo al recuperar las notas.",
    "Fetching note {id} has failed." : "Fallo al recuperar la nota {id}",
    "Refreshing note {id} has failed." : "Fallo al actualizar la nota {id}",
    "Renaming note {id} has failed." : "Fallo al renombrar la nota {id} .",
    "Creating new note has failed." : "Fallo al crear una nueva nota.",
    "Saving note {id} has failed." : "Fallo al guardar la nota {id}.",
    "Updating title for note {id} has failed." : "Fallo al actualizar el título de la nota {id}",
    "Undo delete has failed for note {title}." : "Ha fallado la operación de Deshacer el borrado para la nota {title}.",
    "Deleting note {id} has failed." : "El borrado de la nota {id} ha fallado.",
    "Toggling favorite for note {id} has failed." : "Fallo al marcar la nota {id} como favorita",
    "Updating the note's category has failed. Is the target directory writable?" : "Fallo al actualizar la categoría de la nota. ¿El directorio destino es escribible?",
    "Updating the category for note {id} has failed." : "Fallo al actualizar la categoría de la nota {id}",
    "Uncategorized" : "Sin categoría",
    "Sample note" : "Nota de prueba",
    "15 January 2021, via Nextcloud Notes" : "15 de Enero de 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "¡Tú, yo, y todos nuestros amigos!",
    "Tasks" : "Tareas",
    "Write nice todo lists" : "Escribir bonitas listas de tareas",
    "Buy Fries" : "Comprar patatas fritas",
    "Birthdays" : "Cumpleaños",
    "Jen, in three days!" : "Jen, en tres días!",
    "Moss, 21.03.1973" : "Moss, 21/03/1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Pasos de revisión",
    "Turn PC off" : "Apagar PC",
    "Turn PC on" : "Encender PC",
    "Then call IT" : "Entonces llamar a Informática",
    "Quotes" : "Presupuestos",
    "Nextcloud, a safe home for all your data" : "Nextcloud, un lugar seguro para todos tus datos",
    "Development Mode" : "Modo de Desarrollo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que la aplicación de notas ha sido instalada desde una fuente de desarrollo. Por favor instálela desde la <a href=\"%1$s\">AppStore de Nextcloud</a> oficial. Si quieres hacer la aplicación de Notas por ti mismo, por favor sigue las <a href=\"%2$s\">instrucciones para desarrolladores</a>."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
