OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Create new note" : "Crear unha nova nota",
    "More notes" : "Máis notas",
    "Reading notes from filesystem has failed." : "Produciuse un fallo na lectura de notas do sistema de ficheiros.",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Distraction-free notes and writing" : "Escritura de notas sen distraccións ",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "permitirA aplicación Notas é unha aplicación de toma de notas sen distraccións para o [Nextcloud](https://www.nextcloud.com/).  Proporciona categorías para unha mellor organización e admite o formatado empregando a sintaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). As notas gárdanse como ficheiros no seu Nextcloud, para que poidan ser vistas e editadas con todos os clientes do Nextcloud. Tamén, unha [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) permite unha doada integración nas aplicacións ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) así como [aplicacións de terceiros](https://github.com/nextcloud/notes/wiki#3rd-party-clients) que permiten un acceso cómodo ás súas notas de Nextcloud). Outras características inclúen marcar notas como favoritas.",
    "Deleted {title}" : "{title} foi eliminado",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Eliminada {number} nota","Eliminadas {number} notas"],
    "Undo Delete" : "Desfacer a eliminación",
    "Note recovered" : "Nota recuperada",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Recuperada {number} nota","Recuperadas {number} notas"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hai notas sen gardar. Saír da páxina desbotará todos os cambios!",
    "Notes settings" : "Axustes de Notas",
    "Please see Nextcloud server log for details." : "Vexa o rexistro do servidor de Nextcloud para obter máis detalles.",
    "Custom" : "Personalizado",
    "Rich text" : "Texto mellorado",
    "Plain text" : "Texto simple",
    "Preview" : "Vista previa",
    "Make the selection bold" : "Poñer a selección en negriña",
    "Make the selection italic" : "Poñer a selección en cursiva",
    "Wrap the selection in quotes" : "Envolver a selección entre comiñas",
    "The selection will be turned into monospace" : "A selección converterase a monoespazada",
    "Remove any styles from the selected text" : "Retirar calquera estilo do texto seleccionado",
    "Makes the current line a list element" : "Converte a liña actual nun elemento de lista",
    "Makes the current line a list element with a number" : "Converte a liña actual nun elemento de lista cun número",
    "Toggle heading for current line" : "Alternar o título para a liña actual",
    "Set the current line as a big heading" : "Definir a liña actual como un encabezamento  grande",
    "Insert link" : "Inserir unha ligazón",
    "Insert image" : "Inserir unha imaxe",
    "Switch between editor and viewer" : "Cambiar entre editor e visor",
    "Pick a notes folder" : "Escolla un cartafol de notas",
    "Set notes folder" : "Defina o cartafol de notas",
    "General" : "Xeral",
    "Display" : "Presentar",
    "File extension" : "Extensión de ficheiro",
    "For new notes" : "Para notas novas",
    "Custom file extension" : "Extensións de ficheiro personalizada",
    "Files" : "Ficheiros",
    "Notes folder" : "Cartafol de notas",
    "Mobile apps" : "Aplicacións móbiles",
    "Shortcuts" : "Atallos",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "All notes" : "Todas as notas",
    "Categories" : "Categorías",
    "Create a sample note with Markdown" : "Crear unha nota de mostra con Markdown",
    "No notes yet" : "Aínda non hai ningunha nota",
    "Select an image" : "Seleccione unha imaxe",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Non pode seleccionar imaxes fóra do cartafol de notas. O seu cartafol de notas é: {folder}",
    "Wrong image" : "Imaxe errónea",
    "The file was not uploaded. Check your server logs." : "Non se enviou o ficheiro. Consulte os ficheiros de rexistro do servidor.",
    "Upload image" : "Enviar imaxe",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone e iPad",
    "Rich text editor" : "Editor de texto mellorado",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Agora pode cambiar a usar o editor de texto mellorado doado de usar e sen distraccións. Permítelle editar notas sen ver ningunha marca de Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Esta opción tamén se pode cambiar máis tarde nos axustes da aplicación Notas.",
    "Keep plain Markdown editor" : "Manter o editor de Markdown sinxelo",
    "Use rich editor" : "Usar un editor mellorado",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "Error while renaming note." : "Produciuse un erro ao cambiar o nome da nota.",
    "Error during preparing note for deletion." : "Produciuse un erro ao preparar a nota para a eliminación.",
    "Share" : "Compartir",
    "Change category" : "Cambiar a categoría",
    "Rename" : "Cambiar o nome",
    "Rename note" : "Cambiar o nome da nota",
    "Delete note" : "Eliminar nota",
    "Error from Nextcloud server: {msg}" : "Produciuse un erro no servidor de Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "A nota foi modificada noutra sesión. Escolla que versión quere gardar.",
    "Use version from server" : "Usar a versión do servidor",
    "Use current version" : "Empregar a versión actual",
    "Empty note" : "Nota baleira",
    "Write …" : "Escribir…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Saír da pantalla completa",
    "Full screen" : "Pantalla completa",
    "Note is read-only. You cannot change it." : "A nota é de só lectura. Non pode cambiala.",
    "Save failed. Click to retry." : "Produciuse un fallo ao gardar. Prema para volver tentalo.",
    "Update conflict. Click for resolving manually." : "Conflito de actualización. Prema para resolvelo manualmente.",
    "Today" : "Hoxe",
    "Yesterday" : "Onte",
    "This week" : "Esta semana",
    "Last week" : "A semana pasada",
    "This month" : "Este mes",
    "Last month" : "O mes pasado",
    "Search for notes" : "Buscar notas",
    "Loading …" : "Cargando…",
    "Find in all categories" : "Atopar en todas as categorías",
    "Write down your thoughts without any distractions." : "Anote os seus pensamentos sen distraccións.",
    "Use Markdown markups to style your text." : "Empregue o marcado de Markdown para o estilo do seu texto.",
    "Organize your notes in categories." : "Organice as súas notas en categorías.",
    "Note not found." : "Non se atopou ningunha nota.",
    "Note is locked." : "A nota está bloqueada.",
    "Insufficient storage." : "Non hai espazo de almacenamento abondo.",
    "See JavaScript console and server log for details." : "Vexa a consola de JavaScript e o rexistro do servidor para os detalles.",
    "Updating settings has failed." : "Produciuse un fallo ao actualizar os axustes.",
    "Fetching notes for dashboard has failed." : "Produciuse un fallo ao recuperar as notas para o taboleiro.",
    "Fetching notes has failed." : "Produciuse un fallo ao recuperar as notas.",
    "Fetching note {id} has failed." : "Produciuse un fallo ao recuperar a nota {id}.",
    "Refreshing note {id} has failed." : "Produciuse un fallo ao actualizar a nota {id}.",
    "Renaming note {id} has failed." : "Produciuse un fallo ao cambiarlle o nome a nota {id}.",
    "Creating new note has failed." : "Produciuse un fallo ao crear a nova nota.",
    "Saving note {id} has failed." : "Produciuse un fallo ao gardar a nota {id}.",
    "Updating title for note {id} has failed." : "Produciuse un fallo ao actualizar o titulo da nota {id}.",
    "Undo delete has failed for note {title}." : "Produciuse un fallo ao desfacer a eliminación da nota {title}.",
    "Deleting note {id} has failed." : "Produciuse un fallo ao eliminar a nota {id}.",
    "Toggling favorite for note {id} has failed." : "Produciuse un fallo ao activar o favorito para a nota {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Produciuse un fallo ao actualizar a categoría da nota. Pódese escribir no directorio de destino?",
    "Updating the category for note {id} has failed." : "Produciuse un fallo ao actualizar a categoría da nota {id}.",
    "Uncategorized" : "Sen categorizar",
    "Sample note" : "Nota de mostra",
    "15 January 2021, via Nextcloud Notes" : "15 de xaneiro de 2021, a través de Notas de Nextcloud",
    "Me, you, and all our friends!" : "Eu, ti e todos os nosos amigos!",
    "Tasks" : "Tarefas",
    "Write nice todo lists" : "Escribir listas de tarefas agradábeis",
    "Buy Fries" : "Mercar patacas frixidas",
    "Birthdays" : "Aniversarios",
    "Jen, in three days!" : "Xiana, en tres días!",
    "Moss, 21.03.1973" : "Brais, 21.03.1973",
    "Roy, 1979" : "Roi, 1979",
    "Review Steps" : "Pasos de revisión",
    "Turn PC off" : "Apagar o PC",
    "Turn PC on" : "Acender o PC",
    "Then call IT" : "Após chame a un técnico informático",
    "Quotes" : "Citas",
    "Nextcloud, a safe home for all your data" : "Nextcloud, un acubillo seguro para todos os seus datos",
    "Development Mode" : "Modo desenvolvedor",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que a aplicación de notas foi instalada desde unha orixe de desenvolvemento. Instálea desde a <a href=\"%1$s\">tenda oficial de aplicacións de Nextcloud</a> en troques. Se quere construír a aplicación Notas por si mesmo, siga as <a href=\"%2$s\">instrucións do desenvolvedor</a>."
},
"nplurals=2; plural=(n != 1);");
