OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Create new note" : "Crear nueva nota",
    "More notes" : "Más notas",
    "Reading notes from filesystem has failed." : "Error al leer las notas desde el sistema de archivos.",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "Distraction-free notes and writing" : "Notas sin distracciones y escritura",
    "Deleted {title}" : "Borrado de {título}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Borrada {número} nota","Borradas {número} notas","Borradas {número} notas"],
    "Undo Delete" : "Deshacer borrado",
    "Note recovered" : "Nota recuperada",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Recuperada {número} nota","Recuperadas {número} notas","Recuperadas {número} notas"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
    "Notes settings" : "Configuración de notas",
    "Please see Nextcloud server log for details." : "Por favor, consulta el registro del servidor de Nextcloud para obtener más detalles.",
    "Preview" : "Previsualizar",
    "Make the selection bold" : "Poner en negrita la selección",
    "Make the selection italic" : "Poner en cursiva la selección",
    "Wrap the selection in quotes" : "Añadir comillas a la selección",
    "The selection will be turned into monospace" : "Convertir la selección en espacio de monoespacio",
    "Remove any styles from the selected text" : "Eliminar cualquier estilo del texto seleccionado",
    "Makes the current line a list element" : "Hacer que la línea actual sea un elemento de lista",
    "Makes the current line a list element with a number" : "Hacer que la línea actual sea un elemento de lista numerado",
    "Toggle heading for current line" : "Alternar encabezado para la línea actual",
    "Set the current line as a big heading" : "Establecer la línea actual como un encabezado grande",
    "Insert link" : "Insertar enlace",
    "Insert image" : "Insertar imagen",
    "Switch between editor and viewer" : "Alternar entre el editor y el visor",
    "File extension" : "Extensión de archivo",
    "Files" : "Archivos",
    "Mobile apps" : "Aplicaciones móviles",
    "Shortcuts" : "Atajos de teclado",
    "Cancel" : "Cancelar",
    "All notes" : "Todas las notas",
    "Categories" : "Categorías",
    "Create a sample note with Markdown" : "Crear una nota de muestra con Markdown",
    "No notes yet" : "Aún no hay notas",
    "Select an image" : "Seleccionar una imagen",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "No puedes seleccionar imágenes fuera de tu carpeta de notas. Tu carpeta de notas es: {carpeta}",
    "Wrong image" : "Imagen incorrecta",
    "The file was not uploaded. Check your server logs." : "No se ha subido el archivo. Comprueba los registros del servidor.",
    "Upload image" : "Subir imagen",
    "Rich text editor" : "Editor de texto enriquecido",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ahora puedes cambiar para usar el editor de texto enriquecido fácil de usar y sin distracciones. Te permite editar notas sin ver ninguna marca de Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Esta opción también se puede cambiar más tarde en la configuración de la aplicación de Notas.",
    "Keep plain Markdown editor" : "Mantener el editor de Markdown básico",
    "Use rich editor" : "Usar el editor enriquecido",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a tus favoritos",
    "Error during preparing note for deletion." : "Error al preparar la nota para el borrado.",
    "Share" : "Compartir",
    "Delete note" : "Borrar nota",
    "Error from Nextcloud server: {msg}" : "Error del servidor de Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "La nota ha sido modificada en otra sesión. Por favor, elige qué versión se debe guardar.",
    "Use version from server" : "Usar la versión del servidor",
    "Use current version" : "Usar la versión actual",
    "Empty note" : "Nota vacía",
    "Write …" : "Escribir …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Salir de pantalla completa",
    "Full screen" : "Pantalla completa",
    "Note is read-only. You cannot change it." : "La nota es de solo lectura. No puedes cambiarla.",
    "Save failed. Click to retry." : "Error al guardar. Haz clic para reintentar.",
    "Update conflict. Click for resolving manually." : "Conflicto de actualización. Haz clic para resolverlo manualmente.",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "This week" : "Esta semana",
    "Last week" : "Última semana",
    "This month" : "Este mes",
    "Last month" : "Último mes",
    "Search for notes" : "Buscar notas",
    "Loading …" : "Cargando...",
    "Find in all categories" : "Buscar en todas las categorías",
    "Write down your thoughts without any distractions." : "Escribe tus pensamientos sin distracciones.",
    "Use Markdown markups to style your text." : "Usa marcas de Markdown para dar formato a tu texto.",
    "Organize your notes in categories." : "Organiza tus notas en categorías.",
    "Note not found." : "Nota no encontrada.",
    "Note is locked." : "La nota está bloqueada.",
    "Insufficient storage." : "Almacenamiento insuficiente.",
    "See JavaScript console and server log for details." : "Consulta la consola de JavaScript y el registro del servidor para obtener más detalles.",
    "Updating settings has failed." : "Error al actualizar la configuración.",
    "Fetching notes for dashboard has failed." : "Error al obtener las notas para el panel de control.",
    "Fetching notes has failed." : "Error al obtener las notas.",
    "Fetching note {id} has failed." : "Error al obtener la nota {id}.",
    "Refreshing note {id} has failed." : "Error al actualizar la nota {id}.",
    "Renaming note {id} has failed." : "Error al cambiar el título de la nota {id}.",
    "Creating new note has failed." : "Error al crear una nueva nota.",
    "Saving note {id} has failed." : "Error al guardar la nota {id}.",
    "Updating title for note {id} has failed." : "Error al actualizar el título de la nota {id}.",
    "Undo delete has failed for note {title}." : "Error al deshacer el borrado de la nota {título}.",
    "Deleting note {id} has failed." : "Error al borrar la nota {id}.",
    "Toggling favorite for note {id} has failed." : "Error al alternar la nota {id} como favorita.",
    "Updating the note's category has failed. Is the target directory writable?" : "Error al actualizar la categoría de la nota. ¿El directorio de destino es modificable?",
    "Updating the category for note {id} has failed." : "Error al actualizar la categoría de la nota {id}.",
    "Uncategorized" : "Sin categoría",
    "Sample note" : "Nota de muestra",
    "15 January 2021, via Nextcloud Notes" : "15 de enero de 2021, a través de Notas de Nextcloud",
    "Me, you, and all our friends!" : "¡Yo, tú y todos nuestros amigos!",
    "Tasks" : "Tareas",
    "Write nice todo lists" : "Escribe listas de tareas agradables",
    "Buy Fries" : "Comprar patatas fritas",
    "Birthdays" : "Cumpleaños",
    "Jen, in three days!" : "Jen, en tres días",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Pasos para revisar",
    "Turn PC off" : "Apagar PC",
    "Turn PC on" : "Encender PC",
    "Then call IT" : "Llamar a IT",
    "Quotes" : "Citas",
    "Nextcloud, a safe home for all your data" : "Nextcloud, un hogar seguro para todos tus datos",
    "Development Mode" : "Modo de desarrollo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que la aplicación de Notas fue instalada desde una fuente de desarrollo. Por favor, instálala desde la <a href=\"%1$s\">Tienda de aplicaciones de Nextcloud</a> oficial en su lugar. Si deseas construir la aplicación de Notas tú mismo, sigue las <a href=\"%2$s\">instrucciones para desarrolladores</a>."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
