OC.L10N.register(
    "notes",
    {
    "Error" : "ýalňyşlyk",
    "Files" : "Faýllar",
    "Add to favorites" : "Saýlananlara goşuň",
    "Edit" : "Redaktirläň",
    "Today" : "Şu gün",
    "Yesterday" : "Düýn",
    "This week" : "Bu hepdede"
},
"nplurals=2; plural=(n != 1);");
