/*! For license information please see notes-node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-7_GNN76e_mjs.js.LICENSE.txt */
"use strict";(self.webpackChunknotes=self.webpackChunknotes||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-7_GNN76e_mjs"],{1580(e,t,a){a.r(t),a.d(t,{default:()=>v});var n=a(641),l=a(953),u=a(33),i=a(1777),s=a(3053),r=a(4564),o=a(7244),c=a(7859),m=a(7651),d=a(1379),p=a(240);function b(e){if(""===e.trim())return(0,m.t)("Names must not be empty.");if(e.startsWith("."))return(0,m.t)("Names must not start with a dot.");if(e.length>64)return(0,m.t)("Names may be at most 64 characters long.");try{return(0,d.KT)(e),""}catch(e){if(!(e instanceof d.di))throw e;switch(e.reason){case d.nF.Character:return(0,m.t)('"{char}" is not allowed inside a name.',{char:e.segment});case d.nF.ReservedName:return(0,m.t)('"{segment}" is a reserved name and not allowed.',{segment:e.segment});case d.nF.Extension:return e.segment.match(/\.[a-z]/i)?(0,m.t)('"{extension}" is not an allowed name.',{extension:e.segment}):(0,m.t)('Names must not end with "{extension}".',{extension:e.segment});default:return(0,m.t)("Invalid name.")}}}const h={key:0,class:"public-auth-prompt__text"},f=(0,n.pM)({__name:"PublicAuthPrompt",props:{nickname:{default:""},title:{default:(0,m.t)("Guest identification")},text:{default:""},notice:{default:""},submitLabel:{default:(0,m.t)("Submit name")},cancellable:{type:Boolean}},emits:["close"],setup(e,{emit:t}){const a=e,d=t,p=(0,n.rk)("input"),f=(0,s.c0)("public").build(),v=(0,l.KR)(a.nickname);(0,n.wB)(()=>a.nickname,()=>{v.value=a.nickname}),(0,n.wB)(v,e=>{const t=b(e);t||!p.value||g(t)});const _=(0,n.EW)(()=>{const e={label:(0,m.t)("Cancel"),variant:"tertiary",callback:()=>d("close")},t={label:a.submitLabel,type:"submit",variant:"primary"};return a.cancellable?[e,t]:[t]}),y=(0,n.EW)(()=>a.notice?a.notice:v.value?(0,m.t)("You are currently identified as {nickname}.",{nickname:v.value}):(0,m.t)("You are currently not identified."));function k(){const e=v.value.trim(),t=b(e);if(t)g(t);else if(""!==e)if(e.length<2)g((0,m.t)("Please enter a name with at least 2 characters."));else{try{(0,i.L$)(e)}catch(e){return m.l.error("Failed to set nickname",{error:e}),(0,m.s)((0,m.t)("Failed to set nickname.")),void p.value.focus()}f.setItem("public-auth-prompt-shown","true"),d("close",v.value)}else g((0,m.t)("You cannot leave the name empty."))}function g(e){p.value&&(p.value.setCustomValidity(e),p.value.reportValidity(),p.value.focus())}return(t,a)=>((0,n.uX)(),(0,n.Wv)((0,l.R1)(r.A),{buttons:_.value,class:"public-auth-prompt","data-cy-public-auth-prompt-dialog":"",isForm:"",noClose:"",name:e.title,onSubmit:k},{default:(0,n.k6)(()=>[e.text?((0,n.uX)(),(0,n.CE)("p",h,(0,u.v_)(e.text),1)):(0,n.Q3)("",!0),(0,n.bF)((0,l.R1)(o.A),{class:"public-auth-prompt__header",text:y.value,type:"info"},null,8,["text"]),(0,n.bF)((0,l.R1)(c.A),{ref:"input",modelValue:v.value,"onUpdate:modelValue":a[0]||(a[0]=e=>v.value=e),class:"public-auth-prompt__input","data-cy-public-auth-prompt-dialog-name":"",label:(0,l.R1)(m.t)("Name"),placeholder:(0,l.R1)(m.t)("Enter your name"),required:!e.cancellable,minlength:"2",maxlength:"64",name:"name"},null,8,["modelValue","label","placeholder","required"])]),_:1},8,["buttons","name"]))}}),v=(0,p._)(f,[["__scopeId","data-v-bd4b7f1b"]])}}]);
//# sourceMappingURL=notes-node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-7_GNN76e_mjs.js.map?v=4e5dea25816ef8553eb7