OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "Create new note" : "Skapa ny anteckning",
    "More notes" : "Fler anteckningar",
    "Reading notes from filesystem has failed." : "Läsa anteckningar från filsystemet misslyckades.",
    "Error" : "Fel",
    "New note" : "Ny anteckning",
    "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
    "Deleted {title}" : "Raderad {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
    "Undo Delete" : "Ångra radering",
    "Note recovered" : "Anteckning återskapad",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
    "New category" : "Ny kategori",
    "Notes settings" : "Anteckningsinställningar",
    "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
    "Custom" : "Anpassad",
    "Rich text" : "Formaterad text",
    "Plain text" : "Oformaterad text",
    "Preview" : "Förhandsvisa",
    "Make the selection bold" : "Gör markeringen fetstil",
    "Make the selection italic" : "Gör markeringen kursiv",
    "Wrap the selection in quotes" : "Sätt markeringen inom citattecken",
    "The selection will be turned into monospace" : "Urvalet kommer att förvandlas till monospace",
    "Remove any styles from the selected text" : "Ta bort all formatering från den markerade texten",
    "Makes the current line a list element" : "Gör den aktuella raden till ett listelement",
    "Makes the current line a list element with a number" : "Gör den aktuella raden till ett listelement med ett nummer",
    "Toggle heading for current line" : "Växla rubrik för aktuell rad",
    "Set the current line as a big heading" : "Ställ in den aktuella raden som en stor rubrik",
    "Insert link" : "Infoga länk",
    "Insert image" : "Infoga bild",
    "Switch between editor and viewer" : "Växla mellan redigerings och visnings -läge",
    "Pick a notes folder" : "Välj en anteckningsmapp",
    "Set notes folder" : "Ställ in anteckningsmapp",
    "General" : "Allmänt",
    "Display" : "Visa",
    "File extension" : "Filändelse",
    "For new notes" : "För nya anteckningar",
    "Custom file extension" : "Anpassad filändelse",
    "Files" : "Filer",
    "Notes folder" : "Anteckningsmapp",
    "Mobile apps" : "Mobilappar",
    "Shortcuts" : "Genvägar",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Ta bort kategorin \"{category}\" och dess {count} anteckning?","Ta bort kategorin \"{category}\" och dess {count} anteckningar?"],
    "Delete category" : "Ta bort kategori",
    "Delete" : "Ta bort",
    "Cancel" : "Cancel",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "Rename category" : "Byt namn på kategori",
    "Create a sample note with Markdown" : "Skapa en exempelanteckning med Markdown",
    "No notes yet" : "Inga anteckningar än",
    "Select an image" : "Välj en bild",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Du kan inte välja bilder utanför din anteckningsmapp. Din anteckningsmapp är: {folder}",
    "Wrong image" : "Fel bild",
    "The file was not uploaded. Check your server logs." : "Filen laddades inte upp. Kontrollera dina serverloggar.",
    "Upload image" : "Ladda upp bild",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone och iPad",
    "Rich text editor" : "Rich text-editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Du kan nu byta till att använda den lättanvända och distraktionsfria textredigeraren. Det låter dig redigera anteckningar utan att se några Markdown-märken.",
    "This option can also be changed later on in the Notes app settings." : "Det här alternativet kan också ändras senare i Notes-appens inställningar.",
    "Keep plain Markdown editor" : "Behåll vanlig Markdown-redigerare",
    "Use rich editor" : "Använd rich text-editor",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Error while renaming note." : "Fel vid byte av namn på anteckning.",
    "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
    "Share" : "Dela",
    "Change category" : "Ändra kategori",
    "Rename" : "Byt namn",
    "Rename note" : "Byt namn på anteckningen",
    "Delete note" : "Ta bort anteckning",
    "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Anteckningen har modifierats i en annan session. Vänligen välj vilken version som skall sparas.",
    "Use version from server" : "Använd version från servern",
    "Use current version" : "Använd nuvarande version",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Redigera",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Note is read-only. You cannot change it." : "Anteckningen är skrivskyddad. Du kan inte ändra den.",
    "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
    "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa upp manuellt.",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Search for notes" : "Sök efter anteckningar",
    "Loading …" : "Läser in ...",
    "Find in all categories" : "Hitta i alla kategorier",
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Start writing a note by clicking on “{newnote}”." : "Börja skriva en anteckning genom att klicka på “{newnote}”.",
    "Note not found." : "Anteckningen hittades inte.",
    "Note is locked." : "Anteckningen är låst.",
    "Insufficient storage." : "Otillräckligt utrymme.",
    "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
    "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
    "Fetching notes for dashboard has failed." : "Hämtning av anteckningar för dashboarden misslyckades",
    "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
    "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
    "Refreshing note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
    "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
    "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
    "Saving note {id} has failed." : "Spara anteckning {id} misslyckades.",
    "Updating title for note {id} has failed." : "Uppdatering av titel för anteckning {id} misslyckades.",
    "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
    "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
    "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
    "Renaming category \"{category}\" has failed." : "Det gick inte att byta namn på kategorin \"{category}\".",
    "Deleting category \"{category}\" has failed." : "Det gick inte att ta bort på kategorin \"{category}\".",
    "Uncategorized" : "Okategoriserad",
    "Sample note" : "Exempelanteckning",
    "15 January 2021, via Nextcloud Notes" : "15 januari 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Jag, du och alla våra vänner!",
    "Tasks" : "Uppgifter",
    "Write nice todo lists" : "Skriv fina att göra-listor",
    "Buy Fries" : "Köp pommes frites",
    "Birthdays" : "Födelsedagar",
    "Jen, in three days!" : "Jen, om tre dagar!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Granska steg",
    "Turn PC off" : "Stäng av datorn",
    "Turn PC on" : "Slå på datorn",
    "Then call IT" : "Ring sedan IT",
    "Quotes" : "Citat",
    "Nextcloud, a safe home for all your data" : "Nextcloud, ett säkert hem för all din data",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
},
"nplurals=2; plural=(n != 1);");
