OC.L10N.register(
    "notes",
    {
    "Notes" : "Notities",
    "Create new note" : "Nieuwe notitie aanmaken",
    "More notes" : "Meer notities",
    "Reading notes from filesystem has failed." : "Het ophalen van notities van het bestandssysteem is mislukt.",
    "Error" : "Fout",
    "New note" : "Nieuwe notitie",
    "Distraction-free notes and writing" : "Afleidingsvrije notities en schrijven",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "De Notes-app is een app voor het maken van afleidingsvrije notities [Nextcloud](https://www.nextcloud.com/). Het biedt categorieën voor een betere organisatie en ondersteunt formatteren met behulp van [Markdown](https://en.wikipedia.org/wiki/Markdown) syntaxis. Notities worden opgeslagen als bestanden in jouw Nextcloud, zodat je ze bij elke Nextcloud-client kunt bekijken en bewerken. Bovendien zorgt een aparte [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) voor een gemakkelijke integratie in apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), zowel als [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) die gemakkelijke toegang tot je Nextcloud-notities mogelijk maken). Verdere kenmerken zijn het markeren van notities als favorieten.",
    "Deleted {title}" : "{title} verwijderd",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Verwijderde {number} notitie","{number} notities verwijderd"],
    "Undo Delete" : "Verwijderen ongedaan maken",
    "Note recovered" : "Notitie hersteld",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Herstelde {number} notitie","{number} notities hersteld"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Er zijn niet-opgeslagen notities. Als je de pagina verlaat gaan je wijzigingen verloren!",
    "Notes settings" : "Notities instellingen",
    "Please see Nextcloud server log for details." : "Bekijk het Nextcloud-serverlogboek voor details.",
    "Custom" : "Aangepast",
    "Rich text" : "Rich tekst",
    "Plain text" : "Platte tekst",
    "Preview" : "Voorbeeld",
    "Make the selection bold" : "Zet de selectie in vet",
    "Make the selection italic" : "Zet de selectie in cursief",
    "Wrap the selection in quotes" : "Zet aanhalingstekens rond de selectie",
    "The selection will be turned into monospace" : "De selectie wordt omgezet naar vaste letterbreedte",
    "Remove any styles from the selected text" : "Alle stijlen verwijderen uit de geselecteerde tekst",
    "Makes the current line a list element" : "Maakt de huidige regel tot een lijstelement",
    "Makes the current line a list element with a number" : "Maakt de huidige regel tot een genummerd lijstelement",
    "Toggle heading for current line" : "Kopstijl schakelen voor huidige regel",
    "Set the current line as a big heading" : "Stel de huidige regel in als een grote kop",
    "Insert link" : "Link invoegen",
    "Insert image" : "Invoegen afbeelding",
    "Switch between editor and viewer" : "Wisselen tussen bewerken en weergave",
    "Pick a notes folder" : "Kies een map voor notities",
    "Set notes folder" : "Map voor notities instellen",
    "General" : "Algemeen",
    "Display" : "Scherm",
    "File extension" : "Bestandsextensie",
    "For new notes" : "Voor nieuwe notities",
    "Custom file extension" : "Aangepaste bestandsextensie",
    "Files" : "Bestanden",
    "Notes folder" : "Map voor notities",
    "Mobile apps" : "Mobiele apps",
    "Shortcuts" : "Snelkoppelingen",
    "Delete" : "Verwijderen",
    "Cancel" : "Annuleren",
    "All notes" : "Alle notities",
    "Categories" : "Categorieën",
    "Create a sample note with Markdown" : "Maak een voorbeeldnotitie met Markdown",
    "No notes yet" : "Nog geen notities aanwezig",
    "Select an image" : "Selecteer een afbeelding",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "U kan geen beelden kiezen buiten uw notities map. Uw notities map is {folder}",
    "Wrong image" : "Verkeerde afbeelding",
    "The file was not uploaded. Check your server logs." : "Het bestand is niet geupload. Bekijk uw Server-logboeken",
    "Upload image" : "Upload afbeelding",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone en iPad",
    "Rich text editor" : "Rich text-editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Je kunt nu overschakelen naar de gebruiksvriendelijke en afleidingsvrije rich text-editor. Hiermee kun je notities bewerken zonder enige Markdown-tekens te zien.",
    "This option can also be changed later on in the Notes app settings." : "Deze optie kan later ook in de instellingen van de Notities-app worden gewijzigd.",
    "Keep plain Markdown editor" : "Eenvoudige Markdown-editor gebruiken",
    "Use rich editor" : "Rich text-editor gebruiken",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Toevoegen aan favorieten",
    "Error while renaming note." : "Fout bij het hernoemen van de notitie.",
    "Error during preparing note for deletion." : "Fout bij voorbereiden van verwijdering van notitie",
    "Share" : "Delen",
    "Change category" : "Categorie wijzigen",
    "Rename" : "Hernoemen",
    "Rename note" : "Notitie hernoemen",
    "Delete note" : "Verwijder notitie",
    "Error from Nextcloud server: {msg}" : "Fout van Nextcloud-server: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "De notitie is aangepast in een andere sessie. Kies welke versie opgeslagen moet worden.",
    "Use version from server" : "Gebruik de versie van de server",
    "Use current version" : "Gebruik de huidige versie",
    "Empty note" : "Lege notitie",
    "Write …" : "Schrijf ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Bewerken",
    "Exit full screen" : "Verlaat volledig scherm",
    "Full screen" : "Volledig scherm",
    "Note is read-only. You cannot change it." : "Notitie is in alleen-lezen modus. Je kunt die niet wijzigen.",
    "Save failed. Click to retry." : "Opslaan mislukt. Klik om opnieuw te proberen.",
    "Update conflict. Click for resolving manually." : "Bijwerkconflict. Klik om het handmatig op te lossen.",
    "Today" : "Vandaag",
    "Yesterday" : "Gisteren",
    "This week" : "Deze week",
    "Last week" : "Vorige week",
    "This month" : "Deze maand",
    "Last month" : "Vorige maand",
    "Search for notes" : "Notities zoeken",
    "Loading …" : "Laden ...",
    "Find in all categories" : "Alle categorieën doorzoeken",
    "Write down your thoughts without any distractions." : "Schrijf je gedachten op zonder afleiding.",
    "Use Markdown markups to style your text." : "Gebruik Markdown markeringen om je tekst op te maken.",
    "Organize your notes in categories." : "Organiseer je notities in categorieën. ",
    "Note not found." : "Notitie niet gevonden.",
    "Note is locked." : "Notitie is geblokkeerd.",
    "Insufficient storage." : "Onvoldoende opslagruimte",
    "See JavaScript console and server log for details." : "Bekijk JavaScript-console en server-log voor details.",
    "Updating settings has failed." : "Update van instellingen mislukt.",
    "Fetching notes for dashboard has failed." : "Ophalen van notities voor dashboard mislukt.",
    "Fetching notes has failed." : "Notities ophalen mislukt.",
    "Fetching note {id} has failed." : "Notitie {id} ophalen mislukt.",
    "Refreshing note {id} has failed." : "Het vernieuwen van notitie {id} is mislukt.",
    "Renaming note {id} has failed." : "Hernoemen notitie {id} mislukt.",
    "Creating new note has failed." : "Notitie aanmaken mislukt.",
    "Saving note {id} has failed." : "Opslaan notitie {id} mislukt.",
    "Updating title for note {id} has failed." : "Het updaten van de titel voor notitie {id} is mislukt.",
    "Undo delete has failed for note {title}." : "Verwijderen ongedaan maken is mislukt voor notitie {title}.",
    "Deleting note {id} has failed." : "Notitie {id} verwijderen mislukt.",
    "Toggling favorite for note {id} has failed." : "Favoriet bijwerken voor notitie {id} mislukt.",
    "Updating the note's category has failed. Is the target directory writable?" : "Bijwerken van de notitiecategorie mislukt. Is de doelmap beschrijfbaar?",
    "Updating the category for note {id} has failed." : "Categorie bijwerken voor notitie {id} mislukt.",
    "Uncategorized" : "Niet gecategoriseerd ",
    "Sample note" : "Voorbeeldnotitie",
    "15 January 2021, via Nextcloud Notes" : "15 Januari 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Ik, jij en al onze vrienden!",
    "Tasks" : "Taken",
    "Write nice todo lists" : "Schrijf leuke todolijsten",
    "Buy Fries" : "Koop frietjes",
    "Birthdays" : "Verjaardagen",
    "Jen, in three days!" : "Jen, over drie dagen!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Stappen reviewen",
    "Turn PC off" : "Schakel PC uit",
    "Turn PC on" : "Schakel PC in",
    "Then call IT" : "Bel dan met IT",
    "Quotes" : "Offertes",
    "Nextcloud, a safe home for all your data" : "Nextcloud, een veilige plek voor al je gegevens",
    "Development Mode" : "Ontwikkelmodus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Het lijkt erop dat de Notities-app werd geïnstalleerd vanuit een ontwikkelbron. Installeer de app alsjeblieft vanuit de officiële <a href=\"%1$s\">Nextcloud App Store</a>. Als je de Notities-app zelf wilt opbouwen, volg dan de  <a href=\"%2$s\">ontwikkelaarsinstructies</a>."
},
"nplurals=2; plural=(n != 1);");
