OC.L10N.register(
    "notes",
    {
    "Notes" : "Заметки",
    "Create new note" : "Создать новую заметку",
    "More notes" : "Еще заметки",
    "Reading notes from filesystem has failed." : "Не удалось чтение заметок из файловой системы.",
    "Error" : "Ошибка",
    "New note" : "Новая заметка",
    "Distraction-free notes and writing" : "Простые заметки и записки",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Приложение «Заметки» — это инструмент для создания заметок без отвлекающих элементов, разработанный для [Nextcloud](https://www.nextcloud.com/). Оно позволяет удобно организовывать заметки по категориям и поддерживает форматирование с помощью синтаксиса Markdown. Заметки сохраняются как файлы в вашем Nextcloud, поэтому вы можете просматривать и редактировать их с любого клиента Nextcloud. Кроме того, доступен [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md), который упрощает интеграцию с другими приложениями, включая ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) и [сторонние клиенты](https://github.com/nextcloud/notes/wiki#3rd-party-clients) , обеспечивающие удобный доступ к вашим заметкам. Приятным дополнением к перечисленному является возможность помещать отдельные заметки в избранное.",
    "Deleted {title}" : "Заметка {title} удалена",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Удалена [number] заметка","Удалены [number] заметки","Удалено [number] заметок","Удалено [number] заметок"],
    "Undo Delete" : "Отменить удаление",
    "Note recovered" : "Заметка восстановлена",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Восстановлена [number] заметка","Восстановлены [number] заметки","Восстановлено [number] заметок","Восстановлено [number] заметок"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Есть несохранённые заметки. Если покинуть страницу, все изменения будут утеряны!",
    "Notes settings" : "Настройки заметок",
    "Please see Nextcloud server log for details." : "Для получения подробной информации, пожалуйста, обратитесь к журналам сервера Nextcloud.",
    "Custom" : "Задать",
    "Rich text" : "Rich text",
    "Plain text" : "Обычный текст",
    "Preview" : "Предпросмотр",
    "Make the selection bold" : "Сделайте выделение жирным",
    "Make the selection italic" : "Сделайте выделение курсивом",
    "Wrap the selection in quotes" : "Заключите выделение в кавычки",
    "The selection will be turned into monospace" : "Выделение будет переведено в моноширинный режим",
    "Remove any styles from the selected text" : "Убрать все стили с выделенного текста",
    "Makes the current line a list element" : "Делает текущую строку элементом списка",
    "Makes the current line a list element with a number" : "Делает текущую строку элементом списка с номером",
    "Toggle heading for current line" : "Переключить заголовок для текущей строки",
    "Set the current line as a big heading" : "Установите текущую строку как большой заголовок",
    "Insert link" : "Вставить ссылку",
    "Insert image" : "Вставить изображение",
    "Switch between editor and viewer" : "Переключиться между редактированием и просмотром",
    "Pick a notes folder" : "Выберите папку для заметок",
    "Set notes folder" : "Установить папку для заметок",
    "General" : "Основные",
    "Display" : "Экран",
    "File extension" : "Расширение файла",
    "Files" : "файлов",
    "Notes folder" : "Папка заметок",
    "Mobile apps" : "Мобильные приложения",
    "Shortcuts" : "Горячие клавиши",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "All notes" : "Все заметки",
    "Categories" : "Категории",
    "Create a sample note with Markdown" : "Создайте образец заметки с помощью Markdown",
    "No notes yet" : "Нет ни одной заметки",
    "Select an image" : "Выберите изображение",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Вы не можете выбрать изображения вне папки заметок. Ваша папка заметок: {папка}",
    "Wrong image" : "Неверное изображение",
    "The file was not uploaded. Check your server logs." : "Файл не был загружен. Проверьте журналы вашего сервера.",
    "Upload image" : "Загрузить изображение",
    "Rich text editor" : "Редактор форматированного текста",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Теперь вы можете переключиться на использование простого в использовании и свободного от отвлекающих факторов редактора форматированного текста. Он позволяет вам редактировать заметки, не видя разметки Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Эту настройку также можно изменить позже в настройках приложения \"Заметки\".",
    "Keep plain Markdown editor" : "Сохраните простой редактор Markdown",
    "Use rich editor" : "Использовать расширенный редактор",
    "Remove from favorites" : "Убрать из избранного",
    "Add to favorites" : "Добавить в избранное",
    "Error while renaming note." : "Ошибка при переименовании заметки.",
    "Error during preparing note for deletion." : "Не удалось подготовить заметку к удалению,",
    "Share" : "Публикация",
    "Change category" : "Изменить категорию",
    "Rename" : "Переименовать",
    "Rename note" : "Переименовать заметку",
    "Delete note" : "Удалить заметку",
    "Error from Nextcloud server: {msg}" : "Ошибка сервера Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Данная заметка была изменена в другой сессии. Пожалуйста, выберите, какую версию сохранить.",
    "Use version from server" : "Использовать версию с сервера",
    "Use current version" : "Использовать текущую версию",
    "Empty note" : "Пустая заметка",
    "Write …" : "Запись…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Править",
    "Exit full screen" : "Выйти из полноэкранного режима",
    "Full screen" : "Во весь экран",
    "Note is read-only. You cannot change it." : "Заметка только для чтения. Вы не можете изменить её.",
    "Save failed. Click to retry." : "Сохранение не удалось. Нажмите для повтора.",
    "Update conflict. Click for resolving manually." : "Конфликт обновления. Щелкните для разрешения вручную.",
    "Today" : "Сегодня",
    "Yesterday" : "Вчера",
    "This week" : "Эта неделя",
    "Last week" : "За последнюю неделю",
    "This month" : "Этот месяц",
    "Last month" : "За последний месяц",
    "Search for notes" : "Поиск заметок",
    "Loading …" : "Загрузка ...",
    "Find in all categories" : "Найти во всех категориях",
    "Write down your thoughts without any distractions." : "Записывайте свои мысли, ни на что не отвлекаясь.",
    "Use Markdown markups to style your text." : "Поддержка языка разметки Markdown для оформления текста;",
    "Organize your notes in categories." : "Поддержка категорий;",
    "Note not found." : "Заметка не найдена",
    "Note is locked." : "Заметка заблокирована",
    "Insufficient storage." : "Недостаточно места",
    "See JavaScript console and server log for details." : "Подробные сведения приведены в консоли JavaScript и файле журнала сервера.",
    "Updating settings has failed." : "Не удалось сохранить изменения.",
    "Fetching notes for dashboard has failed." : "Не удалось получить заметки для панели.",
    "Fetching notes has failed." : "Не удалось получить заметки.",
    "Fetching note {id} has failed." : "Не удалось получить заметку {id}.",
    "Refreshing note {id} has failed." : "Не удалось обновить заметку {id}.",
    "Renaming note {id} has failed." : "Не удалось переименовать заметку {id}.",
    "Creating new note has failed." : "Не удалось создать заметку.",
    "Saving note {id} has failed." : "Не удалось сохранить заметку {id}.",
    "Updating title for note {id} has failed." : "Не удалось обновление заголовка для заметки {id}.",
    "Undo delete has failed for note {title}." : "Не удалось отменить удаление заметки {title}.",
    "Deleting note {id} has failed." : "Не удалось удалить заметку {id}.",
    "Toggling favorite for note {id} has failed." : "Не удалось установить отметку «избранное» для заметки {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Не удалось обновить категорию заметки. Разрешена ли запись в целевую директорию?",
    "Updating the category for note {id} has failed." : "Не удалось обновить категорию для заметки {id}.",
    "Uncategorized" : "Без категории",
    "Sample note" : "Пример заметки",
    "15 January 2021, via Nextcloud Notes" : "15 января 2021 г., через Nextcloud Notes",
    "Me, you, and all our friends!" : "Я, ты и все наши друзья!",
    "Tasks" : "Задачи",
    "Write nice todo lists" : "Напишите хорошие списки дел",
    "Buy Fries" : "Купить картофель фри",
    "Birthdays" : "Дни рождения",
    "Jen, in three days!" : "Джен, через три дня!",
    "Moss, 21.03.1973" : "Мосс, 21.03.1973",
    "Roy, 1979" : "Рой, 1979",
    "Review Steps" : "Обзор шагов",
    "Turn PC off" : "Выключить ПК",
    "Turn PC on" : "Включить ПК",
    "Then call IT" : "Тогда позвоните в ИТ-отдел",
    "Quotes" : "Кавычки",
    "Nextcloud, a safe home for all your data" : "Nextcloud — безопасное место для всех ваших данных",
    "Development Mode" : "Режим разработки",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Вероятно, это приложение было установлено из источника, предназначенного для разработчиков. Настоятельно рекомендуется переустановить его из официального <a href=\"%1$s\">каталога приложений Nextcloud</a>. Инструкции по самостоятельной сборке приложения приведены в  <a href=\"%2$s\">руководстве для разработчиков</a>."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
