OC.L10N.register(
    "notes",
    {
    "Notes" : "הערות",
    "Reading notes from filesystem has failed." : "קריאת הפתקים ממערכת הקבצים נכשלה.",
    "Error" : "שגיאה",
    "New note" : "פתק חדש",
    "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
    "Deleted {title}" : "{title} נמחק",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו"],
    "Undo Delete" : "ביטול מחיקה",
    "Note recovered" : "הפתק שוחזר",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
    "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
    "Preview" : "תצוגה מקדימה",
    "Insert image" : "הוספת תמונה",
    "Shortcuts" : "קיצורי דרך",
    "Delete" : "Delete",
    "Cancel" : "ביטו",
    "All notes" : "כל הפתקים",
    "Categories" : "קטגוריות",
    "No notes yet" : "אין פתקים עדיין",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Error during preparing note for deletion." : "שגיאה במהלך הכנת הפתק למחיקה.",
    "Share" : "Share",
    "Rename" : "שנה שם",
    "Delete note" : "מחיקת פתק",
    "Error from Nextcloud server: {msg}" : "שגיאה משרת ה־Nextcloud:‏ {msg}",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Empty note" : "פתק ריק",
    "Write …" : "כתיבה…",
    "CTRL + /" : "CTRL + /‎",
    "Edit" : "עריכה",
    "Exit full screen" : "יציאה ממסך מלא",
    "Full screen" : "מסך מלא",
    "Save failed. Click to retry." : "השמירה נכשלה. יש ללחוץ כדי לנסות שוב.",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "This week" : "השבוע",
    "Last week" : "שבוע שעבר",
    "This month" : "החודש",
    "Last month" : "חודש שעבר",
    "Loading …" : "בטעינה",
    "Write down your thoughts without any distractions." : "כתיבת המחשבות שלך ללא הסחות.",
    "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
    "Organize your notes in categories." : "ארגון הפתקים שלך בקטגוריות.",
    "Note not found." : "הפתק לא נמצא.",
    "Note is locked." : "הפתק נעול.",
    "Insufficient storage." : "אין מספיק שטח אחסון.",
    "See JavaScript console and server log for details." : "ניתן להביט במסוף ה־JavaScript וביומן השרת לקבלת פרטים.",
    "Updating settings has failed." : "עדכון ההגדרות נכשל.",
    "Fetching notes has failed." : "קבלת הפתקים נכשלה.",
    "Fetching note {id} has failed." : "קבלת הפתק {id} נכשלה.",
    "Refreshing note {id} has failed." : "רענון הפתק {id} נכשל.",
    "Renaming note {id} has failed." : "שינוי שם הפתק {id} נכשל.",
    "Creating new note has failed." : "יצירת פתק חדש נכשלה.",
    "Saving note {id} has failed." : "שמירת הפתק {id} נכשלה.",
    "Updating title for note {id} has failed." : "עדכון כותרת הפתק {id} נכשלה.",
    "Undo delete has failed for note {title}." : "ביטול מחיקת הפתק {title} נכשלה.",
    "Deleting note {id} has failed." : "מחיקת הפתק {id} נכשלה.",
    "Toggling favorite for note {id} has failed." : "החלפת מצב העדפה לפתק {id} נכשלה.",
    "Updating the note's category has failed. Is the target directory writable?" : "עדכון קטגוריית הפתק נכשלה. האם תיקיית היעד נגישה לכתיבה?",
    "Updating the category for note {id} has failed." : "עדכון הקטגוריה של הפתק {id} נכשלה.",
    "Uncategorized" : "ללא קטגוריה",
    "Tasks" : "משימות",
    "Development Mode" : "מצב פיתוח"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
