OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Create new note" : "Crea una nota nova",
    "More notes" : "Més notes",
    "Reading notes from filesystem has failed." : "S'ha produït un error en llegir les notes del sistema de fitxers.",
    "Error" : "Error",
    "New note" : "Nota nova",
    "Distraction-free notes and writing" : "Preneu notes i escriviu sense distraccions",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "L'aplicació Notes és una aplicació per prendre notes sense distraccions per a [Nextcloud](https://www.nextcloud.com/). Proporciona categories per a una millor organització i admet el fNextcloudormat mitjançant la sintaxi [Markdown](https://en.wikipedia.org/wiki/Markdown). Les notes es guarden com a fitxers al vostre Nextcloud, de manera que podeu veure-les i editar-les amb tots els clients de Nextcloud. A més, una [API REST] separada (https://github.com/nextcloud/notes/blob/master/docs/api/README.md) permet una fàcil integració a les aplicacions ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), així com [aplicacions de tercers](https://github.com/nextcloud/notes/wiki#3rd-party-clients) que permeten un accés còmode a les vostres notes de Nextcloud). Altres funcions inclouen marcar notes com a preferides.",
    "Deleted {title}" : "S'ha suprimit {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["S'ha suprimit {number} nota","S'han suprimit {number} notes"],
    "Undo Delete" : "Desfés la supressió",
    "Note recovered" : "S'ha recuperat la nota",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["S'ha recuperat {number} nota","S'han recuperat {number} notes"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hi ha notes sense desar. Si sortiu de la pàgina, es perdran tots els canvis!",
    "Notes settings" : "Paràmetres de Notes",
    "Please see Nextcloud server log for details." : "Consulteu el registre del servidor del Nextcloud per a veure més detalls.",
    "Preview" : "Previsualitza",
    "Make the selection bold" : "Feu la selecció en negreta",
    "Make the selection italic" : "Feu la selecció en cursiva",
    "Wrap the selection in quotes" : "Emboliqui la selecció entre cometes",
    "The selection will be turned into monospace" : "La selecció es convertirà en monoespai",
    "Remove any styles from the selected text" : "Suprimeix qualsevol estil del text seleccionat",
    "Makes the current line a list element" : "Fa que la línia actual sigui un element de llista",
    "Makes the current line a list element with a number" : "Fa que la línia actual sigui un element de llista amb un número",
    "Toggle heading for current line" : "Commuta l'encapçalament per a la línia actual",
    "Set the current line as a big heading" : "Estableix la línia actual com un encapçalament gran",
    "Insert link" : "Insereix un enllaç",
    "Insert image" : "Insereix una imatge",
    "Switch between editor and viewer" : "Canvia entre editor i visualitzador",
    "Pick a notes folder" : "Trieu una carpeta de notes",
    "Set notes folder" : "Estableix la carpeta de notes",
    "File extension" : "Extensió dels fitxers",
    "Mobile apps" : "Aplicacions mòbils",
    "Shortcuts" : "Enllaços directes",
    "Delete" : "Elimina",
    "Cancel" : "Cancel•la",
    "All notes" : "Totes les notes",
    "Categories" : "Categories",
    "Create a sample note with Markdown" : "Crea una nota de mostra amb Markdown",
    "No notes yet" : "Encara no hi ha notes",
    "Select an image" : "Seleccioneu una imatge",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "No podeu seleccionar notes que es trobin fora de la carpeta de notes. La carpeta de notes és: {folder}",
    "Wrong image" : "Imatge incorrecta",
    "The file was not uploaded. Check your server logs." : "No s'ha pujat el fitxer. Consulteu els registres del servidor.",
    "Upload image" : "Puja una imatge",
    "Rich text editor" : "Editor de text enriquit",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ara podeu canviar per utilitzar l'editor de text enriquit fàcil d'utilitzar i sense distraccions. Us permet editar notes sense veure cap marca de Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Aquesta opció també es pot canviar més endavant als paràmetres de l'aplicació Notes.",
    "Keep plain Markdown editor" : "Mantingueu un editor de Markdown senzill",
    "Use rich editor" : "Utilitza l'editor",
    "Remove from favorites" : "Suprimeix de preferits",
    "Add to favorites" : "Afegeix als preferits",
    "Error while renaming note." : "S'ha produït un error en canviar el nom de la nota.",
    "Error during preparing note for deletion." : "S'ha produït un error en preparar la nota per la supressió.",
    "Share" : "Comparteix",
    "Change category" : "Canvia categoria",
    "Rename" : "Canvia el nom",
    "Rename note" : "Canvia el nom de la nota",
    "Delete note" : "Suprimeix la nota",
    "Error from Nextcloud server: {msg}" : "Error del servidor del Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "S'ha modificat la nota en una altra sessió. Trieu quina versió voleu desar.",
    "Use version from server" : "Utilitza la versió del servidor",
    "Use current version" : "Utilitza la versió actual",
    "Empty note" : "Nota en blanc",
    "Write …" : "Escriviu…",
    "CTRL + /" : "Ctrl + /",
    "Edit" : "Edita",
    "Exit full screen" : "Surt de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Note is read-only. You cannot change it." : "La nota és de només lectura. No la podeu modificar.",
    "Save failed. Click to retry." : "S'ha produït un error en desar. Feu clic per a tornar-ho a provar.",
    "Update conflict. Click for resolving manually." : "S'ha produït un conflicte d'actualització. Feu clic per a resoldre'l manualment.",
    "Today" : "Avui",
    "Yesterday" : "Ahir",
    "This week" : "Aquesta setmana",
    "Last week" : "La setmana passada",
    "This month" : "Aquest mes",
    "Last month" : "El mes passat",
    "Search for notes" : "Cerca notes",
    "Loading …" : "S'està carregant…",
    "Find in all categories" : "Troba en totes les categories",
    "Write down your thoughts without any distractions." : "Escriviu els vostres pensaments sense distraccions.",
    "Use Markdown markups to style your text." : "Utilitzeu el format Markdown per a donar estil al text.",
    "Organize your notes in categories." : "Organitzeu les vostres notes en categories.",
    "Note not found." : "No s'ha trobat la nota.",
    "Note is locked." : "La nota està blocada.",
    "Insufficient storage." : "No hi ha prou espai d'emmagatzematge.",
    "See JavaScript console and server log for details." : "Consulteu la consola de JavaScript i els registres del servidor per a veure més detalls.",
    "Updating settings has failed." : "S'ha produït un error en actualitzar els paràmetres.",
    "Fetching notes for dashboard has failed." : "S'ha produït un error en recuperar les notes del tauler.",
    "Fetching notes has failed." : "S'ha produït un error en recuperar les notes.",
    "Fetching note {id} has failed." : "S'ha produït un error en recuperar la nota {id}.",
    "Refreshing note {id} has failed." : "S'ha produït un error en actualitzar la nota {id}.",
    "Renaming note {id} has failed." : "S'ha produït un error en canviar el nom de la nota {id}.",
    "Creating new note has failed." : "S'ha produït un error en crear una nota nova.",
    "Saving note {id} has failed." : "S'ha produït un error en desar la nota {id}.",
    "Updating title for note {id} has failed." : "S'ha produït un error en actualitzar el títol de la nota {id}.",
    "Undo delete has failed for note {title}." : "S'ha produït un error en desfer la supressió de la nota {title}.",
    "Deleting note {id} has failed." : "S'ha produït un error en suprimir la nota {id}.",
    "Toggling favorite for note {id} has failed." : "S'ha produït un error en canviar l'estat de preferit de la nota {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "S'ha produït un error en actualitzar la categoria de la nota. Teniu permís d'escriptura a la carpeta de destinació?",
    "Updating the category for note {id} has failed." : "S'ha produït un error en actualitzar la categoria de la nota {id}.",
    "Uncategorized" : "Sense categoria",
    "Sample note" : "Nota de mostra",
    "15 January 2021, via Nextcloud Notes" : "15 de gener de 2021, a través de Nextcloud Notes",
    "Me, you, and all our friends!" : "Jo, tu i tots els nostres amics!",
    "Tasks" : "Tasques",
    "Write nice todo lists" : "Escriu bones llistes de tasques",
    "Buy Fries" : "Comprar patates fregides",
    "Birthdays" : "Aniversaris",
    "Jen, in three days!" : "Jen, en tres dies!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Passos de revisió",
    "Turn PC off" : "Apagueu el PC",
    "Turn PC on" : "Enceneu el PC",
    "Then call IT" : "Llavors truca TI",
    "Quotes" : "Pressupostos",
    "Nextcloud, a safe home for all your data" : "Nextcloud, una llar segura per a totes les teves dades",
    "Development Mode" : "Mode de desenvolupament",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembla que l'aplicació Notes s'ha instal·lat des d'una font de desenvolupament. Instal·leu-la des de la <a href=\"%1$s\">Botiga d'aplicacions del Nextcloud</a> oficial en el seu lloc. Si voleu compilar l'aplicació Notes pel vostre compte, seguiu les <a href=\"%2$s\"> instruccions per a desenvolupadors</a>."
},
"nplurals=2; plural=(n != 1);");
