OC.L10N.register(
    "notes",
    {
    "Notes" : "Նոթեր",
    "Error" : "Սխալ",
    "New note" : "Նոր նոթ",
    "Files" : "Ֆայլեր",
    "Delete" : "Delete",
    "Cancel" : "ընդհատել",
    "No notes yet" : "առայժմ գրառում չկա",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Կիսվել",
    "Rename" : "Rename",
    "Delete note" : "Ջնջել նոթը",
    "Edit" : "մշակել",
    "Today" : "այսօր",
    "Yesterday" : "երեկ",
    "This week" : "այս շաբաթ",
    "This month" : "այս ամիս"
},
"nplurals=2; plural=(n != 1);");
