<?php
/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
?>

<div id="app-content" style="margin: 2em 3em;">
	<h2><?php echo $l->t('Development Mode'); ?></h2>
	<p><?php echo $l->t('It looks that the notes app was installed from a development source. Please install it from the official <a href="%1$s">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href="%2$s">developer instructions</a>.', [ 'https://apps.nextcloud.com/apps/notes', 'https://github.com/nextcloud/notes#warning-developer-info' ]); ?></p>
</div>
