OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Error" : "Error",
    "New note" : "Nove nota",
    "Preview" : "Previsualisar",
    "Files" : "Files",
    "Delete" : "Delete",
    "Cancel" : "Cancellar",
    "No notes yet" : "Nulle notas ancora",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Compartir",
    "Rename" : "Rename",
    "Delete note" : "Dele nota",
    "Edit" : "Modificar",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "This week" : "Iste septimana",
    "This month" : "Iste mense"
},
"nplurals=2; plural=(n != 1);");
