OC.L10N.register(
    "notes",
    {
    "Notes" : "Nòtas",
    "Create new note" : "Crear una nòta novèla",
    "More notes" : "Mai de nòtas",
    "Reading notes from filesystem has failed." : "La lectura de las nòtas a partir del sistèma de fichièr a fracassat.",
    "Error" : "Error",
    "New note" : "Nòta novèla",
    "Distraction-free notes and writing" : "Nòtas e escritura sens cap de distraccion",
    "Deleted {title}" : "{title} suprimit",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} nòta suprimida","{number} nòtas suprimidas"],
    "Undo Delete" : "Anullar la supression",
    "Note recovered" : "Nòta restaurada",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} nòta restaurada","{number} nòtas restauradas"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "I a de nòtas pas enregistradas. Quitar la pagina farà pèrdre las modificacions !",
    "Notes settings" : "Configuracion de las nòtas",
    "Please see Nextcloud server log for details." : "Consultatz los jornals d'audit del servidor Nextcloud per mai de detalhs.",
    "Preview" : "Apercebut",
    "Insert link" : "Inserir un ligam",
    "Insert image" : "Inserir imatge",
    "File extension" : "Extension del fichièr",
    "Files" : "Fichièrs",
    "Mobile apps" : "Aplicacions mobile",
    "Shortcuts" : "Acorchis",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "All notes" : "Totas las nòtas",
    "Categories" : "Categorias",
    "No notes yet" : "Cap de nòta pel moment",
    "Select an image" : "Seleccionar un imatge",
    "Wrong image" : "Marrit imatge",
    "Upload image" : "Enviar un imatge",
    "This option can also be changed later on in the Notes app settings." : "Aquesta opcion se pòt cambiar als paramètres « Configuracion de las nòtas ».",
    "Remove from favorites" : "Tirar dels favorits",
    "Add to favorites" : "Apondre als favorits",
    "Error while renaming note." : "Error en renomenant la nòta.",
    "Error during preparing note for deletion." : "Error pendent la preparacion de la supression de la nòta.",
    "Share" : "Share",
    "Change category" : "Modificar la categoria",
    "Rename" : "Renomenar",
    "Rename note" : "Renomenar la nòta",
    "Delete note" : "Suprimir la nòta",
    "Use version from server" : "Utilizar la version del servidor",
    "Use current version" : "Utilizar la version actuala",
    "Empty note" : "Nòta voida",
    "Write …" : "Escrivètz…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modificar",
    "Exit full screen" : "Sortir de l’ecran complèt",
    "Full screen" : "Ecran complèt",
    "Today" : "Uèi",
    "Yesterday" : "Ièr",
    "This week" : "Aquesta setmana",
    "Last week" : "La setmana passada",
    "This month" : "Aqueste mes",
    "Last month" : "Lo mes passat",
    "Search for notes" : "Cercar de nòtas",
    "Loading …" : "Cargament…",
    "Find in all categories" : "Cercar dins totas las nòtas",
    "Organize your notes in categories." : "Organizatz vòstras nòtas en categorias.",
    "Note not found." : "Cap de nòta pas trobada.",
    "Note is locked." : "La nòta es verrolhada.",
    "Insufficient storage." : "Espaci d'emmagazinatge insufisent.",
    "Uncategorized" : "Sens categoria",
    "Sample note" : "Nòta d’exemple",
    "15 January 2021, via Nextcloud Notes" : "15 de genièr de 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Ieu, tu e totes nòstres amics !",
    "Tasks" : "Prètzfaches",
    "Buy Fries" : "Crompar fritas",
    "Birthdays" : "Anniversaris",
    "Jen, in three days!" : "Joan, d’aquí tres jorns !",
    "Turn PC off" : "Atudar lo PC",
    "Turn PC on" : "Alucar lo PC",
    "Then call IT" : "Sonar l’assisténcia tecnica en seguida",
    "Quotes" : "Citacions",
    "Nextcloud, a safe home for all your data" : "Nextcloud, un ostal segur per vòstras donadas",
    "Development Mode" : "Mòde desvelopament"
},
"nplurals=2; plural=(n > 1);");
