OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "Greška",
    "Files" : "Datoteke",
    "Delete" : "Delete",
    "Cancel" : "Otkaži",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Podjeli",
    "Rename" : "Rename",
    "Edit" : "Izmjeni",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "Loading …" : "Loading …",
    "Tasks" : "Zadaci"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
