OC.L10N.register(
    "notes",
    {
    "Notes" : "Poznámky",
    "Create new note" : "Vytvoriť novú poznámku",
    "More notes" : "Ďaľšie poznámky",
    "Reading notes from filesystem has failed." : "Čítanie poznámok zo súborového systému zlyhalo.",
    "Error" : "Chyba",
    "New note" : "Nová poznámka",
    "Distraction-free notes and writing" : "Písanie a poznámky, čo neodpútavajú pozornosť",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikácia Notes je aplikácia na písanie poznámok bez rozptyľovania pre [Nextcloud] (https://www.nextcloud.com/). Poskytuje kategórie pre lepšiu organizáciu a podporuje formátovanie pomocou syntaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). Poznámky sa ukladajú ako súbory vo vašom Nextcloud, takže si ich môžete prezerať a upravovať pomocou každého klienta Nextcloud. Okrem toho samostatné [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) umožňuje jednoduchú integráciu do aplikácií ([Android](https://github .com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), ako aj [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients), ktoré umožňujú pohodlný prístup k vašim poznámkam Nextcloud). Medzi ďalšie funkcie patrí označovanie poznámok ako obľúbených.",
    "Deleted {title}" : "Zmazané {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Bola odstránená {number} poznámka","Boli odstránené {number} poznámky","Boli odstránené {number} poznámky","Bolo odstránených {number} poznámok"],
    "Undo Delete" : "Zrušiť odstránenie",
    "Note recovered" : "Poznámka bola obnovená",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Bola obnovená {number} poznámka","Boli obnovené {number} poznámky","Boli obnovené {number} poznámky","Bolo obnovených {number} poznámok"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Máte neuložené poznámky. Opustením stránky stratíte všetky zmeny!",
    "Notes settings" : "Nastavenia Poznámok",
    "Please see Nextcloud server log for details." : "Podrobnosti nájdete v protokole servera Nextcloud.",
    "Custom" : "Vlastný",
    "Rich text" : "Formátovaný text",
    "Plain text" : "Obyčajný text",
    "Preview" : "Náhľad",
    "Make the selection bold" : "Pre výber použiť tučné písmo",
    "Make the selection italic" : "Pre výber použiť kurzívu",
    "Wrap the selection in quotes" : "Vložiť výber do úvodzoviek",
    "The selection will be turned into monospace" : "Výber bude zmenený na monospace",
    "Remove any styles from the selected text" : "Odstrániť všetky štýly zo zvoleného textu",
    "Makes the current line a list element" : "Zmeniť aktuálny riadok na prvý prvok zoznamu",
    "Makes the current line a list element with a number" : "Zmeniť aktuálny riadok na prvok zoznamu s číslom",
    "Toggle heading for current line" : "Prepnúť nadpis pre aktuálny riadok",
    "Set the current line as a big heading" : "Nastavte aktuálny riadok ako veľký nadpis",
    "Insert link" : "Vložiť odkaz",
    "Insert image" : "Vložiť obrázok",
    "Switch between editor and viewer" : "Prepnúť medzi editorom a prehliadačom",
    "Pick a notes folder" : "Vyberať adresár pre poznámky",
    "Set notes folder" : "Nastaviť adresár pre poznámky",
    "General" : "Všeobecné",
    "Display" : "Display",
    "File extension" : "Prípona súboru",
    "For new notes" : "Pre nové poznámky",
    "Custom file extension" : "Vlastná prípona súboru",
    "Files" : "Súbory",
    "Notes folder" : "Adresár pre poznámky",
    "Mobile apps" : "Mobilné aplikácie",
    "Shortcuts" : "Skratky",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "All notes" : "Všetky poznámky",
    "Categories" : "Kategórie",
    "Create a sample note with Markdown" : "Vytvoriť vzorovú poznámku s Markdownom",
    "No notes yet" : "Zatiaľ nie sú žiadne poznámky",
    "Select an image" : "Vybrať obrázok",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nemôžete vybrať obrázky mimo priečinka poznámok. Váš priečinok poznámok je: {folder}",
    "Wrong image" : "Chybný obrázok",
    "The file was not uploaded. Check your server logs." : "Súbor nebol nahraný. Skontrolujte záznam o chybách serveru.",
    "Upload image" : "Nahrať obrázok",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone a iPad",
    "Rich text editor" : "Rozšírený textový editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Teraz môžete prejsť na používanie jednoduchého a rozšíreného editora textu. Umožňuje vám upravovať poznámky bez zobrazenia akýchkoľvek značiek Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Táto možnosť môže byť neskôr zmenená aj v nastaveniach aplikácie Poznámky.",
    "Keep plain Markdown editor" : "Zachovať jednoduchý editor Markdown",
    "Use rich editor" : "Použite rozšírený editor",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "Error while renaming note." : "Chyba pri premenovávaní poznámky",
    "Error during preparing note for deletion." : "Chyba pri príprave poznámky na vymazanie.",
    "Share" : "Sprístupňovať",
    "Change category" : "Zmeniť kategóriu",
    "Rename" : "Premenovať",
    "Rename note" : "Premenovať poznámku",
    "Delete note" : "Zmazať poznámku",
    "Error from Nextcloud server: {msg}" : "Chyba Nextcloud servera: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Poznámka bola zmenená v inej relácii. Prosím vyberte ktorá verzia má byť uložená.",
    "Use version from server" : "Použiť verziu zo servera",
    "Use current version" : "Použiť aktuálnu verziu",
    "Empty note" : "Prázdna poznámka",
    "Write …" : "Písať …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Upraviť",
    "Exit full screen" : "Opustiť celú obrazovku",
    "Full screen" : "Na celú obrazovku",
    "Note is read-only. You cannot change it." : "Poznámka je iba na čítanie. Nemôžete ju zmeniť.",
    "Save failed. Click to retry." : "Uloženie zlyhalo. Ťuknutím zopakujete.",
    "Update conflict. Click for resolving manually." : "Konflikt pri aktualizácii. Kliknite pre ručné riešenie problému.",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "This week" : "Tento týždeň",
    "Last week" : "Minulý týždeň",
    "This month" : "Tento mesiac",
    "Last month" : "Minulý mesiac",
    "Search for notes" : "Vyhľadať poznámky",
    "Loading …" : "Načítava sa...",
    "Find in all categories" : "Hľadať vo všetkých kategóriách",
    "Write down your thoughts without any distractions." : "Zapíšte si nápady bez rušivých elementov.",
    "Use Markdown markups to style your text." : "Použite formát Markdown na formátovanie vášho textu.",
    "Organize your notes in categories." : "Organizujte si poznámky do kategórií.",
    "Note not found." : "Poznámky sa nenašli.",
    "Note is locked." : "Poznámka je zamknutá.",
    "Insufficient storage." : "Nedostatočný úložný priestor.",
    "See JavaScript console and server log for details." : "Podrobnosti nájdete v konzole JavaScriptu a protokole servera.",
    "Updating settings has failed." : "Aktualizácia nastavení zlyhala.",
    "Fetching notes for dashboard has failed." : "Načítanie poznámok pre infopanel zlyhalo.",
    "Fetching notes has failed." : "Získavanie poznámok zlyhalo.",
    "Fetching note {id} has failed." : "Získavanie poznámky {id} zlyhalo.",
    "Refreshing note {id} has failed." : "Obnovenie poznámky {id} zlyhalo.",
    "Renaming note {id} has failed." : "Nepodarilo sa premenovat poznámku {id}",
    "Creating new note has failed." : "Vytvorenie novej poznámky zlyhalo.",
    "Saving note {id} has failed." : "Uloženie poznámky {id} zlyhalo.",
    "Updating title for note {id} has failed." : "Aktualizácia názvu poznámky {id} zlyhala.",
    "Undo delete has failed for note {title}." : "Zrušenie odstránenia zlyhalo pre poznámku {title}.",
    "Deleting note {id} has failed." : "Zmazanie poznámky {id} zlyhalo.",
    "Toggling favorite for note {id} has failed." : "Zaradenie poznámky {id} do obľúbených zlyhalo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualizácia kategórie poznámky zlyhalo. Je možné do cieľového priečinka zapisovať?",
    "Updating the category for note {id} has failed." : "Aktualizácia kategórie pre poznámku {id} zlyhala.",
    "Uncategorized" : "Nezaradené",
    "Sample note" : "Vzorová poznámka",
    "15 January 2021, via Nextcloud Notes" : "15. január 2021, cez Nextcloud Poznámky",
    "Me, you, and all our friends!" : "Ja, ty a všetci naši priatelia!",
    "Tasks" : "Úlohy",
    "Write nice todo lists" : "Napíšte pekné zoznamy úloh",
    "Buy Fries" : "Kúpiť hranolky",
    "Birthdays" : "Narodeniny",
    "Jen, in three days!" : "Jana, za tri dni!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Skontrolovať Kroky",
    "Turn PC off" : "Vypnúť počítač",
    "Turn PC on" : "Zapnúť počítač",
    "Then call IT" : "Potom zavolaj IT",
    "Quotes" : "Ponuky",
    "Nextcloud, a safe home for all your data" : "Nextcloud, bezpečný domov pre všetky vaše údaje",
    "Development Mode" : "Režim pre vývojárov",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Zdá sa, že apka Poznámky bola nainštalovaná zo zdroja pre vývojárov. Nainštalujte ju prosím z oficiálneho <a href=\"%1$s\">Nextcloud katalógu apiek</a>. Ak si chcete zostaviť (skompilovať) aplikáciu Poznámky sami, nasledujte <a href=\"%2$s\">pokyny pre vývojárov</a>."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
