/**
 * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
 * SPDX-FileCopyrightText: Jan-Christoph Borchardt http://jancborchardt.net
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

/* workaround for https://github.com/nextcloud/nextcloud-vue/issues/1384 */
body {
	min-height: 100%;
	height: auto;
}

/* App Navigation fixes */
.app-navigation-entry.category-header:not(.app-navigation-entry--opened) .app-navigation-entry__title {
	font-weight: bold;
}

#app-navigation > ul > li.app-navigation-caption.caption-item {
	padding: 0;
	pointer-events: inherit;
}

.app-navigation-entry__utils .action-item {
	visibility: hidden;
}

li.actionsOpen .app-navigation-entry__utils .action-item,
li.app-navigation-entry--deleted .app-navigation-entry__utils .action-item,
li.active .app-navigation-entry__utils .action-item,
li:hover  .app-navigation-entry__utils .action-item,
li:focus  .app-navigation-entry__utils .action-item {
	visibility: visible;
}

/* Welcome / Help */
.feature {
	background-position: 0 center;
	width: 100%;
	min-height: 32px;
	line-height: 32px;
	padding-inline-start: 32px;
	margin-top: 0.3em !important;
	margin-bottom: 0.3em !important;
	display: inline-block;
	vertical-align: middle;
}

body[dir='ltr'] .feature {
	background-position-x: left;
}

body[dir='rtl'] .feature {
	background-position-x: right;
}

.feature ul {
	list-style: circle outside;
	padding-inline-start: 2em;
}


@media print {
	#header,
	.app-navigation,
	#note-container .action-buttons,
	#note-container .upload-button {
		display: none !important;
	}

	.content {
		display: block;
		padding: 0;
		color: #000;
	}

	#note-container .note-editor,
	#note-container .note-preview {
		padding: 0 !important;
		font-size: 10pt !important;
	}

	.app-content {
		margin-inline-start: 0 !important;
	}
}
