OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Create new note" : "Crear un rol",
    "More notes" : "Más notes",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "Notes settings" : "Configuración de Notes",
    "File extension" : "Estensión de los ficheros",
    "Files" : "Ficheros",
    "Mobile apps" : "Aplicaciones pa móviles",
    "Shortcuts" : "Atayos",
    "Delete" : "Desaniciar",
    "Cancel" : "Encaboxar",
    "All notes" : "Toles notes",
    "Categories" : "Categories",
    "No notes yet" : "Nun hai nenguna nota",
    "Rename" : "Rename",
    "Delete note" : "Desaniciar la nota",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Colar de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "This week" : "Esta selmana",
    "Last week" : "La selmana pasada",
    "This month" : "Esti mes",
    "Last month" : "El mes pasáu",
    "Search for notes" : "Buscar notes",
    "Loading …" : "Cargando…",
    "Write down your thoughts without any distractions." : "Escribi cualesquier pensamientu ensin nenguna distraición.",
    "Organize your notes in categories." : "Organiza les notes per categoríes.",
    "Note not found." : "Nun s'atopó la nota",
    "Note is locked." : "La nota ta bloquiada",
    "Uncategorized" : "Ensin categoría",
    "Tasks" : "Xeres",
    "Nextcloud, a safe home for all your data" : "Nexcloud, un llugar seguru pa los datos personales",
    "Development Mode" : "Mou de desendocu"
},
"nplurals=2; plural=(n != 1);");
