OC.L10N.register(
    "notes",
    {
    "Notes" : "Тэмдэглэл",
    "Create new note" : "Шинэ тэмдэглэл үүсгэх",
    "More notes" : "Өөр тэмдэглэлүүд",
    "Reading notes from filesystem has failed." : "Файлын системээс тэмдэглэл унших амжилтгүй боллоо.",
    "Error" : "Алдаа",
    "New note" : "Шинэ тэмдэглэл",
    "Distraction-free notes and writing" : "Анхаарал сарниулахгүй тэмдэглэл бичих",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notes апп нь [Nextcloud](https://www.nextcloud.com/)-д зориулсан анхаарал сарниулалтгүй тэмдэглэл хийх апп юм. Энэ нь илүү сайн зохион байгуулалтын тулд ангиллуудыг хангадаг бөгөөд [Markdown](https://en.wikipedia.org/wiki/Markdown) синтакс ашиглан форматлахыг дэмждэг. Тэмдэглэлүүд таны Nextcloud дээр файл хэлбэрээр хадгалагддаг тул та бүх Nextcloud клиентүүдээр харж, засварлах боломжтой. Цаашилбал, тусдаа [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) нь апп-уудтай ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), мөн таны Nextcloud тэмдэглэлүүдэд хялбар хандах боломжийг олгодог [3rd-party апп-ууд](https://github.com/nextcloud/notes/wiki#3rd-party-clients)) хялбар интеграцчилах боломжийг олгодог. Нэмэлт боломжуудад тэмдэглэлийг дуртай гэж тэмдэглэх орно.",
    "Deleted {title}" : "{title} устгагдлаа",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} тэмдэглэл устгагдлаа","{number} тэмдэглэл устгагдлаа"],
    "Undo Delete" : "Устгалтыг буцаах",
    "Note recovered" : "Тэмдэглэл сэргээгдлээ",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} тэмдэглэл сэргээгдлээ","{number} тэмдэглэл сэргээгдлээ"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Хадгалаагүй тэмдэглэлүүд байна. Хуудаснаас гарвал бүх өөрчлөлт устгагдана!",
    "Notes settings" : "Тэмдэглэлийн тохиргоо",
    "Please see Nextcloud server log for details." : "Дэлгэрэнгүй мэдээллийг Nextcloud серверийн логоос үзнэ үү.",
    "Custom" : "Хувийн",
    "Rich text" : "Баялаг текст",
    "Plain text" : "Энгийн текст",
    "Preview" : "шалгах",
    "Make the selection bold" : "Сонголтыг тод болгох",
    "Make the selection italic" : "Сонголтыг налуу болгох",
    "Wrap the selection in quotes" : "Сонголтыг ишлэлд оруулах",
    "The selection will be turned into monospace" : "Сонголт моноспейс болно",
    "Remove any styles from the selected text" : "Сонгосон текстээс загварыг арилгах",
    "Makes the current line a list element" : "Одоогийн мөрийг жагсаалтын элемент болгох",
    "Makes the current line a list element with a number" : "Одоогийн мөрийг дугаартай жагсаалтын элемент болгох",
    "Toggle heading for current line" : "Одоогийн мөрийн гарчгийг сэлгэх",
    "Set the current line as a big heading" : "Одоогийн мөрийг том гарчиг болгох",
    "Insert link" : "Холбоос оруулах",
    "Insert image" : "Зураг оруулах",
    "Switch between editor and viewer" : "Засварлагч болон харагч хооронд сэлгэх",
    "Pick a notes folder" : "Тэмдэглэлийн хавтас сонгох",
    "Set notes folder" : "Тэмдэглэлийн хавтас тохируулах",
    "General" : "Ерөнхий",
    "Display" : "Дэлгэц",
    "File extension" : "Файлын өргөтгөл",
    "For new notes" : "Шинэ тэмдэглэлүүдэд",
    "Custom file extension" : "Тохируулсан файлын өргөтгөл",
    "Files" : "файлууд",
    "Notes folder" : "Тэмдэглэлийн хавтас",
    "Mobile apps" : "Гар утасны апп-ууд",
    "Shortcuts" : "Товчлолууд",
    "Delete" : "–£—Å—Ç–≥–∞—Ö",
    "Cancel" : "–±–æ–ª–∏—É–ª–∞—Ö",
    "All notes" : "Бүх тэмдэг",
    "Categories" : "төрөл",
    "Create a sample note with Markdown" : "Markdown-тай жишээ тэмдэглэл үүсгэх",
    "No notes yet" : "шинэ тэмдэглэл алга",
    "Select an image" : "Зураг сонгох",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Та тэмдэглэлийн хавтаснаас гадна зургийг сонгох боломжгүй. Таны тэмдэглэлийн хавтас: {folder}",
    "Wrong image" : "Буруу зураг",
    "The file was not uploaded. Check your server logs." : "Файл байршуулагдсангүй. Серверийн логоо шалгана уу.",
    "Upload image" : "Зураг байршуулах",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone болон iPad",
    "Rich text editor" : "Баялаг текст засварлагч",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Та одоо хялбар ашиглах боломжтой, анхаарал сарниулалтгүй баялаг текст засварлагч руу шилжих боломжтой. Энэ нь ямар ч Markdown тэмдэглэгдээсийг харуулахгүйгээр тэмдэглэлийг засварлах боломжийг олгодог.",
    "This option can also be changed later on in the Notes app settings." : "Энэ сонголтыг дараа нь Тэмдэглэл апп тохиргооноос өөрчлөх боломжтой.",
    "Keep plain Markdown editor" : "Энгийн Markdown засварлагч хэвээр байлгах",
    "Use rich editor" : "Баялаг засварлагч ашиглах",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Error while renaming note." : "Тэмдэглэл нэр өөрчлөхөд алдаа гарлаа.",
    "Error during preparing note for deletion." : "Тэмдэглэл устгахад бэлтгэхэд алдаа гарлаа.",
    "Share" : "Түгээх",
    "Change category" : "Ангилал өөрчлөх",
    "Rename" : "Нэр солих",
    "Rename note" : "Тэмдэглэл нэр өөрчлөх",
    "Delete note" : "Тэмдэглэл устгах",
    "Error from Nextcloud server: {msg}" : "Nextcloud сервер алдаа: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Тэмдэглэл өөр сессэд өөрчлөгдсөн байна. Аль хувилбарыг хадгалахыг сонгоно уу.",
    "Use version from server" : "Серверийн хувилбарыг ашиглах",
    "Use current version" : "Одоогийн хувилбарыг ашиглах",
    "Empty note" : "Хоосон тэмдэглэл",
    "Write …" : "Бичих …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "засварлах",
    "Exit full screen" : "Бүтэн дэлгэцээс гарах",
    "Full screen" : "Бүтэн дэлгэц",
    "Note is read-only. You cannot change it." : "Тэмдэглэл зөвхөн унших горимд байна. Та өөрчлөх боломжгүй.",
    "Save failed. Click to retry." : "Хадгалах амжилтгүй болсон. Дахин оролдохын тулд дарна уу.",
    "Update conflict. Click for resolving manually." : "Шинэчлэлтийн зөрчил. Гараар шийдвэрлэхийн тулд дарна уу.",
    "Today" : "өнөөдөр",
    "Yesterday" : "өчигдөр",
    "This week" : "7 хоног",
    "Last week" : "Өнгөрсөн долоо хоног",
    "This month" : "1 сар",
    "Last month" : "Өнгөрсөн сар",
    "Search for notes" : "Тэмдэглэл хайх",
    "Loading …" : "Уншиж байна...",
    "Find in all categories" : "Бүх ангилалаас хайх",
    "Write down your thoughts without any distractions." : "Санаа бодлоо ямар ч саад болохгүйгээр бичнэ үү.",
    "Use Markdown markups to style your text." : "Текстээ загварчлахын тулд Markdown тэмдэглэгээ ашиглана уу.",
    "Organize your notes in categories." : "Тэмдэглэлүүдээ ангилалд зохион байгуулна уу.",
    "Note not found." : "Тэмдэглэл олдсонгүй.",
    "Note is locked." : "Тэмдэглэл түгжигдсэн.",
    "Insufficient storage." : "Хадгалах зай хүрэлцэхгүй байна.",
    "See JavaScript console and server log for details." : "Дэлгэрэнгүй мэдээллийг JavaScript консол болон серверийн логоос үзнэ үү.",
    "Updating settings has failed." : "Тохиргоо шинэчлэх амжилтгүй боллоо.",
    "Fetching notes for dashboard has failed." : "Хянах самбарт тэмдэглэл авах амжилтгүй боллоо.",
    "Fetching notes has failed." : "Тэмдэглэл авах амжилтгүй боллоо.",
    "Fetching note {id} has failed." : "{id} тэмдэглэл авах амжилтгүй боллоо.",
    "Refreshing note {id} has failed." : "{id} тэмдэглэл шинэчлэх амжилтгүй боллоо.",
    "Renaming note {id} has failed." : "{id} тэмдэглэл нэр өөрчлөх амжилтгүй боллоо.",
    "Creating new note has failed." : "Шинэ тэмдэглэл үүсгэх амжилтгүй боллоо.",
    "Saving note {id} has failed." : "{id} тэмдэглэл хадгалах амжилтгүй боллоо.",
    "Updating title for note {id} has failed." : "{id} тэмдэглэлийн гарчиг шинэчлэх амжилтгүй боллоо.",
    "Undo delete has failed for note {title}." : "{title} тэмдэглэл устгалт буцаах амжилтгүй боллоо.",
    "Deleting note {id} has failed." : "{id} тэмдэглэл устгах амжилтгүй боллоо.",
    "Toggling favorite for note {id} has failed." : "{id} тэмдэглэлийн дуртай сэлгэх амжилтгүй боллоо.",
    "Updating the note's category has failed. Is the target directory writable?" : "Тэмдэглэлийн ангиллыг шинэчлэх амжилтгүй боллоо. Зорилтот хавтас бичих эрхтэй юу?",
    "Updating the category for note {id} has failed." : "{id} тэмдэглэлийн ангилал шинэчлэх амжилтгүй боллоо.",
    "Uncategorized" : "Ангилалгүй",
    "Sample note" : "Жишээ тэмдэглэл",
    "15 January 2021, via Nextcloud Notes" : "2021 оны 1 сарын 15, Nextcloud Тэмдэглэл-ээр",
    "Me, you, and all our friends!" : "Би, чи, бүх найзууд маань!",
    "Tasks" : "Даалгаврууд",
    "Write nice todo lists" : "Хийх зүйлсийн жагсаалт бичих",
    "Buy Fries" : "Шарсан төмс авах",
    "Birthdays" : "Төрсөн өдрүүд",
    "Jen, in three days!" : "Жен, гурван өдрийн дараа!",
    "Moss, 21.03.1973" : "Мосс, 1973.03.21",
    "Roy, 1979" : "Рой, 1979",
    "Review Steps" : "Шалгах алхмууд",
    "Turn PC off" : "Компьютер унтраах",
    "Turn PC on" : "Компьютер асаах",
    "Then call IT" : "Дараа нь IT руу залгах",
    "Quotes" : "Ишлэлүүд",
    "Nextcloud, a safe home for all your data" : "Nextcloud, таны бүх өгөгдлийн аюулгүй гэр",
    "Development Mode" : "Хөгжүүлэлтийн горим",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Тэмдэглэлийн апп хөгжүүлэлтийн эх сурвалжаас суулгасан байна. Үүний оронд албан ёсны <a href=\"%1$s\">Nextcloud App Store</a>-с суулгана уу. Хэрэв та Notes аппыг өөрөө бүтээхийг хүсвэл <a href=\"%2$s\">хөгжүүлэгчийн зааврыг</a> дагана уу."
},
"nplurals=2; plural=(n != 1);");
