OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "Files" : "ಕಡತಗಳು",
    "Delete" : "Delete",
    "Cancel" : "﻿ರದ್ದು",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
    "Rename" : "Rename",
    "Edit" : "ಸಂಪಾದಿಸು",
    "Today" : "Today"
},
"nplurals=2; plural=(n > 1);");
