OC.L10N.register(
    "notes",
    {
    "Notes" : "Σημειώσεις",
    "Create new note" : "Δημιουργία νέας σημείωσης",
    "More notes" : "Περισσότερες σημειώσεις",
    "Reading notes from filesystem has failed." : "Η ανάγνωση σημειώσεων από το σύστημα αρχείων απέτυχε.",
    "Error" : "Σφάλμα",
    "New note" : "Νέα σημείωση",
    "Distraction-free notes and writing" : "Σημειώσεις και γραφή χωρίς περισπασμούς",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Η εφαρμογή Σημειώσεις είναι μια εφαρμογή λήψης σημειώσεων χωρίς περισπασμούς για το [Nextcloud](https://www.nextcloud.com/). Παρέχει κατηγορίες για καλύτερη οργάνωση και υποστηρίζει μορφοποίηση χρησιμοποιώντας σύνταξη [Markdown](https://en.wikipedia.org/wiki/Markdown). Οι σημειώσεις αποθηκεύονται ως αρχεία στο Nextcloud σας, ώστε να μπορείτε να τις προβάλλετε και να τις επεξεργαστείτε με κάθε πελάτη Nextcloud. Επιπλέον, ένα ξεχωριστό [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) επιτρέπει την εύκολη ενσωμάτωση σε εφαρμογές ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), καθώς και [εφαρμογές τρίτων ](https://github.com/nextcloud/notes/wiki#3rd-party-clients) που επιτρέπουν εύκολη πρόσβαση στις σημειώσεις σας στο Nextcloud). Περαιτέρω λειτουργίες περιλαμβάνουν τη σήμανση σημειώσεων ως αγαπημένες.",
    "Deleted {title}" : "Διεγραμμένες {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Διαγράφηκε {number} σημείωση","Διαγράφηκαν {number} σημειώσεις"],
    "Undo Delete" : "Αναίρεση διαγραφής",
    "Note recovered" : "Η σημείωση ανακτήθηκε",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Επαναφέρθηκε {number} σημείωση","Επαναφέρθηκαν {number} σημειώσεις"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν σημειώσεις που δεν έχουν αποθηκευτεί. Φεύγοντας από την σελίδα θα διαγραφούν οι αλλαγές!",
    "Notes settings" : "Ρυθμίσεις σημειώσεων",
    "Please see Nextcloud server log for details." : "Για λεπτομέρειες παρακαλούμε δείτε το ιστορικό του διακομιστή Nextcloud.",
    "Custom" : "Προσαρμοσμένο",
    "Rich text" : "Μορφοποιημένο κείμενο",
    "Plain text" : "Απλό κείμενο",
    "Preview" : "Προεπισκόπηση",
    "Make the selection bold" : "Κάντε την επιλογή έντονη",
    "Make the selection italic" : "Κάντε την επιλογή πλάγια",
    "Wrap the selection in quotes" : "Περικλείστε την επιλογή σε εισαγωγικά",
    "The selection will be turned into monospace" : "Η επιλογή θα μετατραπεί σε monospace",
    "Remove any styles from the selected text" : "Αφαίρεση όλων των στυλ από το επιλεγμένο κείμενο",
    "Makes the current line a list element" : "Κάνει την τρέχουσα γραμμή στοιχείο λίστας",
    "Makes the current line a list element with a number" : "Κάνει την τρέχουσα γραμμή στοιχείο αριθμημένης λίστας",
    "Toggle heading for current line" : "Εναλλαγή επικεφαλίδας για τρέχουσα γραμμή",
    "Set the current line as a big heading" : "Ορισμός τρέχουσας γραμμής ως μεγάλης επικεφαλίδας",
    "Insert link" : "Εισαγωγή συνδέσμου",
    "Insert image" : "Εισαγωγή εικόνας",
    "Switch between editor and viewer" : "Εναλλαγή μεταξύ επεξεργαστή και προβολέα",
    "Pick a notes folder" : "Επιλογή φακέλου σημειώσεων",
    "Set notes folder" : "Ορισμός φακέλου σημειώσεων",
    "Display" : "Οθόνη",
    "File extension" : "Επέκταση αρχείου",
    "Notes folder" : "Φάκελος Σημειώσεων",
    "Mobile apps" : "Εφαρμογές κινητού",
    "Shortcuts" : "Συντομεύσεις",
    "Delete" : "Διαγραφή",
    "Cancel" : "Ακύρωση",
    "All notes" : "Όλες οι σημειώσεις",
    "Categories" : "Κατηγορίες",
    "Create a sample note with Markdown" : "Δημιουργία δείγματος σημείωσης με Markdown",
    "No notes yet" : "Δεν υπάρχουν ακόμα σημειώσεις",
    "Select an image" : "Επιλέξτε μια εικόνα",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Δεν μπορείτε να επιλέξετε εικόνες εκτός του φακέλου των σημειώσεων σας. Ο φάκελος των σημειώσεων σας είναι: {folder}",
    "Wrong image" : "Λάθος εικόνα",
    "The file was not uploaded. Check your server logs." : "Το αρχείο δεν μεταφορτώθηκε. Ελέγξτε τα αρχεία καταγραφής του διακομιστή σας.",
    "Upload image" : "Μεταφόρτωση εικόνας",
    "Rich text editor" : "Επεξεργαστής πλούσιου κειμένου",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Μπορείτε τώρα να μεταβείτε στη χρήση του εύχρηστου επεξεργαστή πλούσιου κειμένου χωρίς περισπασμούς. Σας επιτρέπει να επεξεργάζεστε σημειώσεις χωρίς να βλέπετε σημάδια Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Αυτή η επιλογή μπορεί επίσης να αλλάξει αργότερα στις ρυθμίσεις της εφαρμογής Σημειώσεις.",
    "Keep plain Markdown editor" : "Διατήρηση απλού επεξεργαστή Markdown",
    "Use rich editor" : "Χρήση πλούσιου επεξεργαστή",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "Error while renaming note." : "Σφάλμα κατά τη μετονομασία της σημείωσης.",
    "Error during preparing note for deletion." : "Σφάλμα κατά την προετοιμασία της σημείωσης για διαγραφή.",
    "Share" : "Κοινή χρήση",
    "Change category" : "Αλλαγή κατηγορίας",
    "Rename" : "Rename",
    "Rename note" : "Μετονομασία σημείωσης",
    "Delete note" : "Διαγραφή σημείωσης",
    "Error from Nextcloud server: {msg}" : "Σφάλμα από τον διακομιστή Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Η σημείωση έχει τροποποιηθεί σε μια άλλη συνεδρία. Επιλέξτε ποια έκδοση θα αποθηκευτεί.",
    "Use version from server" : "Χρησιμοποιήστε την έκδοση από τον διακομιστή",
    "Use current version" : "Χρησιμοποιήστε την τρέχουσα έκδοση",
    "Empty note" : "Κενή σημείωση",
    "Write …" : "Σύνταξη ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Επεξεργασία",
    "Exit full screen" : "Έξοδος πλήρους οθόνης",
    "Full screen" : "Πλήρης οθόνη",
    "Note is read-only. You cannot change it." : "Η σημείωση είναι μόνο για ανάγνωση. Δεν μπορείτε να την αλλάξετε.",
    "Save failed. Click to retry." : "Η αποθήκευση απέτυχε. Κλίκ για προσπάθεια ξανά.",
    "Update conflict. Click for resolving manually." : "Διένεξη κατά την ενημέρωση. Κάντε κλικ για μη αυτόματη επίλυση.",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθές",
    "This week" : "Αυτή την εβδομάδα",
    "Last week" : "Προηγούμενη εβδομάδα",
    "This month" : "Αυτό το μήνα",
    "Last month" : "Προηγούμενος μήνας",
    "Search for notes" : "Αναζήτηση σημειώσεων",
    "Loading …" : "Φόρτωση…",
    "Find in all categories" : "Αναζήτηση σε όλες τις κατηγορίες",
    "Write down your thoughts without any distractions." : "Κρατήστε τις σκέψεις σας χωρίς περιορισμούς.",
    "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
    "Organize your notes in categories." : "Οργανώστε τις σημειώσεις σας σε κατηγορίες.",
    "Note not found." : "Δεν βρέθηκε η σημείωση.",
    "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
    "Insufficient storage." : "Μη επαρκής αποθηκευτικός χώρος.",
    "See JavaScript console and server log for details." : "Δείτε την κονσόλα JavaScript και το ιστορικό του διακομιστή για λεπτομέρειες.",
    "Updating settings has failed." : "Η ενημέρωση ρυθμίσεων απέτυχε.",
    "Fetching notes for dashboard has failed." : "Η λήψη σημειώσεων για τον πίνακα ελέγχου απέτυχε.",
    "Fetching notes has failed." : "Η λήψη σημειώσεων απέτυχε.",
    "Fetching note {id} has failed." : "Η λήψη της σημείωσης {id} απέτυχε.",
    "Refreshing note {id} has failed." : "Η ανανέωση της σημείωσης {id} απέτυχε.",
    "Renaming note {id} has failed." : "Η μετονομασία της σημείωσης {id} απέτυχε.",
    "Creating new note has failed." : "Η δημιουργία νέας σημείωσης απέτυχε.",
    "Saving note {id} has failed." : "Η αποθήκευση της σημείωσης {id} απέτυχε.",
    "Updating title for note {id} has failed." : "Η ενημέρωση του τίτλου της σημείωσης {id} απέτυχε.",
    "Undo delete has failed for note {title}." : "Η αναίρεση διαγραφής της σημείωσης {title} απέτυχε.",
    "Deleting note {id} has failed." : "Η διαγραφή της σημείωσης {id} απέτυχε.",
    "Toggling favorite for note {id} has failed." : "Η εναλλαγή του αγαπημένου για τη σημείωση {id} απέτυχε.",
    "Updating the note's category has failed. Is the target directory writable?" : "Η ενημέρωση της κατηγορίας σημείωσης απέτυχε. Ο κατάλογος είναι εγγράψιμος;",
    "Updating the category for note {id} has failed." : "Η ενημέρωση της κατηγορίας σημείωσης {id} απέτυχε.",
    "Uncategorized" : "Χωρίς κατηγορία",
    "Sample note" : "Δείγμα σημείωσης",
    "15 January 2021, via Nextcloud Notes" : "15 Ιανουαρίου 2021, μέσω Nextcloud Notes",
    "Me, you, and all our friends!" : "Εγώ, εσύ, και όλοι οι φίλοι μας!",
    "Tasks" : "Εργασίες",
    "Write nice todo lists" : "Γράψτε ωραίες λίστες tasks",
    "Buy Fries" : "Αγόρασε πατάτες",
    "Birthdays" : "Γενέθλια",
    "Jen, in three days!" : "Jen, σε τρεις μέρες!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Βήματα Ανασκόπησης",
    "Turn PC off" : "Απενεργοποίηση υπολογιστή",
    "Turn PC on" : "Ενεργοποίηση υπολογιστή",
    "Then call IT" : "Έπειτα καλέστε το IT",
    "Quotes" : "Αποφθέγματα",
    "Nextcloud, a safe home for all your data" : "Nextcloud, ένα ασφαλές σπίτι για όλα τα δεδομένα σας",
    "Development Mode" : "Κατάσταση προγραμματισμού",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Φαίνεται ότι η εφαρμογή σημειώσεων εγκαταστάθηκε από μια τρίτη πηγή ανάπτυξης. Παρακαλούμε εγκαταστήστε από την επίσημη <a href=\"%1$s\"> Αγορά Εφαρμογών Nextcloud</a>. Αν επιθυμείτε να αναπτύξετε την εφαρμογή Σημειώσεων, παρακαλούμε ακολουθήστε τις <a href=\"%2$s\">οδηγίες προγραμματιστών</a>."
},
"nplurals=2; plural=(n != 1);");
