OC.L10N.register(
    "notes",
    {
    "Notes" : "Notoj",
    "Error" : "Eraro",
    "New note" : "Nova noto",
    "Distraction-free notes and writing" : "Sendistraj notoj kaj skribado",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Estas nekonservitaj notoj. Foriro el la paĝo perdos ĉiujn ŝanĝojn!",
    "Preview" : "Antaŭvidi",
    "Insert image" : "Enmeti bildon",
    "Files" : "Dosieroj",
    "Delete" : "Delete",
    "Cancel" : "Nuligi",
    "All notes" : "Ĉiuj notoj",
    "Categories" : "Kategorioj",
    "Remove from favorites" : "Forigi el pliŝataĵoj",
    "Add to favorites" : "Aldoni al pliŝataĵoj",
    "Share" : "Kunhavigi",
    "Rename" : "Rename",
    "Delete note" : "Forigi noton",
    "Use current version" : "Uzi nunan version",
    "Edit" : "Modifi",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "Loading …" : "Ŝargado...",
    "Updating the note's category has failed. Is the target directory writable?" : "Ĝisdaztigo de la nota kategorio malsukcesis. Ĉu la celdosierujo skribeblas?",
    "Uncategorized" : "Senkategoria",
    "Tasks" : "Taskoj"
},
"nplurals=2; plural=(n != 1);");
