OC.L10N.register(
    "notes",
    {
    "Notes" : "Бележки",
    "Create new note" : "Създаване на нова бележка",
    "More notes" : "Още бележки",
    "Reading notes from filesystem has failed." : "Четенето на бележки от файлова система е неуспешно.",
    "Error" : "Грешка",
    "New note" : "Нова бележка",
    "Distraction-free notes and writing" : "Бележки и писане без разсейване ",
    "Deleted {title}" : "Изтрито {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Изтрити {number} бележки","Изтрити  {number} бележки"],
    "Undo Delete" : "Отмяна на изтриването",
    "Note recovered" : "Бележката е възстановена",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Възстановени {number} бележки","Възстановени {number} бележки"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има незаписани бележки. Напускайте тази страница, направени промени ще бъдат загубени!",
    "Notes settings" : "Настройки на бележки",
    "Please see Nextcloud server log for details." : "За подробности вижте дневника на сървъра Nextcloud.",
    "Preview" : "Преглед",
    "Make the selection bold" : "Удебеляване на избраната селекция.",
    "Make the selection italic" : "Направете селекцията в курсив",
    "Wrap the selection in quotes" : "Ограждане на селекцията в кавички",
    "The selection will be turned into monospace" : "Селекцията ще бъде представена монопространствено",
    "Remove any styles from the selected text" : "Премахване на всички стилове от избрания текст",
    "Makes the current line a list element" : "Превръща текущия ред в елемент от списък",
    "Makes the current line a list element with a number" : "Превръща текущия ред в елемент от списък с номер",
    "Toggle heading for current line" : "Превключване на заглавието на текущия ред",
    "Set the current line as a big heading" : "Задаване на текущия ред като голяма заглавка",
    "Insert link" : "Вмъкване на връзка",
    "Insert image" : "Вмъкване на изображение",
    "Switch between editor and viewer" : "Превключване между редактиране и преглед",
    "File extension" : "Разширение на файл",
    "Mobile apps" : "Мобилни приложения",
    "Shortcuts" : "Преки пътища",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "All notes" : "Всички бележки",
    "Categories" : "Категории",
    "Create a sample note with Markdown" : "Създаване на примерна бележка с Мarkdown",
    "No notes yet" : "Не са открити бележки",
    "Select an image" : "Избор на изображение",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Не можете да избирате изображения извън вашата папка с бележки. Вашата папка с бележки е: {folder}",
    "Wrong image" : "Грешно изображение",
    "The file was not uploaded. Check your server logs." : "Файлът не беше качен. Проверете регистрите /журнали/ на вашия сървър.",
    "Upload image" : "Качване на изображение",
    "Rich text editor" : "Редактор на текст в RTF формат",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Сега можете да преминете към използване на лесния за употреба и неразсейващ редактор на текст в RTF формат. Той ви позволява да редактирате бележки, без да виждате никакви Мarkdown символи.",
    "This option can also be changed later on in the Notes app settings." : "Тази опция може да бъде променена и по-късно в настройките на приложението Notes /бележки/.",
    "Keep plain Markdown editor" : "Запазване на обикновения Мarkdown редактор",
    "Use rich editor" : "Използване на редактор RTF формат",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "Error during preparing note for deletion." : "Грешка при подготовката на бележка за изтриване.",
    "Share" : "Сподели",
    "Rename" : "Rename",
    "Delete note" : "Изтрий бележката",
    "Error from Nextcloud server: {msg}" : "Грешка от Nextcloud сървър: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Бележката е променена в друга сесия. Моля, изберете коя версия да бъде запазена.",
    "Use version from server" : "Използване на версия от сървъра",
    "Use current version" : "Използване на текуща версия",
    "Empty note" : "Празна бележка",
    "Write …" : "Писане ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Променяне",
    "Exit full screen" : "Изход от цял екран",
    "Full screen" : "Цял екран",
    "Note is read-only. You cannot change it." : "Забележката е само за четене. Не можете да я промените.",
    "Save failed. Click to retry." : "Записването не бе успешно. Щракнете за нов опит.",
    "Update conflict. Click for resolving manually." : "Конфликт с актуализиране. Кликнете, за ръчно разрешаване.",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "This week" : "Тази седмица",
    "Last week" : "Миналата седмица",
    "This month" : "Този месец",
    "Last month" : "Миналия месец",
    "Loading …" : "Зарежда …",
    "Write down your thoughts without any distractions." : "Запишете мислите си без разсейване.",
    "Use Markdown markups to style your text." : "Използване на Markdown маркировки , за да оформите текста си.",
    "Organize your notes in categories." : "Организирайте бележките си в категории.",
    "Note not found." : "Бележката не е открита.",
    "Note is locked." : "Бележката е заключена.",
    "Insufficient storage." : "Недостатъчно място в хранилище.",
    "See JavaScript console and server log for details." : "Вижте конзолата на JavaScript и дневника на сървъра за подробности.",
    "Updating settings has failed." : "Неуспешно актуализиране на настройки",
    "Fetching notes for dashboard has failed." : "Извличането на бележки за таблото за управление не бе успешно.",
    "Fetching notes has failed." : "Извличането на бележки не бе успешно.",
    "Fetching note {id} has failed." : "Извличането на бележка {id} не бе успешно.",
    "Refreshing note {id} has failed." : " Обновяването на бележка {id} не бе успешно.",
    "Renaming note {id} has failed." : " Преименуването на бележка {id} не бе успешно.",
    "Creating new note has failed." : "Създаването на нова бележка {id} не бе успешно.",
    "Saving note {id} has failed." : "Запазването на бележка {id} не бе успешно.",
    "Updating title for note {id} has failed." : "Актуализирането на заглавието на бележка {id} не бе успешно.",
    "Undo delete has failed for note {title}." : "Отмяната на изтриването не бе успешна за бележка {title}.",
    "Deleting note {id} has failed." : "Изтриването на бележка {id} не бе успешно.",
    "Toggling favorite for note {id} has failed." : "Превключването на любими за бележка {id} не бе успешно.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешен опит за промяна на категорията. Може ли да се пише в папката на бележките?",
    "Updating the category for note {id} has failed." : "Актуализирането на категорията за бележка {id} не бе успешно.",
    "Uncategorized" : "Некатегоризирана",
    "Sample note" : "Примерна бележка",
    "15 January 2021, via Nextcloud Notes" : "15 януари 2021 г., чрез приложението Nextcloud Бележки",
    "Me, you, and all our friends!" : "Аз, ти и всички наши приятели!",
    "Tasks" : "Задачи",
    "Write nice todo lists" : "Списъци с хубави неща за правене",
    "Buy Fries" : "Купи пържени картофи",
    "Birthdays" : "Рожденни дни",
    "Jen, in three days!" : "Джен, след три дни!",
    "Moss, 21.03.1973" : "Мос, 21.03.1973 г.",
    "Roy, 1979" : "Рой, 1979 г.",
    "Review Steps" : "Стъпки за преглед",
    "Turn PC off" : "Изключване на компютъра",
    "Turn PC on" : "Включване на компютъра",
    "Then call IT" : "След това се обадете на ИТ специалист",
    "Quotes" : "Оферти",
    "Nextcloud, a safe home for all your data" : "Nextcloud - безопасен дом за всичките ви данни",
    "Development Mode" : "Режим на разработка",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Изглежда, че приложението за бележки е инсталирано от източник за разработка. Вместо това го инсталирайте от официалния <a href=\"%1$s\"> Nextcloud  App Store</a>. Ако искате сами да създадете приложението Notes, моля, следвайте <a href=\"%2$s\">инструкциите за разработчици</a>."
},
"nplurals=2; plural=(n != 1);");
