OC.L10N.register(
    "notes",
    {
    "Notes" : "Poznámky",
    "Create new note" : "Vytvořit novou poznámku",
    "More notes" : "Další poznámky",
    "Reading notes from filesystem has failed." : "Načítání poznámek ze souborového systému se nezdařilo.",
    "Error" : "Chyba",
    "New note" : "Nová poznámka",
    "Distraction-free notes and writing" : "Pozornost nerozptylující poznámky a zápisky",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikace poznámky je nerozptylující volně dostupná aplikace pro [Nextcloud](https://www.nextcloud.com/) sloužící k zapisování poznámek a zápisů. Nabízí možnost kategorizace pro lepší organizaci a podporuje formátování syntaxí [Markdown](https://cs.wikipedia.org/wiki/Markdown). Poznámky jsou ukládány jako soubory ve vašem Nextcloudu, takže je můžete zobrazovat a upravovat skrze všechny klienty Nextcloud. Aby toho nebylo málo, tak aplikace poskytuje i [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md), které umožňuje snadnou integraci do dalších aplikací, jako třeba do té pro [Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) a mnoho dalších [aplikací od 3. stran](https://github.com/nextcloud/notes/wiki#3rd-party-clients) pro pohodlnější přístup k vašim poznámkám.",
    "Deleted {title}" : "Smazáno {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Smazána {number} poznámka","Smazány {number} poznámky","Smazáno {number} poznámek","Smazány {number} poznámky"],
    "Undo Delete" : "Vzít zpět vymazání",
    "Note recovered" : "Poznámka obnovena",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Obnovena {number} poznámka","Obnoveny {number} poznámky","Obnoveno {number} poznámek","Obnoveny {number} poznámky"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Máte neuložené poznámky. Opuštění stránky zahodí všechny změny!",
    "Notes settings" : "Nastavení pro Poznámky",
    "Please see Nextcloud server log for details." : "Podrobnosti naleznete v záznamu událostí (log) Nextcloud serveru.",
    "Custom" : "Uživatelsky určené",
    "Rich text" : "Formátovaný text",
    "Plain text" : "Neformátovaný text",
    "Preview" : "Náhled",
    "Make the selection bold" : "Převést vybrané na tučné písmo",
    "Make the selection italic" : "Převést vybrané na kurzívu",
    "Wrap the selection in quotes" : "Obklopit vybrané uvozovkami",
    "The selection will be turned into monospace" : "Vybrané bude převedeno na písmo se všemi znaky stejně širokými",
    "Remove any styles from the selected text" : "Odebrat označenému textu veškeré formátování",
    "Makes the current line a list element" : "Udělá ze stávajícího řádku prvek seznamu",
    "Makes the current line a list element with a number" : "Udělá ze stávajícího řádku prvek číslovaného seznamu",
    "Toggle heading for current line" : "Udělá/zruší ze stávajícího řádku nadpis",
    "Set the current line as a big heading" : "Nastavit stávající řádek jako velký nadpis",
    "Insert link" : "Vložit odkaz",
    "Insert image" : "Vložit obrázek",
    "Switch between editor and viewer" : "Přepnout mezi editorem a prohlížečem",
    "Pick a notes folder" : "Vyberte složku s poznámkami",
    "Set notes folder" : "Nastavit složku s poznámkami",
    "General" : "Obecné",
    "Display" : "Zobrazení",
    "File extension" : "Přípona souboru",
    "For new notes" : "Pro nové poznámky",
    "Custom file extension" : "Uživatelsky určená přípona souboru",
    "Files" : "Soubory",
    "Notes folder" : "Složka s poznámkami",
    "Mobile apps" : "Mobilní aplikace",
    "Shortcuts" : "Zkratky",
    "Delete" : "Smazat",
    "Cancel" : "Storno",
    "All notes" : "Všechny poznámky",
    "Categories" : "Kategorie",
    "Create a sample note with Markdown" : "Vytvořit ukázkovou poznámku využívající Markdown značky",
    "No notes yet" : "Zatím žádné poznámky",
    "Select an image" : "Vyberte obrázek",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Není možné vybírat obrázky nacházející se mimo vaši složku s poznámkami. Vaše složka s poznámkami je: {folder}",
    "Wrong image" : "Chybný obrázek",
    "The file was not uploaded. Check your server logs." : "Soubor nebyl nahrán. Podívejte se do záznamů událostí na serveru.",
    "Upload image" : "Nahrát obrázek",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone a iPad",
    "Rich text editor" : "Editor formátovaného textu",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Nyní je možné přepnout na snadno použitelný a pozornost nerozptylující editor formátovaného textu. Ten umožňuje upravovat poznámky bez zobrazování Markdown značek.",
    "This option can also be changed later on in the Notes app settings." : "Tuto volbu je také možné změnit později v nastavení aplikace Poznámky.",
    "Keep plain Markdown editor" : "Ponechat editor holého Markdown",
    "Use rich editor" : "Použít editor formátovaného",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "Error while renaming note." : "Chyba při přejmenovávání poznámky.",
    "Error during preparing note for deletion." : "Chyba při přípravě vymazání poznámky.",
    "Share" : "Sdílet",
    "Change category" : "Změnit kategorii",
    "Rename" : "Přejmenovat",
    "Rename note" : "Přejmenovat poznámku",
    "Delete note" : "Smazat poznámku",
    "Error from Nextcloud server: {msg}" : "Chyba z Nextcloud serveru: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Poznámka byla upravena v jiném sezení. Zvolte, která verze má být uložena.",
    "Use version from server" : "Použít verzi ze serveru",
    "Use current version" : "Použít stávající verzi",
    "Empty note" : "Prázdná poznámka",
    "Write …" : "Zapsat …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Upravit",
    "Exit full screen" : "Opustit celou obrazovku",
    "Full screen" : "Na celou obrazovku",
    "Note is read-only. You cannot change it." : "Poznámka je pouze pro čtení. Nemůžete ji měnit.",
    "Save failed. Click to retry." : "Uložení se nezdařilo. Klikněte pro opětovný pokus.",
    "Update conflict. Click for resolving manually." : "Konflikt aktualizace. Pokud chcete vyřešit ručně, klikněte sem.",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "This week" : "Tento týden",
    "Last week" : "Minulý týden",
    "This month" : "Tento měsíc",
    "Last month" : "Minulý měsíc",
    "Search for notes" : "Vyhledat poznámky",
    "Loading …" : "Načítání …",
    "Find in all categories" : "Prohledávat ve všech kategoriích",
    "Write down your thoughts without any distractions." : "Zapište si své myšlenky, aniž byste u toho byli rozptylováni.",
    "Use Markdown markups to style your text." : "Pro formátování textu použijte Markdown značky.",
    "Organize your notes in categories." : "Uspořádávejte své poznámky do kategorií.",
    "Note not found." : "Poznámka nenalezena.",
    "Note is locked." : "Poznámka je uzamčena.",
    "Insufficient storage." : "Nedostatečná kapacita úložiště,",
    "See JavaScript console and server log for details." : "Podrobnosti viz konzole JavaScript a záznamy událostí na serveru.",
    "Updating settings has failed." : "Aktualizace nastavení se nezdařila.",
    "Fetching notes for dashboard has failed." : "Načítání poznámek pro nástěnku se nezdařilo.",
    "Fetching notes has failed." : "Načítání poznámek se nezdařilo.",
    "Fetching note {id} has failed." : "Načítání poznámky {id} se nezdařilo.",
    "Refreshing note {id} has failed." : "Znovunačtení poznámky {id} se nezdařilo.",
    "Renaming note {id} has failed." : "Přejmenování poznámky {id} se nezdařilo.",
    "Creating new note has failed." : "Vytváření nové poznámky se nezdařilo.",
    "Saving note {id} has failed." : "Uložení poznámky {id} se nezdařilo.",
    "Updating title for note {id} has failed." : "Aktualizace nadpisu poznámky {id} se nezdařila.",
    "Undo delete has failed for note {title}." : "Vzetí vymazání poznámky {title} zpět se nezdařilo.",
    "Deleting note {id} has failed." : "Mazání poznámky {id} se nezdařilo.",
    "Toggling favorite for note {id} has failed." : "Označení / zrušení označení poznámky {id} jako oblíbené se nezdařilo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualizace kategorie poznámky se nezdařila. Je cílový adresář přístupný pro zápis?",
    "Updating the category for note {id} has failed." : "Aktualizace kategorie u poznámky {id} se nezdařila.",
    "Uncategorized" : "Nezařazené",
    "Sample note" : "Ukázková poznámka",
    "15 January 2021, via Nextcloud Notes" : "15. ledna 2021, prostřednictvím Nextcloud Poznámky",
    "Me, you, and all our friends!" : "Mě, vám a všem našim přátelům!",
    "Tasks" : "Úkoly",
    "Write nice todo lists" : "Napsat hezký seznam úkolů",
    "Buy Fries" : "Koupit hranolky",
    "Birthdays" : "Narozeniny",
    "Jen, in three days!" : "Jen – za tři dny!",
    "Moss, 21.03.1973" : "Moss, 21. 03. 1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Kroky přezkoumání",
    "Turn PC off" : "Vypnout počítač",
    "Turn PC on" : "Zapnout počítač",
    "Then call IT" : "Pak až zavolat na podporu",
    "Quotes" : "Nabídky",
    "Nextcloud, a safe home for all your data" : "Nextcloud – bezpečný domov pro všechna vaše data",
    "Development Mode" : "Režim pro vývojáře",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Zdá se, že aplikace Poznámky byla nainstalována ze zdroje pro vývojáře. Nainstalujte ji namísto toho z oficiálního <a href=\"%1$s\">Nextcloud katalogu aplikací</a>. Pokud si chcete sestavit (zkompilovat) aplikaci Poznámky sami, následujte <a href=\"%2$s\">pokyny pro vývojáře</a>."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
