OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Create new note" : "Crea una nota noa",
    "Reading notes from filesystem has failed." : "Sa letura de is notas dae su filesystem est faddida.",
    "Error" : "Errore",
    "New note" : "Nota noa",
    "Distraction-free notes and writing" : "Notas sena disvios e iscritura ",
    "Deleted {title}" : "Eliminadu {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : [" {number} notas eliminadas","{number} notas eliminadas"],
    "Undo Delete" : "Annulla eliminatzione",
    "Note recovered" : "Nota ripristinada",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} notas ripristinadas","Notas {number} "],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Bi sunt non sarvadas. Essida. Si lassas sa pàgina as a pèrdere totu is modìficas!",
    "Please see Nextcloud server log for details." : "Càstia is registros de su serbidore Nextcloud pro is detàllios.",
    "Preview" : "Anteprima",
    "Insert image" : "Inserta·nche immàgine",
    "General" : "Generale",
    "Shortcuts" : "Incurtzaduras",
    "All notes" : "Totu is notas",
    "Categories" : "Categorias",
    "No notes yet" : "Peruna nota ancora",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "Add to favorites" : "Agiunghe a is preferidos",
    "Error during preparing note for deletion." : "Errore in s'eliminatzione de sa nota.",
    "Rename" : "Torra a numenare",
    "Delete note" : "Elìmina nota",
    "Error from Nextcloud server: {msg}" : "Errore dae su serbidore de Nexcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Sa nota est istada modificada in un'àtera sessione. Sèbera cale versione est a sarvare.",
    "Use version from server" : "Impre versione de su serbidore",
    "Use current version" : "Imprea versione atuale",
    "Empty note" : "Nota bòida",
    "Write …" : "Iscrie ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modìfica ",
    "Exit full screen" : "Essi dae ischermu intreu",
    "Full screen" : "Ischermu intreu",
    "Note is read-only. You cannot change it." : "Sa nota est a letura sola. Non faghet a dda cambiare.",
    "Save failed. Click to retry." : "Sarvamentu faddidu. Incarca pro bi torrare a proare.",
    "Update conflict. Click for resolving manually." : "Cunflitu de agiornamentu. Incarca pro isorvere a manu.",
    "Today" : "Oe",
    "Yesterday" : "Yesterday",
    "This week" : "Custa chida",
    "Last week" : "Sa chida colada",
    "This month" : "Custu mese",
    "Last month" : "Su mese passadu",
    "Loading …" : "Carrigamentu...",
    "Write down your thoughts without any distractions." : "Piga nota de is pensamentos tuos sena perunu disviu.",
    "Use Markdown markups to style your text." : "Imprea cuntrasignos Markdown pro formatare su testu tuo.",
    "Organize your notes in categories." : "Organiza is notas tuas in catègorias.",
    "Note not found." : "Nota no agatada.",
    "Note is locked." : "Sa nota est blocada.",
    "Insufficient storage." : "S'ispàtziu de archiviatzione non bastat.",
    "See JavaScript console and server log for details." : "Càstia sa consolla JavaScript e is registros de su serbidore pro is detàllios.",
    "Updating settings has failed." : "Errore in s'atualizatzione de sa cunfiguratzione.",
    "Fetching notes for dashboard has failed." : "Recùperu de is notas pro su pannellu de controllu faddidu.",
    "Fetching notes has failed." : "Recùperu de is notas faddidu.",
    "Fetching note {id} has failed." : "Recùperu nota {id} faddidu.",
    "Refreshing note {id} has failed." : "L'agiornamentu de sa nota {id} faddidu.",
    "Renaming note {id} has failed." : "Sa torrada a numenare {id} faddida.",
    "Creating new note has failed." : "Creatzione nota noa faddida.",
    "Saving note {id} has failed." : "Su sarvamentu de sa nota {id} est faddidu.",
    "Updating title for note {id} has failed." : "S'agiornamentu de su tìtulu de sa nota {id} faddidu.",
    "Undo delete has failed for note {title}." : "Annullamentu eliminatzione faddidu pro sa nota {title}.",
    "Deleting note {id} has failed." : "Eliminatzione de sa nota {id} faddida.",
    "Toggling favorite for note {id} has failed." : "S'ativatzione comente preferidu de sa nota {id} faddida",
    "Updating the note's category has failed. Is the target directory writable?" : "S'agiornamentu de sa categoria de is notas faddidu. Sa cartella de destinu faghet a dda iscrìere?",
    "Updating the category for note {id} has failed." : "Agiornamentu de sa categoria pro sa nota {id} est faddidu.",
    "Uncategorized" : "Sena categoria",
    "Tasks" : "Fainas",
    "Development Mode" : "Modalidade de isvilupu",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Paret chu s'aplicatzione de is notas siat istada installada dae una fonte de isvilupu. Installa·dda imbetzes dae <a href=\"%1$s\">Butega de aplicatziones de Nextcloud</a> ufitziales. Si cheres compilare s'aplicatzione Note in autonomia, sighi is <a href=\"%2$s\">istrutziones pro isvilupadores</a>"
},
"nplurals=2; plural=(n != 1);");
