OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
    "Preview" : "Previsualizar",
    "Files" : "Archivos",
    "Cancel" : "Cancelar",
    "All notes" : "Todas las notas",
    "Categories" : "Categorías",
    "No notes yet" : "Aún no hay notas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a tus favoritos",
    "Share" : "Compartir",
    "Delete note" : "Borrar nota",
    "Edit" : "Editar",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "This week" : "Esta semana",
    "This month" : "Este mes",
    "Uncategorized" : "Sin categoría",
    "Tasks" : "Tareas"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
