OC.L10N.register(
    "notes",
    {
    "Notes" : "笔记",
    "Create new note" : "创建新笔记",
    "More notes" : "更多笔记",
    "Reading notes from filesystem has failed." : "从文件系统读取笔记失败。",
    "Error" : "错误",
    "New note" : "新建笔记",
    "Distraction-free notes and writing" : "无干扰的笔记和写作",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notes 应用是一款专为 [Nextcloud](https://www.nextcloud.com/) 设计的无干扰笔记应用。它提供了分类功能以便更好地管理笔记，并支持使用 [Markdown](https://en.wikipedia.org/wiki/Markdown) 语法进行格式化。笔记会以文件形式保存在您的 Nextcloud 中，因此您可以使用任何 Nextcloud 客户端查看和编辑它们。此外，独立的 [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) 使得与其他应用（如 [Android](https://github.com/nextcloud/notes-android)、[iOS](https://github.com/nextcloud/notes-ios) 以及允许便捷访问 Nextcloud 笔记的 [第三方应用](https://github.com/nextcloud/notes/wiki#3rd-party-clients)）的集成变得非常容易。其他功能还包括收藏笔记。",
    "Deleted {title}" : "已删除 {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["已删除 {number} 条笔记"],
    "Undo Delete" : "撤销删除",
    "Note recovered" : "笔记已恢复",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["已恢复 {number} 条笔记"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
    "New category" : "新类别",
    "Notes settings" : "笔记设置",
    "Please see Nextcloud server log for details." : "有关详情请参阅 Nextcloud 服务器日志。",
    "Custom" : "自定义",
    "Rich text" : "富文本",
    "Plain text" : "纯文本",
    "Preview" : "预览",
    "Make the selection bold" : "将所选内容加粗",
    "Make the selection italic" : "将所选内容设为斜体",
    "Wrap the selection in quotes" : "将所选内容包括在引号中",
    "The selection will be turned into monospace" : "所选内容会变为等宽。",
    "Remove any styles from the selected text" : "清除所选内容的任何样式",
    "Makes the current line a list element" : "将当前的行变成列表元素",
    "Makes the current line a list element with a number" : "将当前的行变成带有数字的列表元素",
    "Toggle heading for current line" : "切换当前行的标题",
    "Set the current line as a big heading" : "将当前行设置为大标题",
    "Insert link" : "插入链接",
    "Insert image" : "插入图片",
    "Switch between editor and viewer" : "在编辑器和检查器间切换",
    "Pick a notes folder" : "选择一个笔记文件夹",
    "Set notes folder" : "设置笔记文件夹",
    "General" : "常规",
    "Display" : "显示",
    "File extension" : "文件扩展名",
    "For new notes" : "对于新笔记",
    "Custom file extension" : "自定义文件扩展名",
    "Files" : "文件",
    "Notes folder" : "笔记文件夹",
    "Mobile apps" : "移动应用",
    "Shortcuts" : "快捷鍵",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["删除类别“{category}”及其 {count} 个笔记？"],
    "Delete category" : "删除类别",
    "Delete" : "删除",
    "Cancel" : "取消",
    "All notes" : "所有笔记",
    "Categories" : "分类",
    "Rename category" : "重命名类别",
    "Create a sample note with Markdown" : "使用 Markdown 创建示例笔记",
    "No notes yet" : "还没有笔记",
    "Select an image" : "选择一张图片",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "您无法选择在您的笔记文件夹之外的图片。您的笔记文件夹为：{folder}",
    "Wrong image" : "错误的图片",
    "The file was not uploaded. Check your server logs." : "文件未上传。请检查您的服务器日志。",
    "Upload image" : "上传图片",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone 和 iPad",
    "Rich text editor" : "富文本编辑器",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "您现在可以切换到易于使用且无干扰的富文本编辑器。它允许您在编辑笔记时不用看见任何 Markdown 标记。",
    "This option can also be changed later on in the Notes app settings." : "稍后也可以在笔记应用程序中修改此选项。",
    "Keep plain Markdown editor" : "保留普通的 Markdown 编辑器",
    "Use rich editor" : "使用富文本编辑器",
    "Remove from favorites" : "从收藏夹移除",
    "Add to favorites" : "添加到收藏夹",
    "Error while renaming note." : "重命名笔记时出错。",
    "Error during preparing note for deletion." : "准备删除笔记时出错。",
    "Share" : "分享",
    "Change category" : "更改类别",
    "Rename" : "重命名",
    "Rename note" : "重命名笔记",
    "Delete note" : "删除笔记",
    "Error from Nextcloud server: {msg}" : "来自 Nextcloud 服务器的错误：{msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "笔记已在另一会话中被更改。请选择要保存的版本。",
    "Use version from server" : "使用服务器版本",
    "Use current version" : "使用当前版本",
    "Empty note" : "空笔记",
    "Write …" : "编写 ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "编辑",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Note is read-only. You cannot change it." : "笔记是只读的。您无法对其进行更改。",
    "Save failed. Click to retry." : "保存失败。点击以重试。",
    "Update conflict. Click for resolving manually." : "更新冲突。点击手动解决",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "This week" : "本周",
    "Last week" : "上周",
    "This month" : "本月",
    "Last month" : "上月",
    "Search for notes" : "搜索笔记",
    "Loading …" : "正在加载…",
    "Find in all categories" : "在所有分类中寻找",
    "Write down your thoughts without any distractions." : "心无旁骛地写下您的想法。",
    "Use Markdown markups to style your text." : "使用 Markdown 标注来格式化您的文本。",
    "Organize your notes in categories." : "按类别组织您的笔记。",
    "Start writing a note by clicking on “{newnote}”." : "点击“{newnote}”开始写笔记。",
    "Note not found." : "未找到笔记",
    "Note is locked." : "笔记已锁定。",
    "Insufficient storage." : "存储空间不足。",
    "See JavaScript console and server log for details." : "有关详情请参见 JavaScript 控制台和服务器日志。",
    "Updating settings has failed." : "更新设置失败。",
    "Fetching notes for dashboard has failed." : "为仪表盘获取笔记失败。",
    "Fetching notes has failed." : "获取笔记失败。",
    "Fetching note {id} has failed." : "获取笔记 {id} 失败。",
    "Refreshing note {id} has failed." : "刷新笔记 {id} 失败。",
    "Renaming note {id} has failed." : "重命名笔记 {id} 失败。",
    "Creating new note has failed." : "创建新笔记失败。",
    "Saving note {id} has failed." : "保存笔记 {id} 失败。",
    "Updating title for note {id} has failed." : "更新笔记 {id} 的标题失败。",
    "Undo delete has failed for note {title}." : "笔记 {title} 的撤消删除失败。",
    "Deleting note {id} has failed." : "删除笔记 {id} 失败。",
    "Toggling favorite for note {id} has failed." : "将笔记{id}设为收藏失败。",
    "Updating the note's category has failed. Is the target directory writable?" : "无法更新存储笔记的文件夹。请检查目标文件夹是否可写。",
    "Updating the category for note {id} has failed." : "更新笔记 {id} 的分类失败。",
    "Renaming category \"{category}\" has failed." : "重命名类别“{category}”失败。",
    "Deleting category \"{category}\" has failed." : "删除类别“{category}”失败。",
    "Uncategorized" : "未分类",
    "Sample note" : "示例笔记",
    "15 January 2021, via Nextcloud Notes" : "2021 年 1 月 15 日，通过 Nextcloud Notes",
    "Me, you, and all our friends!" : "我，您，以及所有我们的朋友！",
    "Tasks" : "任务",
    "Write nice todo lists" : "编写漂亮的待办事项清单",
    "Buy Fries" : "买薯条",
    "Birthdays" : "生日",
    "Jen, in three days!" : "Jen，三天后！",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "审阅步骤",
    "Turn PC off" : "关电脑",
    "Turn PC on" : "打开电脑",
    "Then call IT" : "然后致电IT",
    "Quotes" : "引用",
    "Nextcloud, a safe home for all your data" : "Nextcloud，给您所有数据一个安全的家",
    "Development Mode" : "开发模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "笔记应用似乎是从一个开发来源安装的。请改从官方<a href=\"%1$s\">Nextcloud 应用商店</a>来安装它。如果您想自己笔记应用，请参考<a href=\"%2$s\">开发者指南</a>。"
},
"nplurals=1; plural=0;");
