<?php

/**
 * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
 * SPDX-FileCopyrightText: 2013 Bernhard Posselt <nukeawhale@gmail.com>
 * SPDX-FileCopyrightText: 2013 Jan-Christoph Borchardt http://jancborchardt.net
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

script('notes', 'notes-main');
style('notes', 'notes');
