OC.L10N.register(
    "notes",
    {
    "Notes" : "Ghi chép",
    "Error" : "Lỗi",
    "New note" : "Ghi chú mới",
    "Preview" : "Xem trước",
    "Insert image" : "Chèn ảnh",
    "Files" : "Tệp tin",
    "Delete" : "Delete",
    "Cancel" : "Hủy bỏ",
    "All notes" : "Tất cả ghi chú",
    "Categories" : "Các hạng mục",
    "No notes yet" : "Chưa có ghi chú",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "Share" : "Chia sẻ",
    "Rename" : "Rename",
    "Use current version" : "Sử dụng phiên bản hiện tại",
    "Edit" : "Chỉnh sửa",
    "Today" : "Hôm nay",
    "Yesterday" : "Hôm qua",
    "This week" : "Tuần này",
    "Last week" : "Tuần trước",
    "This month" : "Tháng này",
    "Last month" : "Tháng trước",
    "Loading …" : "Đang tải...",
    "Uncategorized" : "Chưa phân loại",
    "Tasks" : "Nhiệm vụ"
},
"nplurals=1; plural=0;");
