OC.L10N.register(
    "notes",
    {
    "Notes" : "ჩანაწერები",
    "Error" : "შეცდომა",
    "New note" : "ახალი ჩანაწერი",
    "There are unsaved notes. Leaving the page will discard all changes!" : "არსებობს შეუნახავი ჩანაწერები. გვერდის დატოვება ყველა ცვლილებას უარყოფს!",
    "Preview" : "წინასწარი ჩვენება",
    "Files" : "ფაილები",
    "Delete" : "Delete",
    "Cancel" : "უარყოფა",
    "Categories" : "კატეგორიები",
    "No notes yet" : "ჯერ ჩანაწერები არაა",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Share" : "გაზიარება",
    "Rename" : "Rename",
    "Delete note" : "ჩანაწერის გაუქმება",
    "Edit" : "ცვლილება",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "This week" : "ამ კვირაში",
    "This month" : "ამ თვეში",
    "Uncategorized" : "არაკატეგორიზირებული",
    "Tasks" : "დავალებები"
},
"nplurals=2; plural=(n!=1);");
