OC.L10N.register(
    "notes",
    {
    "Notes" : "ノート",
    "Create new note" : "新しいノートを作成",
    "More notes" : "その他のノート",
    "Reading notes from filesystem has failed." : "ファイルシステムからのノートの読み込みに失敗しました。",
    "Error" : "エラー",
    "New note" : "新しいノート",
    "Distraction-free notes and writing" : "集中モードのノートと執筆",
    "Deleted {title}" : "{title}を削除しました",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number}つのノートを削除しました"],
    "Undo Delete" : "削除取り消し",
    "Note recovered" : "ノートが復元されました",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number}のノートを復元しました"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
    "Notes settings" : "ノート設定",
    "Please see Nextcloud server log for details." : "詳細はNextcloudサーバーログを確認してください。",
    "Preview" : "プレビュー",
    "Make the selection bold" : "選択範囲を太字にする",
    "Make the selection italic" : "選択範囲を斜体にする",
    "Wrap the selection in quotes" : "選択範囲を引用符で囲む",
    "The selection will be turned into monospace" : "選択範囲を等幅フォントにする ",
    "Remove any styles from the selected text" : "選択テキストからスタイルを削除する",
    "Makes the current line a list element" : "現在の行を箇条書きにする",
    "Makes the current line a list element with a number" : "現在の行を番号付き箇条書きにする",
    "Toggle heading for current line" : "現在の行の見出しを切り替える",
    "Set the current line as a big heading" : "現在の行を大見出しにする",
    "Insert link" : "リンクを挿入",
    "Insert image" : "画像の挿入",
    "Switch between editor and viewer" : "エディターとビューアーを切り替える",
    "Pick a notes folder" : "メモフォルダーを選択する",
    "Set notes folder" : "メモフォルダーを設定する",
    "Display" : "表示",
    "File extension" : "ファイル拡張子",
    "Mobile apps" : "モバイルアプリ",
    "Shortcuts" : "キーボードショートカット",
    "Delete" : "Delete",
    "All notes" : "すべてのノート",
    "Categories" : "カテゴリ",
    "Create a sample note with Markdown" : "Markdownでサンプルノートを作成する",
    "No notes yet" : "まだノートはありません",
    "Select an image" : "画像を選択",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "ノートのフォルダー外に存在する画像は選択できません。対象ノートのフォルダー: {folder}",
    "Wrong image" : "使用できない画像",
    "The file was not uploaded. Check your server logs." : "ファイルがアップロードされていません。サーバーログをご確認ください。",
    "Upload image" : "画像をアップロード",
    "Rich text editor" : "リッチテキストエディター",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "使いやすく、邪魔にならないリッチテキストエディタに切り替えることができます。Markdownマークが表示されることなくノートを編集できます。",
    "This option can also be changed later on in the Notes app settings." : "このオプションは、後からノートアプリの設定で変更することもできます。",
    "Keep plain Markdown editor" : "プレーンなMarkdownエディタを維持する",
    "Use rich editor" : "リッチテキストエディターを使用する",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Error while renaming note." : "ノートの名前変更中にエラーが発生しました。",
    "Error during preparing note for deletion." : "ノートの削除準備中にエラーが発生しました。",
    "Share" : "Share",
    "Change category" : "カテゴリの変更",
    "Rename" : "Rename",
    "Rename note" : "ノートの名前を変更",
    "Delete note" : "ノートを削除",
    "Error from Nextcloud server: {msg}" : "Nextcloudサーバーエラー: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "ノートは他のセッションで変更されました。どのバージョンを保存するか選んでください。",
    "Use version from server" : "サーバーからの版を使用する",
    "Use current version" : "現在の版を使用する",
    "Empty note" : "空白のノート",
    "Write …" : "書き込み …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "編集",
    "Exit full screen" : "全画面を終了",
    "Full screen" : "全画面",
    "Note is read-only. You cannot change it." : "ノートは読み込み専用です。変更はできません。",
    "Save failed. Click to retry." : "保存失敗, クリックで再試行",
    "Update conflict. Click for resolving manually." : "更新が衝突しました。手動で解決するためにクリック。",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "This week" : "今週",
    "Last week" : "先週",
    "This month" : "今月",
    "Last month" : "先月",
    "Search for notes" : "メモを検索",
    "Loading …" : "読み込み中...",
    "Find in all categories" : "すべてのカテゴリーで探す",
    "Write down your thoughts without any distractions." : "気を散らすことなくあなたの考えを書き留めてください。",
    "Use Markdown markups to style your text." : "マークダウン・マークアップを使用してテキストを整えます",
    "Organize your notes in categories." : "ノートをカテゴリ別に整理します",
    "Note not found." : "ノートが見つかりません。",
    "Note is locked." : "ノートがロックされています。",
    "Insufficient storage." : "容量が不足しています。",
    "See JavaScript console and server log for details." : "詳細については、JavaScriptコンソールとサーバーログを参照してください。",
    "Updating settings has failed." : "設定を更新できませんでした。",
    "Fetching notes for dashboard has failed." : "ダッシュボードでノートを読み込めませんでした。",
    "Fetching notes has failed." : "ノートを取得できませんでした。",
    "Fetching note {id} has failed." : "ノート {id} を取得できませんでした。",
    "Refreshing note {id} has failed." : "ノート {id} を再読み込みできませんでした。",
    "Renaming note {id} has failed." : "ノート {id} をリネームできませんでした。",
    "Creating new note has failed." : "新しいノートを作成できませんでした。",
    "Saving note {id} has failed." : "ノート {id} の保存に失敗しました。",
    "Updating title for note {id} has failed." : "ノート {id} を更新できませんでした。",
    "Undo delete has failed for note {title}." : "ノート {title}の削除取り消しに失敗しました。",
    "Deleting note {id} has failed." : "ノート {id} を削除できませんでした。",
    "Toggling favorite for note {id} has failed." : "お気に入りノート {id} を切り替えできませんでした。",
    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？",
    "Updating the category for note {id} has failed." : "ノート{id}のカテゴリを更新できませんでした。",
    "Uncategorized" : "未分類",
    "Sample note" : "サンプルノート",
    "15 January 2021, via Nextcloud Notes" : "2021年1月15日、Nextcloudノートから",
    "Me, you, and all our friends!" : "私も、あなたも、そして私たちの友人もみんな！",
    "Tasks" : "タスク",
    "Write nice todo lists" : "素敵なToDoリストを書く",
    "Buy Fries" : "フライドポテトを買う",
    "Birthdays" : "誕生日",
    "Jen, in three days!" : "ジェン、あと3日！",
    "Moss, 21.03.1973" : "モス、1973年3月21日",
    "Roy, 1979" : "ロイ、1979年",
    "Review Steps" : "手順を確認する",
    "Turn PC off" : "パソコンの電源を切る",
    "Turn PC on" : "パソコンの電源を入れる",
    "Then call IT" : "それからIT部門に連絡する",
    "Quotes" : "引用",
    "Nextcloud, a safe home for all your data" : "Nextcloud, すべてのデータを安全に保管します",
    "Development Mode" : "開発モード",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "ノートアプリが開発ソースからインストールされたようです。公式の <a href=\"%1$s\">Nextcloud App Store</a> からインストールしてください。Notesアプリを自分で作成する場合は、 <a href=\"%2$s\">開発者の指示</a>に従ってください。"
},
"nplurals=1; plural=0;");
