OC.L10N.register(
    "notes",
    {
    "Notes" : "Muistiinpanot",
    "Create new note" : "Luo uusi muistiinpano",
    "More notes" : "Lisää muistiinpanoja",
    "Reading notes from filesystem has failed." : "Muistiinpanojen lukeminen tiedostojärjestelmästä epäonnistui.",
    "Error" : "Virhe",
    "New note" : "Uusi muistiinpano",
    "Distraction-free notes and writing" : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
    "Deleted {title}" : "Poistettu {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Poistettu {number} muistiinpano","Poistettu {number} muistiinpanoa"],
    "Undo Delete" : "Kumoa",
    "Note recovered" : "Muistiinpano palautettu",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Palautettu {number} muistiinpano","Palautettu {number} muistiinpanoa"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
    "Notes settings" : "Asetukset",
    "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
    "Preview" : "Esikatselu",
    "Make the selection bold" : "Lihavoi valinta",
    "Make the selection italic" : "Kursivoi valinta",
    "Wrap the selection in quotes" : "Aseta valinta lainausmerkkeihin",
    "The selection will be turned into monospace" : "Valinta muutetaan monospaceksi",
    "Remove any styles from the selected text" : "Poista kaikki tyylit valitusta tekstistä",
    "Makes the current line a list element" : "Tee nykyisestä rivistä listaelementti",
    "Makes the current line a list element with a number" : "Tee nykyisestä rivistä numeroitu listaelementti",
    "Toggle heading for current line" : "Vaihda rivin otsikkoasetusta",
    "Set the current line as a big heading" : "Tee nykyisestä rivistä suuri otsikko",
    "Insert link" : "Lisää linkki",
    "Insert image" : "Lisää kuva",
    "Switch between editor and viewer" : "Vaihda muokkaus- ja katselutilan välllä",
    "General" : "Yleiset",
    "Display" : "Näyttötapa",
    "File extension" : "Tiedostopääte",
    "For new notes" : "Uusille muistiinpanoille",
    "Mobile apps" : "Mobiilisovellukset",
    "Shortcuts" : "Pikanäppäimet",
    "Delete" : "Delete",
    "Cancel" : "Kumoa",
    "All notes" : "Kaikki muistiinpanot",
    "Categories" : "Luokat",
    "No notes yet" : "Ei muistiinpanoja",
    "Select an image" : "Valitse kuva",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Et voi valita kuvia muistiinpanohakemiston ulkopuolelta. Muistiinpanojesi hakemisto: {folder}",
    "Wrong image" : "Väärä kuva",
    "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
    "Upload image" : "Lataa kuva",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone ja iPad",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "Error while renaming note." : "Virhe muuttaessa muistiinpanon nimeä.",
    "Error during preparing note for deletion." : "Virhe valmisteltaessa muistiinpanon poistamista.",
    "Share" : "Share",
    "Change category" : "Vaihda luokkaa",
    "Rename" : "Rename",
    "Rename note" : "Nimeä muistiinpano uudelleen",
    "Delete note" : "Poista muistiinpano",
    "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Muistiinpanoa on muutettu toisessa sessiossa. Valitse, kumpi versio tallennetaan.",
    "Use version from server" : "Käytä versiota palvelimelta",
    "Use current version" : "Käytä nykyistä versiota",
    "Empty note" : "Tyhjä muistiinpano",
    "Write …" : "Kirjoita…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Muokkaa",
    "Exit full screen" : "Poistu koko näytön tilasta",
    "Full screen" : "Koko näytön tila",
    "Note is read-only. You cannot change it." : "Muistiinpano on kirjoitussuojattu. Et voi tehdä siihen muutoksia.",
    "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
    "Update conflict. Click for resolving manually." : "Konflikti päivityksessä. Klikkaa ratkaistaksesi se manuaalisesti.",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "This week" : "Tällä viikolla",
    "Last week" : "Viime viikolla",
    "This month" : "Tässä kuussa",
    "Last month" : "Viime kuussa",
    "Search for notes" : "Etsi muistiinpanoja",
    "Loading …" : "Ladataan…",
    "Find in all categories" : "Etsi kaikista luokista",
    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
    "Note not found." : "Muistiinpanoa ei löytynyt.",
    "Note is locked." : "Muistiinpano on lukittu.",
    "Insufficient storage." : "Tallennustila ei riitä.",
    "See JavaScript console and server log for details." : "Katso yksityiskohdat JavaScript-konsolista ja palvelimen lokista.",
    "Updating settings has failed." : "Asetusten päivittäminen epäonnistui.",
    "Fetching notes for dashboard has failed." : "Muistiinpanojen noutaminen ohjausnäkymään epäonnistui.",
    "Fetching notes has failed." : "Muistiinpanojen noutaminen epäonnistui.",
    "Fetching note {id} has failed." : "Muistiinpanon {id} noutaminen epäonnistui.",
    "Refreshing note {id} has failed." : "Muistiinpanon {id} uudelleenlataaminen epäonnistui.",
    "Renaming note {id} has failed." : "Muistiinpanon {id} nimeäminen uudelleen epäonnistui.",
    "Creating new note has failed." : "Uuden muistiinpanon luominen epäonnistui.",
    "Saving note {id} has failed." : "Muistiinpanon {id} tallentaminen on epäonnistunut.",
    "Updating title for note {id} has failed." : "Muistiinpanon {id} otsikon vaihtaminen on epäonnistunut.",
    "Undo delete has failed for note {title}." : "Poistamisen kumoaminen epäonnistui muistiinpanolle {title}.",
    "Deleting note {id} has failed." : "Muistiinpanon {id} poistaminen epäonnistui.",
    "Toggling favorite for note {id} has failed." : "Suosikkiasetuksen muuttaminen muistiinpanolle {id} epäonnistui.",
    "Updating the note's category has failed. Is the target directory writable?" : "Muistiinpanon kategorian vaihtaminen epäonnistui. Onko kohdehakemistoon kirjoitusoikeuksia?",
    "Updating the category for note {id} has failed." : "Muistiinpanon {id} kategorian vaihtaminen on epäonnistunut.",
    "Uncategorized" : "Luokittelematon",
    "Sample note" : "Esimerkkimuistiinpano",
    "15 January 2021, via Nextcloud Notes" : "15. Tammikuuta 2021, Nextcloud Muistiinpanot",
    "Me, you, and all our friends!" : "Minä, sinä ja kaikki ystävämme!",
    "Tasks" : "Tehtävät",
    "Write nice todo lists" : "Kirjoita kivoja todo-listoja",
    "Buy Fries" : "Osta ranskalaisia perunoita",
    "Birthdays" : "Syntymäpäivät",
    "Jen, in three days!" : "Jenni, kolmen päivän päästä!",
    "Moss, 21.03.1973" : "Matti, 21.03.1973",
    "Roy, 1979" : "Roni, 1979",
    "Review Steps" : "Tarkistuksen vaiheet",
    "Turn PC off" : "Sammuta tietokone",
    "Turn PC on" : "Käynnistä tietokone",
    "Then call IT" : "Soita sitten IT-tukeen",
    "Quotes" : "Lainaukset",
    "Nextcloud, a safe home for all your data" : "Nextcloud on turvallinen koti kaikille tiedoillesi",
    "Development Mode" : "Kehitystila",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Näyttää siltä, että muistiinpanosovellus on asennettu sovelluskehittäjien lähteestä. Asenna se virallisesta <a href=\"%1$s\">Nextcloud App Storesta</a> . Jos haluat rakentaa sovelluksen itse lähdekoodista, lue  <a href=\"%2$s\">sovelluskehittäjän ohjeet</a>."
},
"nplurals=2; plural=(n != 1);");
