OC.L10N.register(
    "notes",
    {
    "Notes" : "Märkmed",
    "Create new note" : "Koosta uus märge",
    "More notes" : "Veel märkmeid",
    "Reading notes from filesystem has failed." : "Märkmete lugemine failisüsteemist ei õnnestunud.",
    "Error" : "Viga",
    "New note" : "Uus märge",
    "Distraction-free notes and writing" : "Müravabad märkmed ja kirjutamine.",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Märkmete rakendus on lihtne ja müravaba viis koostada ja hallata märkmeid [Nextcloudis](https://www.nextcloud.com/). Haldamiseks on olemas kategooriad ning kujundamiseks [Markdown-vormingu](https://en.wikipedia.org/wiki/Markdown) tugi ja loomulikult saad märkmeid ka lemmikuks märkida. Märkmed ise salvestuvad failidena sinu Nextcloudi serveris ja sa saad neid vaadata ja muuta ka teiste Nextcloudi klientidega. Lisaks on olemas eraldi [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md), mis võimaldab lõimingut meie omade nutirakendustega ([Androidi](https://github.com/nextcloud/notes-android) ja [iOS-i](https://github.com/nextcloud/notes-ios) jaoks, aga ka [kolmandate osapoolte rakendustega](https://github.com/nextcloud/notes/wiki#3rd-party-clients) - kõikidel juhtudel on mugav ligipääs sinu Nextcloudi märkmetele tagatud).",
    "Deleted {title}" : "Kustutasin „{title}“ märkme",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Kustutasin {number} märke","Kustutasin {number} märget"],
    "Undo Delete" : "Võta kustutamine tagasi",
    "Note recovered" : "Märge on taastatud",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Taastasin {number} märke","Taastasin {number} märget"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Leidub salvestamata märkmeid. Lehelt lahkudes lähevad kõik muudatused kaotsi!",
    "Notes settings" : "Märkmete seadistused",
    "Please see Nextcloud server log for details." : "Palun vaata üksikasju Nextcloudi serveri logifailidest.",
    "Custom" : "Kohandatud",
    "Rich text" : "Vormindatud tekst",
    "Plain text" : "Vormindamata tekst",
    "Preview" : "Eelvaade",
    "Make the selection bold" : "Muuda valiku tekst paksuks",
    "Make the selection italic" : "Muuda valiku tekst kaldkirjast",
    "Wrap the selection in quotes" : "Muuda valik tsitaadiks",
    "The selection will be turned into monospace" : "Kasuta valiku puhul püsisammuga kirjatüüpi",
    "Remove any styles from the selected text" : "Eemalda valitud tekstist kogu kujundus",
    "Makes the current line a list element" : "Muudab selle valiku nummerdamata loendi elemendiks",
    "Makes the current line a list element with a number" : "Muudab selle valiku nummerdatud loendi elemendiks",
    "Toggle heading for current line" : "Muuda see rida pealkirjaks või eemalda sealt pealkiri",
    "Set the current line as a big heading" : "Muuda see valik suureks pealkirjaks",
    "Insert link" : "Lisa link",
    "Insert image" : "Lisa pilt",
    "Switch between editor and viewer" : "Lülita muutmisvaate ja tavavaate vahel",
    "Pick a notes folder" : "Vali kaust märkmete jaoks",
    "Set notes folder" : "Määra kaust märkmete jaoks",
    "General" : "Üldine",
    "Display" : "Vaade",
    "File extension" : "Faililaiend",
    "For new notes" : "Uute märkmete jaoks",
    "Custom file extension" : "Sinu määratud faililaiend",
    "Files" : "Failid",
    "Notes folder" : "Märkmete kaust",
    "Mobile apps" : "Nutirakendused",
    "Shortcuts" : "Kiirklahvid",
    "Delete" : "Kustuta",
    "Cancel" : "Katkesta",
    "All notes" : "Kõik märkmed",
    "Categories" : "Kategooriad",
    "Create a sample note with Markdown" : "Koosta Markdown-vormingus märkmete näide",
    "No notes yet" : "Märkmeid veel pole",
    "Select an image" : "Vali  pilt",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Sa ei saa valida pilte väljastpoolt oma märkmete kausta, milleks on: {folder}",
    "Wrong image" : "vale pilt",
    "The file was not uploaded. Check your server logs." : "Fail jäi üles laadimata. Lisateavet leiad serveri logidest.",
    "Upload image" : "Laadi pilt üles",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone ja iPad",
    "Rich text editor" : "Vormingusuutlik kirjutusvaade",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Nüüd saad sa kasutada lihtsat vormingusuutlikku kirjutusvaadet, kus sa ei pea arvestama Markdowni süntaksiga.",
    "This option can also be changed later on in the Notes app settings." : "Seda eelistust saad Märkmete rakenduse seadistustest ka hiljem muuta.",
    "Keep plain Markdown editor" : "Jäta alles tavaline Markdownipõhine kirjutusvaade",
    "Use rich editor" : "Kasuta vormingusuutlikku kirjutusvaadet",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikuks",
    "Error while renaming note." : "Viga märke nime muutmisel.",
    "Error during preparing note for deletion." : "Viga märkme kustutamiseks ettevalmistamisel.",
    "Share" : "Jaga",
    "Change category" : "Muuda kategooriat",
    "Rename" : "Muuda nime",
    "Rename note" : "Muuda märke nime",
    "Delete note" : "Kustuta märge",
    "Error from Nextcloud server: {msg}" : "Nextcloudi serveri viga: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Seda märget on muudetud muus sessioonis. Palun vali, kumma versiooni tahaksid salvestada.",
    "Use version from server" : "Kasuta serveri versiooni",
    "Use current version" : "Kasuta praegust versiooni",
    "Empty note" : "Tühi märge",
    "Write …" : "Kirjuta…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Muuda",
    "Exit full screen" : "Välju täisekraanivaatest",
    "Full screen" : "Täisekraanivaade",
    "Note is read-only. You cannot change it." : "See märge on vaid lugemiseks. Sa ei saa teda muuta.",
    "Save failed. Click to retry." : "Salvestamine ei õnnestunud. Klõpsa uuesti proovimiseks.",
    "Update conflict. Click for resolving manually." : "Sisukonflikt andmete uuendamisel. Palun lahenda see käsitsi.",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "This week" : "Sel nädalal",
    "Last week" : "Eelmisel nädalal",
    "This month" : "Sel kuul",
    "Last month" : "Eelmisel kuul",
    "Search for notes" : "Otsi märkmeid",
    "Loading …" : "Laadimisel...",
    "Find in all categories" : "Otsi kõikidest kategooriatest",
    "Write down your thoughts without any distractions." : "Kirjuta oma mõtted üles nii, et miski ei sega.",
    "Use Markdown markups to style your text." : "Teksti  kujundamiseks kasuta Markdown-vormingut.",
    "Organize your notes in categories." : "Halda oma märkmeid kategooriate kaupa.",
    "Note not found." : "Märget ei leidu.",
    "Note is locked." : "Märge on lukus.",
    "Insufficient storage." : "Pol piisavalt andmeruumi.",
    "See JavaScript console and server log for details." : "Lisateavet leiad veebibrauseri JavaScripti konsoolilt ja serveri logidest.",
    "Updating settings has failed." : "Seadistuste uuendamine ei õnnestunud.",
    "Fetching notes for dashboard has failed." : "Ei õnnestunud laadida märkmeid juhtpaneelil kuvamiseks.",
    "Fetching notes has failed." : "Märkmete laadimine ei õnnestunud.",
    "Fetching note {id} has failed." : "„{id}“ märkme laadimine ei õnnestunud.",
    "Refreshing note {id} has failed." : "„{id}“ märkme värskendamine ei õnnestunud.",
    "Renaming note {id} has failed." : "„{id}“ märkme nime muutmine ei õnnestunud.",
    "Creating new note has failed." : "Märkme koostamine ei õnnestunud.",
    "Saving note {id} has failed." : "„{id}“ märkme salvestamine ei õnnestunud.",
    "Updating title for note {id} has failed." : "„{id}“ märkme pealkirja muutmine ei õnnestunud.",
    "Undo delete has failed for note {title}." : "„{title}“ märkme kustutamise tagasivõtmine ei õnnestunud.",
    "Deleting note {id} has failed." : "„{id}“ märkme kustutamine ei õnnestunud.",
    "Toggling favorite for note {id} has failed." : "„{id}“ märkme puhul ei õnnestunud olekut lemmikuna sisse või välja lülitada.",
    "Updating the note's category has failed. Is the target directory writable?" : "Märkme kategooria uuendamine ei õnnestunud. Kas kaust kindlasti on kirjutatav?",
    "Updating the category for note {id} has failed." : "„{id}“ märkme kategooria uuendamine ei õnnestunud.",
    "Uncategorized" : "Kategooria on märkimata",
    "Sample note" : "Näidismärge",
    "15 January 2021, via Nextcloud Notes" : "15. jaanuaril 2021, Nextcloudi Märkmetest",
    "Me, you, and all our friends!" : "Mina, sina ja kõik meie sõbrad!",
    "Tasks" : "Ülesanded",
    "Write nice todo lists" : "Koosta toredaid ülesannete loendeid",
    "Buy Fries" : "Osta friikartuleid",
    "Birthdays" : "Sünnipäevad",
    "Jen, in three days!" : "Kadri, juba kolme päeva pärast",
    "Moss, 21.03.1973" : "Mati, 21.03.1973",
    "Roy, 1979" : "Peeter, 1979",
    "Review Steps" : "Tegevused ülevaatamiseks",
    "Turn PC off" : "Lülita arvuti välja",
    "Turn PC on" : "Lülita arvuti sisse",
    "Then call IT" : "Siis helista it-toele",
    "Quotes" : "Tsitaadid",
    "Nextcloud, a safe home for all your data" : "Nextcloud - turvaline koht sinu andmetele",
    "Development Mode" : "Arendusrežiim",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Tundub, et see märkmete rakendus on paigaldatud arenduseks mõeldud lähtekoodiharust. Selle asemel palun paigalda ta <a href=\"%1$s\">Nextcloudi ametlikust rakendustepoest</a>. Kui tahad Märkmete rakendust ise kompileerida, siis palun järgi <a href=\"%2$s\">juhendit arendajatele</a>."
},
"nplurals=2; plural=(n != 1);");
