OC.L10N.register(
    "notes",
    {
    "Notes" : "Qeydlər",
    "Error" : "Səhv",
    "New note" : "Yeni qeyd",
    "Files" : "Fayllar",
    "Delete" : "Delete",
    "Cancel" : "Dayandır",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Paylaş",
    "Rename" : "Rename",
    "Delete note" : "Qeydi sil",
    "Edit" : "Dəyişiklik et",
    "Today" : "Bu gün",
    "Yesterday" : "Dünən",
    "Tasks" : "Tapşırıqlar"
},
"nplurals=2; plural=(n != 1);");
