OC.L10N.register(
    "notes",
    {
    "Notes" : "Minnispunktar",
    "Create new note" : "Búa til nýjan minnispunkt",
    "More notes" : "Fleiri minnispunktar",
    "Reading notes from filesystem has failed." : "Tókst ekki að lesa minnispunkta úr skráakerfi.",
    "Error" : "Villa",
    "New note" : "Nýr minnispunktur",
    "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notes-minnispunktaforritið er til þess að geta tekið niður minnispunkta í [Nextcloud](https://www.nextcloud.com/) án mikilla truflana. Það býður upp á flokka til að eiga betur við skipulagningu og sniðinn texta með hjálp [Markdown](https://en.wikipedia.org/wiki/Markdown) málskipunar. Minnispunktar eru vistaðir sem skrár á Nextcloud-svæðinu þínu, þannig að þú getir skoðað þá og breytt með hvaða Nextcloud-forriti sem er. Að auki býður sérstakt [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md)-kerfisviðmót upp á einfalda samþættingu við ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) og fyrir [utanaðkomandi forrit](https://github.com/nextcloud/notes/wiki#3rd-party-clients) sem gefa kost á þægilegum aðgangi að Nextcloud-minnispunktunum þínum). Eins má nefna að hægt er að merkja minnispunkta sem eftirlæti.",
    "Deleted {title}" : "Eyddi {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Eyddi {number} minnispunkti","Eyddi {number} minnispunktum"],
    "Undo Delete" : "Afturkalla eyðingu",
    "Note recovered" : "Endurheimti minnispunkt",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Endurheimti {number} minnispunkt","Endurheimti {number} minnispunkta"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
    "Notes settings" : "Stillingar minnispunkta",
    "Please see Nextcloud server log for details." : "Skoðaðu atvikaskrár Nextcloud-netþjónsins til að sjá nánari upplýsingar.",
    "Plain text" : "Ósniðinn texti",
    "Preview" : "Forskoðun",
    "Make the selection bold" : "Gera valið feitletrað",
    "Make the selection italic" : "Gera valið skáletrað",
    "Wrap the selection in quotes" : "Setja valið inn í gæsalappir",
    "The selection will be turned into monospace" : "Völdum texta verður breytt í jafnbreitt letur",
    "Remove any styles from the selected text" : "Fjarlægja alla stíla úr valda textanum",
    "Makes the current line a list element" : "Gerir núverandi línu að listaeinindi",
    "Makes the current line a list element with a number" : "Gerir núverandi línu að númeruðu listaeinindi",
    "Toggle heading for current line" : "Víxla fyrirsögn af/á í fyrirliggjandi línu ",
    "Set the current line as a big heading" : "Setja núverandi línu sem stóra fyrirsögn",
    "Insert link" : "Setja inn tengil",
    "Insert image" : "Setja inn mynd",
    "Switch between editor and viewer" : "Skipta á milli ritils og skoðara",
    "Pick a notes folder" : "Veldu möppu undir minnispunkta",
    "Set notes folder" : "Stilla möppu undir minnispunkta",
    "Display" : "Skjár",
    "File extension" : "Skráarending",
    "Files" : "Skrár",
    "Notes folder" : "Mappa undir minnispunkta",
    "Mobile apps" : "Snjallsímaforrit",
    "Shortcuts" : "Flýtilyklar",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "All notes" : "Allir minnispunktar",
    "Categories" : "Flokkar",
    "Create a sample note with Markdown" : "Útbúðu dæmi um minnispunkt með Markdown",
    "No notes yet" : "Engir minnispunktar ennþá",
    "Select an image" : "Veldu mynd",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Þú getur ekki valið myndir utan minnispunktamöppunnar þinnar. Minnispunktamappan þin er: {folder}",
    "Wrong image" : "Röng mynd",
    "The file was not uploaded. Check your server logs." : "Skráin var ekki send inn. Skoðaðu atvikaskrár netþjónsins.",
    "Upload image" : "Senda inn mynd",
    "Rich text editor" : "Þróaður textaritill",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Þú getur núna skipt yfir í einfalda og truflanalausa ritilinn fyrir sniðinn texta. Hann gerir þér kleift að breyta minnispunktum án þess að þú sjáir neinn Markdown-kóða.",
    "This option can also be changed later on in the Notes app settings." : "Þessum valkosti er hægt að breyta í kjörstillingum Notes-forritsins.",
    "Keep plain Markdown editor" : "Halda einfalda Markdown-ritlinum",
    "Use rich editor" : "Nota þróaðan textaritil",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "Error while renaming note." : "Villa við að endurnefna minnispunkt.",
    "Error during preparing note for deletion." : "Villa við að undirbúa eyðingu á minnispunkti.",
    "Share" : "Deila",
    "Change category" : "Breyta flokki",
    "Rename" : "Endurnefna",
    "Rename note" : "Endurnefna minnispunkt",
    "Delete note" : "Eyða minnispunkti",
    "Error from Nextcloud server: {msg}" : "Villa frá Nextcloud-þjóni: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Minnispunktinum var breytt í annarri lotu. Veldu hvaða útgáfu ætti að vista.",
    "Use version from server" : "Nota útgáfu frá þjóni",
    "Use current version" : "Nota fyrirliggjandi útgáfu",
    "Empty note" : "Tómur minnispunktur",
    "Write …" : "Skrifa …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Breyta",
    "Exit full screen" : "Fara úr skjáfylliham",
    "Full screen" : "Skjáfylli",
    "Note is read-only. You cannot change it." : "Minnispunktur er skrifvarinn. Þú getur ekki breytt honum.",
    "Save failed. Click to retry." : "Vistun mistókst. Smelltu til að reyna aftur.",
    "Update conflict. Click for resolving manually." : "Árekstur við uppfærslu. Smelltu til að leysa þetta handvirkt.",
    "Today" : "Í dag",
    "Yesterday" : "Yesterday",
    "This week" : "Í þessari viku",
    "Last week" : "Í síðustu viku",
    "This month" : "Í þessum mánuði",
    "Last month" : "Í síðasta mánuði",
    "Search for notes" : "Leita að minnispunktum",
    "Loading …" : "Hleð inn …",
    "Find in all categories" : "Finna í öllum flokkum",
    "Write down your thoughts without any distractions." : "Skrifaðu niður hugmyndir þínar án truflana.",
    "Use Markdown markups to style your text." : "Notaðu Markdown-einindi til að setja stíl á textann þinn.",
    "Organize your notes in categories." : "Skipulegðu minnispunktana þína í flokka",
    "Note not found." : "Minnispunktur fannst ekki.",
    "Note is locked." : "Minnispunktur er læstur.",
    "Insufficient storage." : "Ónógt geymslupláss.",
    "See JavaScript console and server log for details." : "Skoðaðu JavaScript-stjórnskjáinn og atvikaskrár netþjónsins til að sjá nánari upplýsingar.",
    "Updating settings has failed." : "Uppfærsla stillinga mistókst.",
    "Fetching notes for dashboard has failed." : "Mistókst að ná í minnispunkta fyrir stjórnborðið.",
    "Fetching notes has failed." : "Mistókst að ná í minnispunkta.",
    "Fetching note {id} has failed." : "Mistókst að ná í minnispunktinn {id}.",
    "Refreshing note {id} has failed." : "Mistókst að endurlesa minnispunktinn {id}.",
    "Renaming note {id} has failed." : "Mistókst að endurnefna minnispunktinn {id}.",
    "Creating new note has failed." : "Mistókst að búa til nýjan minnispunkt.",
    "Saving note {id} has failed." : "Mistókst að vista minnispunktinn {id}.",
    "Updating title for note {id} has failed." : "Mistókst að uppfæra titil fyrir minnispunktinn {id}.",
    "Undo delete has failed for note {title}." : "Afturköllun eyðingar mistókst fyrir minnispunktinn {title}.",
    "Deleting note {id} has failed." : "Mistókst að eyða minnispunktinum {id}.",
    "Toggling favorite for note {id} has failed." : "Mistókst að víxla eftirlæti af/á fyrir minnispunktinn {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppfærsla á flokki minnispunkts mistókst. Er móttökumappan skrifanleg?",
    "Updating the category for note {id} has failed." : "Mistókst að uppfæra flokk fyrir minnispunktinn {id}.",
    "Uncategorized" : "Óflokkað",
    "Sample note" : "Sýnishorn minnispunkts",
    "15 January 2021, via Nextcloud Notes" : "15. janúar 2021, í gegnum Nextcloud-minnispunkta",
    "Me, you, and all our friends!" : "Ég, þú og og vinirnir!",
    "Tasks" : "Verkefni",
    "Write nice todo lists" : "Skrifaðu hentuga verkefnalista",
    "Buy Fries" : "Kaupa franskar",
    "Birthdays" : "Afmælisdagar",
    "Jen, in three days!" : "Jóna, eftir þrjá daga!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Reynir, 1979",
    "Review Steps" : "Skref til að yfirfara",
    "Turn PC off" : "Slökktu á tölvunni",
    "Turn PC on" : "Kveiktu á tölvunni",
    "Then call IT" : "Náðu síðan í tæknideildina",
    "Quotes" : "Tilvitnanir",
    "Nextcloud, a safe home for all your data" : "Nextcloud, öruggur staður fyrir öll gögnin þín",
    "Development Mode" : "Þróunarhamur",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Það lítur út fyrir að minnispunktaforritið hafi verið sett upp með þróunarkóða. Settu það frekar upp úr opinberu <a href=\"%1$s\">Nextcloud-forritaversluninni</a>. Ef þú vilt byggja Notes-forritið sjálf/ur frá grunni, skaltu fara eftir <a href=\"%2$s\">leiðbeiningum fyrir forritara</a>."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
