OC.L10N.register(
    "notes",
    {
    "Notes" : "Notlar",
    "Create new note" : "Not ekle",
    "More notes" : "Diğer notlar",
    "Reading notes from filesystem has failed." : "Notlar dosya sisteminden okunamadı.",
    "Error" : "Hata",
    "New note" : "Not ekle",
    "Distraction-free notes and writing" : "Dikkatinizi dağıtmadan notlar alabilirsiniz",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notlar uygulaması [Nextcloud](https://www.nextcloud.com/) için dikkat dağıtmadan not alınabilmesini sağlar. Kategoriler ile daha notları düzenleyebilme ve [Markdown](https://en.wikipedia.org/wiki/Markdown) söz dizimi ile biçimlendirme yapılabilmesini sağlar. Notlar Nextcloud alanınıza dosya olarak kaydedilir böylece her Nextcloud istemcisi tarafından görülüp düzenlenebilir. Ayrıca [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) kullanarak uygulamalar ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) ve Nextcloud notlarına erişebilecek [üçüncü taraf uygulamalar](https://github.com/nextcloud/notes/wiki#3rd-party-clients)) ile kolayca bütünleştirme sağlanabilir. Gelecek sürümlerde notları sık kullanılanlar olarak işaretlemek gibi özellikler sunulacaktır.",
    "Deleted {title}" : "{title} silindi",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} not silindi","{number} not silindi"],
    "Undo Delete" : "Silmeyi geri al",
    "Note recovered" : "Not geri yüklendi",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} not geri yüklendi","{number} not geri yüklendi"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Kaydedilmemiş notlar var. Sayfadan ayrılırsanız tüm değişiklikler silinecek!",
    "Notes settings" : "Notlar ayarları",
    "Please see Nextcloud server log for details." : "Ayrıntılar için Nextcloud sunucu günlüğü kayıtlarına bakın.",
    "Custom" : "Özel",
    "Rich text" : "Zengin yazı",
    "Plain text" : "Düz yazı",
    "Preview" : "Ön izleme",
    "Make the selection bold" : "Seçimi koyu yap",
    "Make the selection italic" : "Seçimi yatık yap",
    "Wrap the selection in quotes" : "Seçimi tırnak içine al",
    "The selection will be turned into monospace" : "Seçim sabit aralıklı yapılacak",
    "Remove any styles from the selected text" : "Seçilmiş yazıdaki tüm biçemleri kaldır",
    "Makes the current line a list element" : "Geçerli satırı bir liste ögesi yapar",
    "Makes the current line a list element with a number" : "Geçerli satırı bir sıralı liste ögesi yapar",
    "Toggle heading for current line" : "Geçerli satırı başlık/normal yap",
    "Set the current line as a big heading" : "Geçerli satırı büyük başlık yapar",
    "Insert link" : "Bağlantı ekle",
    "Insert image" : "Görsel ekle",
    "Switch between editor and viewer" : "Düzenleyici ve görüntüleyici arasında geçiş yapar",
    "Pick a notes folder" : "Notlar klasörünü seçin",
    "Set notes folder" : "Notlar klasörünü ayarla",
    "General" : "Genel",
    "Display" : "Ekran",
    "File extension" : "Dosya uzantısı",
    "For new notes" : "Yeni notlar için",
    "Custom file extension" : "Özel dosya uzantısı",
    "Files" : "Dosyalar",
    "Notes folder" : "Notlar klasörü",
    "Mobile apps" : "Mobil uygulamalar",
    "Shortcuts" : "Kısa yollar",
    "Delete" : "Sil",
    "Cancel" : "Cancel",
    "All notes" : "Tüm notlar",
    "Categories" : "Kategoriler",
    "Create a sample note with Markdown" : "Markdown ile bir örnek not oluştur",
    "No notes yet" : "Henüz bir not yok",
    "Select an image" : "Bir görsel seçin",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Notlar klasörünüzün dışındaki görselleri seçemezsiniz. Notlar klasörünüz: {folder}",
    "Wrong image" : "Yanlış görsel",
    "The file was not uploaded. Check your server logs." : "Dosya yüklenemedi. Sunucu günlüklerine bakın.",
    "Upload image" : "Görsel yükle",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone ve iPad",
    "Rich text editor" : "Zengin yazı düzenleyici",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Artık kullanımı kolay ve dikkat dağıtmayan zengin yazı düzenleyiciyi kullanabilirsiniz. Notları herhangi bir Markdown kod imi görmeden düzenlemenizi sağlar.",
    "This option can also be changed later on in the Notes app settings." : "Bu seçenek daha sonra Notlar uygulaması ayarlarından da değiştirilebilir.",
    "Keep plain Markdown editor" : "Düz Markdown düzenleyici kullanılsın",
    "Use rich editor" : "Zengin yazı düzenleyici kullanılsın",
    "Remove from favorites" : "Sık kullanılanlardan çıkar",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "Error while renaming note." : "Not yeniden adlandırılırken sorun çıktı.",
    "Error during preparing note for deletion." : "Not silinmeye hazırlanırken sorun çıktı.",
    "Share" : "Paylaş",
    "Change category" : "Kategoriyi değiştir",
    "Rename" : "Yeniden adlandır",
    "Rename note" : "Notu yeniden adlandır",
    "Delete note" : "Notu sil",
    "Error from Nextcloud server: {msg}" : "Nextcloud sunucu hatası: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Bu not başka bir oturumdan değiştirilmiş. Lütfen hangi sürümün kaydedilmesi gerektiğini seçin.",
    "Use version from server" : "Sunucudaki sürüm kullanılsın",
    "Use current version" : "Geçerli sürüm kullanılsın",
    "Empty note" : "Not boş",
    "Write …" : "Yazın …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Düzenle",
    "Exit full screen" : "Tam ekrandan çık",
    "Full screen" : "Tam ekran",
    "Note is read-only. You cannot change it." : "Not salt okunur olduğundan değiştiremezsiniz.",
    "Save failed. Click to retry." : "Kaydedilemedi. Yeniden denemek için tıklayın.",
    "Update conflict. Click for resolving manually." : "Güncelleme çakışması. El ile çözümlemek için tıklayın.",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "This week" : "Bu hafta",
    "Last week" : "Geçen hafta",
    "This month" : "Bu ay",
    "Last month" : "Geçen ay",
    "Search for notes" : "Notlarda arama",
    "Loading …" : "Yükleniyor …",
    "Find in all categories" : "Tüm kategorilerde aransın",
    "Write down your thoughts without any distractions." : "Konuyu dağıtmadan düşüncelerinizi yazın.",
    "Use Markdown markups to style your text." : "Yazıyı biçimlendirmek için Markdown kod imlerini kullanın.",
    "Organize your notes in categories." : "Kategorileri kullanarak notlarınızı gruplayabilirsiniz.",
    "Note not found." : "Not bulunamadı.",
    "Note is locked." : "Not kilitlenmiş.",
    "Insufficient storage." : "Depolama alanı yetersiz.",
    "See JavaScript console and server log for details." : "Ayrıntılı bilgi almak için JavaScript konsoluna ve sunucu günlüğü kayıtlarına bakın.",
    "Updating settings has failed." : "Ayarlar güncellenemedi.",
    "Fetching notes for dashboard has failed." : "Notlar panoya alınamadı.",
    "Fetching notes has failed." : "Notlar alınamadı.",
    "Fetching note {id} has failed." : "Not {id} alınamadı.",
    "Refreshing note {id} has failed." : "Not {id} yenilenemedi.",
    "Renaming note {id} has failed." : "{id} notu yeniden adlandırılamadı.",
    "Creating new note has failed." : "Yeni not eklenemedi.",
    "Saving note {id} has failed." : "{id} notu yeniden kaydedilemedi.",
    "Updating title for note {id} has failed." : "Not {id} başlığı güncellenemedi.",
    "Undo delete has failed for note {title}." : "Silinen {title} notu geri alınamadı.",
    "Deleting note {id} has failed." : "Not {id} silinemedi.",
    "Toggling favorite for note {id} has failed." : "Not {id} sık kullanılanlara eklenemedi/çıkarılamadı.",
    "Updating the note's category has failed. Is the target directory writable?" : "Not kategorisi güncellenemedi. Hedef klasör yazılabilir durumda mı?",
    "Updating the category for note {id} has failed." : "Not {id} kategorisi güncellenemedi.",
    "Uncategorized" : "Kategorisiz",
    "Sample note" : "Örnek not",
    "15 January 2021, via Nextcloud Notes" : "15 Ocak 2021, Nextcloud Notlar ile",
    "Me, you, and all our friends!" : "Ben, sen ve tüm arkadaşlarımız!",
    "Tasks" : "Görevler",
    "Write nice todo lists" : "Güzel bir yapılacak işler listesi hazırlayın",
    "Buy Fries" : "Cips al",
    "Birthdays" : "Doğum günleri",
    "Jen, in three days!" : "Papatya, üç gün içinde!",
    "Moss, 21.03.1973" : "Sevil, 21.03.1973",
    "Roy, 1979" : "Ali, 1979",
    "Review Steps" : "Adımları gözden geçir",
    "Turn PC off" : "Bilgisayarı kapat",
    "Turn PC on" : "Bilgisayarı aç",
    "Then call IT" : "Sonra BT bölümünü ara",
    "Quotes" : "Alıntılar",
    "Nextcloud, a safe home for all your data" : "Nextcloud, tüm verileriniz için güvenli bir barınak",
    "Development Mode" : "Geliştirme kipi",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Notlar uygulaması bir geliştirme kaynağından kurulmuş gibi görünüyor. Lütfen uygulamayı resmi <a href=\"%1$s\">Nextcloud Uygulama Mağazasından</a> kurun. Notlar uygulamasını kendiniz derlemek istiyorsanız, <a href=\"%2$s\">geliştirici yönergelerine</a> bakabilirsiniz."
},
"nplurals=2; plural=(n > 1);");
