OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "ایرر",
    "Delete" : "Delete",
    "Cancel" : "منسوخ کریں",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "تقسیم",
    "Rename" : "Rename",
    "Edit" : "تدوین کریں",
    "Today" : "آج",
    "Tasks" : "کام"
},
"nplurals=2; plural=(n != 1);");
