OC.L10N.register(
    "notes",
    {
    "Notes" : "Nótaí",
    "Create new note" : "Cruthaigh nóta nua",
    "More notes" : "Tuilleadh nótaí",
    "Reading notes from filesystem has failed." : "Theip ar léamh nótaí ón gcóras comhad.",
    "Error" : "Earráid",
    "New note" : "Nóta nua",
    "Distraction-free notes and writing" : "Nótaí agus scríobh gan aon seachrán",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Is aip saor ó seachrán é an aip Nótaí do [Nextcloud](https://www.nextcloud.com/). Soláthraíonn sé catagóirí le haghaidh eagrúcháin níos fearr agus tacaíonn sé le formáidiú trí úsáid a bhaint as comhréir [Markdown](https://en.wikipedia.org/wiki/Markdown). Déantar nótaí a shábháil mar chomhaid i do Nextcloud, ionas gur féidir leat iad a fheiceáil agus a chur in eagar le gach cliant Nextcloud. Ina theannta sin, ceadaíonn [REST API] ar leith(https://github.com/nextcloud/notes/blob/master/docs/api/README.md) comhtháthú éasca le haipeanna ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), chomh maith le[3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) a cheadaíonn rochtain áisiúil ar do nótaí Nextcloud). Áirítear ar ghnéithe eile nótaí a mharcáil mar cheanáin.",
    "Deleted {title}" : "Scriosadh {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Scriosadh {uimhir} nóta","Scriosadh {uimhir} nótaí","Scriosadh {uimhir} nótaí","Scriosadh {uimhir} nótaí","Scriosadh {uimhir} nótaí"],
    "Undo Delete" : "Cealaigh Scrios",
    "Note recovered" : "Nóta aisghafa",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Ghnóthaigh {uimhir} nóta","Ghnóthaigh {uimhir} nótaí","Ghnóthaigh {uimhir} nótaí","Ghnóthaigh {uimhir} nótaí","Ghnóthaigh {uimhir} nótaí"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Tá nótaí gan sábháil. Má fhágann tú an leathanach, scriosfar gach athrú!",
    "New category" : "Catagóir nua",
    "Notes settings" : "Socruithe nótaí",
    "Please see Nextcloud server log for details." : "Féach logáil freastalaí Nextcloud le haghaidh sonraí le do thoil.",
    "Custom" : "Saincheaptha",
    "Rich text" : "Téacs saibhir",
    "Plain text" : "Gnáth-théacs",
    "Preview" : "Réamhamharc",
    "Make the selection bold" : "Déan an rogha trom",
    "Make the selection italic" : "Déan an rogha iodálach",
    "Wrap the selection in quotes" : "Wrap an roghnú i Sleachta",
    "The selection will be turned into monospace" : "Déanfar monaspás ar an rogha",
    "Remove any styles from the selected text" : "Bain aon stíleanna as an téacs roghnaithe",
    "Makes the current line a list element" : "Déanann an líne reatha eilimint liosta",
    "Makes the current line a list element with a number" : "Déanann an líne reatha eilimint liosta le huimhir",
    "Toggle heading for current line" : "Scoránaigh ceannteideal don líne reatha",
    "Set the current line as a big heading" : "Socraigh an líne reatha mar cheannteideal mór",
    "Insert link" : "Ionsáigh nasc",
    "Insert image" : "Ionsáigh íomhá",
    "Switch between editor and viewer" : "Athraigh idir eagarthóir agus breathnóir",
    "Pick a notes folder" : "Roghnaigh fillteán nótaí",
    "Set notes folder" : "Socraigh fillteán nótaí",
    "General" : "Ginearálta",
    "Display" : "Taispeáin",
    "File extension" : "Síneadh comhad",
    "For new notes" : "Le haghaidh nótaí nua",
    "Custom file extension" : "Síneadh comhaid saincheaptha",
    "Files" : "Comhaid",
    "Notes folder" : "Fillteán nótaí",
    "Mobile apps" : "Aipeanna soghluaiste",
    "Shortcuts" : "Aicearraí",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Scrios an chatagóir \"{category}\" agus a nóta {count}?","Scrios an chatagóir \"{category}\" agus a nótaí {count}?","Scrios an chatagóir \"{category}\" agus a nótaí {count}?","Scrios an chatagóir \"{category}\" agus a nótaí {count}?","Scrios an chatagóir \"{category}\" agus a nótaí {count}?"],
    "Delete category" : "Scrios catagóir",
    "Delete" : "Scrios",
    "Cancel" : "Cealaigh",
    "All notes" : "Gach nótaí",
    "Categories" : "Catagóirí",
    "Rename category" : "Athainmnigh an chatagóir",
    "Create a sample note with Markdown" : "Cruthaigh nóta samplach le Markdown",
    "No notes yet" : "Níl aon nótaí fós",
    "Select an image" : "Roghnaigh íomhá",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ní féidir leat íomhánna a roghnú lasmuigh de d'fhillteán nótaí. Is é seo a leanas d'fhillteán nótaí: {folder}",
    "Wrong image" : "Íomhá mícheart",
    "The file was not uploaded. Check your server logs." : "Níor uaslódáladh an comhad. Seiceáil do logaí freastalaí.",
    "Upload image" : "Uaslódáil íomhá",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone agus iPad",
    "Rich text editor" : "Eagarthóir téacs saibhir",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Is féidir leat athrú anois go dtí an t-eagarthóir téacs saibhir saor ó seachrán atá éasca le húsáid. Ligeann sé duit nótaí a chur in eagar gan aon mharcanna Markdown a fheiceáil.",
    "This option can also be changed later on in the Notes app settings." : "Is féidir an rogha seo a athrú níos déanaí freisin i socruithe an aip Nótaí.",
    "Keep plain Markdown editor" : "Coinnigh eagarthóir Markdown simplí",
    "Use rich editor" : "Bain úsáid as eagarthóir saibhir",
    "Remove from favorites" : "Bain ó cheanáin",
    "Add to favorites" : "Cuir le ceanáin",
    "Error while renaming note." : "Earráid agus an nóta á athainmniú.",
    "Error during preparing note for deletion." : "Earráid agus an nóta á ullmhú lena scriosadh.",
    "Share" : "Comhroinn",
    "Change category" : "Athraigh catagóir",
    "Rename" : "Athainmnigh",
    "Rename note" : "Athainmnigh nóta",
    "Delete note" : "Scrios nóta",
    "Error from Nextcloud server: {msg}" : "Earráid ó fhreastalaí Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Athraíodh an nóta i seisiún eile. Roghnaigh cén leagan ba cheart a shábháil le do thoil.",
    "Use version from server" : "Bain úsáid as leagan ón bhfreastalaí",
    "Use current version" : "Úsáid an leagan reatha",
    "Empty note" : "Nóta folamh",
    "Write …" : "Scríobh…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Cuir in eagar",
    "Exit full screen" : "Scoir scáileán iomlán",
    "Full screen" : "Scáileán iomlán",
    "Note is read-only. You cannot change it." : "Nóta inléite amháin. Ní féidir leat é a athrú.",
    "Save failed. Click to retry." : "Theip ar shábháil. Cliceáil chun triail eile a bhaint as.",
    "Update conflict. Click for resolving manually." : "Coimhlint a nuashonrú. Cliceáil le haghaidh réiteach de láimh.",
    "Today" : "Inniu",
    "Yesterday" : "Inné",
    "This week" : "An tseachtain seo",
    "Last week" : "An tseachtain seo caite",
    "This month" : "An mhí seo",
    "Last month" : "An mhí seo caite",
    "Search for notes" : "Cuardaigh nótaí",
    "Loading …" : "Á lódáil…",
    "Find in all categories" : "Faigh i ngach catagóir",
    "Write down your thoughts without any distractions." : "Scríobh síos do chuid smaointe gan aon seachrán.",
    "Use Markdown markups to style your text." : "Bain úsáid as marcálacha Markdown chun do théacs a stíliú.",
    "Organize your notes in categories." : "Eagraigh do nótaí i gcatagóirí.",
    "Start writing a note by clicking on “{newnote}”." : "Tosaigh ag scríobh nóta trí chliceáil ar “{newnote}”.",
    "Note not found." : "Nóta gan aimsiú.",
    "Note is locked." : "Nóta faoi ghlas.",
    "Insufficient storage." : "Stóráil neamhleor.",
    "See JavaScript console and server log for details." : "Féach ar chonsól JavaScript agus logáil freastalaí le haghaidh sonraí.",
    "Updating settings has failed." : "Theip ar nuashonrú na socruithe.",
    "Fetching notes for dashboard has failed." : "Theip ar nótaí a fháil don deais.",
    "Fetching notes has failed." : "Theip ar nótaí a fháil.",
    "Fetching note {id} has failed." : "Theip ar nóta {id} a fháil.",
    "Refreshing note {id} has failed." : "Theip ar nóta {id} a athnuachan.",
    "Renaming note {id} has failed." : "Theip ar athainmniú nóta {id}.",
    "Creating new note has failed." : "Theip ar chruthú nóta nua.",
    "Saving note {id} has failed." : "Theip ar shábháil nóta {id}.",
    "Updating title for note {id} has failed." : "Theip ar nuashonrú an nóta {id}.",
    "Undo delete has failed for note {title}." : "Theip ar chealú scriosadh le haghaidh nóta {title}.",
    "Deleting note {id} has failed." : "Theip ar scriosadh nóta {id}.",
    "Toggling favorite for note {id} has failed." : "Theip ar an gceann is fearr leat don nóta {id} a scor.",
    "Updating the note's category has failed. Is the target directory writable?" : "Theip ar nuashonrú chatagóir an nóta. An bhfuil an sprioc-eolaire inscríofa?",
    "Updating the category for note {id} has failed." : "Theip ar nuashonrú na catagóire don nóta {id}.",
    "Renaming category \"{category}\" has failed." : "Theip ar athainmniú na catagóire \"{category}\".",
    "Deleting category \"{category}\" has failed." : "Theip ar scriosadh na catagóire \"{category}\".",
    "Uncategorized" : "Gan catagóir",
    "Sample note" : "Nóta samplach",
    "15 January 2021, via Nextcloud Notes" : "15 Eanáir 2021, trí Nextcloud Notes",
    "Me, you, and all our friends!" : "Mise, tusa, agus ár gcairde go léir!",
    "Tasks" : "Tascanna",
    "Write nice todo lists" : "Scríobh liostaí le déanamh deas",
    "Buy Fries" : "Ceannaigh Fries",
    "Birthdays" : "Breithlaethanta",
    "Jen, in three days!" : "Jen, i dtrí lá!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Céimeanna Athbhreithnithe",
    "Turn PC off" : "Múch an ríomhaire",
    "Turn PC on" : "Cas ar an ríomhaire",
    "Then call IT" : "Ansin glaoch ar IT",
    "Quotes" : "Sleachta",
    "Nextcloud, a safe home for all your data" : "Nextcloud, baile sábháilte do do shonraí go léir",
    "Development Mode" : "Mód Forbartha",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Dealraíonn sé gur ó fhoinse forbartha a suiteáladh an aip nótaí. Suiteáil é ón<a href=\"%1$s\">Nextcloud Siopa Aip</a> oifigiúil ina ionad sin. Más mian leat an aip Nótaí a thógáil leat féin, lean na treoracha <a href=\"%2$s\">developer instructions</a>le do thoil."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
