OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Create new note" : "Create new note",
    "More notes" : "More notes",
    "Reading notes from filesystem has failed." : "Reading notes from filesystem has failed.",
    "Error" : "Error",
    "New note" : "New note",
    "Distraction-free notes and writing" : "Distraction-free notes and writing",
    "Deleted {title}" : "Deleted {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Deleted {number} note","Deleted {number} notes"],
    "Undo Delete" : "Undo Delete",
    "Note recovered" : "Note recovered",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Recovered {number} note","Recovered {number} notes"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
    "Notes settings" : "Notes settings",
    "Please see Nextcloud server log for details." : "Please see Nextcloud server log for details.",
    "Preview" : "Preview",
    "Make the selection bold" : "Make the selection bold",
    "Make the selection italic" : "Make the selection italic",
    "Wrap the selection in quotes" : "Wrap the selection in quotes",
    "The selection will be turned into monospace" : "The selection will be turned into monospace",
    "Remove any styles from the selected text" : "Remove any styles from the selected text",
    "Makes the current line a list element" : "Makes the current line a list element",
    "Makes the current line a list element with a number" : "Makes the current line a list element with a number",
    "Toggle heading for current line" : "Toggle heading for current line",
    "Set the current line as a big heading" : "Set the current line as a big heading",
    "Insert link" : "Insert link",
    "Insert image" : "Insert image",
    "Switch between editor and viewer" : "Switch between editor and viewer",
    "General" : "General",
    "File extension" : "File extension",
    "Files" : "ფაილები",
    "Mobile apps" : "Mobile apps",
    "Shortcuts" : "Shortcuts",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "All notes" : "All notes",
    "Categories" : "Categories",
    "Create a sample note with Markdown" : "Create a sample note with Markdown",
    "No notes yet" : "No notes yet",
    "Select an image" : "Select an image",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "You cannot select images outside of your notes folder. Your notes folder is: {folder}",
    "Wrong image" : "Wrong image",
    "The file was not uploaded. Check your server logs." : "The file was not uploaded. Check your server logs.",
    "Upload image" : "Upload image",
    "Rich text editor" : "Rich text editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks.",
    "This option can also be changed later on in the Notes app settings." : "This option can also be changed later on in the Notes app settings.",
    "Keep plain Markdown editor" : "Keep plain Markdown editor",
    "Use rich editor" : "Use rich editor",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Error while renaming note." : "Error while renaming note.",
    "Error during preparing note for deletion." : "Error during preparing note for deletion.",
    "Share" : "Share",
    "Change category" : "Change category",
    "Rename" : "Rename",
    "Rename note" : "Rename note",
    "Delete note" : "Delete note",
    "Error from Nextcloud server: {msg}" : "Error from Nextcloud server: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "The note has been changed in another session. Please choose which version should be saved.",
    "Use version from server" : "Use version from server",
    "Use current version" : "Use current version",
    "Empty note" : "Empty note",
    "Write …" : "Write …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Edit",
    "Exit full screen" : "Exit full screen",
    "Full screen" : "Full screen",
    "Note is read-only. You cannot change it." : "Note is read-only. You cannot change it.",
    "Save failed. Click to retry." : "Save failed. Click to retry.",
    "Update conflict. Click for resolving manually." : "Update conflict. Click for resolving manually.",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "This week" : "This week",
    "Last week" : "Last week",
    "This month" : "This month",
    "Last month" : "Last month",
    "Search for notes" : "Search for notes",
    "Loading …" : "Loading …",
    "Find in all categories" : "Find in all categories",
    "Write down your thoughts without any distractions." : "Write down your thoughts without any distractions.",
    "Use Markdown markups to style your text." : "Use Markdown markups to style your text.",
    "Organize your notes in categories." : "Organize your notes in categories.",
    "Note not found." : "Note not found.",
    "Note is locked." : "Note is locked.",
    "Insufficient storage." : "Insufficient storage.",
    "See JavaScript console and server log for details." : "See JavaScript console and server log for details.",
    "Updating settings has failed." : "Updating settings has failed.",
    "Fetching notes for dashboard has failed." : "Fetching notes for dashboard has failed.",
    "Fetching notes has failed." : "Fetching notes has failed.",
    "Fetching note {id} has failed." : "Fetching note {id} has failed.",
    "Refreshing note {id} has failed." : "Refreshing note {id} has failed.",
    "Renaming note {id} has failed." : "Renaming note {id} has failed.",
    "Creating new note has failed." : "Creating new note has failed.",
    "Saving note {id} has failed." : "Saving note {id} has failed.",
    "Updating title for note {id} has failed." : "Updating title for note {id} has failed.",
    "Undo delete has failed for note {title}." : "Undo delete has failed for note {title}.",
    "Deleting note {id} has failed." : "Deleting note {id} has failed.",
    "Toggling favorite for note {id} has failed." : "Toggling favorite for note {id} has failed.",
    "Updating the note's category has failed. Is the target directory writable?" : "Updating the note's category has failed. Is the target directory writable?",
    "Updating the category for note {id} has failed." : "Updating the category for note {id} has failed.",
    "Uncategorized" : "Uncategorized",
    "Sample note" : "Sample note",
    "15 January 2021, via Nextcloud Notes" : "15 January 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Me, you, and all our friends!",
    "Tasks" : "Tasks",
    "Write nice todo lists" : "Write nice todo lists",
    "Buy Fries" : "Buy Fries",
    "Birthdays" : "Birthdays",
    "Jen, in three days!" : "Jen, in three days!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Review Steps",
    "Turn PC off" : "Turn PC off",
    "Turn PC on" : "Turn PC on",
    "Then call IT" : "Then call IT",
    "Quotes" : "Quotes",
    "Nextcloud, a safe home for all your data" : "Nextcloud, a safe home for all your data",
    "Development Mode" : "Development Mode",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>."
},
"nplurals=2; plural=(n!=1);");
