OC.L10N.register(
    "notes",
    {
    "Notes" : "Notizen",
    "Error" : "Fehler",
    "Files" : "Fichieren",
    "Delete" : "Delete",
    "Cancel" : "Ofbriechen",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Share" : "Deelen",
    "Rename" : "Rename",
    "Edit" : "Änneren",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "Loading …" : "Loading …",
    "Tasks" : "Tâchen"
},
"nplurals=2; plural=(n != 1);");
