OC.L10N.register(
    "notes",
    {
    "Notes" : "Notatki",
    "Create new note" : "Utwórz nową notatkę",
    "More notes" : "Więcej notatek",
    "Reading notes from filesystem has failed." : "Odczytanie notatek z systemu plików nie powiodło się.",
    "Error" : "Błąd",
    "New note" : "Nowa notatka",
    "Distraction-free notes and writing" : "Ogólnodostępne notowanie i pisanie ",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikacja Notes to prosta w obsłudze aplikacja do tworzenia notatek dla [Nextcloud](https://www.nextcloud.com/), pozbawiona zbędnych rozpraszaczy. Oferuje kategorie dla lepszej organizacji oraz obsługę formatowania w składni [Markdown] (https://en.wikipedia.org/wiki/Markdown). Notatki zapisywane są jako pliki w Twoim Nextcloud, dzięki czemu możesz je przeglądać i edytować w każdym kliencie Nextcloud. Dodatkowo oddzielne [REST API] (https://github.com/nextcloud/notes/blob/master/docs/api/README.md) umożliwia łatwą integrację z aplikacjami ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) oraz [aplikacjami firm trzecich](https://github.com/nextcloud/notes/wiki#3rd-party-clients), które zapewniają wygodny dostęp do notatek w Nextcloud). Dodatkowe funkcje obejmują możliwość oznaczania notatek jako ulubione.",
    "Deleted {title}" : "Usunięto {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Usunięto {number} notatkę","Usunięto {number} notatki","Usunięto {number} notatek","Usunięto {number} notatek"],
    "Undo Delete" : "Cofnij usunięcie",
    "Note recovered" : "Notatka odzyskana",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Odzyskano {number} notatkę","Odzyskano {number} notatki","Odzyskano {number} notatek","Odzyskano {number} notatek"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Masz niezapisane notatki. Opuszczenie strony spowoduje odrzucenie wszystkich zmian!",
    "New category" : "Nowa kategoria",
    "Notes settings" : "Ustawienia Notatek",
    "Please see Nextcloud server log for details." : "Szczegółowe informacje można znaleźć w dzienniku serwera Nextcloud.",
    "Custom" : "Niestandardowe",
    "Rich text" : "Tekst sformatowany",
    "Plain text" : "Zwykły tekst",
    "Preview" : "Podgląd",
    "Make the selection bold" : "Pogrub zaznaczenie",
    "Make the selection italic" : "Zaznacz kursywą",
    "Wrap the selection in quotes" : "Zawiń zaznaczenie w cudzysłowy",
    "The selection will be turned into monospace" : "Zaznaczenie zostanie zamienione na monospace",
    "Remove any styles from the selected text" : "Usuń wszystkie style z zaznaczonego tekstu",
    "Makes the current line a list element" : "Sprawia, że bieżący wiersz staje się elementem listy",
    "Makes the current line a list element with a number" : "Sprawia, że bieżący wiersz staje się elementem listy z liczbą",
    "Toggle heading for current line" : "Przełącz nagłówek dla bieżącej linii",
    "Set the current line as a big heading" : "Ustaw bieżący wiersz jako duży nagłówek",
    "Insert link" : "Wstaw odnośnik",
    "Insert image" : "Wstaw obraz",
    "Switch between editor and viewer" : "Przełączaj się między edytorem a przeglądarką",
    "Pick a notes folder" : "Wybierz katalog notatek",
    "Set notes folder" : "Ustaw katalog notatek",
    "General" : "Ogólne",
    "Display" : "Wyświetlanie",
    "File extension" : "Rozszerzenie pliku",
    "For new notes" : "Dla nowych notatek",
    "Custom file extension" : "Niestandardowe rozszerzenie pliku",
    "Files" : "Pliki",
    "Notes folder" : "Katalog notatek",
    "Mobile apps" : "Aplikacje mobilne",
    "Shortcuts" : "Skróty",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["Usunąć kategorię \"{category}\" i jej {count} notatkę?","Usunąć kategorię \"{category}\" i jej {count} notatek?","Usunąć kategorię \"{category}\" i jej {count} notatek?","Usunąć kategorię \"{category}\" i jej {count} notatki?"],
    "Delete category" : "Usuń kategorię",
    "Delete" : "Skasuj",
    "Cancel" : "Anuluj",
    "All notes" : "Wszystkie notatki",
    "Categories" : "Kategorie",
    "Rename category" : "Zmień nazwę kategorii",
    "Create a sample note with Markdown" : "Utwórz przykładową notatkę z Markdown",
    "No notes yet" : "Brak notatek",
    "Select an image" : "Wybierz obraz",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nie możesz wybrać obrazów poza katalogiem notatek. Twój katalog notatek to: {folder}",
    "Wrong image" : "Nieprawidłowy obraz",
    "The file was not uploaded. Check your server logs." : "Plik nie został wysłany. Sprawdź logi serwera.",
    "Upload image" : "Wyślij obraz",
    "Android" : "Android",
    "iPhone and iPad" : "iPhone i iPad",
    "Rich text editor" : "Zasobny edytor tekstu",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Możesz teraz przełączyć się na łatwy w obsłudze i wolny od znaczników edytor tekstu sformatowanego. Pozwala edytować notatki bez wyświetlania żadnych znaczników Markdown.",
    "This option can also be changed later on in the Notes app settings." : "Ta opcja może zostać zmieniona później w ustawieniach aplikacji Notatki.",
    "Keep plain Markdown editor" : "Zachowaj zwykły edytor Markdown",
    "Use rich editor" : "Użyj zasobnego edytora",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "Error while renaming note." : "Błąd podczas zmiany nazwy notatki.",
    "Error during preparing note for deletion." : "Błąd podczas przygotowywania notatki do usunięcia.",
    "Share" : "Udostępnij",
    "Change category" : "Zmień kategorię",
    "Rename" : "Zmień nazwę",
    "Rename note" : "Zmień nazwę notatki",
    "Delete note" : "Usuń notatkę",
    "Error from Nextcloud server: {msg}" : "Błąd z serwera Nextcloud: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Notatka została zmieniona w innej sesji. Proszę wybrać, która wersja ma zostać zapisana.",
    "Use version from server" : "Użyj wersji z serwera",
    "Use current version" : "Użyj bieżącej wersji",
    "Empty note" : "Pusta notatka",
    "Write …" : "Zapisywanie…",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Edycja",
    "Exit full screen" : "Wyłącz tryb pełnoekranowy",
    "Full screen" : "Tryb pełnoekranowy",
    "Note is read-only. You cannot change it." : "Notatka jest tylko do odczytu. Nie możesz jej zmienić.",
    "Save failed. Click to retry." : "Zapisywanie nie powiodło się. Kliknij, aby spróbować ponownie.",
    "Update conflict. Click for resolving manually." : "Zaktualizuj konflikt. Kliknij, aby rozwiązać ręcznie.",
    "Today" : "Dzisiaj",
    "Yesterday" : "Wczoraj",
    "This week" : "W tym tygodniu",
    "Last week" : "W zeszłym tygodniu",
    "This month" : "W tym miesiącu",
    "Last month" : "W zeszłym miesiącu",
    "Search for notes" : "Szukaj notatek",
    "Loading …" : "Wczytywanie…",
    "Find in all categories" : "Znajdź we wszystkich kategoriach",
    "Write down your thoughts without any distractions." : "Zapisz swoje myśli, aby nie zapomnieć.",
    "Use Markdown markups to style your text." : "Użyj znaczników Markdown, aby nadać styl tekstowi.",
    "Organize your notes in categories." : "Uporządkuj swoje notatki w kategoriach.",
    "Start writing a note by clicking on “{newnote}”." : "Rozpocznij pisanie notatki, klikając \"{newnote}\".",
    "Note not found." : "Nie znaleziono notatki.",
    "Note is locked." : "Notatka jest zablokowana.",
    "Insufficient storage." : "Niewystarczająca ilość miejsca.",
    "See JavaScript console and server log for details." : "Szczegółowe informacje można znaleźć w konsoli JavaScript i w dzienniku serwera.",
    "Updating settings has failed." : "Aktualizacja ustawień nie powiodła się.",
    "Fetching notes for dashboard has failed." : "Pobieranie notatek na pulpit nie powiodło się.",
    "Fetching notes has failed." : "Pobranie notatek nie powiodło się.",
    "Fetching note {id} has failed." : "Pobranie notatki {id} nie powiodło się.",
    "Refreshing note {id} has failed." : "Odświeżenie notatki {id} nie powiodło się.",
    "Renaming note {id} has failed." : "Zmiana nazwy notatki {id} nie powiodła się.",
    "Creating new note has failed." : "Utworzenie nowej notatki nie powiodło się.",
    "Saving note {id} has failed." : "Zapisanie notatki {id} nie powiodło się.",
    "Updating title for note {id} has failed." : "Aktualizacja tytułu notatki {id} nie powiodła się.",
    "Undo delete has failed for note {title}." : "Cofnięcie usunięcia notatki {title} nie powiodło się.",
    "Deleting note {id} has failed." : "Usunięcie notatki {id} nie powiodło się.",
    "Toggling favorite for note {id} has failed." : "Przełączenie ulubionej notatki {id} nie powiodło się.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualizacja kategorii notatki nie powiodła się. Czy katalog docelowy jest zapisywalny?",
    "Updating the category for note {id} has failed." : "Aktualizacja kategorii dla notatki {id} nie powiodła się.",
    "Renaming category \"{category}\" has failed." : "Zmiana nazwy kategorii \"{category}\" nie powiodła się.",
    "Deleting category \"{category}\" has failed." : "Usuwanie kategorii \"{category}\" nie powiodło się.",
    "Uncategorized" : "Bez kategorii",
    "Sample note" : "Przykładowa notatka",
    "15 January 2021, via Nextcloud Notes" : "15 stycznia 2021, przez Nextcloud Notes",
    "Me, you, and all our friends!" : "Ja, ty i wszyscy nasi przyjaciele!",
    "Tasks" : "Zadania",
    "Write nice todo lists" : "Napisz ładne listy dla rzeczy do zrobienia",
    "Buy Fries" : "Kup frytki",
    "Birthdays" : "Urodziny",
    "Jen, in three days!" : "Kasia, za trzy dni!",
    "Moss, 21.03.1973" : "Marcin, 21.03.1973",
    "Roy, 1979" : "Roman, 1979",
    "Review Steps" : "Przejrzyj kroki",
    "Turn PC off" : "Wyłącz komputer",
    "Turn PC on" : "Włącz komputer",
    "Then call IT" : "Następnie zadzwoń do IT",
    "Quotes" : "Oferty",
    "Nextcloud, a safe home for all your data" : "Nextcloud, bezpieczny dom dla wszystkich Twoich danych",
    "Development Mode" : "Tryb deweloperski",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Wygląda na to, że aplikacja Notes została zainstalowana ze źródła deweloperskiego. Zainstaluj ją z oficjalnego sklepu <a href=\"%1$s\">Nextcloud App Store</a>. Jeśli chcesz samodzielnie zbudować aplikację Notes, postępuj zgodnie z <a href=\"%2$s\">instrukcjami dla programistów</a>."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
